<?php
/**
 * The template for displaying comments.
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @package Validus
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
$post_comments_form_on = validus_get_opt( 'post_comments_form_on', true );

if ( $post_comments_form_on ) : 
	//validus custom
	function validus_move_comment_field_to_bottom( $fields ) {
		$comment_field = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $comment_field;
		return $fields;
	}

	function comment_form_change_cookies_consent( $fields ) {
		if( !is_admin() ) {
			$commenter = wp_get_current_commenter();
			$consent   = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
			$fields['cookies'] = '<input id="wp-comment-cookies-consent" style="display: none;" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />';
		}
		return $fields;
	}
	add_filter( 'comment_form_default_fields', 'comment_form_change_cookies_consent' );
		
	add_filter( 'comment_form_fields', 'validus_move_comment_field_to_bottom' );
?>

    <div id="comments" class="comments-area">

		<?php
		// You can start editing here -- including this comment!
		if ( have_comments() ) : ?>
            <div class="comment-list-wrap">
                <h2 class="comments-title">
					<?php
					$comment_count = get_comments_number();
					if ( 1 === intval( $comment_count ) ) {
						echo esc_html__( '1 Comment', 'validus' );
					} else {
						echo esc_attr( $comment_count ) . ' ' . esc_html__( 'Comments', 'validus' );
					}
					?>
                </h2><!-- .comments-title -->
				<?php the_comments_navigation(); ?>

                <ul class="comment-list">
					<?php
					wp_list_comments( array(
						'style'      => 'ul',
						'short_ping' => true,
						'callback'   => 'validus_comment_list',
						'max_depth'  => 3
					) );
					?>
                </ul><!-- .comment-list -->

				<?php the_comments_navigation(); ?>
            </div>
			<?php if ( ! comments_open() ) : ?>
                <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'validus' ); ?></p>
			<?php
			endif;

		endif; // Check for have_comments().

		$args = array(
			'id_form'              => 'commentform',
			'id_submit'            => 'submit',
			'title_reply'          => esc_attr__( 'Leave A Reply', 'validus' ),
			'title_reply_to'       => esc_attr__( 'Leave A Comment To ', 'validus' ) . '%s',
			'cancel_reply_link'    => esc_attr__( 'Cancel Comment', 'validus' ),
			'label_submit'         => esc_attr__( 'Submit Comment', 'validus' ),
			'comment_notes_before' => '',
			'fields'               => apply_filters( 'comment_form_default_fields', array(

					'author' =>
						'<div class="row"><div class="comment-form-author col-mg40-3 col-smg40-2 col-12">' .
						'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
						'" size="30" placeholder="' . esc_attr__( 'Name', 'validus' ) . '"/></div>',

					'email' =>
						'<div class="comment-form-email col-mg40-3 col-smg40-2 col-12">' .
						'<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) .
						'" size="30" placeholder="' . esc_attr__( 'Email', 'validus' ) . '"/></div>',

					'website' =>
						'<div class="comment-form-website col-mg40-3 col-smg40-2 col-12">' .
						'<input id="website" name="website" type="text" value="" size="30" placeholder="' . esc_attr__( 'Website', 'validus' ) . '"/></div></div>',
				)
			),
			'comment_field'        => '<div class="comment-form-comment"><textarea id="comment" name="comment" cols="45" rows="8" placeholder="' . esc_attr__( 'Comment', 'validus' ) . '" aria-required="true">' .
			                          '</textarea></div>',
			'submit_button' => '<p class="form-submit">
									<button type="submit" name="%1$s" id="%2$s" class="%3$s btn btn-lg radius-2 d-flex justify-content-between">
										<span class="submit-text">Submit Your Request</span>
										<i class="btn-icon cmsi-chevron-circle-right-01"></i>
									</button>
								</p>'
		);
		comment_form( $args );
		?>

    </div><!-- #comments -->

<?php endif; ?>