<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_anchor_register_controls')) {
    add_action('etc_widget_cms_anchor_register_controls', 'validus_widget_cms_anchor_register_controls', 10, 1);
    function validus_widget_cms_anchor_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_anchor/layout-image/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_anchor/layout-image/layout2.jpg'
                    ],
                ],
                'default' => '1',
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-anchor-title' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'title_hover_color',
            [
                'label'   => esc_html__('Title Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-anchor-wrap:hover .cms-anchor-title' => 'color: {{VALUE}};',
                ]
            ]
        );
        $widget->add_control(
            'icon_color',
            [
                'label'   => esc_html__('Icon Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-anchor-wrap i' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'icon_hover_color',
            [
                'label'   => esc_html__('Icon Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-anchor-wrap:hover i' => 'color: {{VALUE}};',
                ]
            ]
        );
        $widget->end_controls_section();
        // Style Section End

        // Content Tab Start

        // anchor Section Start
        $widget->start_controls_section(
            'section_anchor',
            [
                'label' => esc_html__('Single Image', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Back To Top', 'validus'),
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ]
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-anchor-wrap a' => 'justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'anchor_id',
            [
                'label'       => esc_html__( 'ID', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => 'cms-page',
                'description' => __('This ID will be the CSS ID you will have to use in your own page, Without #.', 'validus'),
            ]
        );
        $widget->add_control(
            'anchor_note',
            [
                'type'            => \Elementor\Controls_Manager::RAW_HTML,
                'raw'             => sprintf( __( 'Note: The ID link ONLY accepts these chars: %s', 'validus' ), '`A-Z, a-z, 0-9, _ , -`' ),
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
            ]
        );
        $widget->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Icon', 'validus' ),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'default'          => [
                    'library' => 'cmsi',
                    'value'   => 'cmsi-long-arrow-up'
                ]
            ]
        );
        $widget->end_controls_section(); // anchor Section End

        // Content Tab End

    }
}
