<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

if (!function_exists('validus_widget_cms_basic_gallery_register_controls')) {
    add_action('etc_widget_cms_basic_gallery_register_controls', 'validus_widget_cms_basic_gallery_register_controls', 10, 1);
    function validus_widget_cms_basic_gallery_register_controls($widget)
    {
		$widget->start_controls_section(
			'section_gallery',
			[
				'label' => esc_html__( 'Image Gallery', 'validus' ),
			]
		);

		$widget->add_control(
			'wp_gallery',
			[
				'label' => esc_html__( 'Add Images', 'validus' ),
				'type' => Controls_Manager::GALLERY,
				'show_label' => false,
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'thumbnail', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
				'exclude' => [ 'custom' ],
				'separator' => 'none',
			]
		);

		$gallery_columns = range( 1, 10 );
		$gallery_columns = array_combine( $gallery_columns, $gallery_columns );

		$widget->add_control(
			'gallery_columns',
			[
				'label' => esc_html__( 'Columns', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => 4,
				'options' => $gallery_columns,
			]
		);

		$widget->add_control(
			'gallery_link',
			[
				'label' => esc_html__( 'Link', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'file',
				'options' => [
					'file' => esc_html__( 'Media File', 'validus' ),
					'attachment' => esc_html__( 'Attachment Page', 'validus' ),
					'none' => esc_html__( 'None', 'validus' ),
				],
			]
		);

		$widget->add_control(
			'open_lightbox',
			[
				'label' => esc_html__( 'Lightbox', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default' => esc_html__( 'Default', 'validus' ),
					'yes' => esc_html__( 'Yes', 'validus' ),
					'no' => esc_html__( 'No', 'validus' ),
				],
				'condition' => [
					'gallery_link' => 'file',
				],
			]
		);

		$widget->add_control(
			'gallery_rand',
			[
				'label' => esc_html__( 'Order By', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Default', 'validus' ),
					'rand' => esc_html__( 'Random', 'validus' ),
				],
				'default' => '',
			]
		);

		$widget->add_control(
			'view',
			[
				'label' => esc_html__( 'View', 'validus' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_gallery_images',
			[
				'label' => esc_html__( 'Images', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$widget->add_control(
			'image_spacing',
			[
				'label' => esc_html__( 'Spacing', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Default', 'validus' ),
					'custom' => esc_html__( 'Custom', 'validus' ),
				],
				'prefix_class' => 'gallery-spacing-',
				'default' => '',
			]
		);

		$columns_margin = is_rtl() ? '0 0 -{{SIZE}}{{UNIT}} -{{SIZE}}{{UNIT}};' : '0 -{{SIZE}}{{UNIT}} -{{SIZE}}{{UNIT}} 0;';
		$columns_padding = is_rtl() ? '0 0 {{SIZE}}{{UNIT}} {{SIZE}}{{UNIT}};' : '0 {{SIZE}}{{UNIT}} {{SIZE}}{{UNIT}} 0;';

		$widget->add_control(
			'image_spacing_custom',
			[
				'label' => esc_html__( 'Image Spacing', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'show_label' => false,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'default' => [
					'size' => 15,
				],
				'selectors' => [
					'{{WRAPPER}} .gallery-item' => 'padding:' . $columns_padding,
					'{{WRAPPER}} .gallery' => 'margin: ' . $columns_margin,
				],
				'condition' => [
					'image_spacing' => 'custom',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'image_border',
				'selector' => '{{WRAPPER}} .gallery-item img',
				'separator' => 'before',
			]
		);

		$widget->add_responsive_control(
			'image_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .gallery-item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_caption',
			[
				'label' => esc_html__( 'Caption', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$widget->add_control(
			'gallery_display_caption',
			[
				'label' => esc_html__( 'Display', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'Show', 'validus' ),
					'none' => esc_html__( 'Hide', 'validus' ),
				],
				'selectors' => [
					'{{WRAPPER}} .gallery-item .gallery-caption' => 'display: {{VALUE}};',
				],
			]
		);

		$widget->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'validus' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .gallery-item .gallery-caption' => 'text-align: {{VALUE}};',
				],
				'condition' => [
					'gallery_display_caption' => '',
				],
			]
		);

		$widget->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .gallery-item .gallery-caption' => 'color: {{VALUE}};',
				],
				'condition' => [
					'gallery_display_caption' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'global' => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
				'selector' => '{{WRAPPER}} .gallery-item .gallery-caption',
				'condition' => [
					'gallery_display_caption' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'caption_shadow',
				'selector' => '{{WRAPPER}} .gallery-item .gallery-caption',
			]
		);

		$widget->end_controls_section();
    }
}
