<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_blog_register_controls')) {
    add_action('etc_widget_cms_blog_register_controls', 'validus_widget_cms_blog_register_controls', 10, 1);
    function validus_widget_cms_blog_register_controls($widget)
    {
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_blog/layout-image/layout1.jpg'
                    ],
                ],
                'default' => '1',
            ]
        ); 
        $widget->end_controls_section();


        // Post term options
        if(function_exists('etc_get_grid_term_options')){
            $post_term_options = etc_get_grid_term_options('post',['category']);
        } else {
            $post_term_options = [];
        }

        if(function_exists('validus_get_grid_term_tags')){
            $post_term_tags = validus_get_grid_term_tags('post');
        } else {
            $post_term_tags = [];
        }

        // Content Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'validus'),
                'description' => 'Notice: have to install the Elementor Theme Core plugin and insert categories or tag first!',
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'groupby',
            [
                'label'   => esc_html__('Group By Tag', 'validus'),
                'description' => 'Notice: have to install the Elementor Theme Core plugin and insert tag first!',
                'type'    => Controls_Manager::SELECT,
                'default' => 0,
                'options' => $post_term_tags
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date'   => esc_html__('Date', 'validus'),
                    'ID'     => esc_html__('ID', 'validus'),
                    'author' => esc_html__('Author', 'validus'),
                    'title'  => esc_html__('Title', 'validus'),
                    'rand'   => esc_html__('Random', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label'   => esc_html__('Sort Order', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'validus'),
                    'asc'  => esc_html__('Ascending', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label'   => esc_html__('Total items', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'default' => '5',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'thumbnail',
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'num_words_title',
            [
                'label' => esc_html__('Number Of Words (Title)', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 8,
            ]
        );
        $widget->add_control(
            'num_words',
            [
                'label'     => esc_html__('Excerpt Length', 'validus'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 25,
                'separator' => 'after',
            ]
        );

        $widget->add_control(
            'readmore_text',
            [
                'label'     => esc_html__('Readmore Text', 'validus'),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Read More','validus'),
            ]
        );
        
        $widget->end_controls_section();
        // Display Section End

        // General Section Start
        $widget->start_controls_section(
            'general_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'column_featured',
            [
                'label'        => esc_html__( 'Column Featured', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-featured' => 'flex-basis: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'column_gap',
            [
                'label'        => esc_html__( 'Gap Between 2 Column', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-content' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'column_blog_list',
            [
                'label'        => esc_html__( 'Column Blog List', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => '',//43
                    'unit'     => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-list' => 'flex-basis: {{SIZE}}%;',
                ],
            ]
        );
        $widget->end_controls_section();
        // Featured Section End

        // Featured Section Start
        $widget->start_controls_section(
            'featured_section',
            [
                'label' => esc_html__('Featured Box', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'box_content_max_width',
            [
                'label'        => esc_html__( 'Box Content Max Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-featured .cms-blog-item-inner .cms-blog-item-content' => 'max-width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'box_content_top_space',
            [
                'label'        => esc_html__( 'Box Content Top Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-featured .cms-blog-item-inner' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'box_content_position',
            [
                'label'   => esc_html__('Position', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''   => esc_html__('Default', 'validus'),
                    'absolute'   => esc_html__('Absolute', 'validus'),
                    'relative'   => esc_html__('Relative', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-featured .cms-blog-item-inner' => 'position: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'show_date',
            [
                'label' => esc_html__('Show Date', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'date_color',
            [
                'label' => esc_html__('Date Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-blog-item-date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-blog-item-date .day' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_date' => 'yes',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'featured_heading_typography',
                'label'     => 'Heading Typography',
                'separator' => 'before',
                'selector'  => '{{WRAPPER}} .cms-blog-featured .cms-blog-item-inner .cms-blog-item-content .cms-heading a',
            ]
        );
        $widget->end_controls_section();
        // Featured Section End

        // Style Section Start
        $widget->start_controls_section(
            'blog_list_section',
            [
                'label' => esc_html__('Blog List', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'gap_image_content',
            [
                'label'        => esc_html__( 'Gap Between Image & Content', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 40,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-list .cms-blog-item' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'gap_item',
            [
                'label'        => esc_html__( 'Gap Between Items', 'validus' ),
                'description'  => esc_html__( 'Default: 40px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-list' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'item_top_space',
            [
                'label'        => esc_html__( 'Item Top Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => -20,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-content .cms-blog-list .cms-blog-item .cms-blog-item-content' => 'top: {{SIZE}}{{UNIT}};position: relative;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'meta_bottom_space',
            [
                'label'        => esc_html__( 'Item Meta Bottom Space', 'validus' ),
                'description'  => esc_html__( 'Default: 13px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-blog-content .cms-blog-list .cms-blog-item .cms-blog-item-content .cms-post-meta' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'list_heading_typography',
                'label'     => 'Heading Typography',
                'separator' => 'before',
                'selector'  => '{{WRAPPER}} .cms-blog-list .cms-blog-item .cms-blog-item-content .cms-heading a',
            ]
        );
        $widget->end_controls_section();
        // Style Section Start
        // Content Tab End
    }
}