<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if (!function_exists('validus_widget_cms_blog_carousel_register_controls')) {
    add_action('etc_widget_cms_blog_carousel_register_controls', 'validus_widget_cms_blog_carousel_register_controls', 10, 1);
    function validus_widget_cms_blog_carousel_register_controls($widget)
    {
        // Post term options
        $post_term_options = etc_get_grid_term_options('post',['category']);

        // Content Tab Start
        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'validus'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('Date', 'validus'),
                    'ID' => esc_html__('ID', 'validus'),
                    'author' => esc_html__('Author', 'validus'),
                    'title' => esc_html__('Title', 'validus'),
                    'rand' => esc_html__('Random', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label' => esc_html__('Sort Order', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'validus'),
                    'asc' => esc_html__('Ascending', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label' => esc_html__('Total items', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'show_thumbnail',
            [
                'label' => esc_html__('Show Thumbnail', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'show_title',
            [
                'label' => esc_html__('Show Title', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'title_tag',
            [
                'label' => esc_html__('HTML Tag', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'condition' => [
                    'show_title' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_excerpt',
            [
                'name' => 'show_excerpt',
                'label' => esc_html__('Show Excerpt', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'num_words',
            [
                'name' => 'num_words',
                'label' => esc_html__('Number of Words', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 25,
                'condition' => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_post_date',
            [
                'label' => esc_html__('Show Post Date', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'show_categories',
            [
                'label' => esc_html__('Show Categories', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->end_controls_section();
        // Display Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrow_prev_icon',
            [
                'label' => esc_html__('Previous Arrow Icon', 'validus'),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'skin' => 'inline',
                'label_block' => false,
                'skin_settings' => [
                    'inline' => [
                        'none' => [
                            'label' => 'Default',
                            'icon' => 'eicon-chevron-left',
                        ],
                        'icon' => [
                            'icon' => 'eicon-star',
                        ],
                    ],
                ],
                'recommended' => [
                    'fa-regular' => [
                        'arrow-alt-circle-left',
                        'caret-square-left',
                    ],
                    'fa-solid' => [
                        'angle-double-left',
                        'angle-left',
                        'arrow-alt-circle-left',
                        'arrow-circle-left',
                        'arrow-left',
                        'caret-left',
                        'caret-square-left',
                        'chevron-circle-left',
                        'chevron-left',
                        'long-arrow-alt-left',
                    ],
                ],
                'condition' => [
                    'arrows' => 'yes'
                ],
            ]
        );

        $widget->add_control(
            'arrow_next_icon',
            [
                'label' => esc_html__('Next Arrow Icon', 'validus'),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'skin' => 'inline',
                'label_block' => false,
                'skin_settings' => [
                    'inline' => [
                        'none' => [
                            'label' => 'Default',
                            'icon' => 'eicon-chevron-right',
                        ],
                        'icon' => [
                            'icon' => 'eicon-star',
                        ],
                    ],
                ],
                'recommended' => [
                    'fa-regular' => [
                        'arrow-alt-circle-right',
                        'caret-square-right',
                    ],
                    'fa-solid' => [
                        'angle-double-right',
                        'angle-right',
                        'arrow-alt-circle-right',
                        'arrow-circle-right',
                        'arrow-right',
                        'caret-right',
                        'caret-square-right',
                        'chevron-circle-right',
                        'chevron-right',
                        'long-arrow-alt-right',
                    ],
                ],
                'condition' => [
                    'arrows' => 'yes'
                ],
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Style Tab Start
        // Naivgation Section Start
        $widget->start_controls_section(
            'navigation_section',
            [
                'label' => esc_html__('Navigation', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'arrows',
                            'operator' => '==',
                            'value' => 'yes',
                        ],
                        [
                            'name' => 'dots',
                            'operator' => '==',
                            'value' => 'yes',
                        ],
                    ],
                ],
            ]
        );

        $widget->add_control(
            'heading_style_arrows',
            [
                'label' => esc_html__('Arrows', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'arrows_size',
            [
                'label' => esc_html__('Size', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 60,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'arrows_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'heading_style_dots',
            [
                'label' => esc_html__('Dots', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_size',
            [
                'label' => esc_html__('Size', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 10,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    // The opacity property will override the default inactive dot color which is opacity 0.2.
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_color',
            [
                'label' => esc_html__('Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->end_controls_section();
        // Naivgation Section End
        // Style Tab End
    }
}
