<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if (!function_exists('validus_widget_cms_blog_grid_register_controls')) {
    add_action('etc_widget_cms_blog_grid_register_controls', 'validus_widget_cms_blog_grid_register_controls', 10, 1);
    function validus_widget_cms_blog_grid_register_controls($widget)
    {
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_blog_grid/layout-image/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_blog_grid/layout-image/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_blog_grid/layout-image/layout3.jpg'
                    ],
                ],
                'default' => '1',
            ]
        ); 
        $widget->end_controls_section();

        // Post term options
        $post_term_options = etc_get_grid_term_options('post',['category']);

        // Content Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'validus'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date'   => esc_html__('Date', 'validus'),
                    'ID'     => esc_html__('ID', 'validus'),
                    'author' => esc_html__('Author', 'validus'),
                    'title'  => esc_html__('Title', 'validus'),
                    'rand'   => esc_html__('Random', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label'   => esc_html__('Sort Order', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'validus'),
                    'asc'  => esc_html__('Ascending', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label'   => esc_html__('Total items', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Grid Section Start
        $widget->start_controls_section(
            'grid_section',
            [
                'label' => esc_html__('Grid', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'thumbnail',
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'pagination_type',
            [
                'label'   => esc_html__('Pagination Type', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'pagination' => esc_html__('Pagination', 'validus'),
                    'loadmore'   => esc_html__('Loadmore', 'validus'),
                    'false'      => esc_html__('Disable', 'validus'),
                ],
                'default' => 'false',
            ]
        );
        $widget->add_responsive_control(
            'col',
            [
                'label'        => esc_html__('Columns', 'validus'),
                'type'         => Controls_Manager::SELECT,
                'default'      => '',
                'default_args' => [
                    'tablet' => '',
                    'mobile' => ''
                ],
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '6' => '6',
                ]
            ]
        );
        $widget->end_controls_section();
        // Grid Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'show_animation',
            [
                'label' => esc_html__('Show Animation On Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'layout' => '1',
                ],
            ]
        );

        $widget->add_control(
            'readmore_text',
            [
                'label'     => esc_html__('Readmore Text', 'validus'),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Read More','validus'),
            ]
        );
        $widget->add_responsive_control(
            'title_full',
            [
                'label'    => esc_html__( 'Show Full Title', 'validus' ),
                'type'     => \Elementor\Controls_Manager::SELECT,
                'options'  => [
					'initial' => esc_html__( 'Yes', 'validus' ),
					'1' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
					'{{WRAPPER}} .cms-grid-item .cms-grid-item-inner .cms-content-body .cms-heading' => '-webkit-line-clamp: {{SIZE}}',
				],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'content_bottom',
            [
                'label'        => esc_html__( 'Box Bottom Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => ['px'],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-grid-content' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'content_width',
            [
                'label'        => esc_html__( 'Text Content Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => ['%'],
                'separator'    => 'before',
                'default'      => [
                    'size' => '',
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout' => '3',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-grid-item .cms-grid-item-inner .cms-content-body' => 'max-width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_top_space',
            [
                'label'        => esc_html__( 'Text Content Top Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'layout' => '3',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms--content' => 'margin-top: -{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-grid-item .cms-grid-item-inner .cms--content' => 'margin-top: -{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
			'content_align',
			[
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label' => esc_html__( 'Text Alignment', 'validus' ),
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
                'condition' => ['layout' => '3'],
				'selectors' => [
					'{{WRAPPER}} .cms--content' => 'justify-content: {{VALUE}};',
				],
			]
		);
        $widget->end_controls_section();
        // Display Section End

        // Content Tab End
    }
}