<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_box_carousel_register_controls')) {
    add_action('etc_widget_cms_box_carousel_register_controls', 'validus_widget_cms_box_carousel_register_controls', 10, 1);
    function validus_widget_cms_box_carousel_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_box_carousel/layout-image/layout1.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__( 'Layout 4', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_box_carousel/layout-image/layout4.jpg'
                    ],
                ],
                'default' => '1',
            ]
        ); 
        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Slide Title', 'validus'),
            ]
        );

        $repeater->add_control(
            'heading',
            [
                'label' => esc_html__('Heading', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Slide Heading', 'validus'),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Slide Description', 'validus'),
            ]
        );
        $repeater->add_control(
            'cms_icon',
            [
                'label'            => esc_html__( 'Icon', 'validus' ),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
            ]
        );
        $repeater->add_control(
            'button_primary',
            [
                'label' => esc_html__('Button Primary', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Button Text', 'validus'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'button_primary_link',
            [
                'label'       => esc_html__( 'Button Primary Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $repeater->add_control(
            'button_secondary',
            [
                'label' => esc_html__('Button Secondary', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Button Text', 'validus'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'button_secondary_link',
            [
                'label'       => esc_html__( 'Button Secondary Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );
        $repeater->add_control(
            'button_readmore_link',
            [
                'label'       => esc_html__( 'Readmore Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $widget->add_control(
            'box_carousel',
            [
                'label' => esc_html__('Items', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Slide Title', 'validus'),
                        'heading' => esc_html__('Slide Heading', 'validus'),
                        'description' => esc_html__('Slide Description', 'validus'),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Slide Title', 'validus'),
                        'heading' => esc_html__('Slide Heading', 'validus'),
                        'description' => esc_html__('Slide Description', 'validus'),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Slide Title', 'validus'),
                        'heading' => esc_html__('Slide Heading', 'validus'),
                        'description' => esc_html__('Slide Description', 'validus'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->end_controls_section();
        // List Section End

        // Cta Section Start
        $widget->start_controls_section(
            'cta_section',
            [
                'label' => esc_html__('Call To Anchor', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_control(
            'cta_text',
            [
                'label' => esc_html__('Text', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('We have established a corporate mandate to maintain strong core values that truly reflect the philosophy.', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'cta_name',
            [
                'label' => esc_html__('Anchor Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Schedule A Visit', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'cta_name_link',
            [
                'label'       => esc_html__( 'Anchor Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );
        $widget->end_controls_section();


        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $slides_to_show = range(1,10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '1' => esc_html__('1', 'validus'),
                        '2' => esc_html__('2', 'validus'),
                        '3' => esc_html__('3', 'validus'),
                    ],
                'frontend_available' => true,
                'default' => '1'
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );
        $widget->end_controls_section();
        // Carousel Section End


        $widget->start_controls_section(
            'general_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_responsive_control(
            'content_layout',
            [
                'label' => esc_html__('Content Layout', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'row',
                'options' => [
                    'column' => esc_html__('Column', 'validus'),
                    'row' => esc_html__('Row', 'validus'),
                ],
                'condition' => [
                    'layout' => '1',
                ],
                'frontend_available' => true,
                'selectors' => [
                    '{{WRAPPER}} .cms-box-carousel-info' => 'flex-direction: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_gap',
            [
                'label' => esc_html__('Content Gap', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 400,
                    ],
                ],
                'default' => [
                    'size' => '',
                ],
                'condition' => [
                    'layout' => '1',
                    'content_layout' => 'column',
                ],
                'frontend_available' => true,
                'selectors' => [
                    '{{WRAPPER}} .cms-box-carousel-item-content .cms-box-carousel-info' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
			'left_content_width',
			[
				'label' => esc_html__( 'Left Content Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => '39.375',
                    'unit' => '%'
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'condition' => [
                    'layout' => '4',
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content' => 'width: {{SIZE}}%',
				],
			]
		);
        $widget->add_responsive_control(
			'content_padding',
			[
				'label' => esc_html__( 'Left Content Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'default' => [
                    'top' => 274,
					'right' => 80,
					'bottom' => 80,
					'left' => 80,
                    'unit' => 'px'
                ],
                'condition' => [
                    'layout' => '4',
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-carousel-item .cms-box-carousel-item-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $widget->add_responsive_control(
			'right_content_width',
			[
				'label' => esc_html__( 'Right Content Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => '60.625',
                    'unit' => '%'
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'condition' => [
                    'layout' => '4',
                ],
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-carousel .cms-box-carousel-item-image' => 'width: {{SIZE}}%',
				],
			]
		);
        $widget->add_responsive_control(
			'right_content_width_px',
			[
				'label' => esc_html__( 'Right Content Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
                'description' => 'set width equal px, the default is 580px',
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'condition' => [
                    'layout' => '1',
                ],
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-item-container' => 'width: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->add_responsive_control(
            'image_height',
            [
                'label'        => esc_html__( 'Min Image Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'separator'    => 'before',
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 300,
                        'max' => 1000,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel .cms-box-carousel-item-image' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => 'Title Typography',
                'separator' => 'before',
                'selector'  => '{{WRAPPER}} .cms-carousel-item .cms-box-carousel-item-title',
            ]
        );
        $widget->add_responsive_control(
			'heading_bottom_space',
			[
				'label' => esc_html__( 'Heading Bottom Space', 'validus' ),
				'type' => Controls_Manager::SLIDER,
                'description' => 'Default on layout 1: 137px; layout 4: 24px;',
				'size_units' => [ 'px' ],
                'default' => [
                    'size' => '137'
                ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 250,
					],
				],
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-carousel-item .cms-box-carousel-item-heading' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'heading_typography',
                'label'     => 'Heading Typography',
                'selector'  => '{{WRAPPER}} .cms-carousel-item .cms-box-carousel-item-heading',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'description_typography',
                'label'     => 'Description Typography',
                'selector'  => '{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-desc .cms-box-carousel-item-description',
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
			'description_bottom_space',
			[
				'label' => esc_html__( 'Description Bottom Space', 'validus' ),
				'type' => Controls_Manager::SLIDER,
                'description' => 'Default : 27px',
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150,
					],
				],
                'condition' => [
                    'layout' => '1'
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-desc .cms-box-carousel-item-description p:last-child' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->add_responsive_control(
			'description_bottom_space_layout4',
			[
				'label' => esc_html__( 'Description Bottom Space', 'validus' ),
				'type' => Controls_Manager::SLIDER,
                'description' => 'Default: 31px;',
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150,
					],
				],
                'condition' => [
                    'layout' => '4'
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-item-description' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->end_controls_section();
        // Content Tab End


        $widget->start_controls_section(
            'icon_style_section',
            [
                'label' => esc_html__('Icons', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout' => '1',
                ],
            ]
        );

        $widget->add_responsive_control(
            'icon_pos',
            [
                'label' => esc_html__('Position', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'relative',
                'options' => [
                    'relative' => esc_html__('Relative', 'validus'),
                    'absolute' => esc_html__('Absolute', 'validus'),
                ],
                'condition' => [
                    'layout' => '1',
                ],
                'frontend_available' => true,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo' => 'position: {{VALUE}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'icon_pos_lr',
            [
                'label' => esc_html__('Left Or Right ', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'right',
                'options' => [
                    'left' => esc_html__('Left', 'validus'),
                    'right' => esc_html__('Right', 'validus'),
                ],
                'condition' => [
                    'layout' => '1',
                    'icon_pos' => 'absolute'
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'icon_space_l',
            [
                'label'        => esc_html__( 'Left Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo' => 'left: -{{SIZE}}{{UNIT}};top: auto;bottom: 0;',
					'body.rtl {{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo' => 'right: -{{SIZE}}{{UNIT}};;top: auto;bottom: 0;',
                ],
                'condition' => [
                    'layout' => '1',
                    'icon_pos' => 'absolute',
                    'icon_pos_lr' => 'left',
                ]
            ]
        );

        $widget->add_responsive_control(
            'icon_space_r',
            [
                'label'        => esc_html__( 'Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo' => 'right: -{{SIZE}}{{UNIT}};top: auto;bottom: 0;',
					'body.rtl {{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo' => 'left: -{{SIZE}}{{UNIT}};top: auto;bottom: 0;',
                ],
                'condition' => [
                    'layout' => '1',
                    'icon_pos' => 'absolute',
                    'icon_pos_lr' => 'right',
                ]
            ]
        );

        $widget->add_responsive_control(
            'icon_size',
            [
                'label'        => esc_html__( 'Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '65',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 350,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'icon_opacity',
            [
                'label'        => esc_html__( 'Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => 100,
                    'unit'     => 'px'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel .cms-box-carousel-item-content .cms-box-carousel-info .cms-box-carousel-logo i' => 'opacity: {{SIZE}}%;',
                ],
            ]
        );

        $widget->end_controls_section();

        $widget->start_controls_section(
            'arrow_style_section',
            [
                'label' => esc_html__('Arrows', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'arrows' => 'yes'
            ]
        );
        $widget->add_responsive_control(
            'show_arrows_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'arrow_style',
            [
                'label'        => esc_html__( 'Arrow Style', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => '100%',
                'separator'    => 'before',
                'options'      => [
                    'auto'     => 'Custom',
                    '100%'     => 'Content At Between'
                ],
                'condition' => [
                    'layout'             => '4',
                    'show_arrows_mobile' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position',
            [
                'label'        => esc_html__( 'Arrow Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'left',
                'separator'    => 'before',
                'options'      => [
                    'left'     => 'Left',
                    'right'    => 'Right'
                ],
                'condition' => [
                    'arrow_style'        => 'auto',
                    'layout'             => '4',
                    'show_arrows_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'justify-content: normal;width: auto;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_left',
            [
                'label'        => esc_html__( 'Arrow Left Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px', '%' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 1400,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'margin-inline-start: -{{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrow_position' => 'left',
                    'layout'         => '4',
                    'show_arrows_mobile' => 'flex'
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_right',
            [
                'label'        => esc_html__( 'Arrow Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px', '%' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 1400,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'margin-inline-end: -{{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrow_position' => 'right',
                    'layout'         => '4',
                    'show_arrows_mobile' => 'flex'
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_bottom',
            [
                'label'        => esc_html__( 'Arrow Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 360,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'condition' => [
                    'layout'             => '4',
                    'show_arrows_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_size',
            [
                'label'        => esc_html__( 'Arrow Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 60,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout'             => '4',
                    'show_arrows_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-button' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_radius',
            [
                'label'        => esc_html__( 'Arrow Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout'             => '4',
                    'show_arrows_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button-prev' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                    '{{WRAPPER}} .cms-carousel-button-next' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->end_controls_section();

        // Anchor Style Section Start
        $widget->start_controls_section(
            'cta_style_section',
            [
                'label' => esc_html__('Call To Anchor', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout' => '2'
                ],
            ]
        );
        $widget->add_responsive_control(
			'cta_top_space',
			[
				'label' => esc_html__( 'Top Space', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'default' => [
                    'size' => '20',
                    'unit' => 'px'
                ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
					'em' => [
						'max' => 2,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $widget->add_responsive_control(
			'cta_max_width',
			[
				'label' => esc_html__( 'Max Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => '50',
                    'unit' => '%'
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-container' => 'max-width: {{SIZE}}%;',
				],
			]
		);
        $widget->add_responsive_control(
            'align_cta',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default' => 'center',
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-carousel-cta' => 'justify-content: {{VALUE}}; text-align: {{VALUE}};',
                ],
            ]
        );
		$widget->add_control(
			'cta_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_text!' => '',
				],
                'separator' => 'before',
			]
		);
		$widget->add_control(
			'cta_name_color',
			[
				'label' => esc_html__( 'Anchor Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-name' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_name!' => '',
				],
			]
		);
		$widget->add_control(
			'cta_name_color_hover',
			[
				'label' => esc_html__( 'Anchor Color Hover', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-name:hover' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_name!' => '',
				],
			]
		);
        $widget->add_control(
            'show_underline',
            [
                'label' => esc_html__('Show Underline', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
			'cta_border_color',
			[
				'label' => esc_html__( 'Underline Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-name' => 'border-color: {{VALUE}};',
				],
			]
		);
        $widget->add_control(
			'cta_border_color_hover',
			[
				'label' => esc_html__( 'Underline Color Hover', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-name:hover' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					'show_underline' => 'yes'
				],
			]
		);
        $widget->add_responsive_control(
			'cta_border_width',
			[
				'label' => esc_html__( 'Underline Height', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
					],
					'em' => [
						'max' => 2,
					],
				],
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-box-carousel-cta-name' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
        $widget->end_controls_section();
        // Anchor Style Section End
    }
}
