<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if (!function_exists('validus_widget_cms_box_content_register_controls')) {
    add_action('etc_widget_cms_box_content_register_controls', 'validus_widget_cms_box_content_register_controls', 10, 1);
    function validus_widget_cms_box_content_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_box_content/layout/layout1.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Content Tab Start

        // Left Section Start
        $widget->start_controls_section(
            'section_left',
            [
                'label' => esc_html__('Heading Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'left_heading',
            [
                'label'       => esc_html__( 'Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'Title', 'validus' ),
                'placeholder' => esc_html__( 'Enter your title', 'validus' ),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'left_heading_size',
            [
                'label'   => esc_html__( 'Heading HTML Tag', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p',
                ],
                'default' => 'h3',
            ]
        );
        $widget->end_controls_section(); // Left Section End

        // Right Section Start
        $widget->start_controls_section(
            'section_right',
            [
                'label' => esc_html__('Right Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'right_text',
            [
                'label'       => esc_html__( 'Text', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter your text', 'validus' ),
                'default'     => esc_html__( 'We are happy to take the time and attention to conduct an initial analysis of your project. Thanks to this, we will be able to advise you accordingly.', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'right_image',
            [
                'label' => esc_html__( 'Image', 'validus' ),
                'type'  => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => get_template_directory_uri() . '/assets/images/elementor/jasper-garratt-hori.jpg'
                ],
                'separator' => 'before'
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'full',
            ]
        );
        $widget->add_responsive_control(
            'right_img_min_height',
            [
                'label'        => esc_html__( 'Min Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 100,
                        'max' => 800,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-image > img' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'right_img_max_height',
            [
                'label'        => esc_html__( 'Max Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px', '%' ],
                'range'        => [
                    'px' => [
                        'min' => 50,
                        'max' => 2000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-image > img' => 'max-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section(); // Right Section End

        // Style Column Start
        $widget->start_controls_section(
            'section_style_column',
            [
                'label' => esc_html__('Column Width', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
			'column_left',
			[
				'label' => esc_html__( 'Column Left', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'devices' => [ 'desktop', 'laptop', 'tablet_extra', 'tablet', 'mobile_extra', 'mobile' ],
				'default' => [
					'size' => '21.5686',//21.5686
					'unit' => '%',
				],
                'mobile_default' => [
					'size' => '100',
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-box-left' => 'width: {{SIZE}}%',
				],
			]
		);
        $widget->add_responsive_control(
            'gap_column',
            [
                'label'        => esc_html__( 'Gap Between 2 Column', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-content-wrap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'column_right',
            [
                'label'        => esc_html__( 'Column Right', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '78.429',//78.429
                ],
                'mobile_default' => [
					'size' => '100',
					'unit' => '%',
				],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-right' => 'width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Column End

        // Style Heading Start
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Left Column Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'heading_top_space',
            [
                'label'        => esc_html__( 'Heading Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -30,
                        'max' => 130,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-left .cms-text' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'heading_bottom_space',
            [
                'label'        => esc_html__( 'Heading Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-left .cms-text' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-box-left .cms-text' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_font',
            [
                'label' => esc_html__('Heading Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-left .cms-text' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'label' => 'Heading Typography',
                'selector'     => '{{WRAPPER}} .cms-box-left .cms-text',
            ]
        );
        $widget->end_controls_section(); // Style Heading End

        // Style Right Start
        $widget->start_controls_section(
            'section_style_subheading',
            [
                'label' => esc_html__('Right Heading Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'text_top_space',
            [
                'label'        => esc_html__( 'Text Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -30,
                        'max' => 130,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-right .cms-text' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'text_bottom_space',
            [
                'label'        => esc_html__( 'Text Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 130,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-right .cms-text' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'text_color',
            [
                'label'     => esc_html__( 'Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-box-right .cms-text' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'text_font',
            [
                'label' => esc_html__('Text Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-box-right .cms-text' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'label' => 'Text Typography',
                'selector'     => '{{WRAPPER}} .cms-box-right .cms-text',
            ]
        );
        $widget->end_controls_section(); // Style Text End
        
        // Content Tab End

    }
}
