<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_button_register_controls')) {
    add_action('etc_widget_cms_button_register_controls', 'validus_widget_cms_button_register_controls', 10, 1);
    function validus_widget_cms_button_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout-images/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout-images/layout3.jpg'
                    ]
                ],
                'default' => '1',
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Icon Section Start
        $widget->start_controls_section(
            'icon_section',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'style',
            [
                'label'   => esc_html__( 'Style', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn-primary',
                'options' => [
                    'btn-primary'       => esc_html__( 'Primary', 'validus' ),
                    'btn-secondary'     => esc_html__( 'Secondary', 'validus' ),
                    'btn-white'         => esc_html__( 'White', 'validus' ),
                ],
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
        $widget->add_control(
            'style1',
            [
                'label'   => esc_html__( 'Style', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn-outline',
                'options' => [
                    'btn-outline'           => esc_html__( 'Primary', 'validus' ),
                    'btn-outline-white'     => esc_html__( 'White', 'validus' ),
                    'btn-outline-secondary' => esc_html__( 'Secondary', 'validus' ),
                ],
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
        $widget->add_control(
            'size',
            [
                'label'   => esc_html__( 'Size', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''          => esc_html__( 'Defaut', 'validus' ),
                    'btn-sm'    => esc_html__( 'Small', 'validus' ),
                    'btn-xsm'   => esc_html__( 'X-Small', 'validus' ),
                    'btn-xxm'   => esc_html__( 'XX-Medium', 'validus' ),
                    'btn-xm'    => esc_html__( 'X-Medium', 'validus' ),
                    'btn-lg'    => esc_html__( 'Large', 'validus' ),
                ],
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
        $widget->add_control(
            'text',
            [
                'label'       => esc_html__( 'Text', 'validus' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Awards And Milestones', 'validus' ),
                'placeholder' => esc_html__( 'Click here', 'validus' ),
            ]
        );
        $widget->add_control(
            'link',
            [
                'label'       => esc_html__( 'Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );
        $widget->add_control(
            'btn_icon',
            [
                'label'            => esc_html__( 'Icon', 'validus' ),
                'type'             => Controls_Manager::ICONS,
                'label_block'      => true,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'library' => 'cmsi',
                    'value'   => 'cmsi-chevron-circle-right-01'
                ],
                'condition' => [
                    'layout' => ['1','2']
                ]
            ]
        );
        $widget->add_control(
            'icon_align',
            [
                'label'     => esc_html__( 'Icon Position', 'validus' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'left',
                'options'   => [
                    'left'  => esc_html__( 'Before Text', 'validus' ),
                    'right' => esc_html__( 'After Text', 'validus' ),
                ],
                'condition' => [
                    'layout' => ['1','2']
                ]
            ]
        );
        $widget->add_control(
            'icon_font_size',
            [
                'label'        => esc_html__( 'Icon Font Size', 'validus' ),
                'type'         => Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 15,
                        'max' => 35,
                    ],
                ],
                'default' => [
                    'size' => '23'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .btn-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => ['1','2']
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'btn_padding',
            [
                'label'        => esc_html__( 'Padding', 'validus' ),
                'description'  => esc_html__( 'Default on layout 1: 0px 30px 0px 30px;', 'validus' ),
                'type'         => Controls_Manager::DIMENSIONS,
                'size_units'   => [ 'px' ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-button-wrap .btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'btn_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'validus' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors'  => [
                    '{{WRAPPER}} .cms-button-wrap .btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End

        //Color Style
        $widget->start_controls_section(
            'color_style',
            [
                'label' => esc_html__('Button Color Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'flex' => [
                        'title' => esc_html__( 'Full Width', 'validus' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-button-wrap' => 'text-align: {{VALUE}};justify-content: {{VALUE}};',
                    '{{WRAPPER}} .cms-button-wrap a' => 'display: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography',
                'selector'     => '{{WRAPPER}} .cms-button-wrap .btn',
            ]
        );
        
        $input_selectors = [
			'{{WRAPPER}} .cms-button-wrap a',
			'{{WRAPPER}} .cms-button-wrap a .btn-text',
			'{{WRAPPER}} .cms-button-wrap a .btn-icon',
		];
        $input_selector = implode( ',', $input_selectors );

        $widget->add_control(
            'color',
            [
                'label'     => esc_html__( 'Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    $input_selector => 'color: {{VALUE}};',
                ],
            ]
        );

        $input_selectors = [
			'{{WRAPPER}} .cms-button-wrap a:hover',
			'{{WRAPPER}} .cms-button-wrap a:hover .btn-text',
            '{{WRAPPER}} .cms-button-wrap a:hover .btn-icon',
		];
        $input_selector = implode( ',', $input_selectors );

        $widget->add_control(
            'color_hover',
            [
                'label'     => esc_html__( 'Text Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    $input_selector => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $input_selectors = [
			'{{WRAPPER}} .cms-button-wrap a:hover',
		];
        $input_selector = implode( ',', $input_selectors );
        $widget->add_control(
            'button_hover',
            [
                'label'     => esc_html__( 'Background Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    'layout' => '1'
                ],
                'selectors' => [
                    $input_selector => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        //layout 2
        $widget->add_control(
            'button_hover_outline_style',
            [
                'label'   => esc_html__( 'Outline Hover Style', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'border',
                'options' => [
                    'border'    => esc_html__( 'Border', 'validus' ),
                    'full'      => esc_html__( 'Full Background', 'validus' ),
                ],
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
        $widget->add_control(
            'button_hover_outline_border',
            [
                'label'   => esc_html__( 'Outline Hover Border Color', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn-hover-outline-black',
                'options' => [
                    'btn-hover-outline-black'   => esc_html__( 'Black', 'validus' ),
                    'btn-hover-outline-white'   => esc_html__( 'White', 'validus' ),
                    'btn-hover-outline-primary' => esc_html__( 'Primary', 'validus' ),
                    'custom'                    => esc_html__( 'Custom', 'validus' ),
                ],
                'condition' => [
                    'button_hover_outline_style' => 'border',
                    'layout' => ['2']
                ]
            ]
        );

        $input_selectors = [
			'{{WRAPPER}} .cms-button-wrap a:hover',
		];
        $input_selector = implode( ',', $input_selectors );
        $widget->add_control(
            'button_hover_outline',
            [
                'label'     => esc_html__( 'Outline Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    'button_hover_outline_style'  => 'border',
                    'button_hover_outline_border' => 'custom',
                    'layout' => ['2']
                ],
                'selectors' => [
                    $input_selector => 'color: {{VALUE}} !important;border-color: {{VALUE}} !important;',
                ],
            ]
        );
        $widget->add_control(
            'button_hover_outline_full',
            [
                'label'   => esc_html__( 'Outline Hover Full', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn-hover-black',
                'options' => [
                    'btn-hover-black'       => esc_html__( 'Black', 'validus' ),
                    'btn-hover-white'       => esc_html__( 'White', 'validus' ),
                    'btn-hover-primary'     => esc_html__( 'Primary', 'validus' ),
                ],
                'condition' => [
                    'button_hover_outline_style' => 'full',
                    'layout' => ['2']
                ]
            ]
        );
        $widget->end_controls_section(); // Style Section End
    }
}
