<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Repeater;
use Elementor\Core\Schemes\Color as Scheme_Color;
use Elementor\Core\Schemes\Typography as Scheme_Typography;
use Elementor\Widget_Base;
use Elementor\Modules\DynamicTags\Module as TagsModule;

if (!function_exists('validus_widget_cms_chart_register_controls')) {
    add_action('etc_widget_cms_chart_register_controls', 'validus_widget_cms_chart_register_controls', 10, 1);
    function validus_widget_cms_chart_register_controls($widget)
    {
		/**
		 * `Chart Data` Section
		 */
		$widget->start_controls_section(
			'section_chart_data',
			array(
				'label' => esc_html__( 'Chart Data', 'validus' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'label',
			array(
				'label'   => esc_html__( 'Label', 'validus' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array( 'active' => true ),
			)
		);

		$repeater->add_control(
			'value',
			array(
				'label'   => esc_html__( 'Value', 'validus' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'dynamic' => version_compare( ELEMENTOR_VERSION, '2.7.0', '>=' ) ?
					array(
						'active'     => true,
						'categories' => array(
							TagsModule::POST_META_CATEGORY,
							TagsModule::NUMBER_CATEGORY,
						),
					) : array(),
			)
		);

		$repeater->add_control(
			'color',
			array(
				'label'   => esc_html__( 'Color', 'validus' ),
				'type'	  => Controls_Manager::COLOR,
				'default' => 'red'
			)
		);

		$widget->add_control(
			'chart_data',
			array(
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'label' => esc_html__( 'Google', 'validus' ),
						'value' => 50,
						'color' => '#dd4b39',
					),
					array(
						'label' => esc_html__( 'Facebook', 'validus' ),
						'value' => 50,
						'color' => '#3b5998',
					),
					array(
						'label' => esc_html__( 'Twitter', 'validus' ),
						'value' => 50,
						'color' => '#55acee',
					),
				),
				'title_field' => '{{{ label }}}',
			)
		);

		$widget->add_control(
			'chart_title',
			array(
				'label'     => esc_html__( 'Chart Title', 'validus' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => esc_html__( 'Pie Chart', 'validus' ),
				'dynamic'   => array( 'active' => true ),
				'separator' => 'before',
			)
		);

		$widget->add_control(
			'chart_title_size',
			array(
				'label'   => esc_html__( 'Title HTML Tag', 'validus' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'DIV',
					'span' => 'SPAN',
					'p' => 'P',
				],
				'default' => 'h5',
				'condition' => [
					'chart_title!' => ''
				]
			)
		);

		$widget->add_control(
			'chart_title_position',
			array(
				'label'   => esc_html__( 'Title Position', 'validus' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'before' => esc_html__( 'Before Chart', 'validus' ),
					'after'  => esc_html__( 'After Chart', 'validus' ),
				),
				'default' => 'after',
				'condition' => [
					'chart_title!' => ''
				]
			)
		);

		$widget->end_controls_section();

		/**
		 * `Settings` Section
		 */
		$widget->start_controls_section(
			'section_settings',
			array(
				'label' => esc_html__( 'Settings', 'validus' ),
			)
		);

		$css_scheme = array(
			'container' => '.cms-pie-chart-container',
			'title'     => '.cms-pie-chart-title',
		);

		$widget->add_responsive_control(
			'chart_height',
			array(
				'label' => esc_html__( 'Chart Height', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 100,
						'max' => 1200,
					),
				),
				'selectors' => array(
					'{{WRAPPER}} ' . $css_scheme['container'] => 'height: {{SIZE}}{{UNIT}};',
				),
				'render_type' => 'template',
			)
		);

		$widget->add_control(
			'chart_cutout_percentage',
			array(
				'label'       => esc_html__( 'Cutout Percentage', 'validus' ),
				'description' => esc_html__( 'The percentage of the chart that is cut out of the middle.', 'validus' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( '%' ),
				'range' => array(
					'%' => array(
						'min' => 0,
						'max' => 99,
					),
				),
				'default' => array(
					'unit' => '%',
				),
			)
		);

		$widget->add_control(
			'chart_animation_heading',
			array(
				'label'     => esc_html__( 'Animations', 'validus' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$widget->add_control(
			'chart_animation_duration',
			array(
				'label'       => esc_html__( 'Duration', 'validus' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'ms' ),
				'range' => array(
					'ms' => array(
						'min' => 100,
						'max' => 3000,
					),
				),
				'default' => array(
					'unit' => 'ms',
				),
			)
		);

		$animation_easing = array(
			'linear',
			'easeInQuad',
			'easeOutQuad',
			'easeInOutQuad',
			'easeInCubic',
			'easeOutCubic',
			'easeInOutCubic',
			'easeInQuart',
			'easeOutQuart',
			'easeInOutQuart',
			'easeInQuint',
			'easeOutQuint',
			'easeInOutQuint',
			'easeInSine',
			'easeOutSine',
			'easeInOutSine',
			'easeInExpo',
			'easeOutExpo',
			'easeInOutExpo',
			'easeInCirc',
			'easeOutCirc',
			'easeInOutCirc',
			'easeInElastic',
			'easeOutElastic',
			'easeInOutElastic',
			'easeInBack',
			'easeOutBack',
			'easeInOutBack',
			'easeInBounce',
			'easeOutBounce',
			'easeInOutBounce',
		);

		$widget->add_control(
			'chart_animation_easing',
			array(
				'label'   => esc_html__( 'Easing', 'validus' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'easeOutQuart',
				'options' => array_combine( $animation_easing, $animation_easing )
			)
		);

		$widget->add_control(
			'chart_animate_scale',
			array(
				'label'        => esc_html__( 'Animate Scale', 'validus' ),
				'description'  => esc_html__( 'If yes, will animate scaling the chart from the center outwards.', 'validus' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'return_value' => 'true',
			)
		);

		$widget->add_control(
			'chart_tooltips_heading',
			array(
				'label'     => esc_html__( 'Tooltips', 'validus' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$widget->add_control(
			'chart_tooltip_enabled',
			array(
				'label'        => esc_html__( 'Enabled', 'validus' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'true',
				'return_value' => 'true',
			)
		);

		$widget->add_control(
			'chart_tooltip_suffix',
			array(
				'label'     => esc_html__( 'Suffix', 'validus' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array( 'active' => true ),
				'condition' => array(
					'chart_tooltip_enabled' => 'true',
				),
			)
		);

		$widget->end_controls_section();

		/**
		 * `Chart` Style Section
		 */
		$widget->start_controls_section(
			'section_chart_style',
			[
				'label' => esc_html__( 'Chart', 'validus' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$widget->add_control(
			'chart_border_width',
			[
				'label' => esc_html__( 'Border Width', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 10,
					],
				],
				'default'      => [
					'size' => 1,
				],
			]
		);

		$widget->add_control(
			'chart_border_color',
			[
				'label' => esc_html__( 'Border Color', 'validus' ),
				'type'  => Controls_Manager::COLOR,
			]
		);

		$widget->end_controls_section();

		/**
		 * `Title` Style Section
		 */
		$widget->start_controls_section(
			'section_chart_title_style',
			array(
				'label' => esc_html__( 'Title', 'validus' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'chart_title!' => ''
				]
			)
		);
		
		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'chart_title_typography',
				'selector' => '{{WRAPPER}} ' . $css_scheme['title'],
				'default'  => '50'
			]
		);
		
		$widget->add_control(
			'chart_title_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type'  => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} ' . $css_scheme['title'] => 'color: {{VALUE}};',
				),
				'default'  => ''
			]
		);
		
		$widget->add_control(
			'chart_title_margin',
			[
				'label'      => esc_html__( 'Margin', 'validus' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} ' . $css_scheme['title'] => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'default'      => [
					'size' => 25,
				],
			]
		);
		
		$widget->add_control(
			'chart_title_padding',
			[
				'label'      => esc_html__( 'Padding', 'validus' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} ' . $css_scheme['title'] => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'default'      => [
					'size' => 75,
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			array(
				'name'     => 'chart_title_text_shadow',
				'selector' => '{{WRAPPER}} ' . $css_scheme['title'],
			)
		);

		$widget->end_controls_section();

		/**
		 * `Legend` Style Section
		 */
		$widget->start_controls_section(
			'section_chart_legend_style',
			array(
				'label' => esc_html__( 'Legend', 'validus' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$widget->add_control(
			'chart_legend_font_family',
			array(
				'label'   => esc_html__( 'Font Family', 'validus' ),
				'type'    => Controls_Manager::FONT,
				'default' => '',
				'selectors' => [
                    '{{WRAPPER}} .cms-chart-item-title' => 'font-size: {{VALUE}};',
                ],
			)
		);

		$widget->add_responsive_control(
			'chart_legend_top_space',
			array(
				'label' => esc_html__( 'Top Space', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 1,
						'max' => 50,
					),
				),
				'selectors' => [
                    '{{WRAPPER}} .cms-chart-items' => 'padding-top: {{SIZE}}{{UNIT}};',
                ],
			)
		);

		$widget->add_responsive_control(
			'chart_legend_circle',
			array(
				'label' => esc_html__( 'Icon Size', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 1,
						'max' => 50,
					),
				),
				'default'      => [
					'size' => '8',
				],
				'selectors' => [
                    '{{WRAPPER}} .cms-chart-item-circle' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
			)
		);

		$widget->add_responsive_control(
			'chart_legend_font_size',
			array(
				'label' => esc_html__( 'Font Size', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 1,
						'max' => 50,
					),
				),
				'default'      => [
					'size' => '14',
				],
				'selectors' => [
                    '{{WRAPPER}} .cms-chart-item-title' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
			)
		);

		$typo_weight_options = array(
			'' => esc_html__( 'Default', 'validus' ),
		);

		foreach ( array_merge( [ 'normal', 'bold' ], range( 100, 900, 100 ) ) as $weight ) {
			$typo_weight_options[ $weight ] = ucfirst( $weight );
		}

		$widget->add_control(
			'chart_legend_font_weight',
			[
				'label'   => esc_html__( 'Font Weight', 'validus' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '700',
				'options' => $typo_weight_options,
			]
		);

		$widget->add_control(
			'chart_legend_font_style',
			[
				'label' => esc_html__( 'Font Style', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''        => esc_html__( 'Default', 'validus' ),
					'normal'  => esc_attr_x( 'Normal', 'Typography Control', 'validus' ),
					'italic'  => esc_attr_x( 'Italic', 'Typography Control', 'validus' ),
					'oblique' => esc_attr_x( 'Oblique', 'Typography Control', 'validus' ),
				],
			]
		);

		$widget->add_control(
			'chart_legend_font_color',
			[
				'label' => esc_html__( 'Font Color', 'validus' ),
				'type'  => Controls_Manager::COLOR,
				'default'  => ''
			]
		);

		$widget->end_controls_section();

		/**
		 * `Tooltips` Style Section
		 */
		$widget->start_controls_section(
			'section_chart_tooltips_style',
			array(
				'label' => esc_html__( 'Tooltips', 'validus' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => array(
					'chart_tooltip_enabled' => 'true',
				),
			)
		);

		$widget->add_control(
			'chart_tooltip_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type'  => Controls_Manager::COLOR,
				'default'  => ''
			)
		);

		$widget->add_control(
			'chart_tooltip_font_family',
			array(
				'label'   => esc_html__( 'Font Family', 'validus' ),
				'type'    => Controls_Manager::FONT,
				'default' => '',
			)
		);

		$widget->add_control(
			'chart_tooltip_font_size',
			[
				'label' => esc_html__( 'Font Size', 'validus' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 50,
					],
				],
				'default'      => [
					'size' => 12,
				],
			]
		);

		$widget->add_control(
			'chart_tooltip_font_weight',
			[
				'label'   => esc_html__( 'Font Weight', 'validus' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '',
				'options' => $typo_weight_options,
			]
		);

		$widget->add_control(
			'chart_tooltip_font_style',
			array(
				'label' => esc_html__( 'Font Style', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => array(
					''        => esc_html__( 'Default', 'validus' ),
					'normal'  => esc_attr_x( 'Normal', 'Typography Control', 'validus' ),
					'italic'  => esc_attr_x( 'Italic', 'Typography Control', 'validus' ),
					'oblique' => esc_attr_x( 'Oblique', 'Typography Control', 'validus' ),
				),
				'default'  => ''
			)
		);

		$widget->add_control(
			'chart_tooltip_font_color',
			array(
				'label' => esc_html__( 'Font Color', 'validus' ),
				'type'  => Controls_Manager::COLOR,
				'default'  => ''
			)
		);

		$widget->end_controls_section();
    }
}
