<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_contact_form_register_controls')) {
    add_action('etc_widget_cms_contact_form_register_controls', 'validus_widget_cms_contact_form_register_controls', 10, 1);
    function validus_widget_cms_contact_form_register_controls($widget)
    {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

        $contact_forms = array();
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->post_name] = $cform->post_title;
            }
        } else {
            $contact_forms[esc_html__('No contact forms found', 'validus')] = 0;
        }

        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout-images/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout-images/layout3.jpg'
                    ],
                ],
                'default' => '1',
            ]
        );

        add_filter('wpcf7_autop_or_not', '__return_false');

        $widget->end_controls_section();
        // Layout Tab End


        // Settings Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'general_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_control(
            'background',
            [
                'label' => esc_html__('Background', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'white',
                'options' => [
                    'white' => esc_html__('White', 'validus'),
                    'primary' => esc_html__('Primary', 'validus'),
                ],
            ]
        );
        $widget->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__('Box Shadow', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'separator' => 'before',
                'selector' => '{{WRAPPER}} .cms-contact-form-wrap'
            ]
        );
        $widget->add_responsive_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-contact-form-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);
        $widget->add_responsive_control(
			'padding',
			[
				'label' => esc_html__( 'Padding Form', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-contact-form-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $widget->add_responsive_control(
            'padding_description',
            [
                'label' => esc_html__('Padding Description Bottom', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'description' => 'Just work if the widget has description',
                'default' => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .description' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'heading_bottom_space',
            [
                'label' => esc_html__('Heading Bottom Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        ); 
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'heading_typography',
                'label'     => 'Heading Typography',
                'selector'  => '{{WRAPPER}} .heading',
            ]
        );
        $widget->add_responsive_control(
            'control_border_radius',
            [
                'label' => esc_html__('Text Input Border Radius', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-form-control' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        //0px -20px 0px 0px #000
        $widget->end_controls_section();
        // General Section End

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_control(
            'ctf7_slug',
            [
                'label'   => esc_html__('Select Form', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options'   => $contact_forms,
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Dropdown Section Start
        $widget->start_controls_section(
            'dropdown_section',
            [
                'label' => esc_html__('Dropdown', 'validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_control(
            'font',
            [
                'label' => esc_html__('Select Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'var(--heading-font-family)',
                'options' => [
                    'var(--heading-font-family)' => esc_html__('Heading', 'validus'),
                    'var(--body-font-family)' => esc_html__('Body', 'validus'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .wpcf7-select' => 'font-family: {{VALUE}}',
                ]
            ]
        );
        $widget->add_control(
            'color',
            [
                'label'   => esc_html__('Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-select' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'text_typography',
                'label'     => 'Dropdown Typography',
                'selector'  => '{{WRAPPER}} .wpcf7-select',
            ]
        );
        $widget->end_controls_section();
        // Dropdown Section End

        // Text Area Section Start
        $widget->start_controls_section(
            'textarea_section',
            [
                'label' => esc_html__('Text Area', 'validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_responsive_control(
            'text_area_height',
            [
                'label' => esc_html__('Height', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-textarea' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Text Area Section End

        // Button Section Start
        $widget->start_controls_section(
            'button_section',
            [
                'label' => esc_html__('Button', 'validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_responsive_control(
            'width',
            [
                'label' => esc_html__('Width', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'auto',
                'options' => [
                    'auto' => esc_html__('Auto', 'validus'),
                    '100%' => esc_html__('100%', 'validus'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .submit' => 'width: {{VALUE}}',
                ]
            ]
        );
        $widget->add_responsive_control(
            'button_top_space',
            [
                'label' => esc_html__('Button Top Space', 'validus'),
                'description' => 'Default on layout 2: 32px; layout 3: 29px;',
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .submit' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        ); 
        $widget->add_responsive_control(
            'button_border_radius',
            [
                'label' => esc_html__('Border Radius', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .submit' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->end_controls_section();
        // Button Section End
    }
}
