<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_counter_register_controls')) {
    add_action('etc_widget_cms_counter_register_controls', 'validus_widget_cms_counter_register_controls', 10, 1);
    function validus_widget_cms_counter_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'section_layout',
            [
                'label' => esc_html__('Layout Settings', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT
            ]
        );
            $widget->add_control(
                'layout_mode',
                [
                    'label'   => esc_html__('Layout Mode', 'validus'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'grid'     => esc_html__('Grid', 'validus'),
                        'carousel' => esc_html__('Carousel', 'validus')
                    ],
                    'default'      => 'carousel',
                    'prefix_class' => 'cms-counter-'
                ]
            );

            $widget->add_responsive_control(
                'col',
                [
                    'label'        => esc_html__('Grid Columns Settings', 'validus'),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '',
                    'default_args' => [
                        'tablet' => '',
                        'mobile' => ''
                    ],
                    'options' => [
                        '' => esc_html__('Default', 'validus'),
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '6' => '6',
                    ],
                    'condition' => [
                        'layout_mode' => ['grid']
                    ]
                ]
            );
            
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'validus' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'validus' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/layout1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'validus' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/layout2.jpg'
                        ],
                    ],
                    'style_transfer' => true,
                ]
            );
        $widget->end_controls_section();

        // Banner
        $widget->start_controls_section('banner_section',[
            'label'     => esc_html__('Banner', 'validus'),
            'tab'       => Controls_Manager::TAB_SETTINGS,
            'condition' => [
                'layout' => '1'
            ]
        ]);
            $widget->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'validus' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'label'   => esc_html__('Banner Size','validus'),
                    'default' => 'custom',
                    'condition' => [
                        'banner[url]!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();

        // Carousel
        $widget->start_controls_section(
            'carousel_settings_section',
            [
                'label' => esc_html__('Carousel Settings','validus'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
            ]
        );
            $repeater = new Repeater();

            $repeater->add_control(
                'starting_number',
                [
                    'label'   => esc_html__( 'Starting Number', 'validus' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 1,
                ]
            );
            $repeater->add_control(
                'ending_number',
                [
                    'label'   => esc_html__( 'Ending Number', 'validus' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 100,
                ]
            );
            $repeater->add_control(
                'duration',
                [
                    'label'   => esc_html__( 'Animation Duration', 'validus' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 2000,
                    'min'     => 100,
                    'step'    => 100,
                ]
            );
            $repeater->add_control(
                'thousand_separator',
                [
                    'label'   => esc_html__( 'Thousand Separator', 'validus' ),
                    'type'    => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                ]
            );
            $repeater->add_control(
                'thousand_separator_char',
                [
                    'label'     => esc_html__( 'Separator', 'validus' ),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'condition' => [
                        'thousand_separator' => 'yes',
                    ],
                    'options'   => [
                        ','  => 'Default',
                        '.' => 'Dot',
                        ' ' => 'Space',
                    ],
                    'default'   => ',',
                ]
            );
            $repeater->add_control(
                'description',
                [
                    'label'       => esc_html__( 'Description', 'validus' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default'     => 'Executed Projects with latest processing solutions.',
                    'placeholder' => esc_html__( 'Enter your text', 'validus' ),
                ]
            );
            // add counter item
            $widget->add_control(
                'counters',
                [
                    'label'  => esc_html__('Counters List', 'validus'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'description' => 'Executed Projects with latest processing solutions.',
                            'starting_number' => '1',
                            'ending_number' => '100',
                            'duration' => '2000',
                        ],
                        [
                            'description' => 'Executed Projects with latest processing solutions.',
                            'starting_number' => '1',
                            'ending_number' => '200',
                            'duration' => '2000',
                        ],
                    ],
                ]
            );

            $slides_to_show = range(1, 10);
            $slides_to_show = array_combine($slides_to_show, $slides_to_show);
            $widget->add_responsive_control(
                'slides_to_show',
                [
                    'label' => esc_html__('Slides to Show', 'validus'),
                    'type' => Controls_Manager::HIDDEN,
                    'options' => [
                            '1' => esc_html__('1', 'validus'),
                        ],
                    'default' => 1,
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'dots',
                [
                    'label' => esc_html__('Show Dots', 'validus'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'layout' => '1'
                    ]
                ]
            );

            $widget->add_control(
                'arrow_prev_icon',
                [
                    'label' => esc_html__('Previous Arrow Icon', 'validus'),
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin' => 'inline',
                    'label_block' => false,
                    'skin_settings' => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-left',
                            ],
                            'icon' => [
                                'icon' => 'eicon-star',
                            ],
                        ],
                    ],
                    'recommended' => [
                        'fa-regular' => [
                            'arrow-alt-circle-left',
                            'caret-square-left',
                        ],
                        'fa-solid' => [
                            'angle-double-left',
                            'angle-left',
                            'arrow-alt-circle-left',
                            'arrow-circle-left',
                            'arrow-left',
                            'caret-left',
                            'caret-square-left',
                            'chevron-circle-left',
                            'chevron-left',
                            'long-arrow-alt-left',
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );

            $widget->add_control(
                'arrow_next_icon',
                [
                    'label' => esc_html__('Next Arrow Icon', 'validus'),
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin' => 'inline',
                    'label_block' => false,
                    'skin_settings' => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-right',
                            ],
                            'icon' => [
                                'icon' => 'eicon-star',
                            ],
                        ],
                    ],
                    'recommended' => [
                        'fa-regular' => [
                            'arrow-alt-circle-right',
                            'caret-square-right',
                        ],
                        'fa-solid' => [
                            'angle-double-right',
                            'angle-right',
                            'arrow-alt-circle-right',
                            'arrow-circle-right',
                            'arrow-right',
                            'caret-right',
                            'caret-square-right',
                            'chevron-circle-right',
                            'chevron-right',
                            'long-arrow-alt-right',
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );

            $widget->add_control(
                'lazyload',
                [
                    'label' => esc_html__('Lazyload', 'validus'),
                    'type' => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'autoplay',
                [
                    'label' => esc_html__('Autoplay', 'validus'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'pause_on_hover',
                [
                    'label' => esc_html__('Pause on Hover', 'validus'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'pause_on_interaction',
                [
                    'label' => esc_html__('Pause on Interaction', 'validus'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'autoplay_speed',
                [
                    'label' => esc_html__('Autoplay Speed', 'validus'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 5000,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'infinite',
                [
                    'label' => esc_html__('Infinite Loop', 'validus'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'effect',
                [
                    'label' => esc_html__('Effect', 'validus'),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'slide',
                    'options' => [
                        'slide' => esc_html__('Slide', 'validus'),
                        'fade' => esc_html__('Fade', 'validus'),
                    ],
                    'condition' => [
                        'slides_to_show' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'speed',
                [
                    'label' => esc_html__('Animation Speed', 'validus'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 500,
                    'render_type' => 'none',
                    'frontend_available' => true,
                ]
            );
        $widget->end_controls_section();

        // Style Section Start
        $widget->start_controls_section(
            'section_general',
            [
                'label' => esc_html__('General', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_responsive_control(
            'box_height',
            [
                'label'        => esc_html__( 'Box Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 1200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'background_radius',
            [
                'label'        => esc_html__( 'Background Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Dots Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'dots_color',
            [
                'label' => esc_html__('Dots Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'section_counter',
            [
                'label' => esc_html__('Counter Box', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_control(
            'counter_box_position',
            [
                'label' => esc_html__('Counter Box Position', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left' => esc_html__('Left', 'validus'),
                    'right' => esc_html__('Right', 'validus'),
                ],
                'separator' => 'before',
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'counter_box_left',
            [
                'label'        => esc_html__( 'Counter Box Left Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '40',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'counter_box_position' => 'left'
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-counter-wrap .cms-contents' => 'left: {{SIZE}}{{UNIT}};right: auto;',
					'body.rtl {{WRAPPER}} .cms-counter-wrap .cms-contents' => 'left: auto;right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'counter_box_right',
            [
                'label'        => esc_html__( 'Counter Box Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '40',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'counter_box_position' => 'right'
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-counter-wrap .cms-contents' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-counter-wrap .cms-contents' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'counter_box_bottom',
            [
                'label'        => esc_html__( 'Counter Box Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '53',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap .cms-contents' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'counter_box_width',
            [
                'label'        => esc_html__( 'Counter Box Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap .cms-contents' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'counter_box_radius',
            [
                'label'        => esc_html__( 'Counter Box Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap .cms-contents' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
			'counter_box_padding',
			[
				'label' => esc_html__( 'Counter Box Padding', 'validus' ),
                'description' => esc_html__( 'Default on layout 1: 40px 40px 31px 40px;', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .cms-counter-wrap .cms-contents' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $widget->add_control(
            'counter_box_desc_color',
            [
                'label'     => esc_html__( 'Counter Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-counter-wrap .cms-counter-desc' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section();

        // Number Section Start
        $widget->start_controls_section(
            'section_number',
            [
                'label' => esc_html__('Number', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'number_color',
            [
                'label'     => esc_html__( 'Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-counter-wrap .elementor-counter-number' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'number_typography',
                'selector' => '{{WRAPPER}} .cms-counter-wrap .elementor-counter-number',
            ]
        );
        $widget->add_responsive_control(
            'number_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Space', 'validus' ),
                'description'  => esc_html__( 'Default on layout 1: 17px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-counter-wrap .cms-contents .cms-counter-numbers' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Number Section End
    }
}
