<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Stroke;

if (!function_exists('validus_widget_cms_cta_register_controls')) {
    add_action('etc_widget_cms_cta_register_controls', 'validus_widget_cms_cta_register_controls', 10, 1);
    function validus_widget_cms_cta_register_controls($widget)
    {
		$widget->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'validus' ),
			]
		);

		$widget->add_control(
			'description',
			[
				'label' => esc_html__( 'Description', 'validus' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'default' => esc_html__( 'Serving an impressive list of clients with experience in multiple industries.', 'validus' ),
				'placeholder' => esc_html__( 'Enter your description', 'validus' ),
				'separator' => 'none',
				'rows' => 5,
			]
		);

		$widget->add_control(
			'button',
			[
				'label' => esc_html__( 'Button Text', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => esc_html__( 'Contact Head Office', 'validus' ),
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'link',
			[
				'label' => esc_html__( 'Link', 'validus' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),

			]
		);

		$widget->add_control(
			'link_click',
			[
				'label' => esc_html__( 'Apply Link On', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'box' => esc_html__( 'Whole Box', 'validus' ),
					'button' => esc_html__( 'Button Only', 'validus' ),
				],
				'default' => 'button',
				'separator' => 'none',
				'condition' => [
					'link[url]!' => '',
				],
			]
		);
		$widget->add_control(
            'show_icon',
            [
                'label' => esc_html__('Show Icon', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
            ]
        );
		$widget->add_control(
            'select_icon',
            [
                'label'   => esc_html__( 'Select Icon Type', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'cmsi-chevron-right style1',
                'options' => [
                    'cmsi-chevron-right style1' => esc_html__( 'Icon 1', 'validus' ),
                    'cmsi-chevron-right style2'	=> esc_html__( 'Icon 2', 'validus' ),
                ],
				'condition' => [
					'show_icon' => 'yes'
				]
            ]
        );
		$widget->end_controls_section();
		//

		//
		$widget->start_controls_section(
			'box_style',
			[
				'label' => esc_html__( 'Box', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$widget->add_responsive_control(
			'alignment',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .cms-cta-wrap' => 'justify-content: {{VALUE}};text-align: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'vertical_position',
			[
				'label' => esc_html__( 'Vertical Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => esc_html__( 'Top', 'validus' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'validus' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'validus' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'prefix_class' => 'cms-cta--valign-',
				'separator' => 'none',
			]
		);

		$widget->add_responsive_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'control_type' => 'responsive',
				'size_units' => [ '%' ],
				'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-cta__content' => 'width: {{SIZE}}%',
				],
			]
		);

		$widget->end_controls_section();
		//

		//
		$widget->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'description!' => '',
				],
			]
		);

		$widget->add_control(
			'heading_style_description',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Description', 'validus' ),
				'separator' => 'before',
				'condition' => [
					'description!' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .cms-cta__description',
				'condition' => [
					'description!' => '',
				],
			]
		);

		$widget->add_control(
			'heading_content_colors',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Colors', 'validus' ),
				'separator' => 'before',
			]
		);

		$widget->start_controls_tabs( 'color_tabs' );

		$widget->start_controls_tab( 'colors_normal',
			[
				'label' => esc_html__( 'Normal', 'validus' ),
			]
		);

		$widget->add_control(
			'content_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__content' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'skin' => 'classic',
				],
			]
		);

		$widget->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__title' => 'color: {{VALUE}}',
				],
				'condition' => [
					'title!' => '',
				],
			]
		);

		$widget->add_control(
			'description_color',
			[
				'label' => esc_html__( 'Description Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__description' => 'color: {{VALUE}}',
				],
				'condition' => [
					'description!' => '',
				],
			]
		);

		$widget->end_controls_tab();

		$widget->start_controls_tab(
			'colors_hover',
			[
				'label' => esc_html__( 'Hover', 'validus' ),
			]
		);

		$widget->add_control(
			'content_bg_color_hover',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta:hover .cms-cta__content' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'skin' => 'classic',
				],
			]
		);

		$widget->add_control(
			'title_color_hover',
			[
				'label' => esc_html__( 'Title Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta:hover .cms-cta__title' => 'color: {{VALUE}}',
				],
				'condition' => [
					'title!' => '',
				],
			]
		);

		$widget->add_control(
			'description_color_hover',
			[
				'label' => esc_html__( 'Description Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta:hover .cms-cta__description' => 'color: {{VALUE}}',
				],
				'condition' => [
					'description!' => '',
				],
			]
		);

		$widget->end_controls_tab();

		$widget->end_controls_tabs();

		$widget->end_controls_section();
		//

		//
		$widget->start_controls_section(
			'button_style',
			[
				'label' => esc_html__( 'Text & Underline', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'button!' => '',
				],
			]
		);

		$widget->add_control(
            'show_underline',
            [
                'label' => esc_html__('Show Underline', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'selector' => '{{WRAPPER}} .cms-cta__button',
            ]
        );

		$widget->start_controls_tabs( 'button_tabs' );

		$widget->start_controls_tab( 'button_normal',
			[
				'label' => esc_html__( 'Normal', 'validus' ),
			]
		);

		$widget->add_control(
			'button_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__button' => 'color: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'button_border_color',
			[
				'label' => esc_html__( 'Underline Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-cta__button' => 'border-color: {{VALUE}};',
				],
			]
		);

		$widget->end_controls_tab();

		$widget->start_controls_tab(
			'button-hover',
			[
				'label' => esc_html__( 'Hover', 'validus' ),
			]
		);

		$widget->add_control(
			'button_hover_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'button_hover_border_color',
			[
				'label' => esc_html__( 'Underline Hover Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-cta__button:hover' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					'show_underline' => 'yes'
				],
			]
		);

		$widget->end_controls_tab();

		$widget->end_controls_tabs();

		$widget->add_control(
			'button_border_width',
			[
				'label' => esc_html__( 'Underline Height', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
					],
					'em' => [
						'max' => 2,
					],
				],
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-cta__button' => 'border-width: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$widget->end_controls_section();
		//
    }
}
