<?php

use Elementor\Controls_Manager;

if (!function_exists('validus_widget_cms_divider_register_controls')) {
    add_action('etc_widget_cms_divider_register_controls', 'validus_widget_cms_divider_register_controls', 10, 1);
    function validus_widget_cms_divider_register_controls($widget)
    {
        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $widget->add_control(
            'width',
            [
                'label'        => esc_html__( 'Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
					'size' => 100,
					'unit' => '%',
				],
                'selectors'    => [
                    '{{WRAPPER}} .cms-divider-separator' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'height',
            [
                'label'        => esc_html__( 'Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 10,
                    ],
                ],
                'default' => [
					'size' => 6,
					'unit' => 'px',
				],
                'selectors'    => [
                    '{{WRAPPER}} .cms-divider-separator' => 'min-height: {{SIZE}}{{UNIT}};border: 0;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ]
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-divider-wrap' => 'justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'divider_color',
            [
                'label' => esc_html__( 'Divider Color', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'primary',
                'options' => [
                    'default' => esc_html__( 'Official Color', 'validus' ),
                    'custom' => esc_html__( 'Custom', 'validus' ),
                    'primary' => esc_html__( 'Primary', 'validus' ),
                    'secondary' => esc_html__( 'Secondary', 'validus' ),
                ],
            ]
        );
        $widget->add_control(
            'divider_color_custom',
            [
                'label' => esc_html__( 'Divider Color Custom', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'divider_color' => 'custom',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-divider-separator' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // List Section End
        // Content Tab End
    }
}
