<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_download_register_controls')) {
    add_action('etc_widget_cms_download_register_controls', 'validus_widget_cms_download_register_controls', 10, 1);
    function validus_widget_cms_download_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_download/layout-images/layout1.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Content Tab Start

        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Download Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'heading_text',
            [
                'label'       => esc_html__( 'Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'Download Brochure', 'validus' ),
                'placeholder' => esc_html__( 'Enter your title', 'validus' ),
                'label_block' => true,
            ]
        );


        $repeater = new Repeater();

        $repeater->add_control(
            'item',
            [
                'label' => esc_html__('Item', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'media_types' => ['application/pdf'],
                'default' => [
                    'url' => get_template_directory_uri() . '/assets/doc/CMS-Brochure.pdf',
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Our Report 2023', 'validus'),
            ]
        );

        $widget->add_control(
            'items',
            [
                'label' => esc_html__('Items', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'item' => [
                            'url' => get_template_directory_uri() . '/assets/doc/CMS-Brochure.pdf',
                        ],
                        'name' => esc_html__('Our Report 2023', 'validus'),
                    ],
                    [
                        'item' => [
                            'url' => get_template_directory_uri() . '/assets/doc/CMS-Brochure.pdf',
                        ],
                        'name' => esc_html__('Company Brochure', 'validus'),
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        $widget->add_control(
            'heading_size',
            [
                'label'   => esc_html__( 'Heading HTML Tag', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p',
                ],
                'default' => 'h3',
            ]
        );
        $widget->end_controls_section(); // Heading Section End

        // Style Heading Style Start
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-heading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'heading_text!' => ''
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'heading_typography',
                'label'     => 'Heading Typography',
                'selector'  => '{{WRAPPER}} .cms-download-heading',
                'condition' => [
                    'heading_text!' => ''
                ]
            ]
        );
        $widget->add_control(
            'download_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-item-icon i' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_control(
            'download_icon_color_hover',
            [
                'label'     => esc_html__( 'Icon Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-item:hover i' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_control(
            'download_color1',
            [
                'label'     => esc_html__( 'Download Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-item-url a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-download-item-icon i' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '2'
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'download_hover_color1',
            [
                'label'     => esc_html__( 'Download Hover Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-item:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-download-item:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-download-item:hover i' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'text_typography',
                'label'     => 'Download Text Typography',
                'selector'  => '{{WRAPPER}} .cms-download-item-url a',
            ]
        );

        //layout1
        $widget->add_control(
            'download_hover_color',
            [
                'label'     => esc_html__( 'Item Hover Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-download-item:hover' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '1'
                ],
                'separator' => 'before',
            ]
        );
        $widget->end_controls_section(); // Style Heading Style End
        
        // Content Tab End

    }
}
