<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

if (!function_exists('validus_widget_cms_fancy_box_register_controls')) {
    add_action('etc_widget_cms_fancy_box_register_controls', 'validus_widget_cms_fancy_box_register_controls', 10, 1);
    function validus_widget_cms_fancy_box_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout3.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__('Layout 4', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout4.jpg'
                    ],
                    '5' => [
                        'label' => esc_html__('Layout 5', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout5.jpg'
                    ],
                    '6' => [
                        'label' => esc_html__('Layout 6', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout-images/layout6.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Icon Section Start
        $widget->start_controls_section(
            'fancy_box_section',
            [
                'label' => esc_html__('Fancy Box', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'icon_type',
            [
                'label'   => esc_html__('Icon Type', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'icon'  => 'Icon',
                    'image' => 'Image',
                ],
                'default' => 'icon',
                'condition'        => [
                    'layout' => ['1','3'],
                ],
            ]
        );
        $widget->add_control(
            'selected_icon',
            [
                'label'   => esc_html__('Icon', 'validus'),
                'type'    => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'library' => 'validusicon',
                    'value'   => 'validus-icon-gear'       
                ],
                'condition'        => [
                    'icon_type' => 'icon',
                    'layout' => ['1','3'],
                ],
            ]
        );
        $widget->add_control(
            'quick_icon',
            [
                'label'   => esc_html__( 'Quick Select Icon', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''     => esc_html__( 'Default', 'validus' ),
                    'check-02.png'     => esc_html__( 'Circle Orange', 'validus' ),
                ],
                'condition'        => [
                    'layout' => ['2'],
                ],
            ]
        );
        $widget->add_control(
            'selected_icon1',
            [
                'label'   => esc_html__('Icon', 'validus'),
                'type'    => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'library' => 'validusicon',
                    'value'   => 'validus-icon-gear'       
                ],
                'condition'        => [
                    'layout' => ['2','4','5'],
                ],
            ]
        );
        $widget->add_control(
            'icon_image',
            [
                'label'   => esc_html__('Image', 'validus'),
                'type'    => Controls_Manager::MEDIA,
                'description' => esc_html__('Select image icon.', 'validus'),
                'condition'   => [
                    'icon_type' => 'image',
                    'layout' => ['1','3'],
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $widget->add_control(
            'icon_image1',
            [
                'label'   => esc_html__('Image', 'validus'),
                'type'    => Controls_Manager::MEDIA,
                'description' => esc_html__('Select image icon.', 'validus'),
                'condition'   => [
                    'layout' => ['5','6'],
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'icon_image1',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
                'condition'   => [
                    'layout' => ['6'],
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
                'condition'   => [
                    'icon_type' => 'image',
                    'layout' => ['1','3','4'],
                ],
            ]
        );
        $widget->add_control(
            'number',
            [
                'label'   => esc_html__('Number', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('01', 'validus'),
                'placeholder' => esc_html__('Enter the order number', 'validus'),
                'condition'   => [
                    'layout' => ['5'],
                ],
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('This is the heading', 'validus'),
                'placeholder' => esc_html__('Enter your title', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'description',
            [
                'label'   => esc_html__('Description', 'validus'),
                'type'    => Controls_Manager::TEXTAREA,
                'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'validus'),
                'placeholder' => esc_html__('Enter your description', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->add_control(
            'phone',
            [
                'label'   => esc_html__('Phone', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('02 01061245741', 'validus'),
                'placeholder' => esc_html__('Enter your phone', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
                'condition'   => [
                    'layout'      => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_style',
            [
                'label'   => esc_html__( 'Button Style', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn btn-lg btn-white',
                'options' => [
                    'btn btn-lg btn-secondary btn-hover-white'     => esc_html__( 'Secondary', 'validus' ),
                    'btn btn-lg btn-white'     => esc_html__( 'White', 'validus' ),
                    'btn btn-outline-white btn-hover-outline-black'     => esc_html__( 'Outline White', 'validus' ),
                    'btn-text-underline'        => esc_html__( 'Underline', 'validus' ),
                ],
                'condition' => [
                    'layout' => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_text',
            [
                'label'   => esc_html__('Button Text', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Schedule An Appointment',
                'condition'   => [
                    'layout'      => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_link_type',
            [
                'label'   => esc_html__('Button Link Type', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'custom' => esc_html__('Custom', 'validus'),
                    'page' => esc_html__('Page', 'validus'),
                ],
                'default' => 'custom',
                'condition'   => [
                    'layout'      => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_link',
            [
                'label'   => esc_html__('Button Link', 'validus'),
                'type'    => Controls_Manager::URL,
                'default'     => [
                    'url' => '#',
                ],
                'condition' => [
                    'layout'        => '3'
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End

        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_responsive_control(
            'gap1',
            [
                'label'        => esc_html__( 'Gap Between Icon & Text', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '44',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout!' => ['6', '5', '3']
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-wrap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'gap2',
            [
                'label'        => esc_html__( 'Gap Between Title & Description', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//18
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-content' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'left_right_space',
            [
                'label'        => esc_html__( 'Left-Right Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '40',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition'   => [
                    'layout'    => ['3', '5']
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-wrap' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'     => esc_html__('Number Typography', 'validus'),
                'name'      => 'number_typography',
                'selector'  => '{{WRAPPER}} .cms-fancy-box-number',
                'condition'   => [
                    'layout'    => ['5']
                ]
            ]
        );
        $widget->add_control(
            'style',
            [
                'label'   => esc_html__('Text Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options'   => [
                    'var(--body-font-color)' => 'Default',
                    '#fff' => 'White',
                    'var(--color-secondary)' => 'Black',
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-fancy-box-icon' => 'color: {{VALUE}};',
                ],
                'condition'   => [
                    'layout'    => ['2','4', '6']
                ]
            ]
        );
        $widget->add_control(
            'icon_color',
            [
                'label'   => esc_html__('Icon Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-icon i' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition'   => [
                    'icon_type' => 'icon',
                    'layout'    => ['1','2','4']
                ]
            ]
        );
        $widget->add_responsive_control(
            'title_right_space',
            [
                'label'        => esc_html__( 'Title Right Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-title' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Title Typography', 'validus'),
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-fancy-box-title',
            ]
        );
        $widget->add_responsive_control(
            'title_bottom_space',
            [
                'label'        => esc_html__( 'Title Bottom Space', 'validus' ),
                'description'  => esc_html__( 'Default on layout 1: 15px; layout 2: 18px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'description_right_space',
            [
                'label'        => esc_html__( 'Description Right Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-description' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'description_color',
            [
                'label'   => esc_html__('Description Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-description' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Description Typography', 'validus'),
                'name' => 'description_typography',
                'selector'     => '{{WRAPPER}} .cms-fancy-box-description',
            ]
        );
        $widget->add_control(
            'phone_color',
            [
                'label'   => esc_html__('Phone Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-phone i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-fancy-box-phone span' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_background',
            [
                'label'   => esc_html__('Button Background Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-button a' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_background_hover',
            [
                'label'   => esc_html__('Button Background Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-button:hover a' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '3'
                ]
            ]
        );
        $widget->add_control(
            'btn_color',
            [
                'label'   => esc_html__('Button Text Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-button a' => 'color: {{VALUE}};border-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '3'
                ]
            ]
        );
        $widget->add_control(
            'background_color',
            [
                'label'   => esc_html__('Background Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-background' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .cms-fancy-box-wrap' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => ['3', '5', '6']
                ]
            ]
        );
        $widget->add_control(
            'background_hover_color',
            [
                'label'   => esc_html__('Background Image Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-fancy-box-wrap:hover .cms-fancy-box-icon' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .cms-fancy-box-wrap:hover .cms-fancy-box-background' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_control(
            'opacity',
            [
                'label'        => esc_html__( 'Background Image Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '7',//15
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'condition' => [
                    'layout' => '3'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-fancy-box-background img' => 'opacity: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-fancy-box-background .cms-icon' => 'opacity: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Section End

        // Content Tab End

    }
}
