<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_galleries_register_controls')) {
    add_action('etc_widget_cms_galleries_register_controls', 'validus_widget_cms_galleries_register_controls', 10, 1);
    function validus_widget_cms_galleries_register_controls($widget)
    {
		//
		$widget->start_controls_section(
			'layout_section',
			[
                'label' => esc_html__('Layout', 'validus' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
			]
		);

		$widget->add_responsive_control(
			'layout',
			[
	            'label' => esc_html__('Templates', 'validus' ),
	            'type' => Elementor_Theme_Core::LAYOUT_CONTROL,
	            'default' => '1',
	            'options' => [
	                '1' => [
	                    'label' => esc_html__('Layout 1', 'validus' ),
	                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_galleries/layout-images/layout1.jpg'
	                ],
	            ],
			]
		);

		$widget->end_controls_section();
		//

		$widget->start_controls_section(
			'grid_section',
			[
                'label'    => esc_html__('Image Gallery', 'validus' ),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$widget->add_control(
			'wp_gallery',
			[
                'label'      => esc_html__( 'Add Images', 'validus' ),
                'type'       => \Elementor\Controls_Manager::GALLERY,
                'show_label' => false,
                'dynamic'    => [
                    'active' => true,
                ],
			]
		);

        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'large',
            ]
        );

		$widget->add_responsive_control(
			'gallery_col',
			[
               'label'        => esc_html__('Columns', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'      => '3',
                'options'      => [
                    '1' => esc_html__('1', 'validus' ),
                    '2' => esc_html__('2', 'validus' ),
                    '3' => esc_html__('3', 'validus' ),
                    '4' => esc_html__('4', 'validus' ),
                    '6' => esc_html__('6', 'validus' ),
                ],
			]
		);

		$widget->add_control(
			'gallery_rand',
			[
                'label'   => esc_html__( 'Order By', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    ''     => esc_html__( 'Default', 'validus' ),
                    'rand' => esc_html__( 'Random', 'validus' ),
                ],
                'default' => '',
			]
		);

		$widget->add_control(
			'gallery_show',
			[
                'label'   => esc_html__( 'Number of item to show', 'validus' ),
                'type'    => \Elementor\Controls_Manager::NUMBER,
                'default' => '6',
			]
		);

		$widget->add_control(
			'gallery_loadmore_show',
			[
                'label'   => esc_html__( 'Number of item to show on load more', 'validus' ),
                'type'    => \Elementor\Controls_Manager::NUMBER,
                'default' => '6',

			]
		);

		$widget->add_control(
			'load_more_text',
			[
                'label'   => esc_html__( 'Load More Text', 'validus' ),
                'type'    => \Elementor\Controls_Manager::TEXT
			]
		);

		$widget->end_controls_section();
		//

		//
		$widget->start_controls_section(
			'gallery_images_section',
			[
                'label'    => esc_html__('Images', 'validus' ),
                'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$widget->add_responsive_control(
			'gap',
			[
                'label'        => esc_html__('Image Gap', 'validus' ),
                'type'         => \Elementor\Controls_Manager::NUMBER,
                'default'      => 40
			]
		);

		$widget->end_controls_section();
		//

		//
		$widget->start_controls_section(
			'caption_section',
			[
                'label'    => esc_html__('Caption', 'validus' ),
                'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$widget->add_responsive_control(
			'gallery_display_caption',
			[
                'label'   => esc_html__( 'Display', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'  => esc_html__( 'Hide', 'validus' ),
                    'block' => esc_html__( 'Show', 'validus' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-image-caption' => 'display: {{VALUE}};',
                ],
			]
		);

		$widget->add_control(
			'caption_align',
			[
                'label'   => __( 'Alignment', 'validus' ),
                'type'    => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'start' => [
                        'title' => __( 'Left', 'validus' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'validus' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'end' => [
                        'title' => __( 'Right', 'validus' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-image-caption' => 'text-align: {{VALUE}};',
                ],
                'default'   => 'center',
                'condition' => [
                    'gallery_display_caption!' => 'none',
                ],
			]
		);

		$widget->add_control(
			'caption_color',
			[
                'label'     => esc_html__( 'Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .cms-image-caption' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'gallery_display_caption!' => 'none',
                ],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'caption_typography',
				'label' => esc_html__( 'Height', 'validus' ),
	            'selector'     => '{{WRAPPER}} .cms-image-caption',
	            'condition'    => [
	                'gallery_display_caption!' => 'none',
	            ]
			]
		);

		$widget->end_controls_section();
		//
    }
}
