<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_heading_register_controls')) {
    add_action('etc_widget_cms_heading_register_controls', 'validus_widget_cms_heading_register_controls', 10, 1);
    function validus_widget_cms_heading_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_heading/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_heading/layout-images/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_heading/layout-images/layout3.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__('Layout 4', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_heading/layout-images/layout4.jpg'
                    ],
                    '5' => [
                        'label' => esc_html__('Layout 5', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_heading/layout-images/layout5.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Content Tab Start

        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'heading_text',
            [
                'label'       => esc_html__( 'Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'This is the heading', 'validus' ),
                'placeholder' => esc_html__( 'Enter your title', 'validus' ),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'subheading_text',
            [
                'label'       => esc_html__( 'Sub Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter your sub title', 'validus' ),
                'default'     => esc_html__( 'Yet those that embrace change are thriving, building bigger, better, faster, and stronger products than ever before. You are helping to lead the charge; we can help you build on your past successes and prepare for future.', 'validus'),
                'label_block' => true,
                'condition' => [
                    'layout' => ['1', '2', '3', '5']
                ]
            ]
        );
        $widget->add_control(
            'description_text',
            [
                'label'       => esc_html__( 'Description', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter description', 'validus' ),
                'default'     => "Our Group is recognized as one of the World's leading Industry and Manufacturing Corporation serving an impressive list of long-term clients with experience and expertise in multiple industries.",
                'rows'        => 10,
                'show_label'  => true,
                'condition' => [
                    'layout' => ['1', '2', '4']
                ]
            ]
        );
        $widget->add_control(
            'link',
            [
                'name'  => 'link',
                'label' => esc_html__( 'Link Heading', 'validus' ),
                'type'  => \Elementor\Controls_Manager::URL,
            ]
        );
        $widget->add_control(
            'heading_size',
            [
                'label'   => esc_html__( 'Heading HTML Tag', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p',
                ],
                'default' => 'h3',
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading-wrap' => 'text-align: {{VALUE}};justify-content: {{VALUE}};display: flex;',
                ],
            ]
        );
        $widget->end_controls_section();
        // Heading Section End


        // Style Start
        $widget->start_controls_section(
            'section_style_general',
            [
                'label' => esc_html__('General Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['1', '2', '6']
                ]
            ]
        );
        $widget->add_responsive_control(
			'max_width',
			[
				'label' => esc_html__( 'Width Content', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%', 'px' ],
                'default' => [
                    'size' => '',
                    'unit' => '%'
                ],
				'range' => [
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
					'px' => [
						'min' => 0,
						'max' => 1600,
					],
				],
				
				'selectors' => [
					'{{WRAPPER}} .cms-heading-container' => 'max-width: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->add_responsive_control(
			'padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
                'default' => [
                    'size' => ''
                ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				
				'selectors' => [
					'{{WRAPPER}} .cms-heading-wrap' => 'padding: {{SIZE}}{{UNIT}}',
				],
			]
		);
        $widget->add_control(
            'style',
            [
                'label'   => esc_html__('Text Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options'   => [
                    'style1' => 'Default',
                    'style3' => 'Black',
                    'style4' => 'White (Background Black)',
                ],
                'default'   => 'style1',
                'condition' => [
                    'layout' => ['1','2']
                ]
            ]
        );
        $widget->end_controls_section();
        // Style Content Alignment End

        // Style Start
        $widget->start_controls_section(
            'section_style_column',
            [
                'label' => esc_html__('Column Width', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['4','5']
                ]
            ]
        );
        $widget->add_responsive_control(
			'column_heading',
			[
				'label' => esc_html__( 'Column Heading', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'default'      => [
                    'size' => '40',//15
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-heading' => 'flex-basis: {{SIZE}}%',
				],
			]
		);
        $widget->add_responsive_control(
            'gap_column',
            [
                'label'        => esc_html__( 'Gap Between 2 Column', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//149
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading-wrap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'column_subheading',
            [
                'label'        => esc_html__( 'Column Sub Heading', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '31',
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout' => '5'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-subheading' => 'flex-basis: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'column_text',
            [
                'label'        => esc_html__( 'Column Text', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '48',//15
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout' => '4'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading-description' => 'flex-basis: {{SIZE}}%;',
                ],
            ]
        );
        $widget->end_controls_section();

        // Style Heading Start
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Heading Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'heading_text!' => ''
                ]
            ]
        );
        $widget->add_responsive_control(
            'heading_top_space',
            [
                'label'        => esc_html__( 'Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -30,
                        'max' => 130,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'heading_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'description'  => esc_html__( 'Default on layout 1: 25px; layout 2: 20px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '20',//25
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading, {{WRAPPER}} .cms-heading a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_font',
            [
                'label' => esc_html__('Heading Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'label' => 'Heading Typography',
                'selector'     => '{{WRAPPER}} .cms-heading, {{WRAPPER}} .cms-heading a',
            ]
        );
        $widget->add_responsive_control(
            'heading_right_space',
            [
                'label'        => esc_html__( 'Heading Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'divider',
            [
                'label'   => esc_html__( 'Divider', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'no'  => 'No',
                    'yes' => 'Yes',
                ],
                'default' => 'no',
                'separator' => 'before',
                'condition' => [
                    'layout' => ['1','2'],
                ],
            ]
        );
        $widget->add_control(
            'divider_color',
            [
                'label'     => esc_html__( 'Divider Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-divider span' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'divider' => 'yes',
                    'layout' => ['1','2'],
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Heading End

        // Style Sub Heading Start
        $widget->start_controls_section(
            'section_style_subheading',
            [
                'label' => esc_html__('Sub Heading Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['1','2','3','5'],
                    'subheading_text!' => '',
                ],
            ]
        );
        $widget->add_responsive_control(
            'subheading_top_space',
            [
                'label'        => esc_html__( 'Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => -30,
                        'max' => 130,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-subheading' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'subheading_bottom_space',
            [
                'label'        => esc_html__( 'Margin Bottom Spacing', 'validus' ),
                'description'  => esc_html__( 'Default on layout 1: 22px; layout 2: 25px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 130,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-subheading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'subheading_p_bottom_space',
            [
                'label'        => esc_html__( 'Padding Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 130,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-subheading' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'subheading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-subheading' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'subheading_font',
            [
                'label' => esc_html__('Subheading Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-subheading' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subheading_typography',
                'label' => 'Subheading Typography',
                'selector'     => '{{WRAPPER}} .cms-subheading',
            ]
        );
        $widget->add_control(
            'subheading_border_color',
            [
                'label'     => esc_html__( 'Border Divider Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-subheading' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Sub Heading End

        // Style Description Start
        $widget->start_controls_section(
            'section_style_description',
            [
                'label' => esc_html__('Description Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'description_text!' => '',
                    'layout' => ['1', '2', '4']
                ]
            ]
        );
        $widget->add_responsive_control(
            'description_space_between_paragraph',
            [
                'label'        => esc_html__( 'Spacing Between Paragraphs', 'validus' ),
                'description'  => esc_html__( 'Note: it works only when the text contain 2 or more paragraphs separated by space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '15',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-heading-description p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-heading-description p:last-child' => 'margin-bottom: 0px;',
                ],
            ]
        );
        $widget->add_control(
            'description_color',
            [
                'label'      => esc_html__( 'Color', 'validus' ),
                'type'       => \Elementor\Controls_Manager::COLOR,
                'selectors'  => [
                    '{{WRAPPER}} .cms-heading-description' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector'     => '{{WRAPPER}} .cms-heading-description',
            ]
        );
        $widget->end_controls_section();
        // Style Description End
        
        // Content Tab End

    }
}
