<?php
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_heading_carousel_register_controls')) {
    add_action('etc_widget_cms_heading_carousel_register_controls', 'validus_widget_cms_heading_carousel_register_controls', 10, 1);
    function validus_widget_cms_heading_carousel_register_controls($widget)
    {
        // Content Tab Start
        // Heading Section Start
        $widget->start_controls_section(
            'left_content_section',
            [
                'label' => esc_html__('Left Content', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $widget->add_control(
            'heading',
            [
                'label' => esc_html__('Heading', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Heading', 'validus'),
            ]
        );

        $widget->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Description', 'validus'),
            ]
        );

        $widget->end_controls_section();
        // Heading Section End

        // List Section Start
        $widget->start_controls_section(
            'right_content_section',
            [
                'label' => esc_html__('Right Content (List Carousel)', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Slide Name', 'validus'),
            ]
        );
        $repeater->add_control(
            'heading',
            [
                'label' => esc_html__('Heading', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Slide Heading', 'validus'),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Slide Description', 'validus'),
            ]
        );

        $widget->add_control(
            'heading_carousel',
            [
                'label' => esc_html__('Items', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'heading' => esc_html__('Slide Heading', 'validus'),
                        'description' => esc_html__('Slide Description', 'validus'),
                    ],
                    [
                        'heading' => esc_html__('Slide Heading', 'validus'),
                        'description' => esc_html__('Slide Description', 'validus'),
                    ],
                ],
                'title_field' => '{{{ heading }}}',
            ]
        );
        $widget->end_controls_section();
        // List Section End

        // Left Section Start
        $widget->start_controls_section(
            'left_section',
            [
                'label' => esc_html__('Left Style (Content)', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $widget->add_control(
            'heading_style',
            [
                'label' => esc_html__('Heading Style :', 'validus'),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $widget->add_responsive_control(
            'heading_bottom_space',
            [
                'label' => esc_html__('Heading Bottom Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-left-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-left-heading' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'selector'     => '{{WRAPPER}} .cms-heading-carousel-left-heading',
            ]
        );

        //Description
        $widget->add_control(
            'description_style',
            [
                'label' => esc_html__('Description Style :', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $widget->add_responsive_control(
            'description_between_space',
            [
                'label' => esc_html__('Space Between Descriptions', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-left-description' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'description_color',
            [
                'label'     => esc_html__( 'Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-left-description' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector'     => '{{WRAPPER}} .cms-heading-carousel-left-description',
            ]
        );
        $widget->end_controls_section();

        // Carousel Section Start
        $widget->start_controls_section(
            'right_section',
            [
                'label' => esc_html__('Right Style (Carousel)', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $slides_to_show = range(1,10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '1' => esc_html__('1', 'validus'),
                    ],
                'frontend_available' => true,
                'default' => '1'
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Name', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'right_bottom_space',
            [
                'label' => esc_html__('Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-right' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
                'separator' => 'before',
            ]
        );

        //Heading
        $widget->add_control(
            'right_heading_style',
            [
                'label' => esc_html__('Heading Style :', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'right_heading_bottom_space',
            [
                'label' => esc_html__('Heading Bottom Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-item-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'right_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-item-heading' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'right_heading_typography',
                'selector'     => '{{WRAPPER}} .cms-heading-carousel-item-heading',
            ]
        );

        //Content
        $widget->add_control(
            'right_description_style',
            [
                'label' => esc_html__('Description Style :', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'right_description_between_space',
            [
                'label' => esc_html__('Space Between Descriptions', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-item-description' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
                //'separator' => 'before'
            ]
        );

        $widget->add_control(
            'right_description_color',
            [
                'label'     => esc_html__( 'Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-item-description' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'right_description_typography',
                'selector'     => '{{WRAPPER}} .cms-heading-carousel-item-description',
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End


        $widget->start_controls_section(
            'arrow_section',
            [
                'label' => esc_html__('Arrow Style', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_responsive_control(
            'arrow_top_space',
            [
                'label' => esc_html__('Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'default' => [
                    'size' => '',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-button' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'border_radius_arrow',
            [
                'label' => esc_html__('Border Radius', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 0,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-arrow' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'gap_arrow',
            [
                'label' => esc_html__('Gap', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 20,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-heading-carousel-button' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->end_controls_section();
        //Arrow End

        //Pagination Style
        $widget->start_controls_section(
            'pagi_section',
            [
                'label' => esc_html__('Pagination Style', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
        $widget->add_responsive_control(
            'pagi_radius',
            [
                'label' => esc_html__('Border Radius', 'validus'),
                'description' => esc_html__('Default : 2px', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => '2',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots .swiper-pagination-bullet' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'pagi_bottom_space',
            [
                'label' => esc_html__('Bottom Space', 'validus'),
                'description' => esc_html__('Default : 50px', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 120,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'pagi_heading_bottom_space',
            [
                'label' => esc_html__('Heading Bottom Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 120,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots .swiper-pagination-bullet .cms-carousel-item-number' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pagi_heading_typography',
                'label' => 'Heading Typography',
                'selector'     => '{{WRAPPER}} .cms-carousel-dots .swiper-pagination-bullet .cms-carousel-item-number',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pagi_name_typography',
                'label' => 'Name Typography',
                'selector'     => '{{WRAPPER}} .cms-carousel-dots .swiper-pagination-bullet .cms-carousel-item-name',
                'separator' => 'before'
            ]
        );
        $widget->end_controls_section();
    }
}
