<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_ht_newsletter_register_controls')) {
    add_action('etc_widget_cms_ht_newsletter_register_controls', 'validus_widget_cms_ht_newsletter_register_controls', 10, 1);
    function validus_widget_cms_ht_newsletter_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ht_newsletter/layout-images/1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ht_newsletter/layout-images/2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ht_newsletter/layout-images/3.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End
        
        $widget->start_controls_section(
            'mailchimpform_content',
            [
                'label' => __( 'Mail Chimp Form', 'validus' ),
            ]
        );
            $widget->add_control(
                'mail_chimp_form_id',
                [
                    'label'       => __( 'Mailchimp Form ID', 'validus' ),
                    'type'        => Controls_Manager::TEXT,
                    'placeholder' => __( '290', 'validus' ),
                    'description' => __( 'For show ID <a href="admin.php?page=mailchimp-for-wp-forms" target="_blank"> Click here </a>', 'validus' ),
                    'label_block' => true,
                    'separator'   => 'before',
                ]
            );

        $widget->end_controls_section();

        // Style tab section
        $widget->start_controls_section(
            'ht_mailchimp_section_style',
            [
                'label' => __( 'Style', 'validus' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $widget->add_responsive_control(
                'ht_mailchimp_section_padding',
                [
                    'label' => __( 'Padding', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'description' => 'Default on layout 1: 30px 30px 30px 30px;',
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htformmailchimp-input-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $widget->add_responsive_control(
                'ht_mailchimp_section_margin',
                [
                    'label' => __( 'Margin', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htformmailchimp-input-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $widget->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'ht_mailchimp_section_background',
                    'label' => __( 'Background', 'validus' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .htformmailchimp-input-box',
                ]
            );

            $widget->add_responsive_control(
                'ht_mailchimp_section_align',
                [
                    'label' => __( 'Alignment', 'validus' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'start' => [
                            'title' => __( 'Left', 'validus' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => __( 'Center', 'validus' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'end' => [
                            'title' => __( 'Right', 'validus' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => __( 'Justified', 'validus' ),
                            'icon' => 'eicon-text-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .htformmailchimp-input-box' => 'text-align: {{VALUE}};',
                    ],
                    'default' => 'left',
                    'separator' =>'before',
                ]
            );
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'ht_mailchimp_typography',
                    'label' => 'Heading Typography',
                    'selector' => '{{WRAPPER}} .mc4wp-heading',
                ]
            );

            $widget->add_control(
                'ht_mailchimp_text_color',
                [
                    'label'     => __( 'Heading Text Color', 'validus' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-heading'  => 'color: {{VALUE}};',
                    ],
                ]
            );
            $widget->add_control(
                'ht_mailchimp_radius',
                [
                    'label' => __( 'Border Radius', 'validus' ),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 150,
                        ],
                    ],
                    'default' => [
                        'size' => '',
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .htformmailchimp-input-box'  => '
                            -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                            -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                            -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                            -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                            -o-border-radius: {{SIZE}}{{UNIT}} !important;
                            border-radius: {{SIZE}}{{UNIT}} !important;',
                    ],
                ]
            );
        $widget->end_controls_section();

        // Input Box style tab start
        $widget->start_controls_section(
            'ht_mailchimp_input_style',
            [
                'label'     => __( 'Input Box', 'validus' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $widget->add_control(
                'ht_input_box_height',
                [
                    'label' => __( 'Height', 'validus' ),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 150,
                        ],
                    ],
                    'default' => [
                        'size' => 50,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'height: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'ht_input_box_typography',
                    'selector' => '{{WRAPPER}} .mc4wp-form input[type*="email"]',
                ]
            );

            $widget->add_control(
                'ht_input_box_background',
                [
                    'label'     => __( 'Background Color', 'validus' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]'         => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]'        => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form select[name*="_mc4wp_lists"]' => 'background-color: {{VALUE}};',
                    ],
                ]
            );

            $widget->add_control(
                'ht_input_box_text_color',
                [
                    'label'     => __( 'Text Color', 'validus' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $widget->add_control(
                'ht_input_box_placeholder_color',
                [
                    'label'     => __( 'Placeholder Color', 'validus' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]::-webkit-input-placeholder'  => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]::-moz-placeholder'  => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]:-ms-input-placeholder'  => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]::-webkit-input-placeholder' => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]::-moz-placeholder' => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]:-ms-input-placeholder' => 'color: {{VALUE}};',
                        '{{WRAPPER}} .mc4wp-form select[name*="_mc4wp_lists"]'      => 'color: {{VALUE}};',
                    ],
                ]
            );

            $widget->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'ht_input_box_border',
                    'label' => __( 'Border', 'validus' ),
                    'selector' => '{{WRAPPER}} .mc4wp-form input[type*="email"]',
                ]
            );

            $widget->add_responsive_control(
                'ht_input_box_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                    'separator' =>'before',
                ]
            );

            $widget->add_responsive_control(
                'ht_input_box_padding',
                [
                    'label' => __( 'Padding', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $widget->add_responsive_control(
                'ht_input_box_margin',
                [
                    'label' => __( 'Margin', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form input[type*="text"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );
           
        $widget->end_controls_section(); // Input box style tab end

        // Input submit button style tab start
        $widget->start_controls_section(
            'ht_mailchimp_inputsubmit_style',
            [
                'label'     => __( 'Button', 'validus' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $widget->start_controls_tabs('ht_submit_style_tabs');

                // Button Normal tab start
                $widget->start_controls_tab(
                    'ht_submit_style_normal_tab',
                    [
                        'label' => __( 'Normal', 'validus' ),
                    ]
                );

                    $widget->add_control(
                        'ht_input_submit_width',
                        [
                            'label' => __( 'Width', 'validus' ),
                            'type'  => Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'max' => 250,
                                ],
                            ],
                            'default' => [
                                'size' => '',
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'width: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );
                    $widget->add_control(
                        'ht_input_submit_height',
                        [
                            'label' => __( 'Height', 'validus' ),
                            'type'  => Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'max' => 150,
                                ],
                            ],
                            'default' => [
                                'size' => '',
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $widget->add_group_control(
                        Group_Control_Typography::get_type(),
                        [
                            'name' => 'ht_input_submit_typography',
                            'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
                        ]
                    );

                    $widget->add_control(
                        'ht_input_submit_text_color',
                        [
                            'label'     => __( 'Text Color', 'validus' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]'  => 'color: {{VALUE}};',
                            ],
                        ]
                    );

                    $widget->add_control(
                        'ht_input_submit_background_color',
                        [
                            'label'     => __( 'Background Color', 'validus' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]'  => 'background-color: {{VALUE}};',
                            ],
                        ]
                    );

                    $widget->add_responsive_control(
                        'ht_input_submit_padding',
                        [
                            'label' => __( 'Padding', 'validus' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'separator' =>'before',
                        ]
                    );

                    $widget->add_responsive_control(
                        'ht_input_submit_margin',
                        [
                            'label' => __( 'Margin', 'validus' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'separator' =>'before',
                        ]
                    );

                    $widget->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'ht_input_submit_border',
                            'label' => __( 'Border', 'validus' ),
                            'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
                        ]
                    );

                    $widget->add_responsive_control(
                        'ht_input_submit_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'validus' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                            ],
                            'separator' =>'before',
                        ]
                    );

                    $widget->add_group_control(
                        Group_Control_Box_Shadow::get_type(),
                        [
                            'name' => 'ht_input_submit_box_shadow',
                            'label' => __( 'Box Shadow', 'validus' ),
                            'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
                        ]
                    );

                $widget->end_controls_tab(); // Button Normal tab end

                // Button Hover tab start
                $widget->start_controls_tab(
                    'ht_submit_style_hover_tab',
                    [
                        'label' => __( 'Hover', 'validus' ),
                    ]
                );

                    $widget->add_control(
                        'ht_input_submithover_text_color',
                        [
                            'label'     => __( 'Text Color', 'validus' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover'  => 'color: {{VALUE}};',
                            ],
                        ]
                    );

                    $widget->add_control(
                        'ht_input_submithover_background_color',
                        [
                            'label'     => __( 'Background Color', 'validus' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover'  => 'background-color: {{VALUE}};',
                            ],
                        ]
                    );

                    $widget->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'ht_input_submithover_border',
                            'label' => __( 'Border', 'validus' ),
                            'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover',
                        ]
                    );

                $widget->end_controls_tab(); // Button Hover tab end

            $widget->end_controls_tabs();

        $widget->end_controls_section(); // Input submit button style tab end

        // Form Label Style
        $widget->start_controls_section(
            'ht_mailchimp_label_style',
            [
                'label'     => __( 'Label', 'validus' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $widget->add_control(
                'ht_mailchimp_label_text_color',
                [
                    'label'     => __( 'Color', 'validus' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mc4wp-form label'  => 'color: {{VALUE}};',
                    ],
                ]
            );

            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'ht_mailchimp_label_typography',
                    'selector' => '{{WRAPPER}} .mc4wp-form label',
                ]
            );

        $widget->end_controls_section(); // Label style tab end
    }
}