<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_icon_register_controls')) {
    add_action('etc_widget_cms_icon_register_controls', 'validus_widget_cms_icon_register_controls', 10, 1);
    function validus_widget_cms_icon_register_controls($widget)
    {
        // Content Tab Start

        // icon Section Start
        $widget->start_controls_section(
            'section_icon',
            [
                'label' => esc_html__('Icons', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();

        $repeater->add_control(
            'cms_icon',
            [
                'label'            => esc_html__( 'Icon', 'validus' ),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
            ]
        );
        $repeater->add_control(
            'icon_link',
            [
                'label'       => esc_html__( 'Icon Link', 'validus' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'icons',
            [
                'label' => esc_html__('Icons', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'cms_icon' => 'fas fa-star',
                        'icon_link' => '#',
                    ],
                    [
                        'cms_icon' => 'fas fa-star',
                        'icon_link' => '#',
                    ],
                ],
            ]
        );
        $widget->end_controls_section(); // icon Section End

        // Style Section Start
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Icons Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .cms-icon-wrap' => 'text-align: {{VALUE}};',
				],
			]
		);
        $widget->add_control(
            'background_color',
            [
                'label'     => esc_html__( 'Background Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap i' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'background_color_hover',
            [
                'label'     => esc_html__( 'Background Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap a:hover i' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'color_type',
            [
                'label'   => esc_html__('Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'var(--color-secondary)' => esc_html__('Default', 'validus'),
                    'var(--color-primary)'   => esc_html__('Primary', 'validus'),
                    'custom'    => esc_html__('Custom', 'validus'),
                ],
                'default' => 'var(--color-secondary)',
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap a' => 'color: {{VALUE}};display: inline-block;',
                ],
                'default' => 'false',
            ]
        );
        $widget->add_control(
            'color',
            [
                'label'     => esc_html__( 'Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap a' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'color_type' => 'custom'
                ],
            ]
        );
        $widget->add_control(
            'color_hover',
            [
                'label'     => esc_html__( 'Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap a:hover' => 'color: {{VALUE}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'size',
            [
                'label'        => esc_html__( 'Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'default'      => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-icon-wrap a' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'padding',
            [
                'label'        => esc_html__( 'Padding', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-icon-wrap a i' => 'padding: {{SIZE}}{{UNIT}};display: inline-block;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'border_width',
            [
                'label'        => esc_html__( 'Border Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'separator' => 'before',
                'selectors'    => [
                    '{{WRAPPER}} .cms-icon-wrap a i' => 'border-width: {{SIZE}}{{UNIT}};border-style: solid;border-radius: 200px;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'border_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'default'      => [
                    'size' => '',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-icon-wrap a i' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_control(
            'border_color',
            [
                'label'     => esc_html__( 'Border Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#9B9B9B5C',
                'selectors' => [
                    '{{WRAPPER}} .cms-icon-wrap a i' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section(); // Style Section End

        // Content Tab End

    }
}
