<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('cmsframe_widget_cms_navigation_menu_register_controls')) {
    add_action('etc_widget_cms_navigation_menu_register_controls', 'cmsframe_widget_cms_navigation_menu_register_controls', 10, 1);
    function cmsframe_widget_cms_navigation_menu_register_controls($widget)
    {
        $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
        if ( is_array( $menus ) && ! empty( $menus ) ) {
            foreach ( $menus as $single_menu ) {
                if ( is_object( $single_menu ) && isset( $single_menu->name, $single_menu->term_id ) ) {
                    $custom_menus[ $single_menu->term_id ] = $single_menu->name;
                }
            }
        } else {
            $custom_menus = '';
        }
        // Content Tab Start

        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_navigation_menu/layout-images/layout1.png'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_navigation_menu/layout-images/layout2.png'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_navigation_menu/layout-images/layout3.png'
                    ],
                    '4' => [
                        'label' => esc_html__('Layout 4', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_navigation_menu/layout-images/layout4.png'
                    ],
                    '5' => [
                        'label' => esc_html__('Layout 5', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_navigation_menu/layout-images/layout5.png'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End
        
        // Icon Section Start
        $widget->start_controls_section(
            'navigation_menu_section',
            [
                'label' => esc_html__('Navigation Menu', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Enter your title', 'validus'),
                'label_block' => true,
                'condition' => [
                    'layout' => ['1','3','5']
                ]
            ]
        );
        $widget->add_control(
            'title_link',
            [
                'label'       => esc_html__( 'Title Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition' => [
                    'layout' => ['1','3','5']
                ]
            ]
        );
        $widget->add_control(
            'menu',
            [
                'label'   => esc_html__( 'Select Menu', 'validus' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => $custom_menus,
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'validus' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'condition' => [
                    'layout' => ['1','3','4']
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-navigation-menu-wrap' => 'text-align: {{VALUE}};justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'align_layout2',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'validus' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'default_args' => [
                    'laptop' => '',
                    'tablet' => '',
                    'tablet_extra' => '',
                    'mobile_extra' => '',
                    'mobile' => ''
                ],
                'condition' => [
                    'layout' => ['2']
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End

        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'content_padding_space',
            [
                'label'        => esc_html__( 'Content Padding Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'condition' => [
                    'layout' => ['5']
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-navigation-menu-wrap' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'link_color',
            [
                'label'     => esc_html__( 'Link Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .cms-navigation-menu-wrap .menu a' => 'color: {{VALUE}} !important;',
                ],
            ]
        );
        $widget->add_control(
            'link_color_hover',
            [
                'label'     => esc_html__( 'Link Color Hover & Active', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-navigation-menu-wrap .menu a:hover, {{WRAPPER}} .cms-navigation-menu-wrap .menu li.current_page_item > a' => 'color: {{VALUE}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'link_padding_space',
            [
                'label'        => esc_html__( 'Link Padding Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 30,
                    ],
                ],
                'condition' => [
                    'layout' => ['5']
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-navigation-menu-wrap .menu a' => 'padding: 0px {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-navigation-menu-title' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Title Typography', 'validus'),
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-navigation-menu-title',
                'fields_options' => [
                    'font_size'   => [
                        'default' => [ 
                            'unit' => 'px', 
                            'size' => '20'
                        ] 
                    ]
                ],
            ]
        );
        $widget->add_responsive_control(
            'title_bottom_space',
            [
                'label'        => esc_html__( 'Title Bottom Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-navigation-menu-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Section End

        // Content Tab End

    }
}
