<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_page_title_register_controls')) {
    add_action('etc_widget_cms_page_title_register_controls', 'validus_widget_cms_page_title_register_controls', 10, 1);
    function validus_widget_cms_page_title_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_page_title/layout-images/layout1.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Icon Section Start
        $widget->start_controls_section(
            'page_title_section',
            [
                'label' => esc_html__('Page Title', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'pagetitle_image',
            [
                'label'   => esc_html__('Background Image', 'validus'),
                'type'    => Controls_Manager::MEDIA,
                'description' => esc_html__('Select image icon.', 'validus'),
                'default' => [
                    'url' => get_template_directory_uri() . '/assets/images/1870491403.jpg'
                ]
            ]
        );
        $widget->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_overlay_size` and `image_overlay_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );
        $widget->add_control(
            'background_color',
            [
                'label'   => esc_html__('Background Color Overlay', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-page-title-wrap:before' => 'background-color: {{VALUE}};',
                ],
                'default' => ''//#181515
            ]
        );
        $widget->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('Leadership', 'validus'),
                'placeholder' => esc_html__('Enter your title', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'description',
            [
                'label'   => esc_html__('Description', 'validus'),
                'type'    => Controls_Manager::TEXTAREA,
                'default'     => esc_html__('Our worldwide presence ensures timeliness, cost efficiency and compliance adherence required to ensure your serving you with great expertise as one of the World\'s leading Corporation!                ', 'validus'),
                'placeholder' => esc_html__('Enter your description', 'validus'),
                'rows'        => 8,
                'show_label'  => true,
            ]
        );
        $widget->add_control(
            'btn_text',
            [
                'label'   => esc_html__('Button Text', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Awards And Milestones'
            ]
        );
        $widget->add_control(
            'btn_link_type',
            [
                'label'   => esc_html__('Button Link Type', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'custom' => esc_html__('Custom', 'validus'),
                    'page' => esc_html__('Page', 'validus'),
                ],
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'btn_page_link',
            [
                'label'   => esc_html__('Select Page', 'validus'),
                'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                'post_types' => [
                    'page',
                    'post',
                ],
                'multiple' => true,
                'condition' => [
                    'btn_link_type' => 'page'
                ],
            ]
        );
        $widget->add_control(
            'btn_link',
            [
                'label'   => esc_html__('Button Link', 'validus'),
                'type'    => Controls_Manager::URL,
                'condition' => [
                    'btn_link_type' => 'custom'
                ],
            ]
        );
        $widget->add_control(
            'btn_text2',
            [
                'label'       => esc_html__( 'Button Text 2', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter text', 'validus' ),
                'rows'        => 10,
                'show_label'  => true,
                'default'     => 'Contact Us',
            ]
        );
        $widget->add_control(
            'btn_link2',
            [
                'label'   => esc_html__('Button Link Text 2', 'validus'),
                'type'    => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End



        // Box Section Start
        $widget->start_controls_section(
            'box_section',
            [
                'label' => esc_html__('Box Spacing', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'top_space',
            [
                'label'        => esc_html__( 'Top Spacing', 'validus' ),
                'description'  => esc_html__( 'Default: 139px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '139',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 250,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-wrap' => 'padding-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-page-title-top-space' => 'padding-top: {{SIZE}}{{UNIT}};',
                    
                    /***************************IF NOT USE JAVASCRIPT***************************
                    '{{WRAPPER}} .cms-page-title-wrap:not(.header-transparent)' => 'padding-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-page-title-wrap.header-transparent' => 'padding-top: calc({{SIZE}}px + var(--header-height));',
                    ***************************************************************************/
                ],
                'separator' => 'after',
            ]
        );
        $widget->add_responsive_control(
            'bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '32',
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 250,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-wrap' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->end_controls_section();
        // Box Section End


        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Element Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
			'max_width',
			[
				'label' => esc_html__( 'Width Content', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => ''//39.5
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				
				'selectors' => [
					'{{WRAPPER}} .cms-page-title-content' => 'max-width: {{SIZE}}%',
				],
			]
		);
        $widget->add_responsive_control(
            'align_content',
            [
                'label'        => esc_html__( 'Content Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-content-align' => 'display:flex; justify-content: {{VALUE}}; text-align: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'align_title',
            [
                'label'        => esc_html__( 'Title Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-title' => 'text-align: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'title!' => ''
                ],
            ]
        );
        $widget->add_responsive_control(
            'title_bottom_space',
            [
                'label'        => esc_html__( 'Title Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '17',
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'title!' => ''
                ],
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-page-title-title' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'title!' => ''
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Title Typography', 'validus'),
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-page-title-title',
                'separator' => 'after',
                'condition' => [
                    'title!' => ''
                ],
            ]
        );
        $widget->add_responsive_control(
            'align_description',
            [
                'label'        => esc_html__( 'Description Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default'      => 'start',
                'condition' => [
                    'description!' => ''
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-description' => 'text-align: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'description_right_space',
            [
                'label'        => esc_html__( 'Description Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'description!' => ''
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-description' => 'margin-inline-end: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'description_bottom_space',
            [
                'label'        => esc_html__( 'Description Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '29',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'description!' => ''
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'description_color',
            [
                'label'   => esc_html__('Description Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-page-title-description' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'description!' => ''
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Description Typography', 'validus'),
                'name' => 'description_typography',
                'selector'     => '{{WRAPPER}} .cms-page-title-description',
                'condition' => [
                    'description!' => ''
                ],
                'separator' => 'after',
            ]
        );

        $widget->add_control(
            'show_breadcrumb',
            [
                'label' => esc_html__( 'Show Breadcrumb', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'align_breadcumb',
            [
                'label'        => esc_html__( 'Breadcrumb Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'condition' => [
                    'show_breadcrumb' => 'yes',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-breadcrumb-wrap' => 'display:flex; justify-content: {{VALUE}};',
                ],
            ]
        );
        $input_selectors = [
			'{{WRAPPER}} .cms-page-title-breadcrumb',
			'{{WRAPPER}} .cms-page-title-breadcrumb a',
			'{{WRAPPER}} .cms-page-title-breadcrumb span',
			'{{WRAPPER}} .cms-breadcrumb-wrap .cms-breadcrumb li .breadcrumb-entry',
		];
        $input_selector = implode( ',', $input_selectors );
        $widget->add_control(
            'breadcrumb_color',
            [
                'label'   => esc_html__('Breadcrumb Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    $input_selector => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'breadcrumb_bottom_space',
            [
                'label'        => esc_html__( 'Breadcrumb Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '100',
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-breadcrumb' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'button_section',
            [
                'label' => esc_html__('Button', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'button_align',
            [
                'label'        => esc_html__( 'Button Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default'      => 'start',
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button' => 'text-align: {{VALUE}};justify-content: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'button_left_space',
            [
                'label'        => esc_html__( 'Button Primary Left Spacing', 'validus' ),
                'description'  => esc_html__( 'Default: 30px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary' => 'padding-inline-start: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'button_right_space',
            [
                'label'        => esc_html__( 'Button Primary Right Spacing', 'validus' ),
                'description'  => esc_html__( 'Default: 30px;', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $widget->add_control(
            'button_primary_background',
            [
                'label'   => esc_html__('Button Primary Background', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary' => 'background: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_background_hover',
            [
                'label'     => esc_html__('Button Primary Background Hover', 'validus'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_text_color',
            [
                'label'   => esc_html__('Button Primary Text Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_text_color_hover',
            [
                'label'   => esc_html__('Button Primary Text Color Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-primary:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        //button secondary
        $widget->add_control(
            'button_secondary_background',
            [
                'label'   => esc_html__('Button Secondary Background', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-white' => 'background: {{VALUE}};',
                ],
                'separator' => 'before'
            ]
        );

        $widget->add_control(
            'button_secondary_background_hover',
            [
                'label'   => esc_html__('Button Secondary Background Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-white:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_secondary_text_color',
            [
                'label'   => esc_html__('Button Secondary Text Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-white' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_secondary_text_color_hover',
            [
                'label'   => esc_html__('Button Secondary Text Color Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors'    => [
                    '{{WRAPPER}} .cms-page-title-button .btn-white:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $widget->end_controls_section();

        // Content Tab End

    }
}
