<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_post_carousel_register_controls')) {
    add_action('etc_widget_cms_post_carousel_register_controls', 'validus_widget_cms_post_carousel_register_controls', 10, 1);
    function validus_widget_cms_post_carousel_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout3.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__( 'Layout 4', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout4.jpg'
                    ],
                    '5' => [
                        'label' => esc_html__( 'Layout 5', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout5.jpg'
                    ],
                    '6' => [
                        'label' => esc_html__( 'Layout 6', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_carousel/layout-images/layout6.jpg'
                    ],
                ],
            ]
        );

        $widget->end_controls_section();
        // Layout Section End

        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'heading_text',
            [
                'label'       => esc_html__( 'Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'This is the heading', 'validus' ),
                'placeholder' => esc_html__( 'Enter your heading', 'validus' ),
                'label_block' => true,
            ]
        );
        $widget->end_controls_section();
        // Heading Section     
        
        // Content Tab Start
        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $widget->add_control(
            'post_type',
            [
                'label'    => esc_html__( 'Select Post Type', 'validus' ),
                'type'     => \Elementor\Controls_Manager::SELECT,
                'multiple' => true,
                'options'  => etc_get_post_type_options(),
                'default'  => 'post'
            ]
        );

        $array = validus_get_grid_term_by_post_type_options();
        foreach($array as $item) {
            $widget->add_control(
                $item['name'],
                [
                    'label' => $item['label'],
                    'type' => $item['type'],
                    'multiple' => $item['multiple'],
                    'options' => $item['options'],
                    'condition' => $item['condition']
                ]
            );
        }

        $widget->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('Date', 'validus'),
                    'ID' => esc_html__('ID', 'validus'),
                    'author' => esc_html__('Author', 'validus'),
                    'title' => esc_html__('Title', 'validus'),
                    'rand' => esc_html__('Random', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label' => esc_html__('Sort Order', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'validus'),
                    'asc' => esc_html__('Ascending', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label' => esc_html__('Total items', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'show_thumbnail',
            [
                'label' => esc_html__('Show Thumbnail', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => [
                    'layout' => ['2']
                ],
            ]
        );
        $widget->add_control(
            'show_title',
            [
                'label' => esc_html__('Show Title', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'title_tag',
            [
                'label' => esc_html__('HTML Tag', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'condition' => [
                    'show_title' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_excerpt',
            [
                'name' => 'show_excerpt',
                'label' => esc_html__('Show Excerpt', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => [
                    'layout' => ['1','3'],
                ],
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'num_words',
            [
                'label' => esc_html__('Number Of Characters (Content)', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 110,
                'condition' => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_categories',
            [
                'label' => esc_html__('Show Categories', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before',
                'condition' => [
                    'layout' => ['2','4']
                ],
            ]
        );
        $widget->end_controls_section();
        // Display Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'show_full',
            [
                'label' => esc_html__('Show Full', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'left' => esc_html__('Left', 'validus'),
                    'right' => esc_html__('Right', 'validus'),
                ],
                'default' => '',
            ]
        );
        $widget->add_responsive_control(
            'show_full_left',
            [
                'label' => esc_html__('Show Full Left', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'default' => [
                    'size' => '423',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel' => 'margin-inline-start: -{{SIZE}}{{UNIT}};margin-inline-end: auto;',
                ],
                'condition' => [
                    'show_full' => 'left',
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_full_right',
            [
                'label' => esc_html__('Show Full Right', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'default' => [
                    'size' => '423',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel' => 'margin-inline-start: auto;margin-inline-end: -{{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_full' => 'right',
                ],
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'default_args' => [
                    'laptop' => '',
                    'tablet_extra' => '',
                    'tablet' => '',
                    'mobile_extra' => '',
                    'mobile' => ''
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Style Tab Start
        // Naivgation Section Start

        $widget->start_controls_section(
            'general_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'general_style',
            [
                'label'   => esc_html__('Text Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options'   => [
                    'var(--body-font-color)' => 'Default',
                    'var(--color-secondary)' => 'Black',
                    '#fff' => 'White',
                ],
                'default'   => 'var(--body-font-color)',
                'selectors' => [
                    '{{WRAPPER}} .cms-post-carousel-heading' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-title a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-content' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'carousel_tools_top_space_layout5',
            [
                'label' => esc_html__('Tool Top Spacing', 'validus'),
                'description' => esc_html__('The tool contains arrows & dots', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -10,
                        'max' => 150,
                    ],
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-tool' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => ['5']
                ],
            ]
        );
        $widget->add_responsive_control(
            'carousel_tools_top_space',
            [
                'label' => esc_html__('Tool Top Spacing', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'description' => 'The tool contains arrow & dots, default is 30px',
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -10,
                        'max' => 150,
                    ],
                ],
                'default' => [
                    'size' => '30'
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-tool' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block',
                    'layout!' => ['3','5']
                ],
            ]
        );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content Area', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'title_full',
            [
                'label'    => esc_html__( 'Show Full Title', 'validus' ),
                'type'     => \Elementor\Controls_Manager::SELECT,
                'options'  => [
					'initial' => esc_html__( 'Yes', 'validus' ),
					'1' => esc_html__( 'No', 'validus' ),
				],
                'default'  => '1',
                'selectors' => [
					'{{WRAPPER}} .item-title' => '-webkit-line-clamp: {{SIZE}}',
				],
                'condition' => [
                    'layout' => ['4']
                ],
            ]
        );
        $widget->add_responsive_control(
			'title_width',
			[
				'label' => esc_html__( 'Title Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => ''
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .item-title' => 'max-width: {{SIZE}}%',
				],
			]
		);
        $widget->add_control(
            'title_color',
            [
                'label'     => esc_html__( 'Title Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-title a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-title a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'title_color_hover',
            [
                'label'     => esc_html__( 'Title Color Hover', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => 'var(--color-primary)',
                'selectors' => [
                    '{{WRAPPER}} .item-title:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-title:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => 'Title Typography',
                'selector'     => '{{WRAPPER}} .item-title',
            ]
        );
        
        $widget->add_responsive_control(
			'content_width',
			[
				'label' => esc_html__( 'Content Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => ''
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .item-content' => 'max-width: {{SIZE}}%',
				],
			]
		);
        $widget->add_control(
            'content_color',
            [
                'label'     => esc_html__( 'Content Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-content' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-body .item-content' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => 'Content Typography',
                'selector'     => '{{WRAPPER}} .item-content',
            ]
        );
        $widget->add_responsive_control(
            'content_l_space',
            [
                'label'        => esc_html__( 'Content Left Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 41,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-body' => 'padding-inline-start: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_r_space',
            [
                'label'        => esc_html__( 'Content Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 41,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-body' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Heading Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'heading_text!' => '',
                ],
            ]
        );
        $widget->add_control(
            'heading_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => 0,
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'heading_text!' => '',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-carousel-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    'heading_text!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-post-carousel-heading' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'condition' => [
                    'heading_text!' => '',
                ],
                'selector'     => '{{WRAPPER}} .cms-post-carousel-heading',
            ]
        );
        $widget->end_controls_section();


        //Read More
        $widget->start_controls_section(
            'style_readmore',
            [
                'label' => esc_html__('Read More', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['1','5','6']
                ]
            ]
        );
        $widget->add_responsive_control(
            'readmore_show',
            [
                'label'        => esc_html__( 'Show On Small Screen', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'flex',
                'options'      => [
                    'flex'     => 'Yes',
                    'none'     => 'No'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-featured .item-readmore' => 'display: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'readmore_position_top',
            [
                'label'        => esc_html__( 'Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '30',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-featured .item-readmore' => 'top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .item-readmore' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => '5',
                    'readmore_show' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'readmore_position_right',
            [
                'label'        => esc_html__( 'Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '30',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .item-featured .item-readmore' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .item-featured .item-readmore' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                    'body:not(.rtl) {{WRAPPER}} .item-readmore' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .item-readmore' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
                'condition' => [
                    'layout' => '5',
                    'readmore_show' => 'flex'
                ],
            ]
        );
        $widget->end_controls_section();
        //Read More


        $widget->start_controls_section(
            'heading_style_arrow',
            [
                'label' => esc_html__('Arrows', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_show',
            [
                'label'        => esc_html__( 'Show On Small Screen', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'flex',
                'options'      => [
                    'flex'     => 'Yes',
                    'none'     => 'No'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'display: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_style',
            [
                'label'        => esc_html__( 'Arrow Style', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'row',
                'separator'    => 'before',
                'options'      => [
                    'row'      => '1 Line',
                    'column'   => '2 Line'
                ],
                'condition' => [
                    'layout' => ['1','4','5','6'],
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'flex-direction: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position',
            [
                'label'        => esc_html__( 'Arrow Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'right',
                'separator'    => 'before',
                'options'      => [
                    'left'     => 'Left',
                    'right'    => 'Right'
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'layout' => ['1','5','6']
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_left',
            [
                'label'        => esc_html__( 'Arrow Left Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 30,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 900,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
                    
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'arrow_position' => 'left',
                    'layout' => ['1','5','6']
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_right',
            [
                'label'        => esc_html__( 'Arrow Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => -100,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 900,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'arrow_position' => 'right',
                    'layout' => ['1','6']
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_right_layout5',
            [
                'label'        => esc_html__( 'Arrow Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -100,
                        'max' => 900,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'arrow_position' => 'right',
                    'layout' => ['5']
                ]
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_top',
            [
                'label'        => esc_html__( 'Arrow Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 200,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'condition' => [
                    'layout' => ['1','6'],//,'4','5'
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_top_layout5',
            [
                'label'        => esc_html__( 'Arrow Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -500,
                        'max' => 800,
                    ],
                ],
                'condition' => [
                    'layout' => ['5'],//,'4','5'
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_top_layout3',
            [
                'label'        => esc_html__( 'Arrow Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '30',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'condition' => [
                    'layout' => '3',
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'top: -{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_top_space_layout3',
            [
                'label' => esc_html__('Tool Top Spacing', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -10,
                        'max' => 150,
                    ],
                ],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-tool' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrow' => 'yes',
                    'arrow_show' => 'flex',
                    'layout' => ['3']
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_lr_space_layout3',
            [
                'label'        => esc_html__( 'Arrow Left-Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 40,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout' => '3',
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-tool' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrows_size',
            [
                'label' => esc_html__('Size', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 60,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrow_show' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrows_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'layout!' => '6'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrows_prev_color',
            [
                'label' => esc_html__('Prev Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'layout' => '6'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrows_next_color',
            [
                'label' => esc_html__('Next Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'arrow_show' => 'flex',
                    'layout' => '6'
                ],
            ]
        );
        $widget->add_responsive_control(
            'gap',
            [
                'label'        => esc_html__( 'Gap', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 20,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'layout' => ['1','4','5','6'],
                    'arrow_show' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();

        
        $widget->start_controls_section(
            'heading_style_dots',
            [
                'label' => esc_html__('Dots', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_dots_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
		$widget->add_responsive_control(
			'dots_align',
			array(
				'label'     => esc_html__( 'Alignment', 'validus' ),
				'type'      => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'condition'   => array(
					'dots' => 'yes',
                    'show_dots_mobile' => 'block'
				),
				'selectors' => [
					'{{WRAPPER}} .cms-carousel-dots' => 'text-align: {{VALUE}};flex-basis: 100%;',
				],
			)
		);
        $widget->add_control(
            'dots_size',
            [
                'label' => esc_html__('Size', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 10,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    // The opacity property will override the default inactive dot color which is opacity 0.2.
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'dots_color',
            [
                'label' => esc_html__('Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet-active' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->end_controls_section();
        // Naivgation Section End
        // Style Tab End
    }
}
