<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if (!function_exists('validus_widget_cms_post_image_register_controls')) {
    add_action('etc_widget_cms_post_image_register_controls', 'validus_widget_cms_post_image_register_controls', 10, 1);
    function validus_widget_cms_post_image_register_controls($widget)
    {
        // Post Image Section Start
        $widget->start_controls_section(
            'section_post_image',
            [
                'label' => esc_html__('Post Image', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'full',
            ]
        );
        $widget->add_responsive_control(
            'img_width',
            [
                'label'   => esc_html__('Width', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'initial',
				'options' => [
					'initial' => esc_html__( 'Default', 'validus' ),
					'100%' => esc_html__( '100%', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-post-image-container > img' => 'width: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'min_height',
            [
                'label'        => esc_html__( 'Min Box Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 100,
                        'max' => 800,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-image-wrap' => 'min-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-post-image-container > img' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'img_max_height',
            [
                'label'        => esc_html__( 'Max Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px', '%' ],
                'range'        => [
                    'px' => [
                        'min' => 50,
                        'max' => 2000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-image-wrap img' => 'max-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'border_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-image-container > img' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                    '{{WRAPPER}} .cms-post-image-container .cms-post-image-bg' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'opacity',
            [
                'label'        => esc_html__( 'Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '100',
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-image-container' => 'opacity: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __( 'Box Shadow', 'validus' ),
                'selector' => '{{WRAPPER}} .cms-post-image-container img',
            ]
        );
        $widget->add_responsive_control(
            'show_responsive',
            [
                'label'   => esc_html__('Show On Responsive', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-post-image-wrap' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-post-image-wrap' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Post Image Section End
    }
}
