<?php
use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_price_table_register_controls')) {
    add_action('etc_widget_cms_price_table_register_controls', 'validus_widget_cms_price_table_register_controls', 10, 1);
    function validus_widget_cms_price_table_register_controls($widget)
    {
		$widget->start_controls_section(
			'section_header',
			[
				'label' => esc_html__( 'Header', 'validus' ),
			]
		);

		$widget->add_control(
			'heading',
			[
				'label' => esc_html__( 'Title', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Starter Plan', 'validus' ),
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'sub_heading',
			[
				'label' => esc_html__( 'Description', 'validus' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => "Our highly trained technicians will set-up your security system, they'll show how to work your equipment so you're up to",
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true
			]
		);

		$widget->add_control(
			'heading_tag',
			[
				'label' => esc_html__( 'Title HTML Tag', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h3',
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_pricing',
			[
				'label' => esc_html__( 'Pricing', 'validus' ),
			]
		);

		$widget->add_control(
			'currency_symbol',
			[
				'label' => esc_html__( 'Currency Symbol', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'None', 'validus' ),
					'dollar' => '&#36; ' . _x( 'Dollar', 'Currency', 'validus' ),
					'euro' => '&#128; ' . _x( 'Euro', 'Currency', 'validus' ),
					'baht' => '&#3647; ' . _x( 'Baht', 'Currency', 'validus' ),
					'franc' => '&#8355; ' . _x( 'Franc', 'Currency', 'validus' ),
					'guilder' => '&fnof; ' . _x( 'Guilder', 'Currency', 'validus' ),
					'krona' => 'kr ' . _x( 'Krona', 'Currency', 'validus' ),
					'lira' => '&#8356; ' . _x( 'Lira', 'Currency', 'validus' ),
					'peseta' => '&#8359 ' . _x( 'Peseta', 'Currency', 'validus' ),
					'peso' => '&#8369; ' . _x( 'Peso', 'Currency', 'validus' ),
					'pound' => '&#163; ' . _x( 'Pound Sterling', 'Currency', 'validus' ),
					'real' => 'R$ ' . _x( 'Real', 'Currency', 'validus' ),
					'ruble' => '&#8381; ' . _x( 'Ruble', 'Currency', 'validus' ),
					'rupee' => '&#8360; ' . _x( 'Rupee', 'Currency', 'validus' ),
					'indian_rupee' => '&#8377; ' . _x( 'Rupee (Indian)', 'Currency', 'validus' ),
					'shekel' => '&#8362; ' . _x( 'Shekel', 'Currency', 'validus' ),
					'yen' => '&#165; ' . _x( 'Yen/Yuan', 'Currency', 'validus' ),
					'won' => '&#8361; ' . _x( 'Won', 'Currency', 'validus' ),
					'custom' => esc_html__( 'Custom', 'validus' ),
				],
				'default' => 'dollar',
			]
		);

		$widget->add_control(
			'currency_symbol_custom',
			[
				'label' => esc_html__( 'Custom Symbol', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'currency_symbol' => 'custom',
				],
			]
		);

		$widget->add_control(
			'price',
			[
				'label' => esc_html__( 'Price', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'default' => '150',
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'currency_format',
			[
				'label' => esc_html__( 'Currency Format', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => '1,234.56 (Default)',
					',' => '1.234,56',
				],
			]
		);

		$widget->add_control(
			'sale',
			[
				'label' => esc_html__( 'Sale', 'validus' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'validus' ),
				'label_off' => esc_html__( 'Off', 'validus' ),
				'default' => '',
			]
		);

		$widget->add_control(
			'original_price',
			[
				'label' => esc_html__( 'Original Price', 'validus' ),
				'type' => Controls_Manager::NUMBER,
				'default' => '59',
				'condition' => [
					'sale' => 'yes',
				],
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'period',
			[
				'label' => esc_html__( 'Period', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => esc_html__( '/Mo', 'validus' ),
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_features',
			[
				'label' => esc_html__( 'Features', 'validus' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_text',
			[
				'label' => esc_html__( 'Text', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => esc_html__( 'List Item', 'validus' ),
			]
		);

		$default_icon = [
			'value' => 'cmsi cmsi-check-mark',
			'library' => 'cmsi',
		];

		$repeater->add_control(
			'selected_item_icon',
			[
				'label' => esc_html__( 'Icon', 'validus' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'item_icon',
				'default' => $default_icon,
			]
		);

		$repeater->add_control(
			'item_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} svg' => 'fill: {{VALUE}}',
				],
			]
		);

		$widget->add_control(
			'features_list',
			[
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'item_text' => esc_html__( 'Enterprise Network Video Recorders', 'validus' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => esc_html__( 'Intelligent video technology storage', 'validus' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => esc_html__( 'Streaming over network or Internet', 'validus' ),
						'selected_item_icon' => $default_icon,
					],
				],
				'title_field' => '{{{ item_text }}}',
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_footer',
			[
				'label' => esc_html__( 'Footer', 'validus' ),
			]
		);

		$widget->add_control(
			'button_text',
			[
				'label' => esc_html__( 'Button Text', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Get Started Now', 'validus' ),
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'link',
			[
				'label' => esc_html__( 'Link', 'validus' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
				'default' => [
					'url' => '#',
				],
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'footer_additional_info',
			[
				'label' => esc_html__( 'Additional Info', 'validus' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html( '' ),
				'rows' => 3,
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_ribbon',
			[
				'label' => esc_html__( 'Ribbon', 'validus' ),
			]
		);

		$widget->add_control(
			'show_ribbon',
			[
				'label' => esc_html__( 'Show', 'validus' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'ribbon_title',
			[
				'label' => esc_html__( 'Title', 'validus' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Best Value', 'validus' ),
				'condition' => [
					'show_ribbon' => 'yes',
				],
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$widget->add_control(
			'ribbon_horizontal_position',
			[
				'label' => esc_html__( 'Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'condition' => [
					'show_ribbon' => 'yes',
				],
			]
		);

		$widget->end_controls_section();


		$widget->start_controls_section(
			'section_general_style',
			[
				'label' => esc_html__( 'General', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

        $widget->add_control(
            'general_bg_image',
            [
                'label' => esc_html__('Background Image', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    //'url' => Utils::get_placeholder_image_src(),
					'url' => get_template_directory_uri() . '/assets/images/1870491403.jpg'
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
		$widget->add_control(
			'general_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table' => 'background-color: {{VALUE}};',
				],
			]
		);
        $widget->add_control(
            'opacity',
            [
                'label'        => esc_html__( 'Background Image Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '7',//15
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table-background img' => 'opacity: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'height',
            [
                'label'        => esc_html__( 'Box Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$widget->add_responsive_control(
			'general_padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'default' => [
                    'top' => 77,
					'right' => 50,
					'bottom' => 68,
					'left' => 50,
                    'unit' => 'px'
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$widget->add_control(
			'general_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);

		$widget->end_controls_section();


		$widget->start_controls_section(
			'section_header_style',
			[
				'label' => esc_html__( 'Header', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$widget->add_control(
			'header_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__header' => 'background-color: {{VALUE}}',
				],
			]
		);

		$widget->add_responsive_control(
			'header_padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->add_control(
			'heading_heading_style',
			[
				'label' => esc_html__( 'Title', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'heading_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__heading' => 'color: {{VALUE}}',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'heading_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__heading',
			]
		);

        $widget->add_control(
            'heading_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__heading' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$widget->add_control(
			'heading_sub_heading_style',
			[
				'label' => esc_html__( 'Sub Title', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'sub_heading_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__subheading' => 'color: {{VALUE}}',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_heading_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__subheading',
			]
		);

        $widget->add_control(
            'sub_heading_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__subheading' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_pricing_element_style',
			[
				'label' => esc_html__( 'Pricing', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$widget->add_control(
			'pricing_element_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__price' => 'background-color: {{VALUE}}',
				],
			]
		);

		$widget->add_responsive_control(
			'pricing_element_padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->add_control(
			'price_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__currency, {{WRAPPER}} .cms-price-table__integer-part, {{WRAPPER}} .cms-price-table__fractional-part' => 'color: {{VALUE}}',
				],
				'separator' => 'before',
			]
		);
		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'price_typography',
				// Targeting also the .cms-price-table class in order to get a higher specificity from the inline CSS.
				'selector' => '{{WRAPPER}} .cms-price-table .cms-price-table__price',
			]
		);

		$widget->add_control(
			'heading_currency_style',
			[
				'label' => esc_html__( 'Currency Symbol', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'currency_symbol!' => '',
				],
			]
		);

		$widget->add_control(
			'currency_size',
			[
				'label' => esc_html__( 'Size', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__price > .cms-price-table__currency' => 'font-size: calc({{SIZE}}em/100)',
				],
				'condition' => [
					'currency_symbol!' => '',
				],
			]
		);

		$widget->add_control(
			'currency_position',
			[
				'label' => esc_html__( 'Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'before',
				'options' => [
					'before' => [
						'title' => esc_html__( 'Before', 'validus' ),
						'icon' => 'eicon-h-align-left',
					],
					'after' => [
						'title' => esc_html__( 'After', 'validus' ),
						'icon' => 'eicon-h-align-right',
					],
				],
			]
		);

		$widget->add_control(
			'currency_vertical_position',
			[
				'label' => esc_html__( 'Vertical Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => esc_html__( 'Top', 'validus' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'validus' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'validus' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'default' => 'top',
				'selectors_dictionary' => [
					'top' => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__currency' => 'align-self: {{VALUE}}',
				],
				'condition' => [
					'currency_symbol!' => '',
				],
			]
		);

		$widget->add_control(
			'fractional_part_style',
			[
				'label' => esc_html__( 'Fractional Part', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'fractional-part_size',
			[
				'label' => esc_html__( 'Size', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__fractional-part' => 'font-size: calc({{SIZE}}em/100)',
				],
			]
		);

		$widget->add_control(
			'fractional_part_vertical_position',
			[
				'label' => esc_html__( 'Vertical Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => esc_html__( 'Top', 'validus' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'validus' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'validus' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'default' => 'top',
				'selectors_dictionary' => [
					'top' => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__after-price' => 'justify-content: {{VALUE}}',
				],
			]
		);

		$widget->add_control(
			'heading_original_price_style',
			[
				'label' => esc_html__( 'Original Price', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'sale' => 'yes',
					'original_price!' => '',
				],
			]
		);

		$widget->add_control(
			'original_price_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__original-price' => 'color: {{VALUE}}',
				],
				'condition' => [
					'sale' => 'yes',
					'original_price!' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'original_price_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__original-price',
				'condition' => [
					'sale' => 'yes',
					'original_price!' => '',
				],
			]
		);

		$widget->add_control(
			'original_price_vertical_position',
			[
				'label' => esc_html__( 'Vertical Position', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => esc_html__( 'Top', 'validus' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'validus' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'validus' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'selectors_dictionary' => [
					'top' => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'default' => 'bottom',
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__original-price' => 'align-self: {{VALUE}}',
				],
				'condition' => [
					'sale' => 'yes',
					'original_price!' => '',
				],
			]
		);

		$widget->add_control(
			'heading_period_style',
			[
				'label' => esc_html__( 'Period', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$widget->add_control(
			'period_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__period' => 'color: {{VALUE}}',
				],
				'condition' => [
					'period!' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'period_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__period',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$widget->add_control(
			'period_position',
			[
				'label' => esc_html__( 'Position', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => false,
				'options' => [
					'below' => esc_html__( 'Below', 'validus' ),
					'beside' => esc_html__( 'Beside', 'validus' ),
				],
				'default' => 'beside',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_features_list_style',
			[
				'label' => esc_html__( 'Features', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$widget->add_control(
			'features_list_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list' => 'background-color: {{VALUE}}',
				],
			]
		);

		$widget->add_responsive_control(
			'features_list_padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->add_control(
			'features_list_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list' => 'color: {{VALUE}}',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'features_list_typography',
				'label' => 'Features List Typography',
				'selector' => '{{WRAPPER}} .cms-price-table__features-list .cms-price-table__feature-inner',
			]
		);

		$widget->add_control(
			'features_list_alignment',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list' => 'text-align: {{VALUE}}',
				],
			]
		);

		$widget->add_responsive_control(
			'item_width',
			[
				'label' => esc_html__( 'Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'%' => [
						'min' => 25,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__feature-inner' => 'margin-left: calc((100% - {{SIZE}}%)/2); margin-right: calc((100% - {{SIZE}}%)/2)',
				],
			]
		);

        $widget->add_control(
            'features_gap_items',
            [
                'label'        => esc_html__( 'Gap Between Items', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '10',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__features-list' => 'display: flex;flex-direction: column;gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_control(
            'features_gap_item',
            [
                'label'        => esc_html__( 'Gap Between Icon & Text', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '10',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__feature-inner' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_control(
            'icon_size',
            [
                'label'        => esc_html__( 'Icon Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '23',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__feature-inner i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$widget->add_control(
			'list_divider',
			[
				'label' => esc_html__( 'Divider', 'validus' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'divider_style',
			[
				'label' => esc_html__( 'Style', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'solid' => esc_html__( 'Solid', 'validus' ),
					'double' => esc_html__( 'Double', 'validus' ),
					'dotted' => esc_html__( 'Dotted', 'validus' ),
					'dashed' => esc_html__( 'Dashed', 'validus' ),
				],
				'default' => 'solid',
				'condition' => [
					'list_divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list li:before' => 'border-top-style: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'divider_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ddd',
				'condition' => [
					'list_divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list li:before' => 'border-top-color: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'divider_weight',
			[
				'label' => esc_html__( 'Weight', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', 'rem', 'custom' ],
				'default' => [
					'size' => 2,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 10,
					],
				],
				'condition' => [
					'list_divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list li:before' => 'border-top-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$widget->add_control(
			'divider_width',
			[
				'label' => esc_html__( 'Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'list_divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list li:before' => 'margin-left: calc((100% - {{SIZE}}%)/2); margin-right: calc((100% - {{SIZE}}%)/2)',
				],
			]
		);

		$widget->add_control(
			'divider_gap',
			[
				'label' => esc_html__( 'Gap', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', 'rem', 'custom' ],
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 50,
					],
				],
				'condition' => [
					'list_divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__features-list li:before' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_footer_style',
			[
				'label' => esc_html__( 'Footer (Contain Button)', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

        $widget->add_control(
            'footer_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '20',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-price-table__footer' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$widget->add_control(
			'footer_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__footer' => 'background-color: {{VALUE}}',
				],
			]
		);

		$widget->add_responsive_control(
			'footer_padding',
			[
				'label' => esc_html__( 'Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__footer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->add_control(
			'heading_footer_button',
			[
				'label' => esc_html__( 'Button', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'button_text!' => '',
				],
			]
		);
        $widget->add_control(
            'btn_icon',
            [
                'label'            => esc_html__( 'Button Icon', 'validus' ),
                'type'             => Controls_Manager::ICONS,
                'label_block'      => true,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'library' => 'cmsi',
                    'value'   => 'cmsi-chevron-circle-right-01'
                ]
            ]
        );
		$widget->add_control(
			'button_size',
			[
				'label' => esc_html__( 'Size', 'validus' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'xsm' => esc_html__( 'Extra Small', 'validus' ),
					'sm' => esc_html__( 'Small', 'validus' ),
					'' => esc_html__( 'Medium', 'validus' ),
					'lg' => esc_html__( 'Large', 'validus' ),
				],
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$widget->start_controls_tabs( 'tabs_button_style' );

		$widget->start_controls_tab(
			'tab_button_normal',
			[
				'label' => esc_html__( 'Normal', 'validus' ),
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$widget->add_control(
			'button_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__button' => 'color: {{VALUE}};',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__button',
			]
		);

		$widget->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_background',
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .cms-price-table__button',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Border::get_type(), [
				'name' => 'button_border',
				'selector' => '{{WRAPPER}} .cms-price-table__button',
				'separator' => 'before',
			]
		);

		$widget->add_control(
			'button_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);

		$widget->add_control(
			'button_text_padding',
			[
				'label' => esc_html__( 'Text Padding', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->end_controls_tab();

		$widget->start_controls_tab(
			'tab_button_hover',
			[
				'label' => esc_html__( 'Hover', 'validus' ),
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$widget->add_control(
			'button_hover_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_background_hover',
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .cms-price-table__button:hover',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);

		$widget->add_control(
			'button_hover_border_color',
			[
				'label' => esc_html__( 'Border Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$widget->add_control(
			'button_hover_animation',
			[
				'label' => esc_html__( 'Animation', 'validus' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$widget->end_controls_tab();

		$widget->end_controls_tabs();

		$widget->add_control(
			'heading_additional_info',
			[
				'label' => esc_html__( 'Additional Info', 'validus' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$widget->add_control(
			'additional_info_color',
			[
				'label' => esc_html__( 'Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__additional_info' => 'color: {{VALUE}}',
				],
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'additional_info_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__additional_info',
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$widget->add_control(
			'additional_info_margin',
			[
				'label' => esc_html__( 'Margin', 'validus' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'default' => [
					'top' => 15,
					'right' => 30,
					'bottom' => 0,
					'left' => 30,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__additional_info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'section_ribbon_style',
			[
				'label' => esc_html__( 'Ribbon', 'validus' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_ribbon' => 'yes',
				],
			]
		);

		$widget->add_control(
			'ribbon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__ribbon-inner' => 'background-color: {{VALUE}}',
				],
			]
		);

		$ribbon_distance_transform = 'translateY(-100%) rotate(0deg)';

		$widget->add_responsive_control(
			'ribbon_distance',
			[
				'label' => esc_html__( 'Distance', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'condition' => [
					'ribbon_horizontal_position' => 'center'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__ribbon-inner' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$ribbon_distance_transform = is_rtl() ? 'translateY(-50%) translateX({{SIZE}}{{UNIT}}) rotate(-45deg)' : 'translateY(-50%) translateX(-50%) translateX({{SIZE}}{{UNIT}}) rotate(-45deg)';

		$widget->add_responsive_control(
			'ribbon_distance1',
			[
				'label' => esc_html__( 'Distance', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'ribbon_horizontal_position',
                            'operator' => '==',
                            'value' => 'left',
                        ],
                        [
                            'name' => 'ribbon_horizontal_position',
                            'operator' => '==',
                            'value' => 'right',
                        ],
                    ],
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__ribbon-inner' => 'margin-top: {{SIZE}}{{UNIT}}; transform: ' . $ribbon_distance_transform,
				],
			]
		);

		$widget->add_control(
			'ribbon_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .cms-price-table__ribbon-inner' => 'color: {{VALUE}}',
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ribbon_typography',
				'selector' => '{{WRAPPER}} .cms-price-table__ribbon-inner',
			]
		);

		$widget->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'selector' => '{{WRAPPER}} .cms-price-table__ribbon-inner',
			]
		);

		$widget->end_controls_section();
    }
}
