<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_quickcontact_register_controls')) {
    add_action('etc_widget_cms_quickcontact_register_controls', 'validus_widget_cms_quickcontact_register_controls', 10, 1);
    function validus_widget_cms_quickcontact_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout-images/layout2.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Icon Section Start
        $widget->start_controls_section(
            'quickcontact_section',
            [
                'label' => esc_html__('CMS Quick Contact', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('This is the heading', 'validus'),
                'placeholder' => esc_html__('Enter your title', 'validus'),
                'label_block' => true,
                'condition'   => [
                    'layout' => ['1','3']
                ]
            ]
        );
        $widget->add_control(
            'email',
            [
                'label'   => esc_html__('Email', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('Validus@farost.net', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'link_email',
            [
                'label'   => esc_html__('Link Email', 'validus'),
                'type'    => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => 'mailto:',
                ],
            ]
        );
        $widget->add_control(
            'phone',
            [
                'label'   => esc_html__('Phone', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('Customer Service: +55 654 541 17', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'link_phone',
            [
                'label'   => esc_html__('Link Phone', 'validus'),
                'type'    => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => 'tel:',
                ],
            ]
        );
        $widget->add_control(
            'address',
            [
                'label'   => esc_html__('Address', 'validus'),
                'type'    => Controls_Manager::TEXTAREA,
                'default'     => esc_html__('2307 Beverley Rd Brooklyn, New York 11226 United States.', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'link_address',
            [
                'label'   => esc_html__('Link Address', 'validus'),
                'type'    => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End

        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'show_text',
            [
                'label'   => esc_html__('Show Text', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-item span' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
				'condition' => [
					'layout' => [ '2' ],
				],
            ]
        );
        $widget->add_control(
            'text_color',
            [
                'label'   => esc_html__('Text Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'text-header-top',
				'options' => [
					'' => esc_html__( 'Default', 'validus' ),
					'text-primary' => esc_html__( 'Primary Color', 'validus' ),
					'text-secondary' => esc_html__( 'Secondary Color', 'validus' ),
					'text-header-top' => esc_html__( 'Header Top Color', 'validus' ),
                ],
				'condition' => [
					'layout' => [ '2' ],
				],
            ]
        );
        $widget->add_control(
            'icon_color',
            [
                'label'   => esc_html__('Icon Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-item i' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition'   => [
                    'layout' => ['2','3']
                ]
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-title' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition'   => [
                    'layout' => ['1','3']
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Title Typography', 'validus'),
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-quickcontact-title',
                'condition'   => ['layout' => '1']
            ]
        );

        $widget->add_control(
            'email_color',
            [
                'label'   => esc_html__('Email Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-email' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-email a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-email span' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'email_color_hover',
            [
                'label'   => esc_html__('Email Color Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-email:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-email:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Email Typography', 'validus'),
                'name' => 'email_typography',
                'selector'     => '{{WRAPPER}} .cms-quickcontact-email',
            ]
        );

        $widget->add_control(
            'phone_color',
            [
                'label'   => esc_html__('Phone Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-phone' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-phone a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-phone span' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        
        $widget->add_control(
            'phone_color_hover',
            [
                'label'   => esc_html__('Phone Color Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-phone:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-phone:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-phone:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Phone Typography', 'validus'),
                'name' => 'phone_typography',
                'selector'     => '{{WRAPPER}} .cms-quickcontact-phone',
            ]
        );

        $widget->add_control(
            'address_color',
            [
                'label'   => esc_html__('Address Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-quickcontact-address' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-quickcontact-address span' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Address Typography', 'validus'),
                'name' => 'address_typography',
                'selector'     => '{{WRAPPER}} .cms-quickcontact-address',
            ]
        );
        $widget->end_controls_section();
        // Style Section End

        // Content Tab End

    }
}
