<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_service_carousel_register_controls')) {
    add_action('etc_widget_cms_service_carousel_register_controls', 'validus_widget_cms_service_carousel_register_controls', 10, 1);
    function validus_widget_cms_service_carousel_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_service_carousel/layout-image/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_service_carousel/layout-image/layout2.jpg'
                    ],
                ],
                'default' => '1',
            ]
        );
        $widget->end_controls_section();
        // Layout Tab End

        // Post term options
        //$post_term_options = etc_get_grid_term_id_options('service');

        if(function_exists('etc_get_grid_term_options')){
            $post_term_options = etc_get_grid_term_options('service',['service-category']);
        } else {
            $post_term_options = [];
        }

        if(function_exists('validus_get_grid_term_tags')){
            $post_term_tags = validus_get_grid_term_tags('service');
        } else {
            $post_term_tags = [];
        }

        // Content Tab Start
        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'validus'),
                'description' => 'Notice: have to install the Elementor Theme Core plugin and insert categories or tag first!',
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'groupby',
            [
                'label'   => esc_html__('Group By Tag', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'description' => 'Notice: have to install the Elementor Theme Core plugin and insert tag first!',
                'default' => 0,
                'options' => $post_term_tags
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('Date', 'validus'),
                    'ID' => esc_html__('ID', 'validus'),
                    'author' => esc_html__('Author', 'validus'),
                    'title' => esc_html__('Title', 'validus'),
                    'rand' => esc_html__('Random', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label' => esc_html__('Sort Order', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'validus'),
                    'asc' => esc_html__('Ascending', 'validus'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label' => esc_html__('Total items', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'show_title',
            [
                'label' => esc_html__('Show Title', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $widget->add_control(
            'title_tag',
            [
                'label' => esc_html__('HTML Tag', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'condition' => [
                    'show_title' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_excerpt',
            [
                'name' => 'show_excerpt',
                'label' => esc_html__('Show Excerpt', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'num_words',
            [
                'name' => 'num_words',
                'label' => esc_html__('Number Of Characters', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 25,
                'condition' => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );
        $widget->add_control(
            'show_post_date',
            [
                'label' => esc_html__('Show Post Date', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'show_categories',
            [
                'label' => esc_html__('Show Categories', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => [
                    'layout' => '1'
                ],
            ]
        );
        $widget->add_control(
            'show_cta',
            [
                'label' => esc_html__('Show Call To Action', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => [
                    'layout' => '2'
                ],
            ]
        );
        $widget->end_controls_section();
        // Display Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrow_prev_icon',
            [
                'label' => esc_html__('Previous Arrow Icon', 'validus'),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'skin' => 'inline',
                'label_block' => false,
                'skin_settings' => [
                    'inline' => [
                        'none' => [
                            'label' => 'Default',
                            'icon' => 'eicon-chevron-left',
                        ],
                        'icon' => [
                            'icon' => 'eicon-star',
                        ],
                    ],
                ],
                'recommended' => [
                    'fa-regular' => [
                        'arrow-alt-circle-left',
                        'caret-square-left',
                    ],
                    'fa-solid' => [
                        'angle-double-left',
                        'angle-left',
                        'arrow-alt-circle-left',
                        'arrow-circle-left',
                        'arrow-left',
                        'caret-left',
                        'caret-square-left',
                        'chevron-circle-left',
                        'chevron-left',
                        'long-arrow-alt-left',
                    ],
                ],
                'condition' => [
                    'arrows' => 'yes'
                ],
            ]
        );

        $widget->add_control(
            'arrow_next_icon',
            [
                'label' => esc_html__('Next Arrow Icon', 'validus'),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'skin' => 'inline',
                'label_block' => false,
                'skin_settings' => [
                    'inline' => [
                        'none' => [
                            'label' => 'Default',
                            'icon' => 'eicon-chevron-right',
                        ],
                        'icon' => [
                            'icon' => 'eicon-star',
                        ],
                    ],
                ],
                'recommended' => [
                    'fa-regular' => [
                        'arrow-alt-circle-right',
                        'caret-square-right',
                    ],
                    'fa-solid' => [
                        'angle-double-right',
                        'angle-right',
                        'arrow-alt-circle-right',
                        'arrow-circle-right',
                        'arrow-right',
                        'caret-right',
                        'caret-square-right',
                        'chevron-circle-right',
                        'chevron-right',
                        'long-arrow-alt-right',
                    ],
                ],
                'condition' => [
                    'arrows' => 'yes'
                ],
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Title Section Start
        $widget->start_controls_section(
            'title_section',
            [
                'label' => esc_html__('Title', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $widget->add_responsive_control(
            'title_top_space',
            [
                'label' => esc_html__('Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .item-title' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $widget->add_responsive_control(
            'title_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .item-title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => 'Typography',
                'selector'  => '{{WRAPPER}} .item-title',
            ]
        );
        $widget->end_controls_section();
        // Title Section Start


        // Title Section Start
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $widget->add_responsive_control(
            'content_top_space',
            [
                'label' => esc_html__('Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .item-content' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $widget->add_responsive_control(
            'content_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'content_typography',
                'label'     => 'Typography',
                'selector'  => '{{WRAPPER}} .item-content',
            ]
        );
        $widget->end_controls_section();
        // Content Section Start


        // Cta Section Start
        $widget->start_controls_section(
            'cta_section',
            [
                'label' => esc_html__('Call To Anchor', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2'],
                    'show_cta' => 'yes'
                ]
            ]
        );
        $widget->add_control(
            'cta_text',
            [
                'label' => esc_html__('Text', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('We have established a corporate mandate to maintain strong core values that truly reflect the philosophy.', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'cta_name',
            [
                'label' => esc_html__('Anchor Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Schedule A Visit', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'cta_name_link',
            [
                'label'       => esc_html__( 'Anchor Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );
        $widget->end_controls_section();
        // Cta Section End

        // Arrow Section Start
        $widget->start_controls_section(
            'arrow_section',
            [
                'label' => esc_html__('Arrows', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'arrows' => 'yes'
                ],
            ]
        );

        $widget->add_responsive_control(
            'show_arrow',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
				'condition' => [
					'arrows' => [ 'yes' ],
				],
            ]
        );
        $widget->add_responsive_control(
            'arrow_style',
            [
                'label'        => esc_html__( 'Arrow Style', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'row',
                'separator'    => 'before',
                'options'      => [
                    'row'      => '1 Line',
                    'column'   => '2 Line'
                ],
                'condition' => [
                    'show_arrow' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'flex-direction: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position',
            [
                'label'        => esc_html__( 'Arrow Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'control_type' => 'responsive',
                'default'      => 'right',
                'separator'    => 'before',
                'options'      => [
                    'left'     => 'Left',
                    'right'    => 'Right'
                ],
                'condition' => [
                    'show_arrow' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_padding_left',
            [
                'label' => esc_html__('Arrow Padding Left', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 700,
                    ],
                ],
                'default' => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'selectors' => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_arrow' => 'flex',
                    'arrow_position' => 'left'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_padding_right1',
            [
                'label' => esc_html__('Arrow Padding Right', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 700,
                    ],
                ],
                'default' => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'selectors' => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
                'condition' => [
                    'layout' => '1',
                    'show_arrow' => 'flex',
                    'arrow_position' => 'right'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_padding_right2',
            [
                'label' => esc_html__('Arrow Padding Right', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 700,
                    ],
                ],
                'default' => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'selectors' => [
                    'body:not(.rtl) {{WRAPPER}} .cms-carousel-button' => 'left: auto;right: {{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-carousel-button' => 'left: {{SIZE}}{{UNIT}};right: auto;',
                ],
                'condition' => [
                    'layout' => '2',
                    'show_arrow' => 'flex',
                    'arrow_position' => 'right'
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_position_bottom',
            [
                'label'        => esc_html__( 'Arrow Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => -50,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'arrows' => 'yes',
                    'show_arrow' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-button' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrows_gap',
            [
                'label' => esc_html__('Gap Between 2 Arrow', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'size' => '20'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                    'show_arrow' => 'flex'
                ],
            ]
        );

        $widget->add_responsive_control(
            'arrows_size',
            [
                'label' => esc_html__('Size', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 20,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                    'show_arrow' => 'flex'
                ],
            ]
        );

        $widget->add_responsive_control(
            'arrows_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-tool .cms-carousel-button .cms-carousel-button-prev' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-tool .cms-carousel-button .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                    'show_arrow' => 'flex'
                ],
            ]
        );

        $widget->end_controls_section();


        $widget->start_controls_section(
            'dot_section',
            [
                'label' => esc_html__('Dots', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_dots_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
		$widget->add_responsive_control(
			'dots_align',
			array(
				'label'     => esc_html__( 'Alignment', 'validus' ),
				'type'      => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'condition'   => array(
					'dots' => 'yes',
                    'show_dots_mobile' => 'block'
				),
				'selectors' => [
					'{{WRAPPER}} .cms-carousel-dots' => 'text-align: {{VALUE}};',
				],
			)
		);

        $widget->add_responsive_control(
            'dots_top_space_layout1',
            [
                'label' => esc_html__('Top Spacing', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 150,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => ['1'],
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );
        $widget->add_responsive_control(
            'dots_top_space',
            [
                'label' => esc_html__('Top Spacing', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 150,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => ['2'],
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    // The opacity property will override the default inactive dot color which is opacity 0.2.
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'dots_color',
            [
                'label' => esc_html__('Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet-active' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'block'
                ],
            ]
        );

        $widget->end_controls_section();
        // Dots Section End
        // Style Tab End


        // Cta Style Section Start
        $widget->start_controls_section(
            'cta_style_section',
            [
                'label' => esc_html__('Call To Anchor', 'validus'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_responsive_control(
            'cta_top_space',
            [
                'label' => esc_html__('Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => '30',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-service-carousel-cta' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
			'cta_max_width',
			[
				'label' => esc_html__( 'Max Width', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
                'default' => [
                    'size' => '60',
                    'unit' => '%'
                ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-container' => 'max-width: {{SIZE}}%;',
				],
			]
		);
        $widget->add_responsive_control(
            'cta_align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'condition'   => array(
                    'show_cta' => 'yes'
				),
                'default' => 'center',
                'selectors'    => [
                    '{{WRAPPER}} .cms-service-carousel-cta' => 'justify-content: {{VALUE}}; text-align: {{VALUE}};',
                ],
            ]
        );
		$widget->add_control(
			'cta_text_color',
			[
				'label' => esc_html__( 'Text Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_text!' => '',
				],
                'separator' => 'before',
			]
		);
		$widget->add_control(
			'cta_name_color',
			[
				'label' => esc_html__( 'Anchor Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-name' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_name!' => '',
				],
			]
		);
		$widget->add_control(
			'cta_name_color_hover',
			[
				'label' => esc_html__( 'Anchor Color Hover', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-name:hover' => 'color: {{VALUE}}',
				],
				'condition' => [
					'cta_name!' => '',
				],
			]
		);
        $widget->add_control(
            'show_underline',
            [
                'label' => esc_html__('Show Underline', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
			'cta_border_color',
			[
				'label' => esc_html__( 'Underline Color', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-name' => 'border-color: {{VALUE}};',
				],
			]
		);
        $widget->add_control(
			'cta_border_color_hover',
			[
				'label' => esc_html__( 'Underline Color Hover', 'validus' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-name:hover' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					'show_underline' => 'yes'
				],
			]
		);
        $widget->add_responsive_control(
			'cta_border_width',
			[
				'label' => esc_html__( 'Underline Height', 'validus' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
					],
					'em' => [
						'max' => 2,
					],
				],
				'condition' => [
					'show_underline' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .cms-service-carousel-cta-name' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
        $widget->end_controls_section();
        // Cta Style Section End
    }
}
