<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;

if (!function_exists('validus_widget_cms_signature_register_controls')) {
    add_action('etc_widget_cms_signature_register_controls', 'validus_widget_cms_signature_register_controls', 10, 1);
    function validus_widget_cms_signature_register_controls($widget)
    {
        // Content Tab Start

        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'name',
            [
                'label'       => esc_html__( 'Name', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter name', 'validus' ),
                'default'     => 'Michael Brian',
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->add_control(
            'desc',
            [
                'label'       => esc_html__( 'Desc', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter description', 'validus' ),
                'default'     => 'The Founder',
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->end_controls_section(); // Heading Section End

        // Signature Image
        $widget->start_controls_section('image_section',[
            'label'     => esc_html__('Signature Image', 'validus'),
            'tab'       => Controls_Manager::TAB_CONTENT,
        ]);
            $widget->add_control(
                'image',
                [
                    'label'   => esc_html__( 'Image', 'validus' ),
                    'type'    => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        //'url' => Utils::get_placeholder_image_src()
                        'url' => get_template_directory_uri() . '/assets/images/Award/signature_01.png'
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'thumbnail',
                    'label'   => esc_html__('Image Size','validus'),
                    'default' => 'custom',
                ]
            );
        $widget->end_controls_section();

        // Style Heading Style Start
        $widget->start_controls_section(
            'section_style_signature',
            [
                'label' => esc_html__('Signature Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'signature_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => 0,
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-signature-name' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'name_color',
            [
                'label'     => esc_html__( 'Name Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-signature-name' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Desc Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-signature-desc' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'name_typography',
                'selector'  => '{{WRAPPER}} .cms-signature-name, {{WRAPPER}} .cms-signature-name a',
            ]
        );
        $widget->end_controls_section(); // Style Heading Style End
        // Content Tab End
    }
}
