<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if (!function_exists('validus_widget_cms_single_image_register_controls')) {
    add_action('etc_widget_cms_single_image_register_controls', 'validus_widget_cms_single_image_register_controls', 10, 1);
    function validus_widget_cms_single_image_register_controls($widget)
    {
        // Content Tab Start
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_single_image/layout/layout1.png'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_single_image/layout/layout2.png'
                    ],
                ],
                'default' => '1',
            ]
        );
        $widget->end_controls_section(); // Layout Section End

        // Single Image Section Start
        $widget->start_controls_section(
            'section_single_image',
            [
                'label' => esc_html__('Single Image', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Controls_Manager::HIDDEN,
                'style_transfer' => true,
                'default'      => ' ',
                'condition' => [
                    'use_background' => 'yes'
                ],
                'separator' => 'before',
                'prefix_class'   => 'cms-single-image-prefix'
            ]
        );
        $widget->add_control(
            'image',
            [
                'label' => esc_html__( 'Image', 'validus' ),
                'type'  => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => get_template_directory_uri() . '/assets/images/elementor/jasper-garratt-hori.jpg'
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'full',
            ]
        );
        $widget->add_responsive_control(
            'img_width',
            [
                'label'   => esc_html__('Width', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'initial',
				'options' => [
					'initial' => esc_html__( 'Default', 'validus' ),
					'100%' => esc_html__( '100%', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-single-image-container' => 'width: {{VALUE}};',
                    '{{WRAPPER}} .cms-single-image-container > img' => 'width: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'img_link',
            [
                'label' => esc_html__( 'Link', 'validus' ),
                'type'  => \Elementor\Controls_Manager::URL,
            ]
        );
        $widget->add_responsive_control(
            'min_height',
            [
                'label'        => esc_html__( 'Min Box Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 100,
                        'max' => 800,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-container' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'img_max_height',
            [
                'label'        => esc_html__( 'Max Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px', '%' ],
                'range'        => [
                    'px' => [
                        'min' => 50,
                        'max' => 2000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-wrap img' => 'max-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'border_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-container > img' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                    '{{WRAPPER}} .cms-single-image-container .cms-single-image-bg' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'opacity',
            [
                'label'        => esc_html__( 'Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '100',
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-container' => 'opacity: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __( 'Box Shadow', 'validus' ),
                'selector' => '{{WRAPPER}} .cms-single-image-container img',
            ]
        );
        $widget->add_control(
            'show_overlay',
            [
                'label'     => esc_html__( 'Show Overlay', 'validus' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'default'   => 'no'
            ]
        );
        $widget->add_responsive_control(
            'show_box_stamp',
            [
                'label'     => esc_html__( 'Show Box Stamp', 'validus' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'default'   => 'no',
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
        $widget->add_responsive_control(
            'show_responsive',
            [
                'label'   => esc_html__('Show On Responsive', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-single-image-wrap' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-wrap' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'align_vertical',
            [
                'label'        => esc_html__( 'Vertical Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Left', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'Right', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'prefix_class' => 'cms-single-image-prefix ',
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-wrap .cms-single-image-container' => 'align-items: {{VALUE}};'
                ],
            ]
        );
        $widget->add_control(
            'use_background',
            [
                'label'     => esc_html__( 'Use Image As Background', 'validus' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'separator' => 'before',
                'default'   => 'no'
            ]
        );
        $widget->add_responsive_control(
            'top_space',
            [
                'label'        => esc_html__( 'Top Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'condition' => [
                    'use_background' => 'yes'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-wrap.background .cms-single-image-bg' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'right_space',
            [
                'label'        => esc_html__( 'Right Space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 400,
                    ],
                ],
                'condition' => [
                    'use_background' => 'yes'
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-single-image-wrap.background .cms-single-image-bg' => 'right: -{{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-single-image-wrap.background .cms-single-image-bg' => 'left: -{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Single Image Section End


        // Stamp Section Start
        $widget->start_controls_section(
            'section_stamp_image',
            [
                'label' => esc_html__('Stamp Image', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'stamp_image',
            [
                'label' => esc_html__( 'Image', 'validus' ),
                'type'  => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbstamp',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_responsive_control(
            'stamp_pos_x',
            [
                'label'        => esc_html__( 'X Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-stamp' => 'margin-inline-end: -{{SIZE}}px;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'stamp_pos_y',
            [
                'label'        => esc_html__( 'Y Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-stamp' => 'margin-top: -{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'stamp_size',
            [
                'label'        => esc_html__( 'Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-stamp' => 'width: {{SIZE}}px; height: {{SIZE}}px',
                ],
            ]
        );
        $widget->add_control(
            'show_rotate',
            [
                'label'     => esc_html__( 'Rotate Circle', 'validus' ),
                'description' => esc_html__('Rotate image if image is in circle form', 'validus'),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'default'   => 'no'
            ]
        );
        $widget->end_controls_section(); // single_image Section End

        // Stamp Section Start
        $widget->start_controls_section(
            'section_box_stamp',
            [
                'label' => esc_html__('Box Stamp', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2'],
                    'show_box_stamp' => 'yes'
                ]
            ]
        );
        $widget->add_control(
            'box_stamp_heading',
            [
                'label'       => esc_html__( 'Heading', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'Highly Trusted And Professional Services', 'validus' ),
                'placeholder' => esc_html__( 'Enter your title', 'validus' ),
                'label_block' => true,
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'box_stamp_heading_typography',
                'label' => 'Heading Typography',
                'selector'     => '{{WRAPPER}} .cms-single-image-box-stamp-heading',
            ]
        );
        $widget->add_control(
            'box_stamp_text',
            [
                'label'       => esc_html__( 'Description', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter description', 'validus' ),
                'default'     => esc_html__("Dedication to quality, innovation and a constant objective to serve the global market industry. ", 'validus' ),
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'box_stamp_text_typography',
                'label' => 'Description Typography',
                'selector'     => '{{WRAPPER}} .cms-single-image-box-stamp .cms-single-image-box-stamp-text',
            ]
        );
        $widget->add_responsive_control(
            'box_stamp_pos_x',
            [
                'label'        => esc_html__( 'X Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-box-stamp' => 'margin-inline-end: -{{SIZE}}px;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'box_stamp_pos_y',
            [
                'label'        => esc_html__( 'Y Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-box-stamp' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'box_stamp_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-single-image-box-stamp' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->end_controls_section(); // single_image Section End

        // Content Tab End
    }
}
