<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Modules\DynamicTags\Module as TagsModule;

if (!function_exists('validus_widget_cms_slider_register_controls')) {
    add_action('etc_widget_cms_slider_register_controls', 'validus_widget_cms_slider_register_controls', 10, 1);
    function validus_widget_cms_slider_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'validus'),
            'tab' => Controls_Manager::TAB_LAYOUT,
        ]);
        $widget->add_control('layout', [
            'label' => esc_html__('Templates', 'validus'),
            'type' => Elementor_Theme_Core::LAYOUT_CONTROL,
            'default' => '1',
            'options' => [
                '1' => [
                    'label' => esc_html__('Layout 1', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/1.jpg',
                ],
                '3' => [
                    'label' => esc_html__('Layout 3', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/3.jpg',
                ],
                '4' => [
                    'label' => esc_html__('Layout 4', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/4.jpg',
                ],
                '5' => [
                    'label' => esc_html__('Layout 5', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/5.jpg',
                ],
                '6' => [
                    'label' => esc_html__('Layout 6', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/6.jpg',
                ],
                '7' => [
                    'label' => esc_html__('Layout 7', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider/layout-images/7.jpg',
                ],
            ],
        ]);
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Slider List Section Start
        $widget->start_controls_section('slider_list_section', [
            'label' => esc_html__('Slider List', 'validus'),
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new Repeater();

        $repeater->start_controls_tabs(
			'config_tabs'
		);

            //Slide
            $repeater->start_controls_tab(
                'slide_tab',
                [
                    'label' => esc_html__( 'Slide', 'validus' ),
                ]
            );

            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__('Slide Image', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide-bg' => 'background-image: url({{URL}})',
                    ],
                ]
            );
            
            $repeater->add_control(
                'background_size',
                [
                    'label' => _x( 'Size', 'Background Control', 'validus' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'cover',
                    'options' => [
                        'cover' => _x( 'Cover', 'Background Control', 'validus' ),
                        'contain' => _x( 'Contain', 'Background Control', 'validus' ),
                        'auto' => _x( 'Auto', 'Background Control', 'validus' ),
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide-bg' => 'background-size: {{VALUE}}',
                    ],
                    'conditions' => [
                        'terms' => [
                            [
                                'name' => 'image[url]',
                                'operator' => '!=',
                                'value' => '',
                            ],
                        ],
                    ],
                ]
            );

            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__('Slide Name', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => '',
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__('Title', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('This is the title', 'validus'),
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'subtitle',
                [
                    'label' => esc_html__('Subtitle', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('This is the subtitle', 'validus'),
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'description',
                [
                    'label' => esc_html__('Description', 'validus'),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('This is the description', 'validus'),
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'button_primary',
                [
                    'label' => esc_html__('Button Primary', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Button Text', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'button_primary_link',
                [
                    'label'       => esc_html__( 'Button Primary Link', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ]
            );

            $repeater->add_control(
                'button_secondary',
                [
                    'label' => esc_html__('Button Secondary', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Button Text', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'button_secondary_link',
                [
                    'label'       => esc_html__( 'Button Secondary Link', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ]
                ]
            );
            $repeater->end_controls_tab();

            //Video
            $repeater->start_controls_tab(
                'video_tab',
                [
                    'label' => esc_html__( 'Video', 'validus' ),
                ]
            );

            $repeater->add_control(
                'video_type',
                [
                    'label' => esc_html__( 'Source', 'validus' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'youtube',
                    'options' => [
                        'youtube' => esc_html__( 'YouTube', 'validus' ),
                        'vimeo' => esc_html__( 'Vimeo', 'validus' ),
                        'dailymotion' => esc_html__( 'Dailymotion', 'validus' ),
                        'hosted' => esc_html__( 'Self Hosted', 'validus' ),
                    ],
                    'frontend_available' => true,
                ]
            );

            $repeater->add_control(
                'youtube_url',
                [
                    'label' => esc_html__( 'Video Link', 'validus' ),
                    'type' => Controls_Manager::TEXT,
                    'dynamic' => [
                        'active' => true,
                        'categories' => [
                            TagsModule::POST_META_CATEGORY,
                            TagsModule::URL_CATEGORY,
                        ],
                    ],
                    'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (YouTube)',
                    'default' => 'https://www.youtube.com/watch?v=XHOmBV4js_E',
                    'label_block' => true,
                    'condition' => [
                        'video_type' => 'youtube',
                    ],
                    'frontend_available' => true,
                ]
            );

            $repeater->add_control(
                'vimeo_url',
                [
                    'label' => esc_html__( 'Video Link', 'validus' ),
                    'type' => Controls_Manager::TEXT,
                    'dynamic' => [
                        'active' => true,
                        'categories' => [
                            TagsModule::POST_META_CATEGORY,
                            TagsModule::URL_CATEGORY,
                        ],
                    ],
                    'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (Vimeo)',
                    'default' => 'https://vimeo.com/235215203',
                    'label_block' => true,
                    'condition' => [
                        'video_type' => 'vimeo',
                    ],
                ]
            );

            $repeater->add_control(
                'dailymotion_url',
                [
                    'label' => esc_html__( 'Video Link', 'validus' ),
                    'type' => Controls_Manager::TEXT,
                    'dynamic' => [
                        'active' => true,
                        'categories' => [
                            TagsModule::POST_META_CATEGORY,
                            TagsModule::URL_CATEGORY,
                        ],
                    ],
                    'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (Dailymotion)',
                    'default' => 'https://www.dailymotion.com/video/x6tqhqb',
                    'label_block' => true,
                    'condition' => [
                        'video_type' => 'dailymotion',
                    ],
                ]
            );

            $repeater->add_control(
                'insert_url',
                [
                    'label' => esc_html__( 'External URL', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'condition' => [
                        'video_type' => 'hosted',
                    ],
                ]
            );

            $repeater->add_control(
                'hosted_url',
                [
                    'label' => esc_html__( 'Choose File', 'validus' ),
                    'type' => Controls_Manager::MEDIA,
                    'dynamic' => [
                        'active' => true,
                        'categories' => [
                            TagsModule::MEDIA_CATEGORY,
                        ],
                    ],
                    'media_type' => 'video',
                    'condition' => [
                        'video_type' => 'hosted',
                        'insert_url' => '',
                    ],
                ]
            );

            $repeater->add_control(
                'external_url',
                [
                    'label' => esc_html__( 'URL', 'validus' ),
                    'type' => Controls_Manager::URL,
                    'autocomplete' => false,
                    'options' => false,
                    'label_block' => true,
                    'show_label' => false,
                    'dynamic' => [
                        'active' => true,
                        'categories' => [
                            TagsModule::POST_META_CATEGORY,
                            TagsModule::URL_CATEGORY,
                        ],
                    ],
                    'media_type' => 'video',
                    'placeholder' => esc_html__( 'Enter your URL', 'validus' ),
                    'condition' => [
                        'video_type' => 'hosted',
                        'insert_url' => 'yes',
                    ],
                ]
            );
            //video
            $repeater->add_control(
                'video_image',
                [
                    'label' => esc_html__('Video Image', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );
            $repeater->add_control(
                'video_subject',
                [
                    'label'       => esc_html__( 'Subject', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => '',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'video_title',
                [
                    'label'       => esc_html__( 'Title', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => esc_html__( 'Personalised Solutions', 'validus' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'video_link',
                [
                    'label'       => esc_html__( 'Link', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ]
            );
            $repeater->add_control(
                'start',
                [
                    'label' => esc_html__( 'Start Time', 'validus' ),
                    'type' => Controls_Manager::NUMBER,
                    'description' => esc_html__( 'Specify a start time (in seconds)', 'validus' ),
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'end',
                [
                    'label' => esc_html__( 'End Time', 'validus' ),
                    'type' => Controls_Manager::NUMBER,
                    'description' => esc_html__( 'Specify an end time (in seconds)', 'validus' ),
                    'condition' => [
                        'video_type' => [ 'youtube', 'hosted' ],
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'autoplay',
                [
                    'label' => esc_html__( 'Autoplay', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                    'conditions' => [
                        'relation' => 'or',
                        'terms' => [
                            [
                                'name' => 'video_image[url]',
                                'value' => '',
                            ],
                        ],
                    ],
                ]
            );
            $repeater->add_control(
                'play_on_mobile',
                [
                    'label' => esc_html__( 'Play On Mobile', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'mute',
                [
                    'label' => esc_html__( 'Mute', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'loop',
                [
                    'label' => esc_html__( 'Loop', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'condition' => [
                        'video_type!' => 'dailymotion',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'controls',
                [
                    'label' => esc_html__( 'Player Controls', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'label_off' => esc_html__( 'Hide', 'validus' ),
                    'label_on' => esc_html__( 'Show', 'validus' ),
                    'default' => 'yes',
                    'condition' => [
                        'video_type!' => 'vimeo',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'modestbranding',
                [
                    'label' => esc_html__( 'Modest Branding', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'condition' => [
                        'video_type' => [ 'youtube' ],
                        'controls' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'yt_privacy',
                [
                    'label' => esc_html__( 'Privacy Mode', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'description' => esc_html__( 'When you turn on privacy mode, YouTube/Vimeo won\'t store information about visitors on your website unless they play the video.', 'validus' ),
                    'condition' => [
                        'video_type' => [ 'youtube', 'vimeo' ],
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'lazy_load',
                [
                    'label' => esc_html__( 'Lazy Load', 'validus' ),
                    'type' => Controls_Manager::SWITCHER,
                    'conditions' => [
                        'relation' => 'or',
                        'terms' => [
                            [
                                'name' => 'video_type',
                                'operator' => '===',
                                'value' => 'youtube',
                            ],
                            [
                                'relation' => 'and',
                                'terms' => [
                                    [
                                        'name' => 'video_type',
                                        'operator' => '!==',
                                        'value' => 'hosted',
                                    ],
                                ],
                            ],
                        ],
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'rel',
                [
                    'label' => esc_html__( 'Suggested Videos', 'validus' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '' => esc_html__( 'Current Video Channel', 'validus' ),
                        'yes' => esc_html__( 'Any Video', 'validus' ),
                    ],
                    'condition' => [
                        'video_type' => 'youtube',
                    ],
                ]
            );

            $repeater->add_control(
                'preload',
                [
                    'label' => esc_html__( 'Preload', 'validus' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'metadata' => esc_html__( 'Metadata', 'validus' ),
                        'auto' => esc_html__( 'Auto', 'validus' ),
                        'none' => esc_html__( 'None', 'validus' ),
                    ],
                    'description' => sprintf(
                        esc_html__( 'Preload attribute lets you specify how the video should be loaded when the page loads. %1$sLearn More%2$s', 'validus' ),
                        '<a target="_blank" href="https://go.elementor.com/preload-video/">',
                        '</a>'
                    ),
                    'default' => 'metadata',
                    'condition' => [
                        'video_type' => 'hosted',
                        'autoplay' => '',
                    ],
                ]
            );

            $repeater->add_control(
                'poster',
                [
                    'label' => esc_html__( 'Poster', 'validus' ),
                    'type' => Controls_Manager::MEDIA,
                    'dynamic' => [
                        'active' => true,
                    ],
                    'condition' => [
                        'video_type' => 'hosted',
                    ],
                ]
            );
            $repeater->end_controls_tab();

            //Box1
            $repeater->start_controls_tab(
                'box1_tab',
                [
                    'label' => esc_html__( 'Box1', 'validus' ),
                ]
            );
            $repeater->add_control(
                'box_heading1',
                [
                    'label'       => esc_html__( 'Notice: just use on the layout 2, 3 & 4 order', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::HEADING,
                    'placeholder' => '',
                    'default'     => '',
                    'label_block' => true,
                ]
            );
            //Box Icon1
            $repeater->add_control(
                'box_icon1',
                [
                    'label'   => esc_html__('Box Icon1', 'validus'),
                    'type'    => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                ]
            );
            $repeater->add_control(
                'box_image1',
                [
                    'label' => esc_html__('Box Image1', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );
            $repeater->add_control(
                'box_title1',
                [
                    'label'       => esc_html__( 'Box Title1', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => 'Box Title1',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'box_desc1',
                [
                    'label'       => esc_html__( 'Box Description1', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => esc_html__( 'Personalised Solutions', 'validus' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'box_url1',
                [
                    'label'       => esc_html__( 'Box Url1', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'label_block' => true,
                ]
            );
            $repeater->end_controls_tab();

            //Box2
            $repeater->start_controls_tab(
                'box2_tab',
                [
                    'label' => esc_html__( 'Box2', 'validus' ),
                ]
            );
            $repeater->add_control(
                'box_heading2',
                [
                    'label'       => esc_html__( 'Notice: just use on the layout 3 order', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::HEADING,
                    'placeholder' => '',
                    'default'     => '',
                    'label_block' => true,
                ]
            );
            //Box Icon2
            $repeater->add_control(
                'box_icon2',
                [
                    'label'   => esc_html__('Box Icon2', 'validus'),
                    'type'    => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                ]
            );
            $repeater->add_control(
                'box_image2',
                [
                    'label' => esc_html__('Box Image2', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );
            $repeater->add_control(
                'box_title2',
                [
                    'label'       => esc_html__( 'Box Title2', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => 'Box Title2',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'box_desc2',
                [
                    'label'       => esc_html__( 'Box Description2', 'validus' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'placeholder' => '',
                    'default'     => esc_html__( 'Personalised Solutions', 'validus' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'box_url2',
                [
                    'label'       => esc_html__( 'Box Url2', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'label_block' => true,
                ]
            );
            $repeater->end_controls_tab();
        
        $repeater->end_controls_tabs();

        $widget->add_control(
            'cms_slides',
            [
                'label' => esc_html__('Slides', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Personalised Solutions', 'validus'),
                        'title' => esc_html__('Title', 'validus'),
                        'subtitle' => esc_html__(
                            'Sub Title.', 'validus'
                        ),
                        'description' => '',
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Environmental Sensitivity', 'validus'),
                        'title' => esc_html__('Title', 'validus'),
                        'subtitle' => esc_html__(
                            'Sub Title.', 'validus'
                        ),
                        'description' => '',
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Performance Measures', 'validus'),
                        'title' => esc_html__('Title', 'validus'),
                        'subtitle' => esc_html__(
                            'Sub Title.', 'validus'
                        ),
                        'description' => '',
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->end_controls_section();
        // Slider List Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 3);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'layout' => '5'
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Style Tab Start
        // General Style Section Start
        $widget->start_controls_section(
            'general_style_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'max-top-width',
            [
                'label'        => esc_html__( 'Top Width', 'validus' ),
                'description'  => esc_html__( 'Top width contains the title & subtitle', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => '',//73
                    'unit'     => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-top' => 'max-width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_align',
            [
                'label'        => esc_html__( 'Content Alignment', 'validus' ),
                'description'  => esc_html__( 'Content contains the description, button & the box', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-content .container' => 'justify-content: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'max-width',
            [
                'label'        => esc_html__( 'Content Width', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ '%' ],
                'default'      => [
                    'size'     => '',//73
                    'unit'     => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-content-text' => 'max-width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_top_space',
            [
                'label'        => esc_html__( 'Content Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',//120
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-wrap:not(.header-transparent) .cms-slider-content' => 'padding-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-slider-wrap.header-transparent .cms-slider-content' => 'padding-top: calc({{SIZE}}px + var(--header-height));',
                    //'{{WRAPPER}} .cms-slider-top-space' => 'padding-top: calc({{SIZE}}px + var(--header-height));',
                    //'{{WRAPPER}} .w-ptt-pt' => 'padding-top: calc({{SIZE}}px + 110px);',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_lr_space',
            [
                'label'        => esc_html__( 'Content Left-Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-content' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-slider-content' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-carousel-pagination' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'adjust_slides_height',
            [
                'label' => esc_html__('Adjust Slide Height', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'default_args' => [
                    'laptop' => '',
                    'tablet' => '',
                    'tablet_extra' => '',
                    'mobile_extra' => '',
                    'mobile' => ''
                ],
                'options' => [
                    '' => esc_html__('Auto', 'validus'),
                    'custom' => esc_html__('Custom', 'validus'),
                ],
            ]
        );
        $widget->add_responsive_control(
            'slides_height',
            [
                'label'        => esc_html__( 'Slide Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'max' => 1000,
                    ],
                ],
                'condition' => [
                    'adjust_slides_height' => 'custom',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .swiper-slide' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-carousel .cms-carousel-item.swiper-slide' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->end_controls_section();
        // General Style Section End

        $widget->start_controls_section(
            'arrow_style_section',
            [
                'label' => esc_html__('Arrows', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'arrows' => 'yes'
            ]
        );
        $widget->add_responsive_control(
            'show_arrows_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-button-arrow' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'arrow_color',
            [
                'label'   => esc_html__('Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-button-arrow .cms-carousel-button-prev i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-slider-button-arrow .cms-carousel-button-next i' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'arrow_color_hover',
            [
                'label'   => esc_html__('Color Hover', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-button-arrow .cms-carousel-button-prev:hover i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-slider-button-arrow .cms-carousel-button-next:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'arrow_size',
            [
                'label'        => esc_html__( 'Arrow Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 60,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'show_arrows_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-tool .cms-slider-button-arrow i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();

        // Dot Style Section Start
        $widget->start_controls_section(
            'dot_style_section',
            [
                'label' => esc_html__('Dots', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dots' => 'yes',
                    'layout!' => '3'
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_dots_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'display: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-bottom' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
                'default' => 'center',
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'text-align: {{VALUE}};justify-content: {{VALUE}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'dot_bottom_space',
            [
                'label'        => esc_html__( 'Dot Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 30,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-carousel-bottom' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Dots Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'dots_color',
            [
                'label' => esc_html__('Dots Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
            ]
        );
        $widget->end_controls_section();
        // Dots Style Section End

        // Title Style Section Start
        $widget->start_controls_section(
            'title_style_section',
            [
                'label' => esc_html__('Title', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_control(
            'title_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'title_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'title_bottom_space',
            [
                'label'        => esc_html__( 'Title Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'title_font',
            [
                'label' => esc_html__('Title Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-title' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-title' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-slider-content .cms-slider-top .cms-slider-item-title' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-title',
                'condition' => [
                    'layout!' => '4'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography_layout4',
                'selector'     => '{{WRAPPER}} .cms-slider-content .cms-slider-top .cms-slider-item-title',
                'condition' => [
                    'layout' => '4'
                ]
            ]
        );
        $widget->end_controls_section();
        // Title Style Section End

        // Subtitle Style Section Start
        $widget->start_controls_section(
            'subtitle_style_section',
            [
                'label' => esc_html__('Subtitle', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_control(
            'subtitle_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'subtitle_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'subtitle_bottom_space',
            [
                'label'        => esc_html__( 'Subtitle Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 30,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-slider-content .cms-slider-top .cms-slider-item-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'subtitle_font',
            [
                'label' => esc_html__('Subtitle Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-subtitle' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-subtitle' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-slider-content .cms-slider-top .cms-slider-item-subtitle' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'subtitle_typography',
                'selector'  => '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-subtitle',
                'condition' => [
                    'layout!' => '4'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'subtitle_typography_layout4',
                'selector'  => '{{WRAPPER}} .cms-slider-content .cms-slider-top .cms-slider-item-subtitle',
                'condition' => [
                    'layout' => '4'
                ]
            ]
        );
        $widget->end_controls_section();
        // Subtitle Style Section End

        // Description Style Section Start
        $widget->start_controls_section(
            'description_style_section',
            [
                'label' => esc_html__('Description', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'show_desc_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-description' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'description_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'description_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );

        $widget->add_responsive_control(
            'description__right_space',
            [
                'label'        => esc_html__( 'Description Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-description' => 'padding-inline-end: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_responsive_control(
            'description__bottom_space',
            [
                'label'        => esc_html__( 'Description Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 30,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'description_typography',
                'selector'  => '{{WRAPPER}} .cms-slider-content .cms-slider-content-text .cms-slider-item-description',
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );
        $widget->end_controls_section();
        // Description Style Section End

        // Button Style Section Start
        $widget->start_controls_section(
            'button_style_section',
            [
                'label' => esc_html__('Button', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_responsive_control(
            'show_button_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-content-text .cms-slider-item-button' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );

        $widget->add_responsive_control(
            'button_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'show_button_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-button .btn' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_style',
            [
                'label' => esc_html__('Button Primary', 'validus'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $widget->add_control(
            'button_primary_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_primary_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_primary_background',
            [
                'label'   => esc_html__('Background Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-button .button-primary:hover a' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_text_color',
            [
                'label'   => esc_html__('Text Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'condition' => [
                    'layout' => ['3','5','6'],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-button .button-primary:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-slider-item-button .button-primary:hover a i' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $widget->add_control(
            'button_secondary_style',
            [
                'label' => esc_html__('Button Secondary', 'validus'),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'layout' => ['1','3','4','7'],
                ],
                'separator' => 'before'
            ]
        );

        $widget->add_control(
            'button_secondary_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'condition' => [
                    'layout' => ['1','3','4','7'],
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_secondary_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'condition' => [
                    'layout' => ['1','3','4','7'],
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_secondary_bacgkround',
            [
                'label'   => esc_html__('Background Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-button .button-secondary:hover a' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => ['1','3','4','7'],
                ],
            ]
        );
        $widget->add_control(
            'button_secondary_text_color',
            [
                'label'   => esc_html__('Text Hover Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'condition' => [
                    'layout' => ['3'],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-button .button-secondary:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-slider-item-button .button-secondary:hover a i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_section();
        // Button Style Section End

        //Box1 Style Section Start
        $widget->start_controls_section(
            'box1_style_section',
            [
                'label' => esc_html__('Box 1', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'show_box1_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-left' => 'display: {{VALUE}};',
                ],
                'condition' => [
                    'layout!' => ['5', '6']
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'show_box_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
				'options' => [
					'' => esc_html__( 'Default', 'validus' ),
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-box' => 'display: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => ['5', '6']
                ],
                'separator' => 'before',
            ]
        );
        $widget->end_controls_section();
        //Box1 Style Section End

        //Box2 Style Section Start
        $widget->start_controls_section(
            'box2_style_section',
            [
                'label' => esc_html__('Box 2', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['4']
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_box2_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-right' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->end_controls_section();
        //Box2 Style Section End

        // Pagination Style Section Start
        $widget->start_controls_section(
            'pagination_style_section',
            [
                'label' => esc_html__('Pagination Slide', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '3'
                ],
            ]
        );

        $widget->add_responsive_control(
            'show_pagination_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
                'options' => [
                    'flex' => esc_html__( 'Yes', 'validus' ),
                    'none' => esc_html__( 'No', 'validus' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-pagination' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'pagination_bottom_space',
            [
                'label'        => esc_html__( 'Progress Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '40',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'condition' => [
                    'show_pagination_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-pagination' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'pagination_text_color',
            [
                'label' => esc_html__('Pagination Text Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet .cms-slider-item-name' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'flex'
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Pagination Typography', 'validus'),
                'name' => 'pagination_typography',
                'selector'     => '{{WRAPPER}} .swiper-pagination-bullet .cms-slider-item-name',
            ]
        );
        $widget->end_controls_section();
        // Pagination Style Section End

        // Video Style Section Start
        $widget->start_controls_section(
            'video_style_section',
            [
                'label' => esc_html__('Video', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['3','5','6']
                ],
            ]
        );

        $widget->add_responsive_control(
            'show_video_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__( 'Default', 'validus' ),
                    'flex' => esc_html__( 'Yes', 'validus' ),
                    'none' => esc_html__( 'No', 'validus' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-item-video' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'video_align',
            [
                'label'        => esc_html__( 'Video Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default' => 'end',
                'condition' => [
                    'layout' => '3',
                    'show_video_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-video' => 'justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'video_bottom_space',
            [
                'label'        => esc_html__( 'Video Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '45',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'condition' => [
                    'layout' => '3',
                    'show_video_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-slider-item-video' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'subject_color',
            [
                'label'   => esc_html__('Subject Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'condition' => [
                    'layout' => '3',
                    'show_video_mobile' => 'flex'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-video-subject' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'condition' => [
                    'layout' => ['3','5','6'],
                    'show_video_mobile' => 'flex'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-slider-video-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-slider-video-title a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'video_button_animation',
            [
                'label'   => esc_html__('Video Button Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'separator' => 'before',
                'condition' => [
                    'layout' => ['3','5','6'],
                    'show_video_mobile' => 'flex'
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'video_button_animation_delay',
            [
                'label'   => esc_html__('Video Button Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'condition' => [
                    'layout' => ['3','5','6'],
                    'show_video_mobile' => 'flex'
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'lightbox_content_animation',
            [
                'label' => esc_html__( 'Entrance Animation', 'validus' ),
                'type' => Controls_Manager::ANIMATION,
                'separator' => 'before',
                'condition' => [
                    'layout' => ['3','5','6'],
                    'show_video_mobile' => 'flex'
                ],
            ]
        );
        $widget->end_controls_section();

        // Style Tab End
    }
}
