<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Modules\DynamicTags\Module as TagsModule;

if (!function_exists('validus_widget_cms_slider_landing_register_controls')) {
    add_action('etc_widget_cms_slider_landing_register_controls', 'validus_widget_cms_slider_landing_register_controls', 10, 1);
    function validus_widget_cms_slider_landing_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'validus'),
            'tab' => Controls_Manager::TAB_LAYOUT,
        ]);
        $widget->add_control('layout', [
            'label' => esc_html__('Templates', 'validus'),
            'type' => Elementor_Theme_Core::LAYOUT_CONTROL,
            'default' => '1',
            'options' => [
                '1' => [
                    'label' => esc_html__('Layout 1', 'validus'),
                    'image' =>
                        get_template_directory_uri() .
                        '/elementor/templates/widgets/cms_slider_landing/layout-images/layout1.jpg',
                ],
            ],
        ]);
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Slider List Section Start
        $widget->start_controls_section('slider_list_section', [
            'label' => esc_html__('Slider List', 'validus'),
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new Repeater();

        $repeater->start_controls_tabs(
			'config_tabs'
		);

            //content
            $repeater->start_controls_tab(
                'content_tab',
                [
                    'label' => esc_html__( 'Content', 'validus' ),
                ]
            );
            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__('Slide Image', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide-bg' => 'background-image: url({{URL}})',
                    ],
                ]
            );
            $repeater->add_control(
                'background_size',
                [
                    'label' => _x( 'Background Size', 'Background Control', 'validus' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'cover',
                    'options' => [
                        'cover' => _x( 'Cover', 'Background Control', 'validus' ),
                        'contain' => _x( 'Contain', 'Background Control', 'validus' ),
                        'auto' => _x( 'Auto', 'Background Control', 'validus' ),
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide-bg' => 'background-size: {{VALUE}}',
                    ],
                    'conditions' => [
                        'terms' => [
                            [
                                'name' => 'image[url]',
                                'operator' => '!=',
                                'value' => '',
                            ],
                        ],
                    ],
                ]
            );
            $repeater->add_control(
                'logo',
                [
                    'label' => esc_html__('Logo Image', 'validus'),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__('Title', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('This is the title', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'description',
                [
                    'label' => esc_html__('Description', 'validus'),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('This is the description', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'button_primary',
                [
                    'label' => esc_html__('Button Primary', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Button Text', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'button_primary_link',
                [
                    'label'       => esc_html__( 'Button Primary Link', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ]
            );
            $repeater->add_control(
                'button_secondary',
                [
                    'label' => esc_html__('Button Secondary', 'validus'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Button Text', 'validus'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'button_secondary_link',
                [
                    'label'       => esc_html__( 'Button Secondary Link', 'validus' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ]
            );
            $repeater->end_controls_tab();

            //style
            $repeater->start_controls_tab(
                'style_tab',
                [
                    'label' => esc_html__( 'Style', 'validus' ),
                ]
            );
            $repeater->add_responsive_control(
                'align',
                [
                    'label'        => esc_html__( 'Content Alignment', 'validus' ),
                    'type'         => \Elementor\Controls_Manager::CHOOSE,
                    'options'      => [
                        'start'   => [
                            'title' => esc_html__( 'Start', 'validus' ),
                            'icon'  => 'fa fa-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'validus' ),
                            'icon'  => 'fa fa-align-center',
                        ],
                        'end'  => [
                            'title' => esc_html__( 'End', 'validus' ),
                            'icon'  => 'fa fa-align-right',
                        ],
                    ],
                    'default' => 'center',
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content' => 'justify-content: {{VALUE}};',
                    ],
                ]
            );
            $repeater->add_responsive_control(
                'width',
                [
                    'label' => esc_html__('Content Width', 'validus'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        '%' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => '38',
                        'unit' => '%'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content-text' => 'max-width: {{SIZE}}%;',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_responsive_control(
                'padding',
                [
                    'label' => esc_html__( 'Content Padding', 'validus' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $repeater->add_responsive_control(
                'height',
                [
                    'label'        => esc_html__( 'Content Height', 'validus' ),
                    'type'         => \Elementor\Controls_Manager::SELECT,
                    'control_type' => 'responsive',
                    'default'      => 'auto',
                    'options'      => [
                        'auto'     => 'Auto',
                        '100%'     => '100%'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content' => 'height: {{VALUE}};',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_responsive_control(
                'border_radius',
                [
                    'label' => esc_html__('Content Border Radius', 'validus'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => '0',
                        'unit' => 'px'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content-text' => '
                            -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                            -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                            -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                            -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                            -o-border-radius: {{SIZE}}{{UNIT}} !important;
                            border-radius: {{SIZE}}{{UNIT}} !important;',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'content_background',
                [
                    'label' => esc_html__('Content Background', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text' => 'background: {{VALUE}};',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_responsive_control(
                'logo_bottom_space',
                [
                    'label' => esc_html__('Logo Bottom Space', 'validus'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 400,
                        ],
                    ],
                    'default' => [
                        'size' => 30,
                        'unit' => 'px'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-logo' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'separator' => 'before',
                    'frontend_available' => true,
                ]
            );
            $repeater->add_responsive_control(
                'title_bottom_space',
                [
                    'label' => esc_html__('Title Bottom Space', 'validus'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => 30,
                        'unit' => 'px'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'separator' => 'before',
                    'frontend_available' => true,
                ]
            );
            $repeater->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'      => 'title_typography',
                    'label'     => 'Title Typography',
                    'selector'  => '{{WRAPPER}} .item-content .item-content-text .item-title',
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'title_color',
                [
                    'label' => esc_html__('Title Color', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-title' => 'color: {{VALUE}};',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_responsive_control(
                'description_bottom_space',
                [
                    'label' => esc_html__('Description Bottom Space', 'validus'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => 30,
                        'unit' => 'px'
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'separator' => 'before',
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'description_color',
                [
                    'label' => esc_html__('Description Color', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-description' => 'color: {{VALUE}};',
                    ],
                    'frontend_available' => true,
                ]
            );
            $repeater->add_control(
                'btn_primary_hover',
                [
                    'label' => esc_html__('Button Primary Background Hover', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-button .btn-primary:hover' => 'background: {{VALUE}};',
                    ],
                    'separator' => 'before',
                ]
            );
            $repeater->add_control(
                'btn_primary_icon_hover',
                [
                    'label' => esc_html__('Button Primary Element Hover', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-button .btn-primary:hover > *' => 'color: {{VALUE}};',
                    ],
                    'separator' => 'before',
                ]
            );
            $repeater->add_control(
                'btn_secondary_hover',
                [
                    'label' => esc_html__('Button Secondary Background Hover', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-button .btn-white:hover' => 'background: {{VALUE}};',
                    ],
                ]
            );
            $repeater->add_control(
                'btn_secondary_icon_hover',
                [
                    'label' => esc_html__('Button Secondary Element Hover', 'validus'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}} .item-content .item-content-text .item-button .btn-white:hover > *' => 'color: {{VALUE}};',
                    ],
                    'separator' => 'before',
                ]
            );
            $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $widget->add_control(
            'cms_slides',
            [
                'label' => esc_html__('Slides', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Industrial Business & Handyman Services WordPress Theme!', 'validus'),
                        'description' => esc_html__('Validus is a stunning WordPress theme created for industry business: manufacturing, construction, solar energy, electrician, factory, maintenance, metal works, air conditioning, and other Handyman Services.', 'validus'),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Industrial Business & Handyman Services WordPress Theme!', 'validus'),
                        'description' => esc_html__('Validus is a stunning WordPress theme created for industry business: manufacturing, construction, solar energy, electrician, factory, maintenance, metal works, air conditioning, and other Handyman Services.', 'validus'),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Industrial Business & Handyman Services WordPress Theme!', 'validus'),
                        'description' => esc_html__('Validus is a stunning WordPress theme created for industry business: manufacturing, construction, solar energy, electrician, factory, maintenance, metal works, air conditioning, and other Handyman Services.', 'validus'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->end_controls_section();
        // Slider List Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 3);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Style Tab Start
        // General Style Section Start
        $widget->start_controls_section(
            'general_style_section',
            [
                'label' => esc_html__('General', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'slides_height',
            [
                'label'        => esc_html__( 'Slide Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '900',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 400,
                        'max' => 1000,
                    ],
                ],
                'condition' => [
                    //'adjust_slides_height' => 'custom'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel .cms-carousel-item' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // General Style Section End

        // Dot Style Section Start
        $widget->start_controls_section(
            'dot_style_section',
            [
                'label' => esc_html__('Dots', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_dots_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_responsive_control(
            'dot_align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => [
                    'start'   => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'  => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
                'default' => 'center',
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'text-align: {{VALUE}};justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'dot_bottom_space',
            [
                'label'        => esc_html__( 'Dot Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 30,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-carousel-bottom' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'dot_lr_space',
            [
                'label'        => esc_html__( 'Dot Left-Right Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '30',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    'show_dots_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-carousel-dots' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Dots Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'flex'
                ],
            ]
        );
        $widget->add_responsive_control(
            'dots_color',
            [
                'label' => esc_html__('Dots Active Color', 'validus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                    'show_dots_mobile' => 'flex'
                ],
            ]
        );
        $widget->end_controls_section();
        // Dots Style Section End

        // Title Style Section Start
        $widget->start_controls_section(
            'title_style_section',
            [
                'label' => esc_html__('Title', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_control(
            'title_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'title_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'title_font',
            [
                'label' => esc_html__('Title Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-title' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .item-content .item-content-text .item-title' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->end_controls_section();
        // Title Style Section End

        // Description Style Section Start
        $widget->start_controls_section(
            'description_style_section',
            [
                'label' => esc_html__('Description', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'show_desc_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'block',
				'options' => [
					'block' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .item-content .item-content-text .item-description' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'description_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );

        $widget->add_control(
            'description_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'description_typography',
                'label'     => esc_html__( 'Description Typography', 'validus' ),
                'selector'  => '{{WRAPPER}} .item-content .item-content-text .item-description',
                'condition' => [
                    'show_desc_mobile' => 'block'
                ],
            ]
        );
        $widget->end_controls_section();
        // Description Style Section End

        // Button Style Section Start
        $widget->start_controls_section(
            'button_style_section',
            [
                'label' => esc_html__('Button', 'validus'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_responsive_control(
            'show_button_mobile',
            [
                'label'   => esc_html__('Show On Small Screen', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'flex',
				'options' => [
					'flex' => esc_html__( 'Yes', 'validus' ),
					'none' => esc_html__( 'No', 'validus' ),
				],
                'selectors' => [
                    '{{WRAPPER}} .item-content-text .item-button' => 'display: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );

        $widget->add_responsive_control(
            'button_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => 0,
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'show_button_mobile' => 'flex'
                ],
                'selectors'    => [
                    '{{WRAPPER}} .item-button .btn' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $widget->add_control(
            'button_primary_style',
            [
                'label' => esc_html__('Button Primary', 'validus'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $widget->add_control(
            'button_primary_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_primary_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_secondary_style',
            [
                'label' => esc_html__('Button Secondary', 'validus'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $widget->add_control(
            'button_secondary_animation',
            [
                'label'   => esc_html__('Animation', 'validus'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'button_secondary_animation_delay',
            [
                'label'   => esc_html__('Animation Delay', 'validus'),
                'type'    => Controls_Manager::NUMBER,
                'min' => 50,
                'step' => 50,
                'default' => 350,
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Button Style Section End

        // Style Tab End
    }
}
