<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_social_icons_register_controls')) {
    add_action('etc_widget_cms_social_icons_register_controls', 'validus_widget_cms_social_icons_register_controls', 10, 1);
    function validus_widget_cms_social_icons_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_social_icons/layout-images/layout1.png'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_social_icons/layout-images/layout2.png'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_social_icons/layout-images/layout3.png'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End


        // Content Tab Start

        // icon Section Start
        $widget->start_controls_section(
            'section_icon',
            [
                'label' => esc_html__('Icons', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'social_icon',
            [
                'label' => esc_html__( 'Icon', 'validus' ),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'social',
                'default' => [
                    'value' => 'fab fa-wordpress',
                    'library' => 'fa-brands',
                ],
                'recommended' => [
                    'fa-brands' => [
                        'android',
                        'apple',
                        'behance',
                        'bitbucket',
                        'codepen',
                        'delicious',
                        'deviantart',
                        'digg',
                        'dribbble',
                        'facebook',
                        'flickr',
                        'foursquare',
                        'free-code-camp',
                        'github',
                        'gitlab',
                        'globe',
                        'houzz',
                        'instagram',
                        'jsfiddle',
                        'linkedin',
                        'medium',
                        'meetup',
                        'mix',
                        'mixcloud',
                        'odnoklassniki',
                        'pinterest',
                        'product-hunt',
                        'reddit',
                        'shopping-cart',
                        'skype',
                        'slideshare',
                        'snapchat',
                        'soundcloud',
                        'spotify',
                        'stack-overflow',
                        'steam',
                        'telegram',
                        'thumb-tack',
                        'tripadvisor',
                        'tumblr',
                        'twitch',
                        'twitter',
                        'viber',
                        'vimeo',
                        'vk',
                        'weibo',
                        'weixin',
                        'whatsapp',
                        'wordpress',
                        'xing',
                        'yelp',
                        'youtube',
                        '500px',
                    ],
                    'fa-solid' => [
                        'envelope',
                        'link',
                        'rss',
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'validus' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Social Title',
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label' => esc_html__( 'Link', 'validus' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'is_external' => 'true',
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'validus' ),
            ]
        );

        $widget->add_control(
            'icons',
            [
                'label' => esc_html__('Icons', 'validus'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'social_icon' => [
                            'value' => 'cmsi cmsi-facebook-circle-alt',
                            'library' => 'cmsi-social',
                        ],
                        'title' => 'Facebook',
                    ],
                    [
                        'social_icon' => [
                            'value' => 'cmsi cmsi-twitter',
                            'library' => 'cmsi-social',
                        ],
                        'title' => 'Twitter',
                    ],
                    [
                        'social_icon' => [
                            'value' => 'cmsi cmsi-youtube',
                            'library' => 'cmsi-social',
                        ],
                         'title' => 'Youtube',
                    ],
                ],
                'title_field' => '{{{ "<i class=\"" + social_icon.value + "\"></i>" + " " + title }}}',
            ]
        );
        $widget->end_controls_section();
        // icon Section End
        // Content Tab End

        // Style Tab Start
        // Icons Style Section Start
        $widget->start_controls_section(
            'icons_style_section',
            [
                'label' => esc_html__('Icons', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'icon_gap',
            [
                'label'        => esc_html__( 'Icons Gap', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-social-icons-wrap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'icon_padding',
            [
                'label'        => esc_html__( 'Icon Padding', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'condition' => [
                    'layout' => '1',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-social-icon i' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'icon_radius',
            [
                'label'        => esc_html__( 'Icons Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-social-icon i' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'icon_size',
            [
                'label'        => esc_html__( 'Icons Size', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-social-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__( 'Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__( 'End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ]
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-social-icons-wrap' => 'justify-content: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'primary',
                'options' => [
                    '' => esc_html__( 'Official Color', 'validus' ),
                    'custom' => esc_html__( 'Custom', 'validus' ),
                    'primary' => esc_html__( 'Primary', 'validus' ),
                    'secondary' => esc_html__( 'Secondary', 'validus' ),
                ],
            ]
        );
        $widget->add_control(
            'icon_primary_color',
            [
                'label' => esc_html__( 'Background Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon i' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'icon_secondary_color',
            [
                'label' => esc_html__( 'Icon Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'icon_color' => 'custom',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-social-icon svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_section();
        // Icons Style Section End

        // Icons Hover Style Section Start
        $widget->start_controls_section(
            'icons_hover_style_section',
            [
                'label' => esc_html__('Icons Hover', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'hover_primary_color',
            [
                'label' => esc_html__( 'Background Hover Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon:hover i' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'hover_secondary_color',
            [
                'label' => esc_html__( 'Icon Hover Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon:hover i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-social-icon i:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'border_hover_color',
            [
                'label' => esc_html__( 'Border Icon Hover Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon:hover i' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'hover_animation',
            [
                'label' => esc_html__( 'Hover Animation', 'validus' ),
                'type' => Controls_Manager::HOVER_ANIMATION,
            ]
        );

        $widget->end_controls_section();
        // Icons Hover Style Section End

        // Icons Hover Style Section Start
        $widget->start_controls_section(
            'title_section',
            [
                'label' => esc_html__('Title', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
			'show_title',
			[
				'label' => esc_html__( 'Show Title', 'validus' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'validus' ),
				'label_off' => esc_html__( 'Hide', 'validus' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
        $widget->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'condition' => [
                    'show_title' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'title_hover_color',
            [
                'label' => esc_html__( 'Title Hover Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'condition' => [
                    'show_title' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-social-icon:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_section();
        // Icons Hover Style Section End
        // Style Tab End

    }
}