<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

if (!function_exists('validus_widget_cms_support_register_controls')) {
    add_action('etc_widget_cms_support_register_controls', 'validus_widget_cms_support_register_controls', 10, 1);
    function validus_widget_cms_support_register_controls($widget)
    {
        // Layout Tab Start

        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_support/layout-images/layout1.jpg'
                    ],
                ],
            ]
        );
        $widget->end_controls_section();
        // Layout Section End

        // Layout Tab End

        // Content Tab Start

        // Icon Section Start
        $widget->start_controls_section(
            'support_section',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'background_image',
            [
                'label'   => esc_html__('Background Image', 'validus'),
                'type'    => Controls_Manager::MEDIA,
                'description' => esc_html__('Select image.', 'validus'),
                'default' => [
                    'id' => '-1',
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),// Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
            [
                'name' => 'thumbnail',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('This is the heading', 'validus'),
                'placeholder' => esc_html__('Enter your title', 'validus'),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'description',
            [
                'label'   => esc_html__('Description', 'validus'),
                'type'    => Controls_Manager::TEXTAREA,
                'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'validus'),
                'placeholder' => esc_html__('Enter your description', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->add_control(
            'phone',
            [
                'label'   => esc_html__('Phone', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default'     => esc_html__('02 01061245741', 'validus'),
                'placeholder' => esc_html__('Enter your phone', 'validus'),
                'rows'        => 10,
                'show_label'  => true,
            ]
        );
        $widget->add_control(
            'btn_style',
            [
                'label'   => esc_html__( 'Button Style', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'btn btn-lg btn-white',
                'options' => [
                    'btn btn-lg btn-secondary btn-hover-white'     => esc_html__( 'Secondary', 'validus' ),
                    'btn btn-lg btn-white'     => esc_html__( 'White', 'validus' ),
                    'btn btn-outline-white btn-hover-outline-black'     => esc_html__( 'Outline White', 'validus' ),
                    'btn-text-underline'        => esc_html__( 'Underline', 'validus' ),
                ],
            ]
        );
        $widget->add_control(
            'btn_text',
            [
                'label'   => esc_html__('Button Text', 'validus'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Schedule An Appointment',
            ]
        );
        $widget->add_control(
            'btn_link_type',
            [
                'label'   => esc_html__('Button Link Type', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'custom' => esc_html__('Custom', 'validus'),
                    'page' => esc_html__('Page', 'validus'),
                ],
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'btn_page_link',
            [
                'label'   => esc_html__('Select Page', 'validus'),
                'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                'post_types' => [
                    'page',
                    'post',
                ],
                'multiple' => true,
                'condition' => [
                    'btn_link_type' => 'page',
                ],
            ]
        );
        $widget->add_control(
            'btn_link',
            [
                'label'   => esc_html__('Button Link', 'validus'),
                'type'    => Controls_Manager::URL,
                'condition' => [
                    'btn_link_type' => 'custom',
                ],
            ]
        );
        $widget->end_controls_section();
        // Icon Section End

        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'style',
            [
                'label'   => esc_html__('Text Color', 'validus'),
                'type'    => Controls_Manager::SELECT,
                'options'   => [
                    '#fff' => 'White',
                    'var(--color-secondary)' => 'Black',
                ],
                'default'   => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .cms-support-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-support-description' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-support-phone i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-support-phone span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'title_color',
            [
                'label'   => esc_html__('Title Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-support-title' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Title Typography', 'validus'),
                'name' => 'title_typography',
                'selector'     => '{{WRAPPER}} .cms-support-title',
            ]
        );
        $widget->add_control(
            'description_color',
            [
                'label'   => esc_html__('Description Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-support-description' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'   => esc_html__('Description Typography', 'validus'),
                'name' => 'description_typography',
                'selector'     => '{{WRAPPER}} .cms-support-description',
            ]
        );
        $widget->add_control(
            'phone_color',
            [
                'label'   => esc_html__('Phone Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-support-phone i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-support-phone span' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'btn_color',
            [
                'label'   => esc_html__('Button Text Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-support-button a' => 'color: {{VALUE}};border-color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'background_color',
            [
                'label'   => esc_html__('Background Color', 'validus'),
                'type'    => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-support-background' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );
        $widget->add_control(
            'opacity',
            [
                'label'        => esc_html__( 'Background Image Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '7',//15
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-support-background img' => 'opacity: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Style Section End

        // Content Tab End

    }
}
