<?php

use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_team_grid_register_controls')) {
    add_action('etc_widget_cms_team_grid_register_controls', 'validus_widget_cms_team_grid_register_controls', 10, 1);
    function validus_widget_cms_team_grid_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_team_grid/layout-image/layout1.jpg'
                    ],
                ],
                'default' => '1',
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Team Name', 'validus'),
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label' => esc_html__('Position', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Team Position', 'validus'),
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'       => esc_html__( 'Button Secondary Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $repeater->add_control(
            'social_links',
            [
                'label' => esc_html__('Social Links', 'validus'),
                'type' => Elementor_Theme_Core::ICONS_CONTROL,
            ]
        );

        $widget->add_control(
            'teams',
            [
                'label' => esc_html__('Teams', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Name #1', 'validus'),
                        'position' => esc_html__('Position #1', 'validus'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Name #2', 'validus'),
                        'position' => esc_html__('Position #2', 'validus'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        $widget->end_controls_section();
        // List Section End


        // Content Tab End
    }
}
