<?php

use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_teams_register_controls')) {
    add_action('etc_widget_cms_teams_register_controls', 'validus_widget_cms_teams_register_controls', 10, 1);
    function validus_widget_cms_teams_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout_mode',
            [
                'label' => esc_html__('Layout Mode', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'carousel' => esc_html__('Carousel', 'validus' ),
                    'grid' => esc_html__('Grid', 'validus' ),
                ],
                'default' => 'carousel',
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout-image/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout-image/layout2.jpg'
                    ],
                ],
                'default' => '1',
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Richard Muldoone', 'validus'),
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label' => esc_html__('Position', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Legal Officer', 'validus'),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description (Choose Layout 2 First)', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Customers are increasingly demanding more supply chain transparency on ESG issues to allow better traceability and control.', 'validus'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'       => esc_html__('Link', 'validus' ),
                'type'        => Controls_Manager::URL,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'separator' => 'after',
            ]
        );

        //just use esc_html__ if need really escape html
        for ($i = 1; $i <= 4; $i++) { 
            $repeater->add_control(
                "social_icon_{$i}",
                [
                    'label' => esc_html("Social Icon {$i}" ),
                    'type' => Controls_Manager::ICONS,
                    'default' => [
                        'library'   => 'cmsi',
                        'value'     => 'cmsi-facebook-circle-alt'
                    ]
                ]
            );

            $repeater->add_control(
                "social_link_{$i}",
                [
                    'label' => esc_html("Social Link {$i}" ),
                    'type' => \Elementor\Controls_Manager::URL,
                    'placeholder' => 'https://your-link.com',
                    'options' => [ 'url', 'is_external', 'nofollow' ],
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'separator' => 'after',
                ]
            );
        }

        $widget->add_control(
            'teams',
            [
                'label' => esc_html__('Teams', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Richard Muldoone', 'validus'),
                        'position' => esc_html__('Legal Officer', 'validus'),
                        'description' => esc_html__('Description #1', 'validus'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Richard Muldoone', 'validus'),
                        'position' => esc_html__('Legal Officer', 'validus'),
                        'description' => esc_html__('Description #2', 'validus'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Richard Muldoone', 'validus'),
                        'position' => esc_html__('Legal Officer', 'validus'),
                        'description' => esc_html__('Description #3', 'validus'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        $widget->add_responsive_control(
            'align',
            [
                'label'        => esc_html__('Text Alignment', 'validus' ),
                'type'         => Controls_Manager::CHOOSE,
                'control_type' => 'responsive',
                'options'      => [
                    'start'    => [
                        'title' => esc_html__('Start', 'validus' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__('Center', 'validus' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'end'   => [
                        'title' => esc_html__('End', 'validus' ),
                        'icon'  => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-team-item-description' => 'text-align: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->end_controls_section();
        // List Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End

        // Content Tab End
    }
}
