<?php

use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('validus_widget_cms_testimonials_register_controls')) {
    add_action('etc_widget_cms_testimonials_register_controls', 'validus_widget_cms_testimonials_register_controls', 10, 1);
    function validus_widget_cms_testimonials_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );

        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout-image/layout2.jpg'
                    ],
                ],
                'default' => '2',
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'validus'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Testimonial Name', 'validus'),
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label' => esc_html__('Position', 'validus'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Testimonial Position', 'validus'),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'validus'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Testimonial Description', 'validus'),
            ]
        );

        $widget->add_control(
            'testimonials',
            [
                'label' => esc_html__('Testimonials', 'validus'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Martin Qube Jr', 'validus'),
                        'position' => esc_html__('Dust Manager', 'validus'),
                        'description' => esc_html__('Expertly trained team members who take the extra step and go the extra mile, all to fulfill our promise, deliver innovative and dynamic solutions to our customers! I’ve seen great companies serving industry solutions in my career. But not to the point where you feel that comfort and trust that we get with Validus Industries.', 'validus'),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Michael Brian', 'validus'),
                        'position' => esc_html__('The Founder', 'validus'),
                        'description' => esc_html__('Expertly trained team members who take the extra step and go the extra mile, all to fulfill our promise, deliver innovative and dynamic solutions to our customers! I’ve seen great companies serving industry solutions in my career. But not to the point where you feel that comfort and trust that we get with Validus Industries.', 'validus'),
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        
        $widget->add_control(
            'selected_icon',
            [
                'label'   => esc_html__('Icon', 'validus'),
                'type'    => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'library' => 'fa-solid',
                    'value'   => 'fas fa-quote-left'       
                ]
            ]
        );
        $widget->end_controls_section();
        // List Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'validus'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'validus'),
                'type' => Controls_Manager::HIDDEN,
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'default' => '1',
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'validus'),
                'options' => [
                        '' => esc_html__('Default', 'validus'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show People', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'validus'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'validus'),
                    'fade' => esc_html__('Fade', 'validus'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'validus'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();


        $widget->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('General Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'layout_style',
            [
                'label' => esc_html__('Layout Style', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => 'row',
                'options' => [
                    'column' => esc_html__('Column', 'validus'),
                    'row' => esc_html__('Row', 'validus'),
                ],
                'frontend_available' => true,
                'selectors' => [
                    '{{WRAPPER}} .cms-testimonial-item-content' => 'flex-direction: {{VALUE}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'gap',
            [
                'label' => esc_html__('Gap', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'default' => [
                    'size' => 40,
                ],
                'condition' => [
                    'layout_style' => 'column',
                ],
                'frontend_available' => true,
                'selectors' => [
                    //'{{WRAPPER}} .cms-testimonial-item-content .cms-testimonial-info' => 'margin-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-testimonial-item-content' => 'gap: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-carousel-pagination' => 'padding-inline-start: 0px;margin-inline-start: -6px;',
                ],
            ]
        );
        $widget->add_control(
            'background_color',
            [
                'label'     => esc_html__( 'Background Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .cms-testimonials-carousel-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $widget->end_controls_section();


        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Text Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $widget->add_control(
            'text_color',
            [
                'label'     => esc_html__( 'Text Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#9b9b9b',
                'selectors' => [
                    '{{WRAPPER}} .cms-testimonial-icon' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-testimonial-item-description' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-testimonial-text > *' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'text_font',
            [
                'label' => esc_html__('Text Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-testimonial-item-description' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-testimonial-text > *' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'      => 'text_typography',
                'selector'  => '{{WRAPPER}} .cms-testimonial-item-content .cms-testimonial-info .cms-testimonial-item-description',
            ]
        );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'pagi_style',
            [
                'label' => esc_html__('Pagination Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'pagi_top_space',
            [
                'label' => esc_html__('Top Spacing', 'validus'),
                'description' => esc_html__('Default on layout 2: 21px;', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -20,
                        'max' => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-pagination' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End
    }
}
