<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('validus_widget_cms_text_editor_register_controls')) {
    add_action('etc_widget_cms_text_editor_register_controls', 'validus_widget_cms_text_editor_register_controls', 10, 1);
    function validus_widget_cms_text_editor_register_controls($widget)
    {
        // Content Tab Start

        // Content Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Content', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'text',
            [
                'label'       => esc_html__( 'Text', 'validus' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter text', 'validus' ),
                'rows'        => 10,
                'show_label'  => true,
                'default'     => 'Besides, fleet software keeps vehicles charged and ready with optimized fueling through dynamic depot charging optimization, comprehensive take-home vehicle charging management.'
            ]
        );
        $widget->end_controls_section();
        // Content Section End

        // Style Description Style Start
        $widget->start_controls_section(
            'section_style_text',
            [
                'label' => esc_html__('Text Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_control(
            'text_color',
            [
                'label'      => esc_html__( 'Color', 'validus' ),
                'type'       => \Elementor\Controls_Manager::COLOR,
                'selectors'  => [
                    '{{WRAPPER}} .cms-text-editor' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'selector'     => '{{WRAPPER}} .cms-text-editor p',
            ]
        );
        $widget->add_responsive_control(
            'space_between_paragraph',
            [
                'label'        => esc_html__( 'Spacing Between Paragraphs', 'validus' ),
                'description'  => esc_html__( 'Note: it works only when the text contain 2 or more paragraphs separated by space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '27',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-text-editor' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
			'alignment',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'start',
				'selectors' => [
					'{{WRAPPER}} .cms-text-editor' => 'text-align: {{VALUE}};',
				],
			]
		);
        $widget->end_controls_section(); // Style Description Style End

    }
}
