<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Modules\DynamicTags\Module as TagsModule;

if (!function_exists('validus_widget_cms_video_register_controls')) {
    add_action('etc_widget_cms_video_register_controls', 'validus_widget_cms_video_register_controls', 10, 1);
    function validus_widget_cms_video_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'validus'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'validus' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video/layout-images/layout1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'validus' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video/layout-images/layout2.jpg'
                    ],
                ],
            ]
        );

        $widget->end_controls_section();
        // Layout Section End


        $widget->start_controls_section(
            'section_video',
            [
                'label' => esc_html__( 'Video', 'validus' ),
            ]
        );

        $widget->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'validus' ),
                'type' => Controls_Manager::TEXT,
                'description' => esc_html__( 'It will show above video', 'validus' ),
                'default' => '',//Overview
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'description',
            [
                'label' => esc_html__( 'Description (Above Video)', 'validus' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'frontend_available' => true,
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_control(
            'description_layout2',
            [
                'label' => esc_html__( 'Description', 'validus' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Fostering The Growth Of Solar Energy!',
                'frontend_available' => true,
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $widget->add_control(
            'description2',
            [
                'label' => esc_html__( 'Description 2 (Below Video)', 'validus' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'frontend_available' => true,
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );

        $widget->add_control(
            'video_type',
            [
                'label' => esc_html__( 'Source', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'youtube',
                'options' => [
                    'youtube' => esc_html__( 'YouTube', 'validus' ),
                    'vimeo' => esc_html__( 'Vimeo', 'validus' ),
                    'dailymotion' => esc_html__( 'Dailymotion', 'validus' ),
                    'hosted' => esc_html__( 'Self Hosted', 'validus' ),
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'youtube_url',
            [
                'label' => esc_html__( 'Link', 'validus' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (YouTube)',
                'default' => 'https://www.youtube.com/watch?v=XHOmBV4js_E',
                'label_block' => true,
                'condition' => [
                    'video_type' => 'youtube',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'vimeo_url',
            [
                'label' => esc_html__( 'Link', 'validus' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (Vimeo)',
                'default' => 'https://vimeo.com/235215203',
                'label_block' => true,
                'condition' => [
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $widget->add_control(
            'dailymotion_url',
            [
                'label' => esc_html__( 'Link', 'validus' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'validus' ) . ' (Dailymotion)',
                'default' => 'https://www.dailymotion.com/video/x6tqhqb',
                'label_block' => true,
                'condition' => [
                    'video_type' => 'dailymotion',
                ],
            ]
        );

        $widget->add_control(
            'insert_url',
            [
                'label' => esc_html__( 'External URL', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [
                    'video_type' => 'hosted',
                ],
            ]
        );

        $widget->add_control(
            'hosted_url',
            [
                'label' => esc_html__( 'Choose File', 'validus' ),
                'type' => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                    'categories' => [
                        TagsModule::MEDIA_CATEGORY,
                    ],
                ],
                'media_type' => 'video',
                'condition' => [
                    'video_type' => 'hosted',
                    'insert_url' => '',
                ],
            ]
        );

        $widget->add_control(
            'external_url',
            [
                'label' => esc_html__( 'URL', 'validus' ),
                'type' => Controls_Manager::URL,
                'autocomplete' => false,
                'options' => false,
                'label_block' => true,
                'show_label' => false,
                'dynamic' => [
                    'active' => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'media_type' => 'video',
                'placeholder' => esc_html__( 'Enter your URL', 'validus' ),
                'condition' => [
                    'video_type' => 'hosted',
                    'insert_url' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'start',
            [
                'label' => esc_html__( 'Start Time', 'validus' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify a start time (in seconds)', 'validus' ),
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'end',
            [
                'label' => esc_html__( 'End Time', 'validus' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify an end time (in seconds)', 'validus' ),
                'condition' => [
                    'video_type' => [ 'youtube', 'hosted' ],
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'video_options',
            [
                'label' => esc_html__( 'Video Options', 'validus' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'show_image_overlay',
                            'value' => '',
                        ],
                        [
                            'name' => 'image_overlay[url]',
                            'value' => '',
                        ],
                    ],
                ],
            ]
        );

        $widget->add_control(
            'play_on_mobile',
            [
                'label' => esc_html__( 'Play On Mobile', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'mute',
            [
                'label' => esc_html__( 'Mute', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'loop',
            [
                'label' => esc_html__( 'Loop', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [
                    'video_type!' => 'dailymotion',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'controls',
            [
                'label' => esc_html__( 'Player Controls', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type!' => 'vimeo',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'showinfo',
            [
                'label' => esc_html__( 'Video Info', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type' => [ 'dailymotion' ],
                ],
            ]
        );

        $widget->add_control(
            'modestbranding',
            [
                'label' => esc_html__( 'Modest Branding', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [
                    'video_type' => [ 'youtube' ],
                    'controls' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'logo',
            [
                'label' => esc_html__( 'Logo', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type' => [ 'dailymotion' ],
                ],
            ]
        );

        // YouTube.
        $widget->add_control(
            'yt_privacy',
            [
                'label' => esc_html__( 'Privacy Mode', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'When you turn on privacy mode, YouTube/Vimeo won\'t store information about visitors on your website unless they play the video.', 'validus' ),
                'condition' => [
                    'video_type' => [ 'youtube', 'vimeo' ],
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazy_load',
            [
                'label' => esc_html__( 'Lazy Load', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'video_type',
                            'operator' => '===',
                            'value' => 'youtube',
                        ],
                        [
                            'relation' => 'and',
                            'terms' => [
                                [
                                    'name' => 'show_image_overlay',
                                    'operator' => '===',
                                    'value' => 'yes',
                                ],
                                [
                                    'name' => 'video_type',
                                    'operator' => '!==',
                                    'value' => 'hosted',
                                ],
                            ],
                        ],
                    ],
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'rel',
            [
                'label' => esc_html__( 'Suggested Videos', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => esc_html__( 'Current Video Channel', 'validus' ),
                    'yes' => esc_html__( 'Any Video', 'validus' ),
                ],
                'condition' => [
                    'video_type' => 'youtube',
                ],
            ]
        );

        // Vimeo.
        $widget->add_control(
            'vimeo_title',
            [
                'label' => esc_html__( 'Intro Title', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $widget->add_control(
            'vimeo_portrait',
            [
                'label' => esc_html__( 'Intro Portrait', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $widget->add_control(
            'vimeo_byline',
            [
                'label' => esc_html__( 'Intro Byline', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
                'condition' => [
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $widget->add_control(
            'color',
            [
                'label' => esc_html__( 'Controls Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'condition' => [
                    'video_type' => [ 'vimeo', 'dailymotion' ],
                ],
            ]
        );

        $widget->add_control(
            'download_button',
            [
                'label' => esc_html__( 'Download Button', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'condition' => [
                    'video_type' => 'hosted',
                ],
            ]
        );

        $widget->add_control(
            'preload',
            [
                'label' => esc_html__( 'Preload', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'metadata' => esc_html__( 'Metadata', 'validus' ),
                    'auto' => esc_html__( 'Auto', 'validus' ),
                    'none' => esc_html__( 'None', 'validus' ),
                ],
                'description' => sprintf(
                    esc_html__( 'Preload attribute lets you specify how the video should be loaded when the page loads. %1$sLearn More%2$s', 'validus' ),
                    '<a target="_blank" href="https://go.elementor.com/preload-video/">',
                    '</a>'
                ),
                'default' => 'metadata',
                'condition' => [
                    'video_type' => 'hosted',
                    'autoplay' => '',
                ],
            ]
        );

        $widget->add_control(
            'view',
            [
                'label' => esc_html__( 'View', 'validus' ),
                'type' => Controls_Manager::HIDDEN,
                'default' => 'youtube',
            ]
        );

        $widget->end_controls_section();

        $widget->start_controls_section(
            'section_image_overlay',
            [
                'label' => esc_html__( 'Image Overlay', 'validus' ),
            ]
        );

        $widget->add_control(
            'show_image_overlay',
            [
                'label' => esc_html__( 'Image Overlay', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'validus' ),
                'label_on' => esc_html__( 'Show', 'validus' ),
                'default' => 'yes',
            ]
        );

        $widget->add_control(
            'image_overlay',
            [
                'label' => esc_html__( 'Choose Image', 'validus' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image_overlay', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_overlay_size` and `image_overlay_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
                'condition' => [
                    'show_image_overlay' => 'yes',
                ],
            ]
        );

        $widget->add_responsive_control(
            'image_overlay_width',
            [
                'label' => esc_html__( 'Width', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'default' => '100%',
                'options' => [
                    'auto' => esc_html__( 'Auto', 'validus' ),
                    '100%' => esc_html__( '100%', 'validus' ),
                ],
                'description' => esc_html__( 'If you want the image width is equal with colummn width, set width = 100%', 'validus' ),
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-play .elementor-custom-embed-image-overlay > img' => 'width: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'show_play_icon',
            [
                'label' => esc_html__( 'Play Icon', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'separator' => 'before',
                'condition' => [
                    'show_image_overlay' => 'yes',
                    //'image_overlay[url]!' => '',
                ],
            ]
        );
        $widget->add_control(
            'quick_icon',
            [
                'label'   => esc_html__( 'Quick Select Icon', 'validus' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'play-icon-04',
                'options' => [
                    'play-icon-04'     => esc_html__( 'Default', 'validus' ),
                    'play-icon-01'     => esc_html__( 'Play Icon 01', 'validus' ),
                    'play-icon-02'     => esc_html__( 'Play Icon 02', 'validus' ),
                    'play-icon-03'     => esc_html__( 'Play Icon 03', 'validus' ),
                    'play-icon-05'     => esc_html__( 'Play Icon 05', 'validus' ),
                    'play-icon-06'     => esc_html__( 'Play Icon 06', 'validus' ),
                    'play-icon-07'     => esc_html__( 'Play Icon 07', 'validus' ),
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon!' => '',
                ],
            ]
        );
        $widget->add_control(
            'play_rotate',
            [
                'label'     => esc_html__( 'Rotate Icon', 'validus' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'condition' => [
                    'quick_icon!' => ['play-icon-02','play-icon-06'],
                ],
            ]
        );

        $widget->add_control(
            'lightbox',
            [
                'label' => esc_html__( 'Lightbox', 'validus' ),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
                'label_off' => esc_html__( 'Off', 'validus' ),
                'label_on' => esc_html__( 'On', 'validus' ),
                'condition' => [
                    'show_image_overlay' => 'yes',
                ],
                'separator' => 'before',
            ]
        );

        $widget->end_controls_section();

        //General Section
        $widget->start_controls_section(
            'section_general_style',
            [
                'label' => esc_html__( 'General', 'validus' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'content_width',
            [
                'label' => esc_html__('Content With', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'description' => esc_html__('Just work if the title or content exist.', 'validus'),
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => '100',
                    'unit' => '%'
                ],
                'condition' => [
                    'layout' => '2',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-video-content-container' => 'width: {{SIZE}}%;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'content_top_space',
            [
                'label' => esc_html__('Content Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'description' => esc_html__('Just work if the title or content exist.', 'validus'),
                'size_units' => ['%','px'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'default_args' => [
                    'laptop' => '',
                    'tablet' => '',
                    'tablet_extra' => '',
                    'mobile_extra' => '',
                    'mobile' => ''
                ],
                'condition' => [
                    'layout' => '2',
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-video-content' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
			'content_alignment',
			[
				'label' => esc_html__( 'Alignment', 'validus' ),
				'type' => Controls_Manager::CHOOSE,
                'description' => esc_html__('Just work if the title or content exist.', 'validus'),
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'validus' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'validus' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'validus' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
                'condition' => [
                    'layout' => '2',
                ],
				'selectors' => [
					'{{WRAPPER}} .cms-video-content-container' => 'text-align: {{VALUE}};justify-content: {{VALUE}};',
				],
			]
		);
        $widget->add_control(
            'content_style',
            [
                'label' => esc_html__( 'Text Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-video-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-video-description' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-video-content .cms-video-content-container .cms-video-description' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-video-description2' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '2',
                ],
            ]
        );
        $widget->add_control(
            'border_radius',
            [
                'label'        => esc_html__( 'Border Radius', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '10',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-play .elementor-custom-embed-image-overlay > img' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                    '{{WRAPPER}} .cms-video-layout2' => '
                        -webkit-border-radius: {{SIZE}}{{UNIT}} !important;
                        -khtml-border-radius: {{SIZE}}{{UNIT}} !important;
                        -moz-border-radius: {{SIZE}}{{UNIT}} !important;
                        -ms-border-radius: {{SIZE}}{{UNIT}} !important;
                        -o-border-radius: {{SIZE}}{{UNIT}} !important;
                        border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'slides_height',
            [
                'label'        => esc_html__( 'Min Height', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size'     => '',
                    'unit'     => 'px'
                ],
                'range'        => [
                    'px' => [
                        'max' => 900,
                    ],
                ],
                'condition' => [
                    'layout' => '2',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-play .elementor-custom-embed-image-overlay > img' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section();
        //General Section

        $widget->start_controls_section(
            'section_video_style',
            [
                'label' => esc_html__( 'Video', 'validus' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'video_height',
            [
                'label' => esc_html__('Video Height', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set video height on responsive', 'validus'),
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'auto' => esc_html__('Auto', 'validus'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-video-play' => 'height: {{VALUE}};',
                ],
                'default' => '',
            ]
        );
        $widget->add_control(
            'show_full',
            [
                'label' => esc_html__('Show Full', 'validus'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Show full width with padding left or right space.', 'validus'),
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'left' => esc_html__('Left', 'validus'),
                    'right' => esc_html__('Right', 'validus'),
                ],
                'default' => '',
            ]
        );
        $widget->add_responsive_control(
            'show_full_left',
            [
                'label' => esc_html__('Show Full Left', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'default' => [
                    'size' => 'calc((100% - (1320px - 40px))/2)',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-video-play' => 'margin-inline-start: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_full' => 'left',
                ],
            ]
        );
        $widget->add_responsive_control(
            'show_full_right',
            [
                'label' => esc_html__('Show Full Right', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                    ],
                ],
                'default' => [
                    'size' => 'calc((100% - (1320px - 40px))/2)',
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-video-play' => 'margin-inline-end: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_full' => 'right',
                ],
            ]
        );

        $widget->add_responsive_control(
            'play_button_top_space',
            [
                'label' => esc_html__('Play Button Top Space', 'validus'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-custom-embed-play' => 'top: {{SIZE}}%;',
                ],
            ]
        );

        $label = is_rtl() ? esc_html__( 'Play Button Right Space', 'validus' ) : esc_html__( 'Play Button Left Space', 'validus' );

        $widget->add_responsive_control(
            'play_button_left_space',
            [
                'label' => $label,
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    'body:not(.rtl) {{WRAPPER}} .elementor-custom-embed-play' => 'left: {{SIZE}}%',
                    'body.rtl {{WRAPPER}} .elementor-custom-embed-play' => 'left: auto;right: {{SIZE}}%;transform: translate(50%, -50%);',
                ],
            ]
        );

        $widget->add_control(
            'aspect_ratio',
            [
                'label' => esc_html__( 'Aspect Ratio', 'validus' ),
                'type' => Controls_Manager::HIDDEN,
                'selectors_dictionary' => [
                    '169' => '16 / 9',
                    '219' => '21 / 9',
                    '43' => '4 / 3',
                    '32' => '3 / 2',
                    '11' => '1 / 1',
                    '916' => '9 / 16',
                ],
                'default' => '169',
                'selectors' => [
                    '{{WRAPPER}} .elementor-wrapper' => 'aspect-ratio: auto',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Css_Filter::get_type(),
            [
                'name' => 'css_filters',
                'selector' => '{{WRAPPER}} .elementor-wrapper',
            ]
        );

        $widget->add_control(
            'play_icon_title',
            [
                'label' => esc_html__( 'Play Icon', 'validus' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                ],
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'play_icon_color',
            [
                'label' => esc_html__( 'Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-custom-embed-play i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .elementor-custom-embed-play svg' => 'fill: {{VALUE}}',
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                ],
            ]
        );
        $widget->add_responsive_control(
            'play_icon_opacity',
            [
                'label'        => esc_html__( 'Opacity', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ '%' ],
                'default'      => [
                    'size' => '',
                    'unit' => '%'
                ],
                'range'        => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                ],
                'selectors'    => [
                    '{{WRAPPER}} .elementor-custom-embed-play i' => 'opacity: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-custom-embed-play .play-inner' => 'opacity: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'play_quick_icon_size',
            [
                'label' => esc_html__( 'Background Icon Size', 'validus' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 40,
                    ],
                ],
                'selectors' => [
                    // Not using a CSS vars because the default size value is coming from a global scss file.
                    '{{WRAPPER}} .elementor-custom-embed-play i' => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .elementor-custom-embed-play svg' => 'width: calc({{SIZE}} * 14px); height: calc({{SIZE}} * 14px);',
                    '{{WRAPPER}} .elementor-custom-embed-play .play-circle' => 'width: calc({{SIZE}} * 14px); height: calc({{SIZE}} * 14px);',
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                    'quick_icon!' => ['play-icon-02','play-icon-06'],
                ],
            ]
        );
        $widget->add_responsive_control(
            'play_icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'validus' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    // Not using a CSS vars because the default size value is coming from a global scss file.
                    '{{WRAPPER}} .elementor-custom-embed-play i' => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .elementor-custom-embed-play svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                ],
            ]
        );

        $widget->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'play_icon_text_shadow',
                'selector' => '{{WRAPPER}} .elementor-custom-embed-play i',
                'fields_options' => [
                    'text_shadow_type' => [
                        'label' => esc_html_x( 'Shadow', 'Text Shadow Control', 'validus' ),
                    ],
                ],
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'show_play_icon' => 'yes',
                    'play_icon[library]!' => 'svg',
                ],
            ]
        );

        $widget->end_controls_section();

        $widget->start_controls_section(
            'section_lightbox_style',
            [
                'label' => esc_html__( 'Lightbox', 'validus' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_image_overlay' => 'yes',
                    'image_overlay[url]!' => '',
                    'lightbox' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'lightbox_color',
            [
                'label' => esc_html__( 'Background Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}}' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $widget->add_control(
            'lightbox_ui_color',
            [
                'label' => esc_html__( 'UI Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button' => 'color: {{VALUE}}',
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button svg' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $widget->add_control(
            'lightbox_ui_color_hover',
            [
                'label' => esc_html__( 'UI Hover Color', 'validus' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover' => 'color: {{VALUE}}',
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover svg' => 'fill: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $widget->add_control(
            'lightbox_video_width',
            [
                'label' => esc_html__( 'Content Width', 'validus' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 30,
                    ],
                ],
                'selectors' => [
                    '(desktop+)#elementor-lightbox-{{ID}} .elementor-video-container' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $widget->add_control(
            'lightbox_content_position',
            [
                'label' => esc_html__( 'Content Position', 'validus' ),
                'type' => Controls_Manager::SELECT,
                'frontend_available' => true,
                'options' => [
                    '' => esc_html__( 'Center', 'validus' ),
                    'top' => esc_html__( 'Top', 'validus' ),
                ],
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .elementor-video-container' => '{{VALUE}}; transform: translateX(-50%);',
                ],
                'selectors_dictionary' => [
                    'top' => 'top: 60px',
                ],
            ]
        );

        $widget->add_responsive_control(
            'lightbox_content_animation',
            [
                'label' => esc_html__( 'Entrance Animation', 'validus' ),
                'type' => Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();


        // Style Title Start
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Title Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '1',
                ],
            ]
        );
        $widget->add_responsive_control(
            'heading_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '15',
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Title Color', 'validus' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-video-title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_control(
            'heading_font',
            [
                'label' => esc_html__('Title Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Roboto' => esc_html__('Roboto', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-title' => "font-family: '{{VALUE}}';",
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography1',
                'label' => 'Title Typography',
                'selector' => '{{WRAPPER}} .cms-video-container .cms-video-title',
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography2',
                'label' => 'Title Typography',
                'selector'     => '{{WRAPPER}} .cms-video-content .cms-video-content-container .cms-video-title',
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->end_controls_section();
        // Style Heading End

        // Style Description Start
        $widget->start_controls_section(
            'section_style_description',
            [
                'label' => esc_html__('Description Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $widget->add_responsive_control(
            'description_space_between_paragraph',
            [
                'label'        => esc_html__( 'Spacing Between Paragraphs', 'validus' ),
                'description'  => esc_html__( 'Note: it works only when the text contain 2 or more paragraphs separated by space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '27',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-description p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-video-description p:last-child' => 'margin-bottom: 0px;',
                ],
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_responsive_control(
            'description_bottom_space',
            [
                'label'        => esc_html__( 'Bottom Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '33',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_control(
            'description_color',
            [
                'label'      => esc_html__( 'Color', 'validus' ),
                'type'       => \Elementor\Controls_Manager::COLOR,
                'selectors'  => [
                    '{{WRAPPER}} .cms-video-description' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_control(
            'description_font',
            [
                'label' => esc_html__('Description Font', 'validus'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__('Default', 'validus'),
                    'Changa' => esc_html__('Changa', 'validus'),
                    'Outfit' => esc_html__('Outfit', 'validus'),
                    'Poppins' => esc_html__('Poppins', 'validus'),
                    'Rubik' => esc_html__('Rubik', 'validus'),
                    'Rajdhani' => esc_html__('Rajdhani', 'validus'),
                    'Titillium Web' => esc_html__('Titillium Web', 'validus'),
                    'Paralucent W00 Demi Bold' => esc_html__('Paralucent Demi Bold', 'validus'),
                    'Custom' => esc_html__('Custom', 'validus'),
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-description' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-video-description p' => "font-family: '{{VALUE}}';",
                    '{{WRAPPER}} .cms-video-content .cms-video-content-container .cms-video-description p' => "font-family: '{{VALUE}}';",
                ],
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'label' => esc_html__('Description Typography', 'validus'),
                'selector'     => '{{WRAPPER}} .cms-video-description p',
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography_layout2',
                'label' => esc_html__('Description Typography', 'validus'),
                'selector'     => '{{WRAPPER}} .cms-video-content .cms-video-content-container .cms-video-description p',
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );
        $widget->end_controls_section(); 
        // Style Description End


        // Style Description 2 Start
        $widget->start_controls_section(
            'section_style_description2',
            [
                'label' => esc_html__('Description 2 Style', 'validus'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '1',
                ],
            ]
        );
        $widget->add_responsive_control(
            'description2_space_between_paragraph',
            [
                'label'        => esc_html__( 'Spacing Between Paragraphs', 'validus' ),
                'description'  => esc_html__( 'Note: it works only when the text contain 2 or more paragraphs separated by space', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '27',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-description2 p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .cms-video-description2 p:last-child' => 'margin-bottom: 0px;',
                ],
            ]
        );
        $widget->add_responsive_control(
            'description2_top_space',
            [
                'label'        => esc_html__( 'Top Spacing', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '44',//15
                ],
                'range'        => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-description2' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_control(
            'description2_color',
            [
                'label'      => esc_html__( 'Color', 'validus' ),
                'type'       => \Elementor\Controls_Manager::COLOR,
                'selectors'  => [
                    '{{WRAPPER}} .cms-video-description2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $widget->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description2_typography',
                'selector'     => '{{WRAPPER}} .cms-video-description2',
            ]
        );
        $widget->end_controls_section();
        // Style Description 2 End

        // stamp section start
        $widget->start_controls_section(
            'section_stamp_image',
            [
                'label' => esc_html__('Stamp Image', 'validus'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'stamp_image',
            [
                'label' => esc_html__( 'Image', 'validus' ),
                'type'  => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbstamp',
                'type' => Controls_Manager::NUMBER,
                'default' => 'custom',
            ]
        );
        $widget->add_responsive_control(
            'stamp_pos_x',
            [
                'label'        => esc_html__( 'X Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -900,
                        'max' => 900,
                    ],
                ],
                'selectors'    => [
                    'body:not(.rtl) {{WRAPPER}} .cms-video-image-stamp' => 'left: {{SIZE}}{{UNIT}}; right: -{{SIZE}}{{UNIT}};',
					'body.rtl {{WRAPPER}} .cms-video-image-stamp' => 'left: -{{SIZE}}{{UNIT}}; right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->add_responsive_control(
            'stamp_pos_y',
            [
                'label'        => esc_html__( 'Y Position', 'validus' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'size_units'   => [ 'px' ],
                'default'      => [
                    'size' => '0',
                    'unit' => 'px'
                ],
                'range'        => [
                    'px' => [
                        'min' => -200,
                        'max' => 200,
                    ],
                ],
                'selectors'    => [
                    '{{WRAPPER}} .cms-video-image-stamp' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $widget->end_controls_section(); // stamp section end
    }
}
