<?php
$class = new class {
    public function validus_get_featured($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($posts) || !is_array($posts) || empty($posts_data) || !is_array($posts_data)) {
            return false;
        }
        $posts_data['tax'] = isset($posts_data['tax']) ? $posts_data['tax'] : [];
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => 'cms-blog-featured',
            'bg_class' => 'bg-primary'
        ]); 

        // Start build post item 
        $count = 0;
        foreach ($posts as $post) :
            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            $src = get_the_post_thumbnail_url($post->ID,'medium_large');
            if($src == '') {
                $src = Elementor\Utils::get_placeholder_image_src();
                if($src == '') {
                    $src = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }

            if($count == 0) {
                $layout = isset($settings['layout']) ? $settings['layout'] : null;
            ?>
            <div class="<?php echo implode(' ', array_filter([$args['item_class'], 'item-'.$count])); ?>">
                <?php switch ($layout) {
                    default:
                    echo "<div class='cms-blog-item-image'>";
                        // post image
                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id' => $post->ID,
                            'custom_size' => ['width' => '620', 'height' => '560']
                        ]);
                    echo "</div>";
                    ?>

                    <?php if ($settings['show_date'] == 'yes') { ?>
                    <div class="cms-blog-item-date empty-none">
                        <h3 class="day"><?php echo get_the_date('d', $post->ID); ?></h3>
                        <span class="month-year"><?php echo get_the_date('M Y', $post->ID); ?></span>
                    </div>
                    <?php } ?>

                    <div class="cms-blog-item-inner d-flex justify-content-center">
                        <div class="cms-blog-item-content">
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex gap" style="--gap:10px;">
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                                <li class="author empty-none">
                                    <a href="<?php echo get_author_posts_url( $post->post_author ); ?>">
                                        <?php the_author_meta( 'display_name', $post->post_author ); ?>
                                    </a>
                                </li>
                            </ul>
                            <h4 class="cms-heading"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a></h4>
                            <div class="cms-excerpt text-line-4"><?php
                                $content = wp_trim_words($post->post_content, $settings['num_words'], '&hellip;');
                                echo esc_html($content);
                            ?></div>
                            <div class="cms-readmore">
                                <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="d-flex align-items-center">
                                    <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                    <span class="the-btn-readmore cms-transition cmsi-chevron-right d-flex align-items-center justify-content-center radius-100"></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php
                    break;
                } ?>
            </div>
            <?php } ?>
        <?php
        $count ++;
        endforeach;
    }

    public function validus_get_post($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($posts) || !is_array($posts) || empty($posts_data) || !is_array($posts_data)) {
            return false;
        }
        $posts_data['tax'] = isset($posts_data['tax']) ? $posts_data['tax'] : [];
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary'
        ]); 

        echo "<div class='cms-blog-list d-flex flex-direction-column gap-40'>";
        // Start build post item 
        $count = 0;
        foreach ($posts as $key => $post) :
            if ($key > 0) :
                $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');
                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $layout = isset($settings['layout']) ? $settings['layout'] : null;
                ?>
                <div class="<?php echo implode(' ', array_filter([$args['item_class'], $filter_class, 'item-'.$count])); ?>">
                    <?php switch ($layout) { 
                        default:

                        // post image
                        $settings['thumbnail_size'] = 'custom';
                        
                        echo '<div class="cms-blog-item-image">';
                            echo '<a href="'.esc_url(get_permalink($post->ID)).'">';
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id'     => $post->ID,
                                'prefix'      => 'cms-blog',
                                'custom_size' => ['width' => '180', 'height' => '120']
                            ]);
                            echo '</a>';
                        echo '</div>';
                        ?>
                        <div class="cms-blog-item-content">
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex gap" style="--gap:10px;">
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                                <li class="author empty-none">
                                    <a href="<?php echo get_author_posts_url( $post->post_author ); ?>">
                                        <?php the_author_meta( 'display_name', $post->post_author ); ?>
                                    </a>
                                </li>
                            </ul>
                            <h4 class="cms-heading">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php echo get_the_title($post->ID);?>
                                </a>
                            </h4>
                        </div>
                        <?php
                        break;
                    } ?>
                </div>
            <?php
            endif;
            $count++;
        endforeach;
        echo "</div>";
    }
};

$html_id     = etc_get_element_id($settings);
$tax         = array();
$source      = $widget->get_setting('source', '');
$tag         = $widget->get_setting('groupby', '');
if ($tag) {
    $source = [$tag];
}
$orderby     = $widget->get_setting('orderby', 'date');
$order       = $widget->get_setting('order', 'desc');
$limit       = $widget->get_setting('limit', 6);

extract(etc_get_posts_of_grid('post', [
    'source'   => $source,
    'orderby'  => $orderby,
    'order'    => $order,
    'limit'    => $limit,
]));

$thumbnail_size             = $widget->get_setting('thumbnail_size', '');
$thumbnail_custom_dimension = $widget->get_setting('thumbnail_custom_dimension', '');
$num_words                  = $widget->get_setting('num_words', '');
$readmore_text              = $widget->get_setting('readmore_text', '');
$posts_data = array(
    'startPage'                  => $paged,
    'maxPages'                   => $max,
    'total'                      => $total,
    'perpage'                    => $limit,
    'nextLink'                   => $next_link,
    'source'                     => $source,
    'orderby'                    => $orderby,
    'order'                      => $order,
    'limit'                      => $limit,
    'thumbnail_size'             => $thumbnail_size,
    'thumbnail_custom_dimension' => $thumbnail_custom_dimension,
    'num_words'                  => $num_words,
    'readmore_text'              => $readmore_text
);
// Wrap attributes
$widget->add_render_attribute('wrap',[
    'id'              => $html_id,
    'class'           => ['cms-blog-wrap cms-blog-layout2', 'cms-blog-'.$widget->get_setting('layout','1')],
    'data-start-page' => $paged,
    'data-max-pages'  => $max,
    'data-total'      => $total,
    'data-perpage'    => $limit,
    'data-next-link'  => $next_link
]);
// Content attributes
$widget->add_render_attribute('content',[
    'class' => [
        'cms-blog-content',
        'gap d-flex',
    ],
    'style' => '--gap:80px;--gap-tablet:30px;--gap-mobile:20px;'
]);
?>

<div <?php echo wp_kses_post($widget->get_render_attribute_string('wrap')); ?>>
    <div <?php echo wp_kses_post($widget->get_render_attribute_string('content')); ?>><?php
        
        $class->validus_get_featured($settings, $posts, $posts_data, [
            'item_class' => 'cms-blog-featured d-flex flex-direction-column',
            'bg_class' => ''
        ]);
        $class->validus_get_post($settings, $posts, $posts_data, [
            'item_class' => 'cms-blog-item d-flex align-items-center gap-40',
            'bg_class' => ''
        ]);
    ?></div>
</div>