<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Control_Media;

$settings = $widget->get_settings_for_display();
$carousels = $widget->get_setting('box_carousel', []);
$arrows = $widget->get_setting('arrows', '');
$dots = $widget->get_setting('dots', '');

$has_icon = ! empty( $widget->get_setting('cms_icon') );
if ( $has_icon ) {
	$widget->add_render_attribute( 'i', 'class', $widget->get_setting('cms_icon') );
	$widget->add_render_attribute( 'i', 'aria-hidden', 'true' );
}

$thumbnail_size = $widget->get_setting('thumbnail_size', 'full');
$thumbnail_custom_dimension = $widget->get_setting('thumbnail_custom_dimension', '');
if ($thumbnail_size != 'custom') {
    $img_size = $thumbnail_size;
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
} else {
    $img_size = 'full';
}
?>
<div class="cms-box-carousel-wrap cms-box-carousel-layout1">
    <div class="cms-carousel swiper">
        <div class="swiper-wrapper">
            <?php
            foreach ($carousels as $key => $carousel) {
                $src = Group_Control_Image_Size::get_attachment_image_src( $carousel['image']['id'], 'thumbnail', $settings );
                if ($src == '') {
                    $src = $carousel['image']['url'];
                }
                
                $style = 'style="background-image:url(\''.$src.'\');background-size: cover;"';
                ?>
                <div class="cms-carousel-item swiper-slide">
                    <?php if (isset($carousel['image']) && isset($carousel['image']['url']) && !empty($carousel['image']['url'])) { ?>
                        <div class="cms-box-carousel-item-image" <?php echo wp_kses_post($style);?>></div>
                    <?php } ?>
                    <div class="cms-box-carousel-item-content cms-hover-icon-bounce">
                        <div class="cms-box-carousel-item-container">
                            <?php if (isset($carousel['title'])) { ?>
                                <div class="cms-box-carousel-item-title">
                                    <?php echo esc_html($carousel['title']); ?>
                                </div>
                            <?php } ?>
                            <?php if (isset($carousel['heading'])) { ?>
                                <h3 class="cms-box-carousel-item-heading">
                                    <?php echo esc_html($carousel['heading']); ?>
                                </h3>
                            <?php } ?>

                            <div class="cms-box-carousel-info">
                                <?php if (!empty($carousel['cms_icon']['value'])) { ?>
                                <div class="cms-box-carousel-logo">
                                    <?php \Elementor\Icons_Manager::render_icon( $carousel['cms_icon'], [ 'aria-hidden' => 'true', 'class' => 'cms-icon' ] ); ?>
                                </div>
                                <?php } ?>
                                <div class="cms-box-carousel-desc">
                                    <?php if (isset($carousel['description'])) { ?>
                                    <div class="cms-box-carousel-item-description">
                                        <span <?php echo wp_kses_post($widget->get_render_attribute_string( 'description' )); ?>>
                                            <?php echo wpautop(esc_html($carousel['description'])); ?>
                                        </span>
                                    </div>
                                    <?php } ?>

                                    <div class="cms-box-carousel-desc-btn">
                                        <?php
                                            if ( ! empty( $carousel['button_primary'] ) ) :
                                                $button_primary_url = '';
                                                if(isset($carousel['button_primary_link']) && is_array($carousel['button_primary_link']) && isset($carousel['button_primary_link']['url'])){
                                                    $button_primary_url = $carousel['button_primary_link']['url'];
                                                }
                                        ?>
                                            <div class="cms-box-carousel-item-button">
                                                <a href="<?php echo esc_attr($button_primary_url); ?>" class="btn btn-white btn-hover-black radius-2">
                                                    <span class="btn-icon cmsi-chevron-circle-right-01"></span>
                                                    <span class="btn-text"><?php echo esc_attr( $carousel['button_primary'] ); ?></span>
                                                </a>
                                            </div>
                                        <?php endif; ?>
                                        <?php
                                            if ( ! empty( $carousel['button_secondary'] ) ) :
                                                $button_secondary_url = '';
                                                if(isset($carousel['button_secondary_link']) && is_array($carousel['button_secondary_link']) && isset($carousel['button_secondary_link']['url'])){
                                                    $button_secondary_url = $carousel['button_secondary_link']['url'];
                                                }
                                        ?>
                                            <div class="cms-box-carousel-item-button">
                                                <a href="<?php echo esc_url($button_secondary_url); ?>" class="btn btn-outline-white btn-hover-white radius-2">
                                                    <?php echo esc_attr( $carousel['button_secondary'] ); ?>
                                                </a>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php if ($arrows == 'yes') : ?>
            <div class="cms-box-carousel-button">
                <div class="cms-box-carousel-button-arrow cms-carousel-button-prev cms-transition d-flex align-items-center justify-content-center text-center cursor-pointer text-11 radius-100">
                    <i aria-hidden="true" class="cmsi-arrow-left d-flex align-items-center justify-content-center text-center text-11 text-secondary bg-white radius-50"></i>
                </div>
                <div class="cms-box-carousel-button-arrow cms-carousel-button-next cms-transition d-flex align-items-center justify-content-center text-center cursor-pointer text-11 radius-100">
                    <i aria-hidden="true" class="cmsi-arrow-right d-flex align-items-center justify-content-center text-center text-11 text-secondary bg-white radius-50"></i>
                </div>
            </div>
        <?php endif ?>
        <?php if ($dots == 'yes') : ?>
            <div class="cms-carousel-dots"></div>
        <?php endif ?>
    </div>
</div>