<?php
$node = new class {
	public function get_chart_data($widget) {
		$settings = $widget->get_settings_for_display();

		$data = array(
			'datasets' => array(
				array(
					'data'             => array(),
					'backgroundColor'  => array(),
				),
			),
			'labels' => array()
		);

		$chart_data = isset($settings['chart_data']) ? $settings['chart_data'] : null;

		foreach ( $chart_data as $item_data ) {
			$data['datasets'][0]['data'][]            = ! empty( $item_data['value'] ) ? $item_data['value'] : '';
			$data['datasets'][0]['backgroundColor'][] = ! empty( $item_data['color'] ) ? $item_data['color'] : '';
			$data['labels'][]                         = ! empty( $item_data['label'] ) ? $item_data['label'] : '';
		}

		$data['datasets'][0]['borderWidth']      = ( isset( $settings['chart_border_width']['size'] ) && '' !== $settings['chart_border_width']['size'] ) ? $settings['chart_border_width']['size'] : 1;
		$data['datasets'][0]['borderColor']      = ! empty( $settings['chart_border_color'] ) ? $settings['chart_border_color'] : '#ffffff';
		$data['datasets'][0]['hoverBorderColor'] = ! empty( $settings['chart_border_color'] ) ? $settings['chart_border_color'] : '#ffffff';

		return $data;
	}

	public function get_chart_title($widget) {
		$settings = $widget->get_settings_for_display();

		$title_format = '<div class="cms-pie-chart-title-container"><%1$s class="cms-pie-chart-title">%2$s</%1$s></div>';

		return sprintf( $title_format, $settings['chart_title_size'], $settings['chart_title'] );
	}

	public function get_chart_font_style_string( $widget, $settings_names = array() ) {
		if ( ! is_array( $settings_names ) ) {
			return '';
		}

		$settings = $widget->get_settings_for_display();

		$font_styles = array();

		foreach ( $settings_names as $setting_name ) {
			if ( ! empty( $settings[ $setting_name ] ) ) {
				$font_styles[] = $settings[ $setting_name ];
			}
		}

		if ( empty( $font_styles ) ) {
			return '';
		}

		$font_styles = array_unique( $font_styles );

		return join( ' ', $font_styles );
	}

	public function get_chart_options($widget) {
		$settings = $widget->get_settings_for_display();

		$legend_display   = isset($settings['chart_legend_display']) ? filter_var( $settings['chart_legend_display'], FILTER_VALIDATE_BOOLEAN ) : '';
		$tooltips_enabled = filter_var( $settings['chart_tooltip_enabled'], FILTER_VALIDATE_BOOLEAN );

		$options = array(
			'animation' => array(
				'duration'     => ! empty( $settings['chart_animation_duration']['size'] ) ? $settings['chart_animation_duration']['size'] : 1000,
				'easing'       => ! empty( $settings['chart_animation_easing'] ) ? $settings['chart_animation_easing'] : 'easeOutQuart',
				'animateScale' => filter_var( $settings['chart_animate_scale'], FILTER_VALIDATE_BOOLEAN ),
			),
			'legend' => array(
				'display'  => $legend_display,
				'position' => ! empty( $settings['chart_legend_position'] ) ? $settings['chart_legend_position'] : 'top',
				'reverse'  => filter_var( (isset($settings['chart_legend_reverse']) ? $settings['chart_legend_reverse'] : null), FILTER_VALIDATE_BOOLEAN ),
				'align'    => ! empty( $settings['chart_legend_alignment'] ) ? $settings['chart_legend_alignment'] : 'center',
			),
			'tooltips' => array(
				'enabled' => $tooltips_enabled,
			),
		);

		if ( ! empty( $settings['chart_cutout_percentage']['size'] ) ) {
			$options['cutoutPercentage'] = $settings['chart_cutout_percentage']['size'];
		}

		$legend_style = array();

		$legend_style_dictionary = array(
			'boxWidth'   => 'chart_legend_box_width',
			'fontFamily' => 'chart_legend_font_family',
			'fontSize'   => 'chart_legend_font_size',
			'fontStyle'  => array( 'chart_legend_font_style', 'chart_legend_font_weight' ),
			'fontColor'  => 'chart_legend_font_color',
		);

		if ( $legend_display ) {
			foreach ( $legend_style_dictionary as $style_property => $setting_name ) {

				if ( is_array( $setting_name ) ) {
					$style_value = $this->get_chart_font_style_string( $widget, $setting_name );

					if ( ! empty( $style_value ) ) {
						$legend_style[ $style_property ] = $style_value;
					}
				} else {
					if ( ! empty( $settings[ $setting_name ] ) ) {
						if ( is_array( $settings[ $setting_name ] ) ) {
							if ( ! empty( $settings[ $setting_name ]['size'] ) ) {
								$legend_style[ $style_property ] = $settings[ $setting_name ]['size'];
							}
						} else {
							$legend_style[ $style_property ] = $settings[ $setting_name ];
						}
					}
				}
			}

			$legend_style['usePointStyle'] = 'true';
			//$legend_style['pointStyle'] = 'circle';
			//$legend_style['radius'] = '50';

			if ( ! empty( $legend_style ) ) {
				$options['legend']['labels'] = $legend_style;
			}

			$options['legend']['title'] = [
				'padding' => 100
			];
		}

		$tooltip_style_dictionary = array(
			'backgroundColor' => 'chart_tooltip_bg_color',
			'bodyFontFamily'  => 'chart_tooltip_font_family',
			'bodyFontSize'    => 'chart_tooltip_font_size',
			'bodyFontStyle'   => array( 'chart_tooltip_font_style', 'chart_tooltip_font_weight' ),
			'bodyFontColor'   => 'chart_tooltip_font_color',
		);

		if ( $tooltips_enabled ) {
			foreach ( $tooltip_style_dictionary as $style_property => $setting_name ) {
				if ( is_array( $setting_name ) ) {
					$style_value = $this->get_chart_font_style_string( $widget, $setting_name );

					if ( ! empty( $style_value ) ) {
						$options['tooltips'][ $style_property ] = $style_value;
					}
				} else {
					if ( ! empty( $settings[ $setting_name ] ) ) {
						if ( is_array( $settings[ $setting_name ] ) ) {
							if ( ! empty( $settings[ $setting_name ]['size'] ) ) {
								$options['tooltips'][ $style_property ] = $settings[ $setting_name ]['size'];
							}
						} else {
							$options['tooltips'][ $style_property ] = $settings[ $setting_name ];
						}
					}
				}
			}
		}

		return $options;
	}
};

$widget->_context = 'render';

$settings     = $widget->get_settings_for_display();

$data_chart   = $node->get_chart_data($widget);
$data_options = $node->get_chart_options($widget);
$data_tooltip = isset( $settings['chart_tooltip_suffix'] ) ? $settings['chart_tooltip_suffix'] : '';

$widget->add_render_attribute( 'container', 'class', 'cms-pie-chart-container' );
$widget->add_render_attribute( 'container', 'data-chart', esc_attr( json_encode( $data_chart ) ) );
$widget->add_render_attribute( 'container', 'data-options', esc_attr( json_encode( $data_options ) ) );
$widget->add_render_attribute( 'container', 'data-tooltip', esc_attr( $data_tooltip ) );

$widget->add_render_attribute( 'canvas', 'class', 'cms-pie-chart' );
$widget->add_render_attribute( 'canvas', 'role', 'img' );

if ( ! empty( $settings['chart_title'] ) ) {
	$widget->add_render_attribute( 'canvas', 'aria-label', esc_attr( $settings['chart_title'] ) );
}

if ( isset($settings['chart_title_position']) && 'before' === $settings['chart_title_position'] ) {
	echo wp_kses_post($node->get_chart_title($widget));
}
?>
<div class="cms-chart">
	<div <?php $widget->print_render_attribute_string( 'container' ); ?>>
		<canvas <?php $widget->print_render_attribute_string( 'canvas' ); ?>></canvas>
	</div>
	<div class="cms-chart-items pl-lg-30 pt-15 d-flex row gutters-20 row-cols-1 row-cols-md-2">
		<?php 
		$datasets = $data_chart['datasets'][0]['backgroundColor'];
		$labels = $data_chart['labels'];
		
		$i = 0;
		foreach($datasets as $k => $color) {
			echo '<div class="cms-chart-item col-md-6 col-sm-4 col-6 font-700 text-14">
				<span class="cms-chart-item-circle d-inline-block circle mr-15" style="background-color:'.$color.'"></span>
				<span class="cms-chart-item-title">'.$labels[$k].'</span>
			</div>';
			$i++;
		}
		?>
	</div>
</div>
<?php
if ( 'after' === $settings['chart_title_position'] ) {
	echo wp_kses_post($node->get_chart_title($widget));
}
?>