<?php
// Add custom field to section
if(!function_exists('validus_custom_column_params_counter')){
    add_filter('etc-custom-column/custom-params', 'validus_custom_column_params_counter');
    function validus_custom_column_params_counter(){
        return array(
            'sections' => array(
                array(
                    'name'     => 'custom_sectionz',
                    'label'    => esc_html__( 'Custom Settings', 'validus' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        array(
                            'name'    => 'element_background_image',
                            'label'   => esc_html__( 'Element Display Settings', 'validus' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
							'options' => array(
                                ''           => __( 'Default', 'validus' ),
                            ),
                            'default'      => '',
                            'prefix_class' => 'cms-counter-background'
                        ),
                    )
                )
            )
        );
    }
}

$counters = $widget->get_setting('counters', []);
if(empty($counters)) return;

use Elementor\Icons_Manager;
// Items
$widget->add_render_attribute( 'counter-item',[
	'class' => [
		'counter-item',
		'relative',
		($settings['layout_mode'] === 'carousel') ? 'swiper-slide' : ''
	]
]);
// Title
$widget->add_inline_editing_attributes( 'title');
$widget->add_render_attribute('title', 'class', 'cms-counter-title cms-heading' );

// Description
$widget->add_inline_editing_attributes( 'description');
$widget->add_render_attribute('description', 'class', 'cms-counter-desc text-15' );

$grid = ($settings['layout_mode'] === 'carousel') ? 1 : $widget->get_setting('col','1');
$grid_tablet = ($settings['layout_mode'] === 'carousel') ? 1 : $widget->get_setting('col_tablet','1');
$grid_mobile = ($settings['layout_mode'] === 'carousel') ? 1 : $widget->get_setting('col_mobile','1');

// Layout mode setting
$widget->add_render_attribute('grid-settings',[
    'class' => [
        'cms-counter-grid',
        'd-grid',
        'grid-'.$widget->get_setting('col','1'),
        'grid-tablet-'.$widget->get_setting('col_tablet','1'),
        'grid-mobile-'.$widget->get_setting('col_mobile','1'),
        'gap'
    ],
    'style' => '--gap:40px;--gap-tablet:30px;--gap-mobile:20px;'
]);

$src = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['banner']['id'], 'banner', $settings );
if ($src == '') {
	$src = $settings['banner']['url'];
}
$style = 'style="background-image:url('.$src.');background-size: cover;background-repeat: no-repeat;background-position: 79% 55%;"';
?>
<style type="text/css">
.cms-counter-background {
	background-image:url('<?php echo esc_html($src);?>');
	background-size: cover;
	background-repeat: no-repeat;
	background-position: 79% 55%;
}
.cms-counter-background .elementor-widget-wrap {
	height: 100%;
}
</style>

<div class="cms-counter-wrap cms-counter-layout1" <?php echo wp_kses_post($style);?>>
<?php
//
//\Elementor\Group_Control_Image_Size::print_attachment_image_html( $settings, 'banner', 'banner' );
?>
<div class="cms-contents">
	<?php
	switch ($settings['layout_mode']) {
		case 'carousel':
	?>
	<div class="cms-carousel swiper">
		<div class="swiper-wrapper">
	<?php
		break;
		default:
	?>
	<div <?php echo wp_kses_post($widget->get_render_attribute_string('grid-settings')); ?>>
	<?php
		break;
	}
	// Start item
	foreach ($counters as $key => $counter) {
	$data_counter     = $widget->get_repeater_setting_key( 'counter-number', 'cms_counter', $key );
    $widget->add_render_attribute( $data_counter, [
        'class'          => 'cms-counter-number heading elementor-counter-number text-white text-75',
        'data-duration'  => $counter['duration'],
        'data-to-value'  => $counter['ending_number'],
        'data-delimiter' => !empty($counter['thousand_separator_char']) ? $counter['thousand_separator_char'] : ',',
    ] );
	$widget->add_inline_editing_attributes( $data_counter);

	if(isset($counter['show_icon'])) {
		$show_icon = $counter['show_icon'];
	} else {
		$show_icon = null;
	}
   	?>
   	<div <?php echo wp_kses_post($widget->get_render_attribute_string('counter-item')); ?>>
	   	<?php if($show_icon === 'yes'){ ?>
		    <div class="cms-counter-icon empty-none"><?php
			    // Counter Icon
				switch ($counter['icon_type']) {
					case 'image':
						fortis_elementor_image_render($counter, [
							'name'           => 'icon_image',
							'image_size_key' => 'icon_image',
							'custom_size' => ['width' => 64, 'height' => 64]
						]);
						break;
					
					default:
						\Elementor\Icons_Manager::render_icon( $counter['counter_icon'], [ 'aria-hidden' => 'true' ] );
						break;
				}
			?></div>
		<?php } ?>
		<?php
			$prefix = isset($counter['prefix']) ? $counter['prefix'] : null;
			$suffix = isset($counter['suffix']) ? $counter['suffix'] : null;
		?>
		<div class="cms-counters d-flex align-items-end">
			<div class="cms-counter-numbers">
			    <span class="cms-counter-number-prefix"><?php echo esc_html( $prefix ); ?></span>
			    <h4 <?php echo wp_kses_post( $widget->get_render_attribute_string( $data_counter ) ); ?>><?php echo esc_html( $counter['starting_number'] ); ?></h4>
			    <span class="cms-counter-number-suffix"><?php echo esc_html( $suffix ); ?></span>
			</div>
		</div>
		<?php
		// Description
		if ( $counter['description'] ) : ?>
		    <div <?php echo wp_kses_post($widget->get_render_attribute_string( 'description')); ?>>
				<?php echo esc_html( $counter['description'] ); ?>
			</div>
		<?php endif; ?>
	</div>
<?php
	} // end foreach

	switch ($settings['layout_mode']) {
		case 'carousel':
	?>
		</div>
		<?php if (isset($settings['arrows']) && $settings['arrows'] == 'yes') : ?>
            <div class="cms-carousel-button-in-vert prev cms-carousel-button-prev">
                <?php
                $icon_settings = $widget->get_settings_for_display('arrow_prev_icon');
                if (empty($icon_settings['value'])) {
                    $icon_settings = [
						'library' => 'eicons',
						'value'   => 'eicon-chevron-left',
                    ];
                }
                Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true']);
                ?>
            </div>
            <div class="cms-carousel-button-in-vert next cms-carousel-button-next">
                <?php
                $icon_settings = $widget->get_settings_for_display('arrow_next_icon');
                if (empty($icon_settings['value'])) {
                    $icon_settings = [
						'library' => 'eicons',
						'value'   => 'eicon-chevron-right',
                    ];
                }
                Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true']);
                ?>
            </div>
        <?php endif ?>
        <?php if ($settings['dots'] == 'yes') : ?>
            <div class="cms-carousel-dots cms-carousel-dots-in style-2"></div>
        <?php endif ?>
	</div>
	<?php
		break;
		default:
	?>
	</div>
	<?php
		break;
	}
?>
</div>
</div>