<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;
use Elementor\Utils;

$settings = $widget->get_settings_for_display();

$wrapper_tag = 'div';
$button_tag = 'a';
$print_content = true;

if ( empty( $settings['title'] ) && empty( $settings['description'] ) && empty( $settings['button'] ) ) {
    $print_content = false;
}

$display_inline = (isset($settings['button_type']) && $settings['button_type'] == 'btn btn-text-underline')?'d-inline':'';
$display_inline = 'd-inline';

$widget->add_render_attribute( 'wrapper', 'class', 'cms-cta-wrap' );

$widget->add_render_attribute( 'title', 'class', [
  'cms-cta__title',
  'cms-cta__content-item',
  'elementor-content-item',
] );

$widget->add_render_attribute( 'description', 'class', [
  'cms-cta__description',
  'cms-cta__content-item',
  'elementor-content-item',
  $display_inline
] );

$widget->add_render_attribute( 'button', 'class', [
  'cms-cta__button',
  'd-inline-flex',
  'align-items-center',
] );

if ( ! empty( $settings['link']['url'] ) ) {
  $link_element = 'button';

  if ( 'box' === $settings['link_click'] ) {
    $wrapper_tag = 'a';
    $button_tag = 'span';
    $link_element = 'wrapper';
  }

  $widget->add_link_attributes( $link_element, $settings['link'] );
}

$widget->add_inline_editing_attributes( 'title' );
$widget->add_inline_editing_attributes( 'description' );
$widget->add_inline_editing_attributes( 'button' );

$migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
$is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

if(isset($settings['button_type'])) {
  if($settings['button_type'] == 'btn btn-text-underline') {
    $button_type = 'cms-cta-text-underline';
  } else {
    $button_type = $settings['button_type'];
  }
} else {
  $button_type = '';
}

if($settings['show_underline'] == 'yes') {
  $widget->add_render_attribute( 'button', 'class', 'btn-text-underline' );
} else {
  $widget->add_render_attribute( 'button', 'class', '' );
}

$icon_type = $widget->get_setting('select_icon', 'cmsi-chevron-right');

switch($icon_type) {
  case 'cmsi-chevron-right style1':
    $icon_type = 'cmsi-chevron-right style1 d-inline-flex align-items-center justify-content-center text-center radius-100 text-11 cms-transition';
    break;
  case 'cmsi-chevron-right style2':
    $icon_type = 'cmsi-chevron-right style2 text-11 text-white radius-100 d-inline-flex align-items-center justify-content-center bg-primary';
    break;
}

$widget->add_render_attribute( 'icon', 'class', 'cms-cta__icon ' . $icon_type );
?>
<<?php Utils::print_validated_html_tag( $wrapper_tag ); ?> <?php $widget->print_render_attribute_string( 'wrapper' ); ?>>
<?php if ( $print_content ) : ?>
  <div class="cms-cta__content">

    <?php
    if ( ! empty( $settings['title'] ) ) :
      $title_tag = Utils::validate_html_tag( $settings['title_tag'] );

      echo '<' . $title_tag . ' ' . $widget->get_render_attribute_string( 'title' ) . '>';
      $widget->print_unescaped_setting( 'title' );
      echo '</' . $title_tag . '>';
    endif;
    ?>

    <?php if ( ! empty( $settings['description'] ) ) : ?>
      <div <?php $widget->print_render_attribute_string( 'description' ); ?>>
        <?php $widget->print_unescaped_setting( 'description' ); ?>
      </div>
    <?php endif; ?>

    <?php if ( ! empty( $settings['button'] ) ) : ?>
      <div class="cms-cta__button-wrapper cms-cta__content-item elementor-content-item <?php echo esc_html($display_inline);?>">
      <<?php Utils::print_validated_html_tag( $button_tag ); ?> <?php $widget->print_render_attribute_string( 'button' ); ?>>
        <?php $widget->print_unescaped_setting( 'button' ); ?>

        <?php if ( $settings['show_icon'] == 'yes' ) : ?>
          <span <?php $widget->print_render_attribute_string( 'icon' ); ?>></span>
        <?php endif; ?>
      </<?php Utils::print_unescaped_internal_string( $button_tag ); ?>>
      </div>
    <?php endif; ?>
  </div>
<?php endif; ?>
</<?php Utils::print_validated_html_tag( $wrapper_tag ); ?>>