<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;
use Elementor\Utils;

$widget->add_render_attribute( 'selected_icon', 'class' );
$has_icon = ! empty( $settings['selected_icon'] );

if ( ! empty( $settings['btn_link']['url'] ) ) {
	$widget->add_render_attribute( 'link', 'href', $settings['btn_link']['url'] );

	if ( $settings['btn_link']['is_external'] ) {
		$widget->add_render_attribute( 'link', 'target', '_blank' );
	}

	if ( $settings['btn_link']['nofollow'] ) {
		$widget->add_render_attribute( 'link', 'rel', 'nofollow' );
	}
}
$link_attributes = $widget->get_render_attribute_string( 'link' );

if ( $has_icon ) {
	$widget->add_render_attribute( 'i', 'class', $settings['selected_icon'] );
	$widget->add_render_attribute( 'i', 'aria-hidden', 'true' );
}

$icon_attributes = $widget->get_render_attribute_string( 'selected_icon' );

$_w_default = 290;
$_h_default = 190;

$image_size_key = 'icon_image1';

$thumbnail_size = $widget->get_setting($image_size_key.'_size', 'full');
$thumbnail_custom_dimension = $widget->get_setting($image_size_key.'_custom_dimension', '');
if ($thumbnail_size != 'custom') {
    $img_size = $thumbnail_size;

	$width = get_option( $thumbnail_size.'_size_w' );
	$height = get_option( $thumbnail_size.'_size_h' );

	if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
		$array = explode('x',$thumbnail_size);
		$width = $array[0];
		$height = $array[1];
	}

	$image = wp_get_attachment_image_src($settings[$image_size_key]['id'], $img_size);

	if (empty($height) || $height == '' || $height == 0) {
		if(isset($image) && is_array($image) && !empty($image)) {
			if ($image[2] <= $_h_default && $image[2] <= 300) {
				$width = $_w_default;
				$height = $_h_default;
	
				$settings[$image_size_key.'_size'] = 'custom';
				//$settings[$image_size_key.'_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
			} else {
				$width = $image[1];
				$height = $image[2];
			}
		} else {
			$width = $_w_default;
			$height = $_h_default;
		}
	}

	//$settings[$image_size_key.'_size'] = 'custom';
	//$settings[$image_size_key.'_custom_dimension'] = ['width' => $width, 'height' => $height];
	
    $params = array(
        'width' => $width,
        'height' => $height
    );
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

    $params = array(
        'width' => $thumbnail_custom_dimension['width'],
        'height' => $thumbnail_custom_dimension['height']
    );
} else {
    $img_size = $_w_default.'x'.$_h_default;

    $params = array(
        'width' => $_w_default,
        'height' => $_h_default
    );
}

$widget->add_render_attribute( 'title', 'class', 'cms-fancy-box-title text-21' );
$widget->add_render_attribute( 'description', 'class', 'cms-fancy-box-description text-16' );
$widget->add_render_attribute( 'background_color', 'class', 'cms-fancy-box-background' );
$widget->add_render_attribute( 'background_color', 'style', '--max-height: ' . $params['height'] . 'px;' );

$widget->add_inline_editing_attributes( 'title', 'none' );
$widget->add_inline_editing_attributes( 'description' );
$widget->add_inline_editing_attributes( 'btn_text' );
$widget->add_inline_editing_attributes( 'background_color' );
?>
<div class="cms-fancy-box-wrap cms-fancy-box-layout6 radius-10 bg-white">
	<?php if ( !empty($settings[$image_size_key]['id']) ) : ?>
        <div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'background_color' ) ); ?>>
			<?php $img_icon = etc_get_image_by_size( array(
				'attach_id'  => $settings[$image_size_key]['id'],
				'thumb_size' => $img_size,
				'class'      => 'cms-transition',
			) );
			//$thumbnail_icon = $img_icon['thumbnail'];
			$thumbnail_icon = '<img decoding="async" class="cms-transition" src="'.$img_icon['p_img_large'][0].'" loading="lazy" />';
			echo wp_kses_post( $thumbnail_icon ); ?>
        </div>
	<?php endif;?>

	<?php if(empty($settings[$image_size_key]['id'])) {
		$url = Utils::get_placeholder_image_src();
		?>
		<div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'background_color' ) ); ?>>
			<img src="<?php echo wp_kses_post($url);?>" class="cms-transition" />
		</div>
	<?php } ?>

    <div class="cms-fancy-box-content d-flex flex-direction-column">
        <h3 <?php echo wp_kses_post( $widget->get_render_attribute_string( 'title' ) ); ?>><?php echo wp_kses_post( $settings['title'] ); ?></h3>
        <div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'description' ) ); ?>>
			<?php echo wp_kses_post( $settings['description'] ); ?>
		</div>
		<?php if ( ! empty( $settings['btn_text'] ) ) : ?>
            <div class="cms-fancy-box-button btn-text-line">
                <a <?php echo wp_kses_post( $widget->get_render_attribute_string( 'btn_text' ) ); ?>><?php echo esc_attr( $settings['btn_text'] ); ?></a>
            </div>
		<?php endif; ?>
    </div>
</div>