<?php
$class = new class{
    /**
     * Elementor Text Render
    */
    function elementor_text_render($args = [], $widget = null, $settings = []) {
        $args = wp_parse_args($args, [
            'name'         => 'text',
            'tag'          => 'div',
            'color'        => 'body',
            'class'        => '', 
            'selector'     => '',
            'render_attrs' => '',
            'before'       => '', 
            'after'        => '',
            'wrap_before'  => '', 
            'wrap_after'   => '',
            'autop'        => false,
            'default'      => '' 
        ]);
        if( empty($widget->get_setting($args['name'],$args['default'])) || $widget->get_setting($args['name']) === '-1' ) return;
        if(empty($args['render_attrs'])) $args['render_attrs'] = $args['name'];
        // Heading
        $text_tag = $widget->get_setting($args['name'].'_tag', $args['tag']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', $args['class']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', $args['selector']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'text-'.$widget->get_setting($args['name'].'_color', $args['color']));
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'empty-none');
        
        if ( isset($settings[$args['name'].'_animation']) && $settings[$args['name'].'_animation'] ) {
            $widget->add_render_attribute( $args['render_attrs'], 'class', 'elementor-invisible');
            $widget->add_render_attribute( $args['render_attrs'], 'class', 'animated-'.$widget->get_setting($args['name'].'_animation_duration', ''));
            $widget->add_render_attribute( $args['render_attrs'], 'data-settings', json_encode([
                '_animation'      => $widget->get_setting($args['name'].'_animation', ''),
                'animation_delay' => $widget->get_setting($args['name'].'_animation_delay', '')
            ]));
        }
        if($args['autop']){
            $text = nl2br($widget->get_setting($args['name'], $args['default']));
        } else {
            $text = $widget->get_setting($args['name'], $args['default']);
        }
        printf('%s', $args['wrap_before']);
    ?>
        <<?php echo wp_kses_post($text_tag);?> <?php echo wp_kses_post($widget->get_render_attribute_string( $args['render_attrs'] )); ?>><?php
            echo wp_kses_post($args['before'].$text.$args['after']);
        ?></<?php echo wp_kses_post($text_tag);?>>
        <div class="extra-space clearfix"> </div>
    <?php
        printf('%s', $args['wrap_after']);
    }

    // Alignment css class
    // Text Align
    function elementor_align_class($settings, $args = []){
        $args = wp_parse_args($args, [
            'id'          => 'text-align',
            'extra_class' => '',
            'default'     => '',
            'prefix'      => 'text-'  
        ]);
        if(empty($args['default'])) $args['default'] = $settings[$args['id']];
        $align_class = [];
        $align_class[] = empty($settings[$args['id'].'_mobile']) ? $args['prefix'].$args['default'] : $args['prefix'].$settings[$args['id'].'_mobile'];
        $align_class[] = empty($settings[$args['id'].'_tablet']) ? '' : $args['prefix'].'md-'.$settings[$args['id'].'_tablet'];
        $align_class[] = empty($settings[$args['id']]) ? '' : $args['prefix'].'lg-'.$settings[$args['id']];
        
        $align_class[] = $args['extra_class'];
        return trim(implode(' ', $align_class));
    }

    // Alignment options
    function elementor_text_align($args = []) {
        $args = wp_parse_args($args, [
            'prefix'      => '',
            'name'        => 'text-align',   
            'default'     => '',
            'label'       => esc_html__( 'Content Alignment', 'validus' ),
            'label_block' => false,
            'condition'   => []
        ]);
        return array(
            'name'         => $args['prefix'].$args['name'],
            'label'        => $args['label'],
            'label_block'  => $args['label_block'],
            'type'         => \Elementor\Controls_Manager::CHOOSE,
            'control_type' => 'responsive',
            'options'      => $this->text_align_opts(),
            'default'      => $args['default'],
            'condition'    => $args['condition']
        );
    }

    function text_align_opts($args = []){
        $args = wp_parse_args($args, [
            'default' => '',
        ]);
        return [
            'start' => [
                'title' => esc_html__( 'Start', 'validus' ),
                'icon' => 'eicon-text-align-left',
            ],
            'center' => [
                'title' => esc_html__( 'Center', 'validus' ),
                'icon' => 'eicon-text-center',
            ],
            'end' => [
                'title' => esc_html__( 'End', 'validus' ),
                'icon' => 'eicon-text-align-right',
            ],
            'justify' => [
                'title' => esc_html__( 'Justified', 'validus' ),
                'icon' => 'eicon-text-align-justify',
            ],
        ];
    }
};

$logo     = validus_get_opts( 'logo', array( 
	'id' => '',
	'url' => get_template_directory_uri() . '/assets/images/logo/logo.png',
), 'header_custom');
$logo_url = $logo['url'];

// Wrapper attributes
$widget->add_render_attribute( 'wrap', 'class', 'cms-newsletter-wrap cms-newsletter-layout3 d-flex');
$widget->add_render_attribute( 'wrap', 'class', $class->elementor_align_class($settings));

if (class_exists('Newsletter')) :
    $newsletter = Newsletter::instance();
?>
<div <?php echo wp_kses_post($widget->get_render_attribute_string( 'wrap' )); ?>>
    <?php
    // Small Heading 
    $class->elementor_text_render([
        'name'         => 'smallheading_text',
        'tag'          => 'div',
        'color'        => 'accent',
        'class'        => 'cms-smallheading cms-heading text-17 font-700 mt-n5 pb-17' 
    ], $widget, $settings);
    // Large Heading 
    $class->elementor_text_render([
        'name'         => 'largeheading_text',
        'tag'          => 'div',
        'color'        => 'heading',
        'class'        => 'cms-largeheading cms-heading text-30 text-lg-50 text-xl-75 lh-1 font-700 mt-n5 mb-43' 
    ], $widget, $settings);
    ?>
        <div class="cms-newsletter-logo"><img src="<?php echo esc_html($logo_url);?>" /></div>
        <div class="cms-newsletter-form relative">
            <div><b>
                <form method="post" action="<?php echo esc_url($newsletter->build_action_url('s')); ?>" class="tnp-subscription" style="">
                    <input type="hidden" name="nlang" value="">
                    <div class="tnp-field tnp-field-email">
                        <input class="tnp-email" type="email" name="ne" id="tnp-1" value="" placeholder="<?php echo $widget->get_setting('email_text',esc_html__('Your Email Address','validus'));?>" required="">
                    </div>
                    <div class="tnp-field tnp-field-button">
                        <input class="tnp-button" type="submit" value="<?php echo $widget->get_setting('button_text',esc_html__('Subscribe','validus'));?>">
                    </div>
                </form>
            </b></div>
        </div>
    <?php 
    // Desc
    $class->elementor_text_render([
        'name'         => 'description_text',
        'tag'          => 'div',
        'color'        => 'body',
        'class'        => 'cms-desc font-700 pt-25' 
    ], $widget, $settings);
    ?>
</div>
<?php else:; ?>
<h4 class="text-body">You have to install The Newsletter Plugin first!</h4>
<?php endif; ?>