<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;
use Elementor\Utils;

$settings = $widget->get_settings_for_display();
$symbol = '';

if ( ! empty( $settings['currency_symbol'] ) ) {
    if ( 'custom' !== $settings['currency_symbol'] ) {
        //$symbol = $widget->get_currency_symbol( $settings['currency_symbol'] );
        $symbols = [
            'dollar' => '&#36;',
            'euro' => '&#128;',
            'franc' => '&#8355;',
            'pound' => '&#163;',
            'ruble' => '&#8381;',
            'shekel' => '&#8362;',
            'baht' => '&#3647;',
            'yen' => '&#165;',
            'won' => '&#8361;',
            'guilder' => '&fnof;',
            'peso' => '&#8369;',
            'peseta' => '&#8359',
            'lira' => '&#8356;',
            'rupee' => '&#8360;',
            'indian_rupee' => '&#8377;',
            'real' => 'R$',
            'krona' => 'kr',
        ];

        $symbol = isset( $symbols[ $settings['currency_symbol'] ] ) ? $symbols[ $settings['currency_symbol'] ] : '';
    } else {
        $symbol = $settings['currency_symbol_custom'];
    }
}
$currency_format = empty( $settings['currency_format'] ) ? '.' : $settings['currency_format'];
$price = explode( $currency_format, $settings['price'] );
$intpart = $price[0];
$fraction = '';
if ( 2 === count( $price ) ) {
    $fraction = $price[1];
}

$widget->add_render_attribute( 'button_text', 'class', [
    'cms-price-table__button d-inline-flex gap-10',
    //'elementor-button',
    //'elementor-size-' . $settings['button_size'],
    'btn',
    'btn-' . $settings['button_size'],
] );

if ( ! empty( $settings['link']['url'] ) ) {
    $widget->add_link_attributes( 'button_text', $settings['link'] );
}

if ( ! empty( $settings['button_hover_animation'] ) ) {
    $widget->add_render_attribute( 'button_text', 'class', 'elementor-animation-' . $settings['button_hover_animation'] );
}

$widget->add_render_attribute( 'heading', 'class', 'cms-price-table__heading text-white' );
$widget->add_render_attribute( 'sub_heading', 'class', 'cms-price-table__subheading text-white d-block' );
$widget->add_render_attribute( 'period', 'class', [ 'cms-price-table__period', 'elementor-typo-excluded' ] );
$widget->add_render_attribute( 'footer_additional_info', 'class', 'cms-price-table__additional_info' );
$widget->add_render_attribute( 'ribbon_title', 'class', 'cms-price-table__ribbon-inner radius-2' );

$widget->add_inline_editing_attributes( 'heading', 'none' );
$widget->add_inline_editing_attributes( 'sub_heading', 'none' );
$widget->add_inline_editing_attributes( 'period', 'none' );
$widget->add_inline_editing_attributes( 'footer_additional_info' );
$widget->add_inline_editing_attributes( 'button_text' );
$widget->add_inline_editing_attributes( 'ribbon_title' );

$period_position = $settings['period_position'];
$period_element = '<span ' . $widget->get_render_attribute_string( 'period' ) . '>' . $settings['period'] . '</span>';
$heading_tag = Utils::validate_html_tag( $settings['heading_tag'] );

$migration_allowed = Icons_Manager::is_migration_allowed();


//thumbnail size
$thumbnail_size = $settings['thumbnail_size'];
$thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];
if ($thumbnail_size != 'custom') {
    $img_size = $thumbnail_size;

    $image = wp_get_attachment_image_src($settings['general_bg_image']['id'],$thumbnail_size);
    if(isset($image) && is_array($image) && !empty($image)) {
        $params = array(
            'width' => $image[1],
            'height' => $image[2]
        );
    } else {
        $params = array(
            'width' => '400',
            'height' => '570'
        );
    }
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

    $params = array(
        'width' => $thumbnail_custom_dimension['width'],
        'height' => $thumbnail_custom_dimension['height']
    );
} else {
    $img_size = '400x570';

    $params = array(
        'width' => '400',
        'height' => '570'
    );
}

$img = etc_get_image_by_size(array(
    'attach_id' => $settings['general_bg_image']['id'],
    'thumb_size' => $img_size,
    'class' => '',
));

if(isset($img['p_img_large'][0])) {
    $src = $img['p_img_large'][0];
} else {
    $src = '';
}

if($src == '') {
    $image = $settings['general_bg_image'];

    if($image['url'] == '') {
        $src = Elementor\Utils::get_placeholder_image_src();
    } else {
        $src = $image['url'];
    }

    //crop image by $params['width'],$params['height']
}

$widget->add_render_attribute( [
    'icon-align' => [
        'class' => [
            'btn-icon d-flex',
        ],
    ],
] );

$style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
?>

<div class="cms-price-table">
    <div class="cms-price-table-background absolute t-0 l-0 r-0 b-0">
        <img decoding="async" class="" src="<?php echo esc_html($src);?>" width="<?php echo esc_html($params['width']);?>" height="<?php echo esc_html($params['height']);?>" />
    </div>
    <div class="cms-price-table-content">
        <?php if ( $settings['heading'] || $settings['sub_heading'] ) : ?>
            <div class="cms-price-table__header">
                <?php if ( ! empty( $settings['heading'] ) ) : ?>
                    <<?php Utils::print_validated_html_tag( $heading_tag ); ?> <?php $widget->print_render_attribute_string( 'heading' ); ?>>
                    <?php $widget->print_unescaped_setting( 'heading' ); ?>
                    </<?php Utils::print_validated_html_tag( $heading_tag ); ?>>
                <?php endif; ?>

                <?php if ( ! empty( $settings['sub_heading'] ) ) : ?>
                    <span <?php $widget->print_render_attribute_string( 'sub_heading' ); ?>>
                        <?php $widget->print_unescaped_setting( 'sub_heading' ); ?>
                    </span>
                <?php endif; ?>
            </div>
        <?php endif; ?>

        <?php if ( ! empty( $settings['features_list'] ) ) : ?>
            <ul class="cms-price-table__features-list text-white">
                <?php
                foreach ( $settings['features_list'] as $index => $item ) :
                    $repeater_setting_key = $widget->get_repeater_setting_key( 'item_text', 'features_list', $index );
                    $widget->add_render_attribute( $repeater_setting_key, [
                        'class' => [ '' ],
                    ] );
                    $widget->add_inline_editing_attributes( $repeater_setting_key );

                    $migrated = isset( $item['__fa4_migrated']['selected_item_icon'] );
                    // add old default
                    if ( ! isset( $item['item_icon'] ) && ! $migration_allowed ) {
                        $item['item_icon'] = 'fa fa-check-circle';
                    }
                    $is_new = ! isset( $item['item_icon'] ) && $migration_allowed;
                    ?>
                    <li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">
                        <div class="cms-price-table__feature-inner d-flex flex-nowrap align-items-center font-bold">
                            <?php if ( ! empty( $item['item_icon'] ) || ! empty( $item['selected_item_icon'] ) ) :
                                if ( $is_new || $migrated ) :
                                    Icons_Manager::render_icon( $item['selected_item_icon'], [ 'aria-hidden' => 'true' ] );
                                else : ?>
                                    <i class="<?php echo esc_attr( $item['item_icon'] ); ?>" aria-hidden="true"></i>
                                    <?php
                                endif;
                            endif; ?>
                            <?php if ( ! empty( $item['item_text'] ) ) : ?>
                                <span <?php $widget->print_render_attribute_string( $repeater_setting_key ); ?>>
                                    <?php $widget->print_unescaped_setting( 'item_text', 'features_list', $index ); ?>
                                </span>
                                <?php
                            else :
                                echo '&nbsp;';
                            endif;
                            ?>
                        </div>
                    </li>
                <?php endforeach; ?>
            </ul>
        <?php endif; ?>

        <?php if ( ! empty( $settings['button_text'] ) || ! empty( $settings['footer_additional_info'] ) ) : ?>
            <div class="cms-price-table__footer">
                <?php if ( ! empty( $settings['button_text'] ) ) : ?>
                    <a <?php $widget->print_render_attribute_string( 'button_text' ); ?>>
                        <?php if(trim($settings['btn_icon']['value']) !== '') { ?>
                        <span <?php echo wp_kses_post( $widget->get_render_attribute_string( 'icon-align' ) ); ?>>
                            <?php \Elementor\Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                        </span>
                        <?php } ?>

                        <span class="btn-text">
                            <?php $widget->print_unescaped_setting( 'button_text' ); ?>
                        </span>
                    </a>
                <?php endif; ?>

                <?php if ( ! empty( $settings['footer_additional_info'] ) ) : ?>
                    <div <?php $widget->print_render_attribute_string( 'footer_additional_info' ); ?>>
                        <?php $widget->print_unescaped_setting( 'footer_additional_info' ); ?>
                    </div>
                <?php endif; ?>
            </div>
        <?php endif; ?>

        <div class="cms-price-table__price d-flex text-white">
            <?php if ( 'yes' === $settings['sale'] && ! empty( $settings['original_price'] ) ) : ?>
                <div class="cms-price-table__original-price elementor-typo-excluded">
                    <?php
                    $currency_position = $widget->get_settings( 'currency_position' );
                    $location_setting = ! empty( $currency_position ) ? $currency_position : 'before';
                    if ( ! empty( $symbol ) && $location_setting === 'before' ) {
                        echo '<span class="elementor-price-table__currency">' . esc_html( $symbol ) . '</span>';
                    }


                    $widget->print_unescaped_setting( 'original_price' );


                    $currency_position = $widget->get_settings( 'currency_position' );
                    $location_setting = ! empty( $currency_position ) ? $currency_position : 'before';
                    if ( ! empty( $symbol ) && $location_setting === 'after' ) {
                        echo '<span class="elementor-price-table__currency">' . esc_html( $symbol ) . '</span>';
                    }
                    ?>
                </div>
            <?php endif; ?>

            <?php
            $currency_position = $widget->get_settings( 'currency_position' );
            $location_setting = ! empty( $currency_position ) ? $currency_position : 'before';
            if ( ! empty( $symbol ) && $location_setting === 'before' ) {
                echo '<span class="cms-price-table__currency">' . esc_html( $symbol ) . '</span>';
            }
            ?>

            <?php if ( ! empty( $intpart ) || 0 <= $intpart ) : ?>
                <span class="cms-price-table__integer-part">
                    <?php
                        // PHPCS - the main text of a widget should not be escaped.
                        echo wp_kses_post($intpart); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                    ?>
                </span>
            <?php endif; ?>

            <?php if ( '' !== $fraction || ( ! empty( $settings['period'] ) && 'below' === $period_position ) ) : ?>
                <div class="cms-price-table__after-price">
                    <span class="cms-price-table__fractional-part">
                        <?php
                            // PHPCS - the main text of a widget should not be escaped.
                            echo wp_kses_post($fraction); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                        ?>
                    </span>

                    <?php if ( ! empty( $settings['period'] ) && 'below' === $period_position ) : ?>
                        <?php
                            // PHPCS - already escaped before
                            echo wp_kses_post($period_element); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                        ?>
                    <?php endif; ?>
                </div>
            <?php endif; ?>

            <?php 
            $currency_position = $widget->get_settings( 'currency_position' );
            $location_setting = ! empty( $currency_position ) ? $currency_position : 'before';
            if ( ! empty( $symbol ) && $location_setting === 'after' ) {
                echo '<span class="cms-price-table__currency">' . esc_html( $symbol ) . '</span>';
            }
            ?>

            <?php if ( ! empty( $settings['period'] ) && 'beside' === $period_position ) : ?>
                <?php
                    // PHPCS - already escaped before
                    echo wp_kses_post($period_element); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                ?>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php
if ( 'yes' === $settings['show_ribbon'] && ! empty( $settings['ribbon_title'] ) ) :
    $widget->add_render_attribute( 'ribbon-wrapper', 'class', 'cms-price-table__ribbon' );

    if ( ! empty( $settings['ribbon_horizontal_position'] ) ) :
        $widget->add_render_attribute( 'ribbon-wrapper', 'class', 'elementor-ribbon-' . $settings['ribbon_horizontal_position'] );
    endif;

    ?>
    <div <?php $widget->print_render_attribute_string( 'ribbon-wrapper' ); ?>>
        <div <?php $widget->print_render_attribute_string( 'ribbon_title' ); ?>>
            <?php $widget->print_unescaped_setting( 'ribbon_title' ); ?>
        </div>
    </div>
    <?php
endif;
?>








<style type="text/css">
.cms-price-table__ribbon {
  position: absolute;
  top: 0;
  left: 0;
  right: auto;
  transform: rotate(0);
  width: 150px;
  height: 150px;
}
.cms-price-table__ribbon-inner {
  text-align: center;
  left: 0;
  transform: translateY(-50%) translateX(-50%) translateX(35px) rotate(-45deg);
  margin-top: 35px;
  font-size: 13px;
  line-height: 2;
  font-weight: 800;
  background: #000;
  height: 40px;
  width: 150px;
  display: flex;
  align-items: center;
  justify-content: center;
}
.cms-price-table__ribbon.elementor-ribbon-left {
  transform: rotate(0);
  left: 0;
  right: auto;
  overflow: hidden;
}
.cms-price-table__ribbon.elementor-ribbon-left .cms-price-table__ribbon-inner {
  height: auto;
}
.cms-price-table__ribbon.elementor-ribbon-center {
  justify-content: center;
  display: flex;
  width: 100%;
}
.cms-price-table__ribbon.elementor-ribbon-center .cms-price-table__ribbon-inner {
  transform: translateY(-100%) rotate(0deg);
  margin-top: 22px;
}
.cms-price-table__ribbon.elementor-ribbon-right {
  transform: rotate(90deg);
  left: auto;
  right: 0;
  overflow: hidden;
}
.cms-price-table__ribbon.elementor-ribbon-right .cms-price-table__ribbon-inner {
  height: auto;
}
</style>