<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Icons_Manager;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Embed;

$class = new class($widget) {
	public $_settings;
	public $_widget;
    public $_slide;
	
	public function __construct($widget) {
		$this->_settings = $widget->get_settings_for_display();
		$this->_widget = $widget;
	}
    public function has_video_image() {
		$settings = $this->_slide;

		return !empty($settings['video_image']['url']);// && 'yes' === $settings['show_video_image']
	}
	public function get_embed_params() {
		$settings = $this->_slide;

		$params = [];

		if ( $settings['autoplay'] && ! $this->has_video_image() ) {
			$params['autoplay'] = '1';

			if ( $settings['play_on_mobile'] ) {
				$params['playsinline'] = '1';
			}
		}

		$params_dictionary = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'controls',
				'mute',
				'rel',
				'modestbranding',
			];

			if ( $settings['loop'] ) {
				$video_properties = Embed::get_video_properties( $settings['youtube_url'] );

				$params['playlist'] = $video_properties['video_id'];
			}

			$params['start'] = $settings['start'];

			$params['end'] = $settings['end'];

			$params['wmode'] = 'opaque';
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'mute' => 'muted',
				'vimeo_title' => 'title',
				'vimeo_portrait' => 'portrait',
				'vimeo_byline' => 'byline',
			];

			$params['color'] = str_replace( '#', '', $settings['color'] );

			$params['autopause'] = '0';

			if ( ! empty( $settings['yt_privacy'] ) ) {
				$params['dnt'] = 'true';
			}
		} elseif ( 'dailymotion' === $settings['video_type'] ) {
			$params_dictionary = [
				'controls',
				'mute',
				'showinfo' => 'ui-start-screen-info',
				'logo' => 'ui-logo',
			];

			$params['ui-highlight'] = str_replace( '#', '', $settings['color'] );

			$params['start'] = $settings['start'];

			$params['endscreen-enable'] = '0';
		}

		foreach ( $params_dictionary as $key => $param_name ) {
			$setting_name = $param_name;

			if ( is_string( $key ) ) {
				$setting_name = $key;
			}

			$setting_value = isset($settings[ $setting_name ]) ? '1' : '0';

			$params[ $param_name ] = $setting_value;
		}

		return $params;
	}
	public function get_embed_options() {
		$settings = $this->_slide;

		$embed_options = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$embed_options['privacy'] = $settings['yt_privacy'];
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$embed_options['start'] = $settings['start'];
		}

		$embed_options['lazy_load'] = ! empty( $settings['lazy_load'] );

		return $embed_options;
	}
	private function render_hosted_video() {
		$video_url = $this->get_hosted_video_url();
		if ( empty( $video_url ) ) {
			return;
		}

		$video_params = $this->get_hosted_params();
		/* Sometimes the video url is base64, therefore we use `esc_attr` in `src`. */
		?>
		<video class="elementor-video" src="<?php echo esc_attr( $video_url ); ?>" <?php Utils::print_html_attributes( $video_params ); ?>></video>
		<?php
	}
	private function get_hosted_params() {
		$settings = $this->_slide;

		$video_params = [];

		foreach ( [ 'autoplay', 'loop', 'controls' ] as $option_name ) {
			if ( $settings[ $option_name ] ) {
				$video_params[ $option_name ] = '';
			}
		}

		if ( $settings['preload'] ) {
			$video_params['preload'] = $settings['preload'];
		}

		if ( $settings['mute'] ) {
			$video_params['muted'] = 'muted';
		}

		if ( $settings['play_on_mobile'] ) {
			$video_params['playsinline'] = '';
		}

		if ( ! $settings['download_button'] ) {
			$video_params['controlsList'] = 'nodownload';
		}

		if ( $settings['poster']['url'] ) {
			$video_params['poster'] = $settings['poster']['url'];
		}

		return $video_params;
	}
	private function get_hosted_video_url() {
		$settings = $this->_slide;

		if ( ! empty( $settings['insert_url'] ) ) {
			$video_url = $settings['external_url']['url'];
		} else {
			$video_url = $settings['hosted_url']['url'];
		}

		if ( empty( $video_url ) ) {
			return '';
		}

		if ( $settings['start'] || $settings['end'] ) {
			$video_url .= '#t=';
		}

		if ( $settings['start'] ) {
			$video_url .= $settings['start'];
		}

		if ( $settings['end'] ) {
			$video_url .= ',' . $settings['end'];
		}

		return $video_url;
	}
	public function print_a11y_text( $video_image ) {
		if ( empty( $video_image['alt'] ) ) {
			echo esc_html__( 'Play Video', 'validus' );
		} else {
			echo esc_html__( 'Play Video about', 'validus' ) . ' ' . esc_attr( $video_image['alt'] );
		}
	}
};

$header_transparent = validus_get_opts( 'header_transparent', false, 'header_custom');
if (is_search()) {
    $header_transparent = validus_get_opt( 'header_transparent', false );
}

if ( $header_transparent == 'on' ) {
    $transparent = 'header-transparent ';
} else {
    $transparent = '';
}

$cms_slides = $widget->get_setting('cms_slides', []);
$arrows = $widget->get_setting('arrows', '');
$dots = $widget->get_setting('dots', '');
$style = $widget->get_setting('style', 'style1');

$adjust = $widget->get_setting('adjust_slides_height', '');
$adjust_mobile = $widget->get_setting('adjust_slides_height_mobile', '');
$adjust_mobile_extra = $widget->get_setting('adjust_slides_height_mobile_extra', '');
$adjust_tablet = $widget->get_setting('adjust_slides_height_tablet', '');
$adjust_tablet_extra = $widget->get_setting('adjust_slides_height_tablet_extra', '');
$adjust_laptop = $widget->get_setting('adjust_slides_height_laptop', '');

$_adjust = '';

if (empty($adjust) && $adjust == '') {
    $_adjust .= 'cms-slider-adjust';
} 
if (empty($adjust_laptop)) {
    $_adjust .= ' cms-slider-adjust-laptop';
}
if (empty($adjust_tablet_extra)) {
    $_adjust .= ' cms-slider-adjust-tablet-extra';
}
if (empty($adjust_tablet)) {
    $_adjust .= ' cms-slider-adjust-tablet';
}
if (empty($adjust_mobile_extra)) {
    $_adjust .= ' cms-slider-adjust-mobile-extra';
}
if (empty($adjust_mobile)) {
    $_adjust .= ' cms-slider-adjust-mobile';
}

$widget->add_render_attribute( 'wrap', 'class', 'cms-slider-wrap cms-slider-layout3 ' . $transparent . esc_attr($style) . ' ' . $_adjust);

$widget->add_inline_editing_attributes( 'btn_text' );

$thumbnail_size = $widget->get_setting('thumbnail_size', 'full');
$thumbnail_custom_dimension = $widget->get_setting('thumbnail_custom_dimension', '');
if ($thumbnail_size != 'custom') {
    $img_size = $thumbnail_size;
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
} else {
    $img_size = '1600x800';

    $settings['thumbnail_custom_dimension'] = ['width' => '1600', 'height' => '800'];
}

$autoplay_speed = isset($settings['autoplay_speed']) ? $settings['autoplay_speed'] : 300;
$animation_speed = isset($settings['autoplay_speed']) ? $settings['autoplay_speed'] : '';
?>
<div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'wrap' ) ); ?>>
    <div class="cms-carousel swiper d-flex align-items-center">
        <div class="swiper-wrapper">
            <?php
            foreach ($cms_slides as $key => $cms_slide) {
                $settings['thumbvideo_size'] = '130x130';
                $settings['thumbvideo_custom_dimension'] = ['width' => '130', 'height' => '130'];
                $video_image = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $cms_slide['video_image']['id'], 'thumbvideo', $settings );
                if ($video_image == '') {
                    $video_image = $cms_slide['image']['url'];
                }
                ?>
                <div class="cms-carousel-item elementor-repeater-item-<?php echo esc_html($cms_slide['_id']);?> swiper-slide relative">
                    <div class="swiper-slide-bg"></div>
                    <div class="cms-slider-item-overlay cms-transition absolute d-flex align-items-center justify-content-center t-0 r-0 l-0 b-0"></div>

                    <div class="cms-slider-top-space pt-105"></div>
	                <div class="cms-slider-top-last"></div>

                    <div class="cms-slider-content w-ptt-pt w-ptt-pt-tablet-extra-30 pt-213 absolute t-0">
                        <div class="container d-flex justify-content-start relative">
                            <div class="cms-slider-content-text">
                                <?php if (isset($cms_slide['title']) && !empty($cms_slide['title'])) { ?>
                                    <div class="cms-slider-item-title text-17 text-white font-600" data-cms-animation="title_animation" data-cms-animation-delay="title_animation_delay">
                                        <?php echo esc_html($cms_slide['title']); ?>
                                    </div>
                                <?php } ?>
                                <?php if (isset($cms_slide['subtitle']) && !empty($cms_slide['subtitle'])) { ?>
                                    <h3 class="cms-slider-item-subtitle text-75 text-white m-0" data-cms-animation="subtitle_animation" data-cms-animation-delay="subtitle_animation_delay">
                                        <?php echo esc_html($cms_slide['subtitle']); ?>
                                    </h3>
                                <?php } ?>
                                <?php if (isset($cms_slide['description']) && !empty($cms_slide['description'])) { ?>
                                    <div class="cms-slider-item-description text-17 text-white font-bold" data-cms-animation="description_animation" data-cms-animation-delay="description_animation_delay">
                                        <?php echo esc_html($cms_slide['description']); ?>
                                    </div>
                                <?php } ?>
                                <div class="cms-slider-item-button d-flex gap-30">
                                    <?php
                                        if ( ! empty( $cms_slide['button_primary'] ) ) :
                                            $button_primary_url = '';
                                            if(isset($cms_slide['button_primary_link']) && is_array($cms_slide['button_primary_link']) && isset($cms_slide['button_primary_link']['url'])){
                                                $button_primary_url = $cms_slide['button_primary_link']['url'];
                                            }
                                    ?>
                                        <div class="button-primary" data-cms-animation="button_primary_animation" data-cms-animation-delay="button_primary_animation_delay">
                                            <a href="<?php echo esc_attr($button_primary_url); ?>" class="btn btn-primary">
                                                <i class="btn-icon cmsi-chevron-circle-right-01"></i>
                                                <span <?php echo wp_kses_post( $widget->get_render_attribute_string( 'btn_text' ) ); ?>><?php echo esc_attr( $cms_slide['button_primary'] ); ?></span>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                    <?php
                                        if ( ! empty( $cms_slide['button_secondary'] ) ) :
                                            $button_secondary_url = '';
                                            if(isset($cms_slide['button_secondary_link']) && is_array($cms_slide['button_secondary_link']) && isset($cms_slide['button_secondary_link']['url'])){
                                                $button_secondary_url = $cms_slide['button_secondary_link']['url'];
                                            }
                                    ?>
                                        <div class="button-secondary" data-cms-animation="button_secondary_animation" data-cms-animation-delay="button_secondary_animation_delay">
                                            <a href="<?php echo esc_url($button_secondary_url); ?>" class="btn btn-white">
                                                <?php echo esc_attr( $cms_slide['button_secondary'] ); ?>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                                <?php if (isset($cms_slide['name'])) { ?>
                                    <div class="cms-slider-item-dot">
                                        <div class="cms-slider-item-name text-white text-20 font-heading mb-22">
                                            <?php echo esc_html($cms_slide['name']); ?>
                                        </div>
                                        <div class="cms-slider-item-bullet absolute b-0 bg-primary" data-cms-animation="effect" data-cms-animation-delay="autoplay_speed" style="--autoplay-speed:<?php echo esc_html($autoplay_speed);?>ms;--animation-speed:<?php echo esc_html($animation_speed);?>ms;"></div>
                                    </div>
                                <?php } ?>
                            </div>
                            <div class="cms-slider-item-video d-flex align-items-end justify-content-end pb-45" data-cms-animation="video_button_animation" data-cms-animation-delay="video_button_animation_delay">
                                <div class="cms-slider-item-video-container d-flex justify-content-end">
                                    <div class="cms-slider-video-play d-flex align-items-center justify-content-center text-center cursor-pointer" style="background-image: url('<?php echo esc_html($video_image);?>'); background-size: cover;background-repeat: no-repeat;">
                                        <?php
                                        //video params
                                        $settings['aspect_ratio'] = '169';
                                        $settings['lightbox'] = 1;
                                        if ($settings['lightbox']) {
                                            $class->_slide = $cms_slide;

                                            $video_url = $cms_slide[ $cms_slide['video_type'] . '_url' ];

                                            if ( 'hosted' === $cms_slide['video_type'] ) {
                                                $video_url = $class->get_hosted_video_url();
                                            } else {
                                                $embed_params = $class->get_embed_params();
                                                $embed_options = $class->get_embed_options();
                                            }
                                            
                                            if ( 'hosted' === $cms_slide['video_type'] ) {
                                                $widget->add_render_attribute( 'video-wrapper', 'class', 'e-hosted-video' );
                                            } else {
                                                $is_static_render_mode = Plugin::$instance->frontend->is_static_render_mode();
                                                $post_id = get_queried_object_id();
                                            
                                                //need these to play on click
                                                $params = array(
                                                    'width' => '640',
                                                    'height' => '500'
                                                );
                                            
                                                $embed_attr = array(
                                                    'class' => 'elementor-video-iframe',
                                                    'allow' => 'accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share',
                                                    'width' => $params['width'],
                                                    'height' => $params['height'],
                                                );
                                            }
                                            if ( 'hosted' === $cms_slide['video_type'] ) {
                                                $lightbox_url = $video_url;
                                            } else {
                                                $lightbox_url = Embed::get_embed_url( $video_url, $embed_params, $embed_options );
                                            }

                                            $tablet = isset($settings['lightbox_content_animation_tablet']) ? $settings['lightbox_content_animation_tablet'] : '';
                                            $mobile = isset($settings['lightbox_content_animation_mobile']) ? $settings['lightbox_content_animation_mobile'] : '';

                                            $lightbox_options = [
                                                'type' => 'video',
                                                'videoType' => $cms_slide['video_type'],
                                                'url' => $lightbox_url,
                                                'modalOptions' => [
                                                    'id' => 'elementor-lightbox-' . $widget->get_id().'-'.$key,
                                                    'entranceAnimation' => $settings['lightbox_content_animation'],
                                                    'entranceAnimation_tablet' => $tablet,
                                                    'entranceAnimation_mobile' => $mobile,
                                                    'videoAspectRatio' => $settings['aspect_ratio'],
                                                ],
                                            ];

                                            if ( 'hosted' === $cms_slide['video_type'] ) {
                                                $lightbox_options['videoParams'] = $class->get_hosted_params();
                                            }

                                            $widget->add_render_attribute('image-playbutton'.$key, [
                                                'data-elementor-open-lightbox' => 'yes',
                                                'data-elementor-lightbox' => wp_json_encode( $lightbox_options ),
                                                'data-e-action-hash' => Plugin::instance()->frontend->create_action_hash( 'lightbox', $lightbox_options ),
                                            ]);
                                        }
                                        $widget->add_render_attribute('image-playbutton'.$key, [
                                            'class' => 'cms-slider-video-container cms-transition d-flex align-items-center justify-content-center radius-100',
                                            'role' => 'button',
                                            'tabindex' => '0'
                                        ]);
                                        ?>
                                        <div <?php $widget->print_render_attribute_string( 'image-playbutton'.$key ); ?>>
                                            <div class="cms-slider-video-icon bg-primary d-flex align-items-center justify-content-center text-center cms-transition radius-100">
                                                <?php
                                                if(isset($cms_slide['video_icon'])) {
                                                    $icon_settings = $cms_slide['video_icon'];
                                                } else {
                                                    $icon_settings = null;
                                                }
                                                
                                                $icon_settings = [
                                                    'library' => 'cmsi',
                                                    'value' => 'cmsi-play',
                                                ];
                                                
                                                Elementor\Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true', 'class' => 'text-14 text-white radius-100']);
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="cms-slider-video-desc bg-white">
                                        <div class="cms-slider-video-subject text-15 text-primary font-bold mb-5">
                                            <?php echo esc_html($cms_slide['video_subject']); ?>
                                        </div>
                                        <h4 class="cms-slider-video-title text-20 font-normal m-0">
                                            <?php echo esc_html($cms_slide['video_title']); ?>
                                        </h4>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php if ($arrows == 'yes') : ?>
            <div class="cms-carousel-tool absolute">
                <div class="cms-slider-button-arrow relative d-flex justify-content-between p-lr-40 p-lr-mobile-20 text-50 gap-30">
                    <div class="cms-carousel-button-prev d-flex align-items-center cursor-pointer">
                        <i aria-hidden="true" class="cmsi-arrow-prev"></i>
                    </div>
                    <div class="cms-carousel-button-next d-flex align-items-center cursor-pointer">
                        <i aria-hidden="true" class="cmsi-arrow-next"></i>
                    </div>
                </div>
            </div>
        <?php endif ?>
        <?php if ($dots == 'yes') : ?>
            <?php 
            $reset = $widget->get_setting('reset_mobile', 'no');
            $widget->add_render_attribute( 'pagination', [
                'class' => [ 
                    'cms-carousel-pagination absolute b-5',
                ],
            ]);
            ?>
            <div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'pagination' ) ); ?>>
                <div class="container">
                    <input type="hidden" class="reset-pagination" />
                    <div class="cms-carousel-dots d-flex flex-nowrap gap-40 relative"></div>
                </div>
            </div>
        <?php endif ?>
    </div>
</div>