<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Icons_Manager;

$class = new class($widget) {
	public $_settings;
	public $_widget;
	
	public function __construct($widget) {
		$this->_settings = $widget->get_settings_for_display();
		$this->_widget = $widget;
	}
};

$cms_slides = $widget->get_setting('cms_slides', []);
$arrows = $widget->get_setting('arrows', '');
$dots = $widget->get_setting('dots', '');
$style = $widget->get_setting('style', 'style1');

$_adjust = '';

$widget->add_render_attribute( 'wrap', 'class', 'cms-slider-landing-wrap cms-slider-landing-layout1 ' . esc_attr($style) . ' ' . $_adjust);
$widget->add_render_attribute( 'btn_text', 'class', 'cms-transition');

$widget->add_inline_editing_attributes( 'btn_text' );

$thumbnail_size = $widget->get_setting('thumbnail_size', 'full');
$thumbnail_custom_dimension = $widget->get_setting('thumbnail_custom_dimension', '');
if ($thumbnail_size != 'custom') {
    $img_size = $thumbnail_size;
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
} else {
    $img_size = '1600x900';

    $settings['thumbnail_custom_dimension'] = ['width' => '1600', 'height' => '900'];
}
?>
<div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'wrap' ) ); ?>>
    <div class="cms-carousel swiper">
        <div class="swiper-wrapper">
            <?php
            foreach ($cms_slides as $key => $cms_slide) {
                $slide_image = $cms_slide['image']['url'];
                $slide_image = ' style="background-image: url('.$slide_image.'")';
                $slide_image = '';

                $slide_color = $cms_slide['content_background'];
                $slide_color = ' style="background-color: '.$slide_color.'"';

                //"Regenerate File & Data" from backend in case elementor-repeater-item-$id not work
                ?>
                <div class="cms-carousel-item elementor-repeater-item-<?php echo esc_html($cms_slide['_id']);?> swiper-slide">
                    <div class="swiper-slide-bg"<?php echo esc_html($slide_image);?>></div>
                    <div class="item-content">
                        <div class="item-content-text"<?php echo wp_kses_post($slide_color);?>>
                            <?php if (isset($cms_slide['logo']) && isset($cms_slide['logo']['url']) && !empty($cms_slide['logo']['url'])) { ?>
                                <div class="item-logo">
                                    <?php
                                    //
                                    $logo['thumbnail_size'] = 'full';
                                    $src = Group_Control_Image_Size::get_attachment_image_src( $cms_slide['logo']['id'], 'thumbnail', $logo );

                                    if ($src == '') {
                                        $src = $cms_slide['logo']['url'];

                                        //crop image by 156x41
                                    }
                                    echo sprintf( '<img src="%s" loading="lazy" />', esc_attr( $src ));
                                    ?>
                                </div>
                            <?php } ?>
                            <?php if (isset($cms_slide['title'])) { ?>
                                <h3 class="item-title" data-cms-animation="title_animation" data-cms-animation-delay="title_animation_delay">
                                    <?php echo esc_html($cms_slide['title']); ?>
                                </h3>
                            <?php } ?>
                            <?php if (isset($cms_slide['description'])) { ?>
                                <div class="item-description" data-cms-animation="description_animation" data-cms-animation-delay="description_animation_delay">
                                    <?php echo esc_html($cms_slide['description']); ?>
                                </div>
                            <?php } ?>
                            <div class="item-button">
                                <?php
                                    if ( ! empty( $cms_slide['button_primary'] ) ) :
                                        $button_primary_url = '';
                                        if(isset($cms_slide['button_primary_link']) && is_array($cms_slide['button_primary_link']) && isset($cms_slide['button_primary_link']['url'])){
                                            $button_primary_url = $cms_slide['button_primary_link']['url'];
                                        }
                                ?>
                                    <div data-cms-animation="button_primary_animation" data-cms-animation-delay="button_primary_animation_delay">
                                        <a href="<?php echo esc_attr($button_primary_url); ?>" class="btn btn-primary cms-transition">
                                            <i class="btn-icon cmsi-chevron-circle-right-01 cms-transition"></i>
                                            <span <?php echo wp_kses_post( $widget->get_render_attribute_string( 'btn_text' ) ); ?>><?php echo esc_attr( $cms_slide['button_primary'] ); ?></span>
                                        </a>
                                    </div>
                                <?php endif; ?>
                                <?php
                                    if ( ! empty( $cms_slide['button_secondary'] ) ) :
                                        $button_secondary_url = '';
                                        if(isset($cms_slide['button_secondary_link']) && is_array($cms_slide['button_secondary_link']) && isset($cms_slide['button_secondary_link']['url'])){
                                            $button_secondary_url = $cms_slide['button_secondary_link']['url'];
                                        }
                                ?>
                                    <div data-cms-animation="button_secondary_animation" data-cms-animation-delay="button_secondary_animation_delay">
                                        <a href="<?php echo esc_url($button_secondary_url); ?>" class="btn btn-white cms-transition">
                                            <i class="btn-icon cmsi-chevron-circle-right-01 cms-transition"></i>
                                            <span <?php echo wp_kses_post( $widget->get_render_attribute_string( 'btn_text' ) ); ?>>
                                                <?php echo esc_attr( $cms_slide['button_secondary'] ); ?>
                                            </span>
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php if ($dots == 'yes') : ?>
            <div class="cms-carousel-dots"></div>
        <?php endif ?>
    </div>
</div>