<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Control_Media;
use Elementor\Icons_Manager;

$layout_mode = $widget->get_setting('layout_mode', 'carousel');
$teams = $widget->get_setting('teams', []);
$arrows = $widget->get_setting('arrows', '');
$dots = $widget->get_setting('dots', '');

?>
<div class="cms-teams-wrapper cms-teams-layout2">
    <div class="cms-carousel swiper">
        <div class="swiper-wrapper">
            <?php
            foreach ($teams as $key => $team) {
                ?>
                <div class="cms-carousel-item swiper-slide">
                    <?php if (isset($team['image']) && isset($team['image']['url']) && !empty($team['image']['url'])) { ?>
                        <div class="cms-team-item-image relative d-flex justify-content-center">
                            <?php
                                $image_key = $widget->get_repeater_setting_key( 'image', 'cms_team', $key );
                                $widget->add_render_attribute( $image_key, 'src', $team['image']['url'] );
                                $widget->add_render_attribute( $image_key, 'alt', Control_Media::get_image_alt( $team['image'] ) );
                                $widget->add_render_attribute( $image_key, 'title', Control_Media::get_image_title( $team['image'] ) );
                                echo Group_Control_Image_Size::get_attachment_image_html( $team, 'thumbnail', 'image' );
                            ?>
                            <div class="cms-team-item-title absolute bg-primary d-flex align-items-center flex-direction-column gap-9">
                                <?php if (isset($team['name'])) { ?>
                                    <div class="cms-team-item-name">
                                        <h4>
                                        <?php
                                            if(!empty( $team['link']['url'])){
                                                $link_key = $widget->get_repeater_setting_key( 'link', 'cms_team', $key );
                                                $widget->add_link_attributes( $link_key, $team['link'] );
                                                ?>
                                                <a <?php echo wp_kses_post($widget->get_render_attribute_string( $link_key )); ?>>
                                                    <?php echo esc_html($team['name']); ?>
                                                </a>
                                                <?php
                                            }
                                            else{
                                                echo esc_html($team['name']);
                                            }
                                        ?>
                                        </h4>
                                    </div>
                                <?php } ?>
                                <?php if (isset($team['position'])) { ?>
                                    <div class="cms-team-item-position text-15 text-white">
                                        <?php echo esc_html($team['position']); ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    <?php } ?>
                    <div class="cms-team-item-content d-flex flex-direction-column gap-21">
                        <?php if (isset($team['description'])) { ?>
                            <div class="cms-team-item-description">
                                <?php echo esc_html($team['description']); ?>
                            </div>
                        <?php } ?>
                        <?php
                            ob_start();
                            for ($i = 1; $i <= 4; $i++) {
                                $social_icon = isset($team["social_icon_{$i}"]) ? $team["social_icon_{$i}"] : null;
                                $social_link = isset($team["social_link_{$i}"]) ? $team["social_link_{$i}"] : null;
                                if($social_icon && $social_link){
                                    if ( ! empty( $social_link['url'] ) ) {
                                        $social_link_key = $widget->get_repeater_setting_key( "social_link_{$i}", 'cms_team', $key );
                                        $widget->add_link_attributes( $social_link_key, $social_link );
                                        $widget->add_render_attribute( $social_link_key, 'class', 'cms-team-item-social' );
                                        ?>
                                            <a <?php echo wp_kses_post($widget->get_render_attribute_string( $social_link_key )); ?>>
                                                <?php
                                                    Icons_Manager::render_icon( $social_icon, [ 'aria-hidden' => 'true', 'class' => 'text-20 text-center' ] );
                                                ?>
                                            </a>
                                        <?php
                                    }
                                }
                            }
                            $socials_html = ob_get_clean();

                            if(!empty($socials_html)){
                                ?>
                                <div class="cms-team-social-wrap d-flex justify-content-center">
                                    <div class="cms-team-item-socials d-flex">
                                        <?php echo wp_kses_post($socials_html); ?>
                                    </div>
                                </div>
                                <?php
                            }
                        ?>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php if ($arrows == 'yes') : ?>
            <div class="cms-team-button-arrow cms-carousel-button-prev">
                <i aria-hidden="true" class="eicon-chevron-left"></i>
            </div>
            <div class="cms-team-button-arrow cms-carousel-button-next">
                <i aria-hidden="true" class="eicon-chevron-right"></i>
            </div>
        <?php endif ?>
        <?php if ($dots == 'yes') : ?>
            <div class="cms-carousel-dots"></div>
        <?php endif ?>
    </div>
</div>