<?php
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Embed;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Image_Size;

$class = new class($widget) {
	public $_settings;
	public $_widget;
	
	public function __construct($widget) {
		$this->_settings = $widget->get_settings_for_display();
		$this->_widget = $widget;
	}
	public function has_image_overlay() {
		$settings = $this->_settings;

		return 'yes' === $settings['show_image_overlay'];//&& ! empty( $settings['image_overlay']['url'] )
	}
	public function get_embed_params() {
		$settings = $this->_settings;

		$params = [];

		if ( $settings['autoplay'] && ! $this->has_image_overlay() ) {
			$params['autoplay'] = '1';

			if ( $settings['play_on_mobile'] ) {
				$params['playsinline'] = '1';
			}
		}

		$params_dictionary = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'controls',
				'mute',
				'rel',
				'modestbranding',
			];

			if ( $settings['loop'] ) {
				$video_properties = Embed::get_video_properties( $settings['youtube_url'] );

				$params['playlist'] = $video_properties['video_id'];
			}

			$params['start'] = $settings['start'];

			$params['end'] = $settings['end'];

			$params['wmode'] = 'opaque';
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'mute' => 'muted',
				'vimeo_title' => 'title',
				'vimeo_portrait' => 'portrait',
				'vimeo_byline' => 'byline',
			];

			$params['color'] = str_replace( '#', '', $settings['color'] );

			$params['autopause'] = '0';

			if ( ! empty( $settings['yt_privacy'] ) ) {
				$params['dnt'] = 'true';
			}
		} elseif ( 'dailymotion' === $settings['video_type'] ) {
			$params_dictionary = [
				'controls',
				'mute',
				'showinfo' => 'ui-start-screen-info',
				'logo' => 'ui-logo',
			];

			$params['ui-highlight'] = str_replace( '#', '', $settings['color'] );

			$params['start'] = $settings['start'];

			$params['endscreen-enable'] = '0';
		}

		foreach ( $params_dictionary as $key => $param_name ) {
			$setting_name = $param_name;

			if ( is_string( $key ) ) {
				$setting_name = $key;
			}

			$setting_value = $settings[ $setting_name ] ? '1' : '0';

			$params[ $param_name ] = $setting_value;
		}

		return $params;
	}
	public function get_embed_options() {
		$settings = $this->_settings;

		$embed_options = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$embed_options['privacy'] = $settings['yt_privacy'];
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$embed_options['start'] = $settings['start'];
		}

		$embed_options['lazy_load'] = ! empty( $settings['lazy_load'] );

		return $embed_options;
	}
	public function render_hosted_video() {
		$video_url = $this->get_hosted_video_url();
		if ( empty( $video_url ) ) {
			return;
		}

		$video_params = $this->get_hosted_params();
		/* Sometimes the video url is base64, therefore we use `esc_attr` in `src`. */
		?>
		<video class="elementor-video" src="<?php echo esc_attr( $video_url ); ?>" <?php Utils::print_html_attributes( $video_params ); ?>></video>
		<?php
	}
	public function get_hosted_params() {
		$settings = $this->_settings;

		$video_params = [];

		foreach ( [ 'autoplay', 'loop', 'controls' ] as $option_name ) {
			if ( $settings[ $option_name ] ) {
				$video_params[ $option_name ] = '';
			}
		}

		if ( $settings['preload'] ) {
			$video_params['preload'] = $settings['preload'];
		}

		if ( $settings['mute'] ) {
			$video_params['muted'] = 'muted';
		}

		if ( $settings['play_on_mobile'] ) {
			$video_params['playsinline'] = '';
		}

		if ( ! $settings['download_button'] ) {
			$video_params['controlsList'] = 'nodownload';
		}

		return $video_params;
	}
	public function get_hosted_video_url() {
		$settings = $this->_settings;

		if ( ! empty( $settings['insert_url'] ) ) {
			$video_url = $settings['external_url']['url'];
		} else {
			$video_url = $settings['hosted_url']['url'];
		}

		if ( empty( $video_url ) ) {
			return '';
		}

		if ( $settings['start'] || $settings['end'] ) {
			$video_url .= '#t=';
		}

		if ( $settings['start'] ) {
			$video_url .= $settings['start'];
		}

		if ( $settings['end'] ) {
			$video_url .= ',' . $settings['end'];
		}

		return $video_url;
	}
	public function print_a11y_text( $image_overlay, $print = true ) {
		if ( empty( $image_overlay['alt'] ) ) {
			$result = esc_html__( 'Play Video', 'validus' );
		} else {
			$result = esc_html__( 'Play Video about', 'validus' ) . ' ' . esc_attr( $image_overlay['alt'] );
		}

		if ($print) {
			echo esc_html($result);
		} else {
			return $result;
		}
	}
};

$settings = $widget->get_settings_for_display();

//need this :
$settings['aspect_ratio'] = '169';

$video_url = $settings[ $settings['video_type'] . '_url' ];

if ( 'hosted' === $settings['video_type'] ) {
	$video_url = $class->get_hosted_video_url();
} else {
	$embed_params = $class->get_embed_params();
	$embed_options = $class->get_embed_options();
}

if ( empty( $video_url ) ) {
	return;
}

$_w_default = 640;
$_h_default = 500;

//need these to play on click
$thumbnail_size = $widget->get_setting('image_overlay_size', 'full');
$thumbnail_custom_dimension = $widget->get_setting('image_overlay_custom_dimension', ['width' => $_w_default, 'height' => $_h_default]);
if ($thumbnail_size != 'custom') {
	//if thumbnail is not full size
	if (!empty($settings['image_overlay']['id'])) {
		$id = $settings['image_overlay']['id'];
	} else {
		if( has_post_thumbnail()) {
			$id = get_post_thumbnail_id();
		}
	}

	if (isset($id)) {
		$_size_w = get_option( $thumbnail_size.'_size_w' );
		$_size_h = get_option( $thumbnail_size.'_size_h' );

		$image = wp_get_attachment_image_src($id,$thumbnail_size);
		$_width = $image[1];
		$_height = $image[2];

		if ($_width < $_size_w) {
			$width = $_size_w;
		} else {
			$width = $image[1];
		}

		if ($_height < $_size_h) {
			$height = $_size_h;
		} else {
			$height = $image[2];
		}

		if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
			$array = explode('x',$thumbnail_size);
			$width = $array[0];
			$height = $array[1];
		}
	} else {
		$width = $_w_default; // image width
		$height = $_h_default; // image height
	}
	
	//if thumbnail is full size
	if ($thumbnail_size == 'full') {
		if (isset($id)) {
			$src = wp_get_attachment_image_src( $id, 'full' );
			$width = $src[1]; // image width
			$height = $src[2]; // image height

			//check if full image size > 900, set height = 900
			if ($height > 853) {
				$height = 853;
			}
		} else {
			$width = $_w_default; // image width
			$height = $_h_default; // image height
		}
	}

	$image_overlay_size = $thumbnail_size;
	
	$params = array(
		'width' => $width,
		'height' => $height
	);
} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
	$image_overlay_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

	$params = array(
		'width' => $thumbnail_custom_dimension['width'],
		'height' => $thumbnail_custom_dimension['height']
	);
} else {
	$image_overlay_size = $_w_default.'x'.$_h_default;

	$params = array(
		'width' => $_w_default,
		'height' => $_h_default
	);
	
	$settings['image_overlay_custom_dimension'] = $params;
}

if ( 'youtube' === $settings['video_type'] ) {
	$video_html = '<div class="elementor-video"></div>';
}

if ( 'hosted' === $settings['video_type'] ) {
	$widget->add_render_attribute( 'video-wrapper', 'class', 'e-hosted-video' );

	ob_start();

	$class->render_hosted_video();

	$video_html = ob_get_clean();
} else {
	$is_static_render_mode = Plugin::$instance->frontend->is_static_render_mode();
	$post_id = get_queried_object_id();

	if ( $is_static_render_mode ) {
		$video_html = Embed::get_embed_thumbnail_html( $video_url, $post_id );
		// YouTube API requires a different markup which was set above.
	} else if ( 'youtube' !== $settings['video_type'] ) {
		$video_html = Embed::get_embed_html( $video_url, $embed_params, $embed_options );
	}

	$embed_attr = array(
		'class' => 'elementor-video-iframe',
		'allow' => 'accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share',
		'width' => $params['width'],
		'height' => $params['height'],
	);

	$video_html = Embed::get_embed_html( $video_url, $embed_params, $embed_options, $embed_attr );
}

if ( empty( $video_html ) ) {
	echo esc_url( $video_url );
	return;
}


/***************************** STAMP *****************************/
$thumbstamp_size = $widget->get_setting('thumbstamp_size', 'full');
$thumbstamp_custom_dimension = $widget->get_setting('thumbstamp_custom_dimension', ['width' => '400', 'height' => '267']);
if ($thumbstamp_size != 'custom') {
    $img_size = $thumbstamp_size;
} elseif (!empty($thumbstamp_custom_dimension['width']) && !empty($thumbstamp_custom_dimension['height'])) {
    $img_size = $thumbstamp_custom_dimension['width'] . 'x' . $thumbstamp_custom_dimension['height'];
} else {
    $img_size = 'full';
}

$play_rotate = $widget->get_settings( 'play_rotate', 'no' );


if (isset($params['height'])) {
	$max_height = $params['height'].'px;';
} else {
	$max_height = '900px;';
}

$widget->add_render_attribute( 'video-wrapper', 'class', 'elementor-wrapper cms-video-wrap cms-video-layout1' );

$widget->add_render_attribute( 'video-wrapper', 'class', 'elementor-open-' . ( $settings['lightbox'] ? 'lightbox' : 'inline' ) );

$widget->add_render_attribute( 'title', 'class', 'cms-video-title' );
$widget->add_render_attribute( 'description', 'class', 'cms-video-description text-17' );
$widget->add_render_attribute( 'description2', 'class', 'cms-video-description2 text-17 mt-44' );

//stamp
$stamp = '';

$img = etc_get_image_by_size( array(
    'attach_id'  => $settings['stamp_image']['id'],
    'thumb_size' => $img_size,
    'class'      => '',
) );

if(isset($img['p_img_large'])) {
    $stamp = $img['p_img_large'][0];
}
?>
<div <?php $widget->print_render_attribute_string( 'video-wrapper' ); ?>>
	<?php if(!empty($stamp)) { ?>
		<div class="cms-video-image-stamp">
			<img src="<?php echo esc_html($stamp);?>" />
		</div>
	<?php } ?>

	<div class="cms-video-container">
		<?php if(!empty($settings['title'])) { ?>
		<h4 <?php $widget->print_render_attribute_string( 'title' ); ?>>
			<?php echo esc_html($settings['title']);?>
		</h4>
		<?php } ?>

		<?php if(!empty($settings['description'])) { ?>
		<div <?php $widget->print_render_attribute_string( 'description' ); ?>>
			<?php echo wpautop(esc_html($settings['description']));?>
		</div>
		<?php } ?>

		<div class="cms-video-play" style="--max-height: <?php echo esc_html($max_height);?>">
			<?php if ( 'yes' === $settings['show_play_icon'] ) : ?>
				<?php
				if ($settings['lightbox']) {
					if ( 'hosted' === $settings['video_type'] ) {
						$lightbox_url = $video_url;
					} else {
						$lightbox_url = Embed::get_embed_url( $video_url, $embed_params, $embed_options );
					}

					//$lightbox_url = 'https://www.dailymotion.com/video/x6tqhqb';

					$lightbox_options = [
						'type' => 'video',
						'videoType' => $settings['video_type'],
						'url' => $lightbox_url,
						'modalOptions' => [
							'id' => 'elementor-lightbox-' . $widget->get_id(),
							'entranceAnimation' => $settings['lightbox_content_animation'],
							'entranceAnimation_tablet' => $settings['lightbox_content_animation_tablet'],
							'entranceAnimation_mobile' => $settings['lightbox_content_animation_mobile'],
							'videoAspectRatio' => $settings['aspect_ratio'],
						],
					];

					if ( 'hosted' === $settings['video_type'] ) {
						$lightbox_options['videoParams'] = $class->get_hosted_params();
					}

					$widget->add_render_attribute('image-playbutton', [
						'data-elementor-open-lightbox' => 'yes',
						'data-elementor-lightbox' => wp_json_encode( $lightbox_options ),
						'data-e-action-hash' => Plugin::instance()->frontend->create_action_hash( 'lightbox', $lightbox_options ),
					] );
				}
				$widget->add_render_attribute('image-playbutton', [
					'class' => 'elementor-custom-embed-play cursor-pointer',
					'role' => 'button',
					'tabindex' => '0'
				]);
				?>
				<div <?php $widget->print_render_attribute_string( 'image-playbutton' ); ?>>
					<?php
					switch($settings['quick_icon']) {
						case 'play-icon-02':
						case 'play-icon-06':
						case 'play-icon-07':
							?>
							<div class="play-inner bg-<?php echo esc_html($settings['quick_icon']);?> relative cms-transition radius-100 d-flex align-items-center justify-content-center">
								<?php
								echo "<div class='play-icon-bg d-flex align-items-center justify-content-center bg-white radius-100 cms-transition'>";
									$settings['play_icon'] = [
										'library' => 'fa-regular',
										'value' => 'fas fa-play',
									];
									Icons_Manager::render_icon( $settings['play_icon'], [ 'aria-hidden' => 'true' ] );
								echo "</div>";
								?>
								<span class="elementor-screen-only"><?php $class->print_a11y_text( $settings['image_overlay'] ); ?></span>
							</div>
							<?php
							break;
						default:
							echo '<div class="play-inner relative cms-transition d-flex align-items-center justify-content-center">';
								$settings['play_icon'] = [
									'library' => 'eicons',
									'value' => 'eicon-play',
								];
								$cls = (isset($play_rotate) && $play_rotate == 'yes') ? 'play-rotate' : '';
								$path = get_template_directory_uri() . '/assets/images/video/'.$settings['quick_icon'].'.png';
								
								echo "<img class='play-circle $cls' src='$path' />";
								echo '<i class="play-icon '.$settings['quick_icon'].' fas fa-play text-15 absolute"></i>';

								echo '<span class="elementor-screen-only">'.$class->print_a11y_text( $settings['image_overlay'], false ).'</span>';
							echo "</div>";
							break;
					}
					?>
				</div>
			<?php endif; ?>

			<?php
			if ( ! $settings['lightbox'] ) {
				Utils::print_unescaped_internal_string( $video_html ); // XSS ok.
			} else {
				//dailymotion
			}

			if ( $class->has_image_overlay() ) {
				$widget->add_render_attribute( 'image-overlay', 'class', 'elementor-custom-embed-image-overlay' );

				if ( $settings['lightbox'] ) {
					if ( 'hosted' === $settings['video_type'] ) {
						$lightbox_url = $video_url;
					} else {
						$lightbox_url = Embed::get_embed_url( $video_url, $embed_params, $embed_options );
					}

					$lightbox_options = [
						'type' => 'video',
						'videoType' => $settings['video_type'],
						'url' => $lightbox_url,
						'modalOptions' => [
							'id' => 'elementor-lightbox-' . $widget->get_id(),
							'entranceAnimation' => $settings['lightbox_content_animation'],
							'entranceAnimation_tablet' => $settings['lightbox_content_animation_tablet'],
							'entranceAnimation_mobile' => $settings['lightbox_content_animation_mobile'],
							'videoAspectRatio' => $settings['aspect_ratio'],
						],
					];

					if ( 'hosted' === $settings['video_type'] ) {
						$lightbox_options['videoParams'] = $class->get_hosted_params();
					}

					$widget->add_render_attribute( 'image-overlay', [
						'data-elementor-open-lightbox' => 'yes',
						'data-elementor-lightbox' => wp_json_encode( $lightbox_options ),
						'data-e-action-hash' => Plugin::instance()->frontend->create_action_hash( 'lightbox', $lightbox_options ),
					] );

					if ( Plugin::$instance->editor->is_edit_mode() ) {
						$widget->add_render_attribute( 'image-overlay', [
							'class' => 'elementor-clickable',
						] );
					}

					// When there is an image URL but no ID, it means the overlay image is the placeholder. In this case, get the placeholder URL.
					if ( empty( $settings['image_overlay']['id'] ) ) {
						if( has_post_thumbnail()) {
							$settings['image_overlay']['id'] = get_post_thumbnail_id(get_the_ID());
							$settings['image_overlay']['url'] = get_the_post_thumbnail_url(get_the_ID());

							if ($settings['image_overlay_size'] == 'thumbnail') {
								$settings['image_overlay_size'] = 'custom';
							}

							$image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()),$settings['image_overlay_size']);
                    
							if(isset($image) && is_array($image) && !empty($image)) {
								if ($image[2] <= $_h_default && $image[2] <= 300) {
									$settings['image_overlay_size'] = 'custom';
									$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
								}
							}

							$image_url = Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'image_overlay', $settings );

							$attach = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'large' );
							$large = $attach[0];
						} else {
							if (! empty( $settings['image_overlay']['url'] )) {
								$image_url = $settings['image_overlay']['url'];
							} else {
								$image_url = '';
							}

							$large = $image_url;
						}
					} else {
						if ($thumbnail_size != 'custom') {
							if ($settings['image_overlay_size'] == 'thumbnail') {
								$settings['image_overlay_size'] = 'custom';
								$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
							}

							$image = wp_get_attachment_image_src($settings['image_overlay']['id'],$settings['image_overlay_size']);
					
							if(isset($image) && is_array($image) && !empty($image)) {
								if ($image[2] <= $_h_default && $image[2] <= 300) {
									$settings['image_overlay_size'] = 'custom';
									$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
								}
							}
						} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
							$settings['image_overlay_custom_dimension'] = ['width' => $thumbnail_custom_dimension['width'], 'height' => $thumbnail_custom_dimension['height']];
						} else {
							$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
						}

						$image_url = Group_Control_Image_Size::get_attachment_image_src( $settings['image_overlay']['id'], 'image_overlay', $settings );

						$attach = wp_get_attachment_image_src( $settings['image_overlay']['id'], 'large' );
						$large = $attach[0];
					}
					
					//$widget->add_render_attribute( 'image-overlay', 'style', 'background-image: url(' . esc_html($image_url) . ');background-size: cover;' );
				} else {
					// When there is an image URL but no ID, it means the overlay image is the placeholder. In this case, get the placeholder URL.
					if ( empty( $settings['image_overlay']['id'] ) ) {
						if( has_post_thumbnail()) {
							$settings['image_overlay']['id'] = get_post_thumbnail_id(get_the_ID());

							if ($thumbnail_size != 'custom') {
								if ($settings['image_overlay_size'] == 'thumbnail') {
									$settings['image_overlay_size'] = 'custom';
									$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
								}
	
								$image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()),$settings['image_overlay_size']);
						
								if(isset($image) && is_array($image) && !empty($image)) {
									if ($image[2] <= $_h_default && $image[2] <= 300) {
										$settings['image_overlay_size'] = 'custom';
										$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
									}
								}
							} elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
								$settings['image_overlay_custom_dimension'] = ['width' => $thumbnail_custom_dimension['width'], 'height' => $thumbnail_custom_dimension['height']];
							} else {
								$settings['image_overlay_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
							}
							
							$image_url = Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'image_overlay', $settings );

							$attach = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'large' );
							$large = $attach[0];
						} else {
							if (! empty( $settings['image_overlay']['url'] )) {
								$image_url = $settings['image_overlay']['url'];
							} else {
								$image_url = '';
							}

							$large = $image_url;
						}
					} else {
						$image_url = Group_Control_Image_Size::get_attachment_image_src( $settings['image_overlay']['id'], 'image_overlay', $settings );

						$attach = wp_get_attachment_image_src( $settings['image_overlay']['id'], 'large' );
						$large = $attach[0];
					}

					$widget->add_render_attribute( 'image-overlay', 'style', 'background-image: url(' . $image_url . ');' );
				}
				?>
				<div <?php $widget->print_render_attribute_string( 'image-overlay' ); ?>>
					<?php
					if (strpos($image_url, "80x80") !== false) {
						echo "<img src='$large' />";
					} else {
						Group_Control_Image_Size::print_attachment_image_html( $settings, 'image_overlay' );
					}
					?>
				</div>
			<?php }
			?>

		</div>
	</div>

	<?php if(!empty($settings['description2'])) { ?>
	<div <?php $widget->print_render_attribute_string( 'description2' ); ?>>
		<?php echo wpautop(esc_html($settings['description2']));?>
	</div>
	<?php } ?>
</div>



<style type="text/css">/*! elementor - v3.12.0 - 29-03-2023 */
.play-rotate {
	-webkit-animation: cog 5s infinite;			
	-moz-animation: cog 5s infinite;
	-ms-animation: cog 5s infinite; 			
	animation: cog 5s infinite;
	-webkit-animation-timing-function: linear;
	-moz-animation-timing-function: linear;		
	-ms-animation-timing-function: linear;
	animation-timing-function: linear	
}
.elementor-widget-cms_video .elementor-widget-container{transform:translateZ(0)}
.elementor-widget-cms_video .elementor-wrapper iframe,
.elementor-widget-cms_video .elementor-wrapper video{width:100%;display:flex;border:none;background-color:#000}
.elementor-widget-cms_video .elementor-open-inline .elementor-custom-embed-image-overlay{position:absolute;top:0;left:0;width:100%;height:100%;background-size:cover;background-position:50%}
.elementor-widget-cms_video .elementor-custom-embed-image-overlay{cursor:pointer;text-align:center}
.elementor-widget-cms_video .elementor-custom-embed-image-overlay:hover .elementor-custom-embed-play i{opacity:1}
.elementor-widget-cms_video .elementor-custom-embed-image-overlay img{display:block;}
.elementor-widget-cms_video .e-hosted-video .elementor-video{-o-object-fit:cover;object-fit:cover}
.e-con-inner>.elementor-widget-cms_video,
.e-con>.elementor-widget-cms_video{
	width:var(--container-widget-width);
	--flex-grow:var(--container-widget-flex-grow)
}
</style>