<?php
/**
 * Functions and definitions
 *
 * @package Validus
 * 
 */

if ( ! function_exists( 'validus_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function validus_setup() {
		// Make theme available for translation.
		load_theme_textdomain( 'validus', get_template_directory() . '/languages' );
		// Theme Support
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support(
			'html5',
			[
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			]
		);
		add_theme_support(
			'custom-logo',
			[
				'height'      => 100,
				'width'       => 350,
				'flex-height' => true,
				'flex-width'  => true,
			] 
		);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'validus' )
		) );

		/*
		 * WooCommerce.
		 */
		if ( apply_filters( 'validus_add_woocommerce_support', true ) ) {
			// WooCommerce in general.
			add_theme_support( 'woocommerce' );
			// swipe.
			add_theme_support( 'wc-product-gallery-slider' );
		}
	}
endif;
add_action( 'after_setup_theme', 'validus_setup' );

add_action( 'cms_locations', function ( $cms_locations ) {
	return $cms_locations;
} );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 */
function validus_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'validus_content_width', 1280 );
}
add_action( 'after_setup_theme', 'validus_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function validus_scripts() {
	$theme = wp_get_theme( get_template() );
	// Theme style
	wp_enqueue_style( 'validus', get_template_directory_uri() . '/assets/css/theme.css', array(), $theme->get( 'Version' ) );
	wp_add_inline_style('validus', validus_inline_styles() );
	// theme font icon
	wp_enqueue_style( 'font-cmsi', get_template_directory_uri() . '/assets/fonts/font-cmsi/style.css', array(), $theme->get( 'Version' ) );
	// theme font icon
	wp_enqueue_style( 'font-validus', get_template_directory_uri() . '/assets/fonts/font-theme/style.css', array('validus'), $theme->get( 'Version' ) );
	wp_enqueue_style( 'font-awesome' );
	wp_enqueue_style( 'font-awesome-solid', get_template_directory_uri() . '/assets/fonts/font-awesome/css/solid.min.css', [], '5.15.3' );
	// WP Comment
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	/* Theme JS */
	wp_enqueue_script( 'validus-main', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery' ), $theme->get( 'Version' ), true );
	wp_localize_script( 'validus-main', 'main_data', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

	/*
	 * Elementor Widget JS
	 */
	// Counter Widget
	wp_register_script( 'cms-counter-widget-js', get_template_directory_uri() . '/elementor/js/cms-counter-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	// Progress Bar Widget
	wp_register_script( 'cms-progressbar-widget-js', get_template_directory_uri() . '/elementor/js/cms-progressbar-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	// Clients List Widget
	wp_register_script( 'cms-clients-list-widget-js', get_template_directory_uri() . '/elementor/js/cms-clients-list-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	// Pie Charts Widget
	wp_register_script( 'cms-piecharts-widget-js', get_template_directory_uri() . '/elementor/js/cms-piecharts-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	// CMS Post Carousel Widget
	wp_register_script( 'cms-post-carousel-widget-js', get_template_directory_uri() . '/elementor/js/cms-post-carousel-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-clients-widget-js', get_template_directory_uri() . '/elementor/js/cms-clients-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-box-carousel-widget-js', get_template_directory_uri() . '/elementor/js/cms-box-carousel-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-box-testimonials-widget-js', get_template_directory_uri() . '/elementor/js/cms-box-testimonials-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-testimonials-widget-js', get_template_directory_uri() . '/elementor/js/cms-testimonials-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-heading-carousel-widget-js', get_template_directory_uri() . '/elementor/js/cms-heading-carousel-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-slider-widget-js', get_template_directory_uri() . '/elementor/js/cms-slider-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-page-title-widget-js', get_template_directory_uri() . '/elementor/js/cms-page-title-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	
	wp_register_script( 'cms-mytestimonials-widget-js', get_template_directory_uri() . '/elementor/js/cms-mytestimonials-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_style('cms-mytestimonials-slick-css', get_template_directory_uri() . '/elementor/js/slick.css', [], '1.8.0');
	wp_register_script( 'cms-mytestimonials-slick-js', get_template_directory_uri() . '/elementor/js/slick.js', [ 'jquery' ], $theme->get( 'Version' ) );

	wp_register_script( 'cms-galleries', get_template_directory_uri() . '/elementor/js/cms-galleries.js', [ 'jquery' ], $theme->get( 'Version' ) );
	wp_register_script( 'cms-video', get_template_directory_uri() . '/elementor/js/cms-video-widget.js', [ 'jquery' ], $theme->get( 'Version' ) );
	// Google Maps Widget
	$api    = validus_get_opt( 'gm_api_key', 'AIzaSyC08_qdlXXCWiFNVj02d-L2BDK5qr6ZnfM' );
	$api_js = "https://maps.googleapis.com/maps/api/js?sensor=false&key=" . $api;
	wp_register_script( 'maps-googleapis', $api_js, [], date( "Ymd" ) );
	wp_register_script( 'custom-gm-widget-js', get_template_directory_uri() . '/elementor/js/custom-gm-widget.js', [
		'maps-googleapis',
		'jquery'
	], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-post-grid-widget-js', get_template_directory_uri() . '/elementor/js/cms-post-grid-widget.js', [
		'isotope',
		'jquery'
	], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-toggle-widget-js', get_template_directory_uri() . '/elementor/js/cms-toggle-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-accordion-widget-js', get_template_directory_uri() . '/elementor/js/cms-accordion-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-alert-widget-js', get_template_directory_uri() . '/elementor/js/cms-alert-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-tabs-widget-js', get_template_directory_uri() . '/elementor/js/cms-tabs-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-contact-form-widget-js', get_template_directory_uri() . '/elementor/js/cms-contact-form-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_register_script( 'cms-button-widget-js', get_template_directory_uri() . '/elementor/js/cms-button-widget.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_enqueue_script('cms-button-widget-js');

	wp_register_script( 'chart-min', get_template_directory_uri() . '/elementor/js/chart-min.js', [ 'jquery' ], $theme->get( 'Version' ) );
}

add_action( 'wp_enqueue_scripts', 'validus_scripts' );

if (!function_exists('validus_default_fonts')) {
	function validus_default_fonts() {
	?>
		<link rel="preconnect" href="https://fonts.googleapis.com">
		<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>

		<link href="https://fonts.googleapis.com/css2?family=Changa:wght@400;500;600;700&display=swap" rel="stylesheet">
		<!-- <link href="https://fonts.googleapis.com/css2?family=Poppins&display=swap" rel="stylesheet"> -->
		<link href="https://fonts.googleapis.com/css2?family=Poppins:wght@600&display=swap" rel="stylesheet">
		<link href="https://fonts.googleapis.com/css2?family=Rajdhani:wght@600;700&display=swap" rel="stylesheet">
		<link href="https://fonts.googleapis.com/css2?family=Rubik:wght@300;400;500;600;700&display=swap" rel="stylesheet">
		<link href="<?php echo get_template_directory_uri() . '/assets/fonts/font-material/css/material-design-iconic-font.min.css';?>" rel="stylesheet">
		<!-- <link rel="stylesheet" href="/ajax/libs/material-design-iconic-font/2.2.0/css/material-design-iconic-font.min.css"> -->
		<link href="https://fonts.googleapis.com/css2?family=Titillium+Web:wght@600&display=swap" rel="stylesheet">
		<link href="https://db.onlinewebfonts.com/c/4cf5af941f7c70b2c0b7c36c78612735?family=Paralucent+W00+Demi+Bold" rel="stylesheet">
		<!-- <link href="https://fonts.googleapis.com/css2?family=Outfit:wght@600&display=swap" rel="stylesheet"> -->
		<link href="https://fonts.googleapis.com/css2?family=Outfit:wght@400;500;600&display=swap" rel="stylesheet">
	<?php
	}
}
add_action('wp_footer','validus_default_fonts');
/**
 * Widgets
 * Just show widgets if it enable via theme option
 * **/
function validus_widgets(){
    // Register Theme Sidebars, Validus Custom
    if(class_exists('Theme_Core_Options')){
    	$all = apply_filters('validus_register_sidebar_all_post_type', false);
    	if($all){
	        $all_post_type = validus_all_post_types();
	        unset($all_post_type['product']);
	        foreach ($all_post_type as $key => $value) {
	            register_sidebar([
	                'name'          => sprintf( esc_html__( '%s Sidebar', 'validus' ), $value ),
	                'id'            => 'sidebar-'.$key,
	                'description'   => sprintf(esc_html__( 'Add widgets here to show in %1$s archive page and single %2$s page', 'validus' ), strtoupper(str_replace('-', ' ', $key)), $value),
	                'class'         => 'cms-post-type-widget',
	                'title_class'   => ''
	            ]);
	        }
	    } else {
	    	register_sidebar([
                'name'          => esc_html__( 'Blog Sidebar', 'validus' ),
                'id'            => 'sidebar-post',
                'description'   => esc_html__( 'Add widgets here to show in Blog archive page and single post page', 'validus' ),
                'class'         => 'cms-post-type-widget',
                'title_class'   => ''
            ]);

			if (function_exists('etc_register_wp_widget')) {
				require_once get_template_directory() . '/inc/widgets/class-categories.php';
				etc_register_wp_widget( 'WP_Widget_CMS_Categories' );

				require_once get_template_directory() . '/inc/widgets/class-recent-posts.php';
				etc_register_wp_widget( 'WP_Widget_CMS_Recent_Blog' );

				require_once get_template_directory() . '/inc/widgets/class-tag-cloud.php';
				etc_register_wp_widget( 'WP_Widget_CMS_Tag_Cloud' );
			}
	    }

        // WooCommerce Sidebar
        if(class_exists('WooCommerce')){
            register_sidebar([
                'name'          => esc_html__( 'Shop Sidebar', 'validus' ),
                'id'            => 'sidebar-product',
                'description'   => esc_html__( 'Add widgets here to show in WooCommerce archive and single product page', 'validus'),
                'class'         => 'cms-post-type-widget',
                'title_class'   => ''
            ]);
        }
    }
}

add_action( 'widgets_init', 'validus_widgets', 11 );
/**
 * Change default widget title structure
*/
if(!function_exists('validus_widgets_structure')){
    add_filter('widget_display_callback', 'validus_widgets_structure');
    add_filter('register_sidebar_defaults', 'validus_widgets_structure');
    function validus_widgets_structure($args){
        $args = wp_parse_args($args, [
            'class'       => '',  
            'title_class' => ''
        ]);
        $widget_title_tag = 'h4';
        $title_class = [
            'cms-wgtitle',
            isset($args['title_class']) ? $args['title_class'] : ''
        ];
        $args['before_title'] = '<h3 class="'.implode(' ', array_filter($title_class)).'">';
        $args['after_title'] = '</h3>';
        $args['before_widget'] = '<div id="%1$s" class="cms-widget %2$s">';
        $args['after_widget']  = '</div>';
        return $args;
    }
}
if(!function_exists('etc_get_grid_term_options')){
    function etc_get_grid_term_options($post_type, $taxonomy = array())
    {
        if (empty($taxonomy)) {
            $taxonomy = get_object_taxonomies($post_type, 'names');
        }
        $term_list = array();
        foreach ($taxonomy as $tax) {
            $terms = get_terms(
                array(
                    'taxonomy' => $tax,
                    'hide_empty' => true,
                )
            );
            foreach ($terms as $term) {
                $term_list[$term->slug . '|' . $tax] = $term->name;
            }
        }

        return $term_list;
    }
}
/**
 * Term option for post type
 * make option for elementor element option 
*/
if(!function_exists('validus_get_grid_term_by_post_type_options')){
    function validus_get_grid_term_by_post_type_options($args=[]){
        $args = wp_parse_args($args, ['condition' => 'post_type', 'custom_condition' => []]);
        $post_types = get_post_types([
            'public'   => true,
        ], 'objects');
		
		$DefaultExcludedPostTypes = [
			'cms-header-top',
			'cms-footer',
			'attachment',
			'revision',
			'nav_menu_item',
			'vc_grid_item',
			'custom_css',
			'customize_changeset',
			'oembed_cache',
			'cms-mega-menu',
			'elementor_library',
			'e-landing-page'
		];
		$ExtraExcludedPostTypes = apply_filters('etc_get_post_types', []);
		$excludedPostTypes      = $DefaultExcludedPostTypes;
		

        $result = [];
        if (!is_array($post_types))
            return $result;
        foreach ($post_types as $post_type) {
            if (!$post_type instanceof WP_Post_Type)
                continue;
            if (in_array($post_type->name, $excludedPostTypes))
                continue;

			//check cat
			if ($post_type->name == 'post') {
				$cat = ['category'];
			} else if ($post_type->name == 'page') {
				$cat = [];
			} else if ($post_type->name == 'product') {
				$cat = [$post_type->name.'_cat'];
			} else {
				$cat = [$post_type->name.'-category'];
			}

            $result[] = array(
                'name'     => 'source_'.$post_type->name,
                'label'    => sprintf(esc_html__( 'Select Term of %s', 'validus' ), $post_type->labels->singular_name),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => etc_get_grid_term_options($post_type->name,$cat),
                'condition' => array_merge(
                    [
                        $args['condition'] => [$post_type->name]
                    ],
                    $args['custom_condition']
                )
            );
			$result[] = array(
				'name'     => 'groupby_'.$post_type->name,
				'label'    => esc_html__('Group By Tag', 'validus'),
				'type'     => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'default'  => 0,
				'options'  => validus_get_grid_term_tags($post_type->name),
				'condition' => array_merge(
                    [
                        $args['condition'] => [$post_type->name]
                    ],
                    $args['custom_condition']
                )
			);
        }
		
        return $result;
    }
}
/**
 * Remove Some CSS
 * 
*/
if(!function_exists('validus_remove_styles')){
    add_action( 'wp_enqueue_scripts', 'validus_remove_styles', 999 );
    add_action( 'wp_footer', 'validus_remove_styles', 999 );
    add_action( 'wp_header', 'validus_remove_styles', 999 );
    function validus_remove_styles() {
        $default = ['gglcptch' ];
        $styles  = apply_filters( 'etc_remove_styles', $default );
        foreach ( $styles as $style ) {
            wp_dequeue_style( $style );
            wp_deregister_style( $style );
        }
    }
}
if(!function_exists('validus_filter_remove_styles')){
    add_filter('etc_remove_styles', 'validus_filter_remove_styles');
    function validus_filter_remove_styles($styles){
        $_styles = [
            // newsletter
            'newsletter',
            // elementor
            'elementor-frontend-legacy',
            // woo
            'woocommerce-smallscreen',
            'woocommerce-general',
            'woocommerce-layout',
            'wc-blocks-vendors-style',
            'wc-blocks-style',
            // theme core
            'oc-css',
            'etc-main-css',
            'progressbar-lib-css',
            'slick-css',
            'tco-main-css',
            // language switcher
            'trp-floater-language-switcher-style',
            'trp-language-switcher-style',
        ];
        $styles = array_merge($styles, $_styles);
        return $styles;
    }
}

/**
 *  Add admin styles 
 * 
 * */
function validus_admin_style() {
	$theme = wp_get_theme( get_template() );
	wp_enqueue_style( 'validus-admin-style', get_template_directory_uri() . '/assets/admin/admin.css' );
	// Admin Font
	// theme font icon
    wp_enqueue_style( 'validus-font-cmsi', get_template_directory_uri() . '/assets/fonts/font-cmsi/style.css', array(), $theme->get( 'Version' ) );
    wp_enqueue_style( 'validus-font-theme', get_template_directory_uri() . '/assets/fonts/font-theme/style.css', array(), $theme->get( 'Version' ) );
    // Get Start
	wp_enqueue_style( 'validus-get-started-css', get_template_directory_uri() . '/assets/admin/get-started.css' );
	wp_enqueue_script( 'validus-get-started-js', get_template_directory_uri() . '/assets/admin/get-started.js', [ 'jquery' ], $theme->get( 'Version' ), true );
	wp_localize_script( 'validus-get-started-js', 'main_data', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
}
add_action( 'admin_enqueue_scripts', 'validus_admin_style' );

/**
 * Check if is build with Elementor
 * 
 * **/
if(!function_exists('validus_is_built_with_elementor')){
    function validus_is_built_with_elementor() {
		$id = get_queried_object_id();
		if ($id != 0 && !is_tax() && !is_tag() && !is_category() && !is_author()) {
			if ( class_exists('\Elementor\Plugin') && \Elementor\Plugin::$instance->documents->get( $id )->is_built_with_elementor() ) {
				return true;
			} else {
				return false;
			}
		}
		return false;
    }
}

/**
 * Custom template tags for this theme.
 * 
 */
require_once get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require_once get_template_directory() . '/inc/template-functions.php';

/**
 * Theme Functions
 */
require_once get_template_directory() . '/inc/theme-functions.php';

/**
 * Breadcrumb.
 */
require_once get_template_directory() . '/inc/classes/class-breadcrumb.php';

/**
 * Add Template Woocommerce
 */
if ( class_exists( 'Woocommerce' ) ) {
	require_once( get_template_directory() . '/woocommerce/wc-function-hooks.php' );
}

/**
 * Add Template Translate_Press
 */
if(class_exists('TRP_Translate_Press')){
	require_once( get_template_directory() . '/inc/extensions/translatepress.php' );
}

/**
 * Theme Options
 */
require get_template_directory() . '/inc/theme-options/theme-options.php';

/**
 * Post Type Options
 */
// Page Options
require get_template_directory() . '/inc/post-type-options/page-options.php';

/**
 * Post Type Options
 */
// Page Options
require get_template_directory() . '/inc/post-type-options/post-options.php';

/**
 * Post Type Options
 */
// Service Options
require get_template_directory() . '/inc/post-type-options/service-options.php';

/**
 * Post Type Options
 */
// Industry Options
require get_template_directory() . '/inc/post-type-options/industry-options.php';

/**
 * Post Type Options
 */
// Case Study Options
require get_template_directory() . '/inc/post-type-options/case-study-options.php';

/**
 * Post Type Options
 */
// Product Options
require get_template_directory() . '/inc/post-type-options/product-options.php';

require get_template_directory() . '/assets/fonts/font-cmsi.php';
require get_template_directory() . '/assets/fonts/font-theme.php';

/**
 * CSS Generator.
 */
if ( ! class_exists( 'CSS_Generator' ) ) {
	require_once get_template_directory() . '/inc/classes/class-css-generator.php';
}

/*
 * Get Started
 */
require_once get_template_directory() . '/inc/get-started.php';


