<?php
/**
 * Helper functions for the theme
 *
 * @package Validus
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function validus_body_classes($classes){
    $page = is_page() ? get_post() : null;
    $post = is_single() ? get_post() : null;

	if ( $page ) {
		$classes[] = 'page-'.$page->post_name.' ovx-cl';//ovx-hd 
	}

    if ($post) {
        $classes[] = 'post-'.$post->post_name.' ovx-cl';//ovx-hd
    }

    $font = validus_get_opts('body_font');
    if ($font === 'custom') {
        $classes[] = 'body-font-custom';
    }

    return $classes;
}
add_filter('body_class', 'validus_body_classes');


function validus_archive_title_remove_label($title){
    if (is_category()) {
        $title = single_cat_title('', false);
    } elseif (is_tag()) {
        $title = single_tag_title('', false);
    } elseif (is_author()) {
        $title = get_the_author();
    } elseif (is_post_type_archive()) {
        $title = post_type_archive_title('', false);
    } elseif (is_tax()) {
        $title = single_term_title('', false);
    } elseif (is_home()) {
        $title = single_post_title('', false);
    }
    return $title;
}
add_filter('get_the_archive_title', 'validus_archive_title_remove_label');
/**
 * Custom Post Type
 * 
 * **/
add_filter('cms_extra_post_types', 'validus_add_posttype');
if(!function_exists('validus_add_posttype')){
    function validus_add_posttype($postypes){
        $portfolio      = validus_get_opt('portfolio_slug', 'portfolio');
        $portfolio_name = validus_get_opt(
            'portfolio_name',
            esc_attr__('Portfolio', 'validus')
        );
        $postypes['portfolio'] = [
            'status'     => apply_filters('validus_enable_portfolio', false),
            'item_name'  => $portfolio_name,
            'items_name' => $portfolio_name,
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => $portfolio,
                ],
            ],
            'labels' => [],
        ];
        // Service
        $postypes['service'] = [
            'status'     => apply_filters('validus_enable_service', false),
            'item_name'  => esc_html__('Services', 'validus'),
            'items_name' => esc_html__('Services', 'validus'),
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];
        // Header Top
        $postypes['cms-header-top'] = [
            'status'     => apply_filters('validus_enable_header_top', true),
            'item_name'  => esc_html__('Header Top', 'validus'),
            'items_name' => esc_html__('Headers Top', 'validus'),
            'args'       => [
                'menu_icon'          => 'dashicons-editor-insertmore',
                'supports'           => ['title', 'editor', 'thumbnail', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];
        // Footer
        $postypes['cms-footer'] = [
            'status'     => apply_filters('validus_enable_footer', true),
            'item_name'  => esc_html__('Footer', 'validus'),
            'items_name' => esc_html__('Footers', 'validus'),
            'args'       => [
                'menu_icon'          => 'dashicons-editor-insertmore',
                'supports'           => ['title', 'editor', 'thumbnail', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];

        return $postypes;
    }
}
add_filter('cms_extra_taxonomies', 'validus_add_tax');
if(!function_exists('validus_add_tax')){
    function validus_add_tax($taxonomies){
        $taxonomies['portfolio-category'] = [
            'status'      => apply_filters('validus_enable_portfolio', false),
            'post_type'   => ['portfolio'],
            'taxonomy'    => esc_html__('Portfolio Category', 'validus'),
            'taxvalidusmy' => esc_html__('Portfolio Category', 'validus'),
            'taxonomies'  => esc_html__('Portfolio Categories', 'validus'),
            'args'        => [],
            'labels'      => [],
        ];
        $taxonomies['service-category'] = [
            'status'      => apply_filters('validus_enable_service', false),
            'post_type'   => ['service'],
            'taxonomy'    => esc_html__('Service Category', 'validus'),
            'taxvalidusmy' => esc_html__('Service Category', 'validus'),
            'taxonomies'  => esc_html__('Service Categories', 'validus'),
            'args'        => [],
            'labels'      => [],
        ];
        return $taxonomies;
    }
}
add_filter('cms_extra_taxonomies', 'validus_add_tag');
if(!function_exists('validus_add_tag')){
    function validus_add_tag($taxonomies){
        $taxonomies['post-tax'] = [
            'status'      	=> true,
            'post_type'   	=> ['post'],
            'taxonomy'    	=> esc_html__('Taxonomy', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Taxonomy', 'validus'),
            'taxonomies'  	=> esc_html__('Taxonomies', 'validus'),
            'args'        	=> ['hierarchical' => false],
			'hierarchical'	=> false,
            'labels'	  	=> ['Taxonomy'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['page-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['page'],
            'taxonomy'    	=> esc_html__('Page Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Page Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Page Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
			'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['service-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['service'],
            'taxonomy'    	=> esc_html__('Service Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Service Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Service Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
            'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['industry-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['industry'],
            'taxonomy'    	=> esc_html__('Industry Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Industry Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Industry Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
            'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['case-study-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['case-study'],
            'taxonomy'    	=> esc_html__('Case Study Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Case Study Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Case Study Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
            'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['project-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['project'],
            'taxonomy'    	=> esc_html__('Project Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Project Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Project Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
            'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        $taxonomies['portfolio-tag'] = [
            'status'      	=> true,
            'post_type'   	=> ['portfolio'],
            'taxonomy'    	=> esc_html__('Portfolio Tags', 'validus'),
            'taxvalidusmy' 	=> esc_html__('Portfolio Tags', 'validus'),
            'taxonomies'  	=> esc_html__('Portfolio Tags', 'validus'),
            'args'        	=> ['hierarchical' => false],
            'hierarchical'	=> false,
            'labels'	  	=> ['Tags'],
			'show_ui'	  	=> true,
        ];
        return $taxonomies;
    }
}

/**
 * Enable Service
 **/
if (!function_exists('validus_cpt_service')) {
    add_filter('cms_extra_post_types', 'validus_cpt_service');
    function validus_cpt_service($postypes)
    {
        $service             = validus_get_opt('service_slug', 'service');
        $service_name        = validus_get_opt('service_name', esc_attr__('Service', 'validus'));
        $postypes['service'] = array(
            'status'     => true,
            'item_name'  => $service_name,
            'items_name' => $service_name,
            'args'       => array(
                'menu_position' => 4,
                'menu_icon' => 'dashicons-admin-tools',
                'supports' => array(
                    'title',
                    'excerpt',
                    'thumbnail',
                    'editor',
                ),
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => array(
                    'slug' => $service
                ),
                'taxonomy' => 'service-tag'
            ),
            'labels' => array()
        );

        return $postypes;
    }
}
if (!function_exists('validus_cpt_service_taxonomies')) {
    add_filter('cms_extra_taxonomies', 'validus_cpt_service_taxonomies');
    function validus_cpt_service_taxonomies($taxonomies)
    {
        $taxonomies['service-category'] = array(
            'status'     => true,
            'post_type'  => array('service'),
            'taxonomy'   => esc_html__('Service Category', 'validus'),
            'taxmorimy'  => esc_html__('Service Category', 'validus'),
            'taxonomies' => esc_html__('Service Categories', 'validus'),
            'args'       => array(),
            'labels'     => array()
        );
        return $taxonomies;
    }
}

/**
 * Enable Industry
 **/
if (!function_exists('validus_cpt_industry')) {
    add_filter('cms_extra_post_types', 'validus_cpt_industry');
    function validus_cpt_industry($postypes)
    {
        $industry             = validus_get_opt('industry_slug', 'industry');
        $industry_name        = validus_get_opt('industry_name', esc_attr__('Industry', 'validus'));
        $postypes['industry'] = array(
            'status'     => true,
            'item_name'  => $industry_name,
            'items_name' => $industry_name,
            'args'       => array(
                'menu_position' => 5,
                'menu_icon' => 'dashicons-admin-tools',
                'supports' => array(
                    'title',
                    'excerpt',
                    'thumbnail',
                    'editor',
                ),
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => array(
                    'slug' => $industry
                ),
                'taxonomy' => 'industry-tag'
            ),
            'labels' => array()
        );

        return $postypes;
    }
}
if (!function_exists('validus_cpt_industry_taxonomies')) {
    add_filter('cms_extra_taxonomies', 'validus_cpt_industry_taxonomies');
    function validus_cpt_industry_taxonomies($taxonomies)
    {
        $taxonomies['industry-category'] = array(
            'status'     => true,
            'post_type'  => array('industry'),
            'taxonomy'   => esc_html__('Industry Category', 'validus'),
            'taxmorimy'  => esc_html__('Industry Category', 'validus'),
            'taxonomies' => esc_html__('Industry Categories', 'validus'),
            'args'       => array(),
            'labels'     => array()
        );
        return $taxonomies;
    }
}

/**
 * Enable Case Study
 **/
if (!function_exists('validus_cpt_case_study')) {
    add_filter('cms_extra_post_types', 'validus_cpt_case_study');
    function validus_cpt_case_study($postypes)
    {
        $case_study             = validus_get_opt('case_study_slug', 'case-study');
        $case_study_name        = validus_get_opt('case_study_name', esc_attr__('Case Study', 'validus'));
        $postypes['case-study'] = array(
            'status'     => true,
            'item_name'  => $case_study_name,
            'items_name' => $case_study_name,
            'args'       => array(
                'menu_position' => 5,
                'menu_icon' => 'dashicons-admin-tools',
                'supports' => array(
                    'title',
                    'excerpt',
                    'thumbnail',
                    'editor',
                ),
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => array(
                    'slug' => $case_study
                ),
                'taxonomy' => 'case-study-tag'
            ),
            'labels' => array()
        );

        return $postypes;
    }
}
if (!function_exists('validus_cpt_case_study_taxonomies')) {
    add_filter('cms_extra_taxonomies', 'validus_cpt_case_study_taxonomies');
    function validus_cpt_case_study_taxonomies($taxonomies)
    {
        $taxonomies['case-study-category'] = array(
            'status'     => true,
            'post_type'  => array('case-study'),
            'taxonomy'   => esc_html__('Case Study Category', 'validus'),
            'taxmorimy'  => esc_html__('Case Study Category', 'validus'),
            'taxonomies' => esc_html__('Case Study Categories', 'validus'),
            'args'       => array(),
            'labels'     => array()
        );
        return $taxonomies;
    }
}

/**
 * Enable Project
 **/
if (!function_exists('validus_cpt_project')) {
    add_filter('cms_extra_post_types', 'validus_cpt_project');
    function validus_cpt_project($postypes)
    {
        $project             = validus_get_opt('project_slug', 'project');
        $project_name        = validus_get_opt('project_name', esc_attr__('Project', 'validus'));
        $postypes['project'] = array(
            'status'     => true,
            'item_name'  => $project_name,
            'items_name' => $project_name,
            'args'       => array(
                'menu_position' => 5,
                'menu_icon' => 'dashicons-admin-tools',
                'supports' => array(
                    'title',
                    'excerpt',
                    'thumbnail',
                    'editor',
                ),
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => array(
                    'slug' => $project
                ),
                'taxonomy' => 'project-tag'
            ),
            'labels' => array()
        );

        return $postypes;
    }
}
if (!function_exists('validus_cpt_project_taxonomies')) {
    add_filter('cms_extra_taxonomies', 'validus_cpt_project_taxonomies');
    function validus_cpt_project_taxonomies($taxonomies)
    {
        $taxonomies['project-category'] = array(
            'status'     => true,
            'post_type'  => array('project'),
            'taxonomy'   => esc_html__('Project Category', 'validus'),
            'taxmorimy'  => esc_html__('Project Category', 'validus'),
            'taxonomies' => esc_html__('Project Categories', 'validus'),
            'args'       => array(),
            'labels'     => array()
        );
        return $taxonomies;
    }
}

/**
 * Enable Portfolio
 **/
if (!function_exists('validus_cpt_portfolio')) {
    add_filter('cms_extra_post_types', 'validus_cpt_portfolio');
    function validus_cpt_portfolio($postypes)
    {
        $portfolio              = validus_get_opt('portfolio_slug', 'portfolio');
        $portfolio_name         = validus_get_opt('portfolio_name', esc_attr__('Portfolio', 'validus'));
        $postypes['portfolio'] = array(
            'status'     => true,
            'item_name'  => $portfolio_name,
            'items_name' => $portfolio_name,
            'args'       => array(
                'menu_position' => 5,
                'menu_icon' => 'dashicons-admin-tools',
                'supports' => array(
                    'title',
                    'excerpt',
                    'thumbnail',
                    'editor',
                ),
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => array(
                    'slug' => $portfolio
                ),
                'taxonomy' => 'portfolio-tag'
            ),
            'labels' => array()
        );

        return $postypes;
    }
}
if (!function_exists('validus_cpt_portfolio_taxonomies')) {
    add_filter('cms_extra_taxonomies', 'validus_cpt_portfolio_taxonomies');
    function validus_cpt_portfolio_taxonomies($taxonomies)
    {
        $taxonomies['portfolio-category'] = array(
            'status'     => true,
            'post_type'  => array('portfolio'),
            'taxonomy'   => esc_html__('Portfolio Category', 'validus'),
            'taxmorimy'  => esc_html__('Portfolio Category', 'validus'),
            'taxonomies' => esc_html__('Portfolio Categories', 'validus'),
            'args'       => array(),
            'labels'     => array()
        );
        return $taxonomies;
    }
}

/**
 * Enable mega menu
 **/
add_filter('cms_enable_megamenu', 'validus_enable_megamenu');
if(!function_exists('validus_enable_megamenu')){
    function validus_enable_megamenu(){
        return true;
    }
}
/* Enable onepage */
add_filter('cms_enable_onepage', 'validus_enable_onepage');
if(!function_exists('validus_enable_onepage')){
    function validus_enable_onepage(){
        return false;
    }
}
/**
 * Pagination Ajax
 * **/
add_action('wp_ajax_validus_get_pagination_html', 'validus_get_pagination_html');
add_action('wp_ajax_nopriv_validus_get_pagination_html', 'validus_get_pagination_html');
if (!function_exists('validus_get_pagination_html')) {
    function validus_get_pagination_html()
    {
        try {
            if (!isset($_POST['query_vars'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'validus'));
            }
            $query = $_POST['query_vars'];
            if(isset($_POST['filter']) && !empty($_POST['filter'])){
                $query['tax_query'] = [
                    'relation'       => 'OR',
                ];
                $tmp = explode('|', $_POST['filter']);
                if (isset($tmp[0]) && isset($tmp[1])) {
                    $query['tax_query'][] = array(
                        'taxonomy' => $tmp[1],
                        'field' => 'slug',
                        'operator' => 'IN',
                        'terms' => array($tmp[0]),
                    );
                }
            }
            $query = new WP_Query($query);
            ob_start();
            validus_posts_pagination($query, true);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'validus'),
                    'data' => array(
                        'html' => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post' => $query->have_posts()
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
add_action('wp_ajax_validus_load_more_post_grid', 'validus_load_more_post_grid');
add_action('wp_ajax_nopriv_validus_load_more_post_grid', 'validus_load_more_post_grid');
if (!function_exists('validus_load_more_post_grid')) {
    function validus_load_more_post_grid()
    {
        try {
            if (!isset($_POST['settings'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'validus'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(etc_get_posts_of_grid($settings['posttype'], [
                'source' => isset($settings['source']) ? $settings['source'] : '',
                'orderby' => isset($settings['orderby']) ? $settings['orderby'] : 'date',
                'order' => isset($settings['order']) ? $settings['order'] : 'desc',
                'limit' => isset($settings['limit']) ? $settings['limit'] : '6',
                'post_ids' => '',
            ]));
            ob_start();
            validus_get_post_grid($settings, $posts);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'validus'),
                    'data' => array(
                        'html' => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                        'max' => $max,
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

/**
 * ================================================
 * All function for Demo Data
 * 
 * @package CMS Theme
 * @subpackage validus
 * @since 1.0
 * ================================================
 * 
*/
/* Create Demo Data */
if(!function_exists('validus_enable_export_mode')){
    function validus_enable_export_mode() {
        return defined('DEV_MODE') && DEV_MODE == true ? true : false;
    }
}
add_filter('swa_ie_export_mode', 'validus_enable_export_mode');
if (!function_exists('validus_cpt_dev_mode')) {
    function validus_cpt_dev_mode()
    {
        return defined('DEV_MODE') && DEV_MODE == true ? true : false;
    }
}
add_filter('cpt_dev_mode', 'validus_cpt_dev_mode');
/**
 * Update custom post type edit with Elementor
 * **/
if (!function_exists('validus_elementor_cpts')) {
    add_action('theme_core_ie_after_import', 'validus_elementor_cpts');
    function validus_elementor_cpts(){
        $default = (array)get_option('elementor_cpt_support');
        $cpt_support = array_merge(
            $default, 
            [
                //core
                'post',
                'page',
                'cms-footer',
                'cms-header-top',
                'cms-mega-menu',
                'portfolio',
                // theme
                'case-study',
                'industry',
                'service',
                // WooCommerce
                //'product'
            ]
        );
        update_option( 'elementor_cpt_support', $cpt_support );
    }
}
/**
 * Update Option TranslatePress
 * 
 * */
if(!function_exists('validus_translatepress_configs')){
    add_action('plugins_loaded', 'validus_translatepress_configs');
    add_action('activate_translatepress-multilingual/index.php', 'validus_translatepress_configs');
    add_action('theme_core_ie_after_import', 'validus_translatepress_configs');
    function validus_translatepress_configs(){
        $trp_settings = (array)get_option('trp_settings');
        $trp_settings['trp-ls-floater'] = 'no'; // Hide Floating language selection
        $trp_settings['trp-ls-show-poweredby'] = 'no'; // Hide "Powered by TranslatePress"
        update_option( 'trp_settings', $trp_settings );
    }
}

/**
 * cms_get_options_by_groups
 * 
 * */

// validus custom
if(!function_exists('validus_cms_get_options_by_groups')){
    function validus_cms_get_options_by_groups( $styles, $group = false ) {
		$groups = [
			'line' => [
				'label' => esc_html__( 'Line', 'validus' ),
				'options' => [
					'solid' => esc_html__( 'Solid', 'validus' ),
					'double' => esc_html__( 'Double', 'validus' ),
					'dotted' => esc_html__( 'Dotted', 'validus' ),
					'dashed' => esc_html__( 'Dashed', 'validus' ),
				],
			],
		];
		foreach ( $styles as $key => $style ) {
			if ( ! isset( $groups[ $style['group'] ] ) ) {
				$groups[ $style['group'] ] = [
					'label' => ucwords( str_replace( '_', '', $style['group'] ) ),
					'options' => [],
				];
			}
			$groups[ $style['group'] ]['options'][ $key ] = $style['label'];
		}

		if ( $group && isset( $groups[ $group ] ) ) {
			return $groups[ $group ];
		}
    }
}
if(!function_exists('validus_cms_filter_styles_by')){
    function validus_cms_filter_styles_by( $array, $key, $value ) {
        return array_filter( $array, function( $style ) use ( $key, $value ) {
            return $value === $style[ $key ];
        } );
    }
}
function add_menu_link_class( $atts, $item, $args ) {
    if (property_exists($args, 'link_class')) {
        $atts['class'] = $args->link_class;
    }
    return $atts;
}
function add_menu_list_item_class($classes, $item, $args) {
    if (property_exists($args, 'list_item_class')) {
        $classes[] = $args->list_item_class;
    }
    return $classes;
}
add_filter('nav_menu_css_class', 'add_menu_list_item_class', 1, 3);
add_filter( 'nav_menu_link_attributes', 'add_menu_link_class', 1, 3 );

/*
 *  Dashboard Configurations
 */
if (!function_exists('validus_cpt_dashboard_config')) {
    add_filter('cpt_dashboard_config', 'validus_cpt_dashboard_config');
    function validus_cpt_dashboard_config()
    {
        return [
            'documentation_link'  => 'https://7oroof-themes.gitbook.io/validus-wordpress-theme/',
            'ticket_link'         => 'https://farost.net/support',
            'video_tutorial_link' => 'https://www.youtube.com/c/CMSSuperheroes',
            'demo_link'           => 'http://farost.net/tfdemos/validus/',
        ];
    }
}
add_filter('cms_documentation_link', function(){ return 'https://7oroof-themes.gitbook.io/validus-wordpress-theme/';});
add_filter('cms_ticket_link', function(){ return ['type' => 'url', 'link' => 'https://farost.net/support'];});
add_filter('cms_video_tutorial_link', function(){ return 'https://www.youtube.com/c/CMSSuperheroes';});
/**
 * =========================
 * End Demo Data
 * =========================
 * */

/* ------Disable Lazy loading---- */
add_filter('wp_lazy_loading_enabled', '__return_true');