<?php
if (class_exists('Theme_Core_Options')) {
    // Set Location of Theme Options Menu
    add_filter('tco_page_parent', 'validus_tco_parent_page');
    function validus_tco_parent_page()
    {
        $current_theme = wp_get_theme();
        if (is_child_theme()) {
            $current_theme = $current_theme->parent();
        }
        return $current_theme->get('TextDomain');
    }

    // Set Theme Options Name
    add_filter('tco_theme_options_name', 'validus_tco_theme_options_name');
    add_filter('swa_ie_options_name', 'validus_tco_theme_options_name');
    function validus_tco_theme_options_name()
    {
        $opt_name = validus_get_opt_name();
        return $opt_name;
    }

    add_filter('tco_theme_options_args', 'validus_theme_options_args');

    function validus_theme_options_args()
    {
        $default        = false;
        $default_value  = '1';
        $default_layout = '1';
        $default_on     = 'on';
        $default_off    = 'off';
        $default_width  = 'container';
        $custom_opts    = false;

        $general     = include get_template_directory() . '/inc/theme-options/args/general.php';
        $header_top  = include get_template_directory() . '/inc/theme-options/args/header-top.php';
        $header      = include get_template_directory() . '/inc/theme-options/args/header.php';
        $page_title  = include get_template_directory() . '/inc/theme-options/args/page-title.php';
        $content     = include get_template_directory() . '/inc/theme-options/args/content.php';
        $sidebar     = include get_template_directory() . '/inc/theme-options/args/sidebar.php';
        $shop        = include get_template_directory() . '/inc/theme-options/args/shop.php';
        $footer      = include get_template_directory() . '/inc/theme-options/args/footer.php';
        $api         = include get_template_directory() . '/inc/theme-options/args/api.php';
        $page_404    = include get_template_directory() . '/inc/theme-options/args/404-page.php';

        $args = [
            'general'     => $general,
            'header_top'  => $header_top,
            'header'      => $header,
            'page-title'  => $page_title,
            'content'     => $content,
            'sidebar'     => $sidebar,
            'footer'      => $footer,
            '404-page'    => $page_404,
        ];
        if(class_exists('WooCommerce')){
            $args['shop'] =  $shop;
        }
        $args['api'] = $api;

        return $args;
    }
}
/**
 * Get post thumbnail as image options
 * @return array
 *
*/
function validus_list_post_thumbnail($post_type = 'post', $default = false, $args = []){
    $layouts = [];
    if($default){
        $layouts['-1'] = get_template_directory_uri() . '/assets/images/default-opt/default.jpg';
        $layouts['none'] = get_template_directory_uri() . '/assets/images/default-opt/none.jpg';
    }
    $layouts = array_unique($layouts + $args);
    $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
    
    foreach($posts as $post){
        $layouts[$post->ID] = wp_get_attachment_image_url(get_post_thumbnail_id($post->ID), 'full');
    }
    return $layouts;
}
/**
 * Typography
**/
if(!function_exists('validus_typography_opts')){
    function validus_typography_opts($args = []){
        $default = [
            'body_font' => [
                'type'        => Theme_Core_Options::SELECT_FIELD,
                'title'       => esc_html__('Body Font', 'validus'),
                'options'     => [
                    'default' => esc_html__('Default', 'validus'),
                    'custom'  => esc_html__('Custom', 'validus'),
                ],
                'default'     => 'default'
            ],
            'body_font_typo' => [
                'type'     => Theme_Core_Options::TYPOGRAPHY_FIELD,
                'title'    => esc_html__('Body Custom Font', 'validus'),
                'subtitle' => esc_html__('This will be the default font of your website.', 'validus'),
                'required' => [
                    'body_font',
                    '=',
                    'custom'
                ],
                'font_backup'  => false,
                'font_subsets' => false,
                'font_style'   => true,
                'line_height'  => false,
                'font_size'    => false,
                'color'        => false,
                'output'         => ['body.body-font-custom']
            ],
            'heading_font' => [
                'type'    => Theme_Core_Options::SELECT_FIELD,
                'title'   => esc_html__('Heading Default Font', 'validus'),
                'options' => [
                    'default' => esc_html__('Default', 'validus'),
                    'custom'  => esc_html__('Google Font', 'validus'),
                ],
                'default' => 'default'
            ],
            'heading_font_typo' => [
                'type'     => Theme_Core_Options::TYPOGRAPHY_FIELD,
                'title'    => esc_html__('Heading', 'validus'),
                'subtitle' => esc_html__('This will be the default font for all Heading tags of your website.', 'validus'),
                'output'   => [
                    'h1,h2,h3,h4,h5,h6',
                    '.h1,.h2,.h3,.h4,.h5,.h6',
                    '.heading',
                    '.cms-heading'
                ],
                'required' => [
                    'heading_font',
                    '=',
                    'custom',
                ],
                'font_backup'  => false,
                'font_subsets' => false,
                'font_style'   => true,
                'line_height'  => false,
                'font_size'    => false,
                'color'        => false,    
            ]
        ];
        return [
            'title'  => esc_html__('Typographys', 'validus'),
            'fields' => array_merge($default, $args)
        ];
    }
}

/**
 * ON/ OFF option
 * 
 * */
function validus_theme_on_off_opts($args = []){
    $args = wp_parse_args($args, [
        'default'       => false,
        'default_value' => 'off',
        'title'         => esc_html__('On/Off', 'validus'),
        'subtitle'      => '',
        'required'      => ''
    ]);
    $opts = [
        'on' => esc_html__('On', 'validus'),
        'off' => esc_html__('Off', 'validus'),
    ];
    if($args['default']) {
        $opts['-1'] = esc_html__('Default','validus');
        $args['default_value'] = '-1';
    }
    return [
        'type'     => Theme_Core_Options::BUTTON_SET_FIELD,
        'title'    => $args['title'],
        'subtitle' => $args['subtitle'],
        'options'  => $opts,
        'default'  => $args['default_value'],
        'required' => $args['required']
    ];
}
/**
 * Show/ Hide option
 * 
 * */
function validus_theme_show_hide_opts($args = []){
    $args = wp_parse_args($args, [
        'default'       => false,
        'default_value' => 'off',
        'title'         => esc_html__('Show/Hide', 'validus'),
        'subtitle'      => '',
        'required'      => ''    
    ]);
    $opts = [
        'on' => esc_html__('Show', 'validus'),
        'off' => esc_html__('Hide', 'validus'),
    ];
    if($args['default']) {
        $opts['-1'] = esc_html__('Default','validus');
        $args['default_value'] = '-1';
    }
    return [
        'type'     => Theme_Core_Options::BUTTON_SET_FIELD,
        'title'    => $args['title'],
        'subtitle' => $args['subtitle'],
        'options'  => $opts,
        'default'  => $args['default_value'],
        'required' => $args['required']
    ];
}
/**
 * Content Width
 * 
 * */
function validus_theme_content_width_opts($args = []){
    $args = wp_parse_args($args, [
        'default'       => false,
        'default_value' => 'container',
        'title'         => esc_html__('Content Width','validus'),
        'subtitle'      => '',
        'required'      => ''
    ]);
    $opts = [
        'container'       => esc_html__('Container', 'validus'),
        'container-wide'  => esc_html__('Container Wide', 'validus'),
        'container-fluid' => esc_html__('Container Fluid', 'validus'),
        'container-full'  => esc_html__('Container Full', 'validus')
    ];
    if($args['default']) {
        $opts['-1'] = esc_html__('Default','validus');
        $args['default_value'] = '-1';
    }
    return [
        'type'     => Theme_Core_Options::BUTTON_SET_FIELD,
        'title'    => $args['title'],
        'subtitle' => $args['subtitle'],
        'options'  => $opts,
        'default'  => $args['default_value'],
        'required' => $args['required']
    ];
}
function validus_theme_content_width_render($args = []){
    $args = wp_parse_args($args, [
        'name'    => '',
        'default' => 'container'
    ]);
    $settings = validus_get_opts($args['name'], $agrs['default']);
    if(!empty($settings)) return $args['prefix'].$settings;
}
/**
 * Content Alignment
 * **/
function validus_them_content_align_opts($args = []){
    $args = wp_parse_args($args, [
        'default'       => false,
        'default_value' => 'start',
        'title'         => esc_html__('Content Alignment','validus'),
        'subtitle'      => '',
        'required'      => ''
    ]);
    $opts = [
        'start'  => esc_html__('Start', 'validus'),
        'center' => esc_html__('Center', 'validus'),
        'end'    => esc_html__('End', 'validus'),
    ];
    if($args['default']) {
        $opts['-1'] = esc_html__('Default','validus');
        $args['default_value'] = '-1';
    }
    return [
        'type'     => Theme_Core_Options::BUTTON_SET_FIELD,
        'title'    => $args['title'],
        'subtitle' => $args['subtitle'],
        'options'  => $opts,
        'default'  => $args['default_value'],
        'required' => $args['required']
    ];
}
function validus_them_content_align_render($args = []){
    $args = wp_parse_args($args, [
        'name'    => '',
        'prefix'  => 'text-',
        'default' => 'start'
    ]);
    $settings = validus_get_opts($args['name'], $agrs['default']);
    if(!empty($settings)) return $args['prefix'].$settings;
}
/**
 * Button Settings
 * 
 * **/
if(!function_exists('validus_theme_button_settings')){
    function validus_theme_button_settings($args = []){
        $args = wp_parse_args($args, [
            'name'          => 'h_btn',
            'heading'       => esc_html__('Button Settings','validus'), 
            'subtitle'      => '', 
            'default'       => false,
            'default_value' => 'off'
        ]);
        return [
            $args['name'].'_heading' => [
                'type' => Theme_Core_Options::HEADING_FIELD,
                'title' => $args['heading'],
                'subtitle' => $args['subtitle'],
            ],
            $args['name'].'_on' => validus_theme_on_off_opts([
                'default'       => $args['default'],    
                'default_value' => $args['default_value'],
                'title'         => esc_html__('Show/Hide Button', 'validus')
            ]),
            $args['name'].'_text' => [
                'type' => Theme_Core_Options::TEXT_FIELD,
                'title' => esc_html__('Button Text', 'validus'),
                'required' => [
                    $args['name'].'_on',
                    '=',
                    'on'
                ],
                'default' => $args['default'],
            ],
            $args['name'].'_link_type' => [
                'type' => Theme_Core_Options::BUTTON_SET_FIELD,
                'title' => esc_html__('Button Link Type', 'validus'),
                'options' => [
                    'page' => esc_html__('Page', 'validus'),
                    'custom' => esc_html__('Custom', 'validus'),
                ],
                'default' => 'page',
                'required' => [
                    $args['name'].'_on',
                    '=',
                    'on'
                ],
            ],
            $args['name'].'_link' => [
                'type' => Theme_Core_Options::SELECT_FIELD,
                'title' => esc_html__('Page Link', 'validus'),
                'args' => [
                    'post_type' => 'page',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'select2' => true,
                'required' => [
                    $args['name'].'_link_type',
                    '=',
                    'page'
                ],
            ],
            $args['name'].'_link_custom' => [
                'type' => Theme_Core_Options::TEXT_FIELD,
                'title' => esc_html__('Custom Link', 'validus'),
                'required' => [
                    $args['name'].'_link_type',
                    '=',
                    'custom'
                ],
            ],
            $args['name'].'_target' => [
                'type' => Theme_Core_Options::BUTTON_SET_FIELD,
                'title' => esc_html__('Button Target', 'validus'),
                'options' => [
                    '_self' => esc_html__('Self', 'validus'),
                    '_blank' => esc_html__('Blank', 'validus'),
                ],
                'default' => '_self',
                'required' => [
                    $args['name'].'_on',
                    '=',
                    'on'
                ],
            ]
        ];
    }
}
/**
 * Phone Settings
 * **/
if(!function_exists('validus_theme_phone_settings')){
    function validus_theme_phone_settings($args = []){
        $args = wp_parse_args($args, [
            'name'        => '',
            'default'     => false,  
            'default_opt' => 'off'
        ]);
        return [
            'show_phone'.$args['name'] => [
                'type' => Theme_Core_Options::HEADING_FIELD,
                'title' => esc_html__('Phone', 'validus').' '.$args['name'],
            ],
            'h_phone'.$args['name'].'_on' => validus_theme_on_off_opts([
                'default'       => $args['default'],
                'default_value' => 'off',
                'title'         => esc_html__('Show/Hide Phone', 'validus').' '.$args['name']
            ]),
            'h_phone'.$args['name'].'_number' => [
                'type' => Theme_Core_Options::TEXT_FIELD,
                'title' => esc_html__('Phone Number', 'validus'),
                'required' => [
                    'h_phone'.$args['name'].'_on',
                    '=',
                    'on'
                ]
            ]
        ];
    }
}
/**
 * Header layout 
 * 
 * */
if(!function_exists('validus_theme_header_layout_opts')){
    function validus_theme_header_layout_opts($args = []){
        $args = wp_parse_args($args, [
            'default'       => false,
            'default_value' => '1',
            'required'      => ''
        ]);
        $header_layout = [];
        if($args['default']){
            $header_layout['-1'] = get_template_directory_uri() . '/assets/images/default-opt/default.jpg';
            $header_layout['none'] = get_template_directory_uri() . '/assets/images/default-opt/default.jpg';
        }
        // Theme Layout
        $layouts = [
            '1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
            '2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
            '3'  => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
            '4'  => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
            '5' => get_template_directory_uri() . '/assets/images/header-layout/h5.jpg',
            '6' => get_template_directory_uri() . '/assets/images/header-layout/h6.jpg',
            '7' => get_template_directory_uri() . '/assets/images/header-layout/h7.jpg',
            '8' => get_template_directory_uri() . '/assets/images/header-layout/h8.jpg',
            '9' => get_template_directory_uri() . '/assets/images/header-layout/h9.jpg',
            //'10' => get_template_directory_uri() . '/assets/images/header-layout/h10.jpg',
        ];
        return [
            'type'     => Theme_Core_Options::IMAGE_SELECT_FIELD,
            'title'    => esc_html__('Layout', 'validus'),
            'subtitle' => esc_html__('Select a layout for header.', 'validus'),
            'options'  => array_unique ($header_layout + $layouts),
            'default'  => $args['default_value'],
            'required' => $args['required']
        ];
    }
}
/**
 * Header Top Options
**/
if(!function_exists('validus_header_top_opts')){
    function validus_header_top_opts($args=[]){
        $args = wp_parse_args($args, [
            'default'        => false,
            'default_value'  => '1',
            'default_on'     => 'off',
            'custom'         => false   
        ]);
        if($args['default']){
            $args['default_value'] = '-1';
        }
        $custom_fields = [];
        if($args['custom']){
            $custom_fields['header_top_custom'] = validus_theme_on_off_opts([
                'title'         => esc_html__('Custom Header Top','validus'),
                'default'       => false
            ]);
        }
        $default_fields = [
            'header_top_layout' => array(
                'type'        => Theme_Core_Options::IMAGE_SELECT_FIELD,
                'title'       => esc_html__('Layout', 'validus'),
                'subtitle'    => esc_html__('Select a layout for upper footer area.', 'validus'),
                'description' => sprintf(esc_html__('%sClick Here%s to add your custom header top layout.','validus'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=cms-header-top' ) ) . '" target="_blank">','</a>'),
                'placeholder' => esc_html__('Default','validus'),
                'options'     => validus_list_post_thumbnail('cms-header-top', $args['default'], [
                    'none' => get_template_directory_uri() . '/assets/images/default-opt/none.jpg'
                ]),
                'default'     => $args['default_value'],
                'required' => [
                    'header_top_custom', "=", 'on'
                ]
            )
        ];
        // Return
        return [
            'title'      => esc_html__('Header Top', 'validus'),
            'fields'     => $custom_fields + $default_fields
        ];
    }
}
/**
 * Footer Options
**/
if(!function_exists('validus_footer_opts')){
    function validus_footer_opts($args=[]){
        $args = wp_parse_args($args, [
            'default'        => false,
            'default_value'  => '1',
            'default_on'     => 'off',
            'custom'         => false   
        ]);
        if($args['default']){
            $args['default_value'] = '-1';
        }
        $custom_fields = [];
        if($args['custom']){
            $custom_fields['footer_custom'] = validus_theme_on_off_opts([
                'title'         => esc_html__('Custom Footer','validus'),
                'default'       => false
            ]);
        }
        $default_fields = [
            'footer_layout' => array(
                'type'        => Theme_Core_Options::IMAGE_SELECT_FIELD,
                'title'       => esc_html__('Layout', 'validus'),
                'subtitle'    => esc_html__('Select a layout for upper footer area.', 'validus'),
                'description' => sprintf(esc_html__('%sClick Here%s to add your custom footer layout.','validus'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=cms-footer' ) ) . '" target="_blank">','</a>'),
                'placeholder' => esc_html__('Default','validus'),
                'options'     => validus_list_post_thumbnail('cms-footer', $args['default'], [
                    '1' => get_template_directory_uri() . '/assets/images/footer-layout/default.png'
                ]),
                'default'     => $args['default_value'],
                'required' => [
                    'footer_custom', "=", 'on'
                ]
            ),
            'footer_fixed' => validus_theme_on_off_opts([
                'title'         => esc_html__('Footer Fixed', 'validus'),
                'subtitle'      => esc_html__('Make footer fixed at bottom?', 'validus'),
                'default'       => $args['default'],
                'default_value' => $args['default_on'], 
                'required' => [
                    'footer_custom', "=", 'on'
                ]
            ])
        ];
        // Return
        return [
            'title'      => esc_html__('Footer', 'validus'),
            'fields'     => $custom_fields + $default_fields
        ];
    }
}

/**
 * Icon 
*/
if(!function_exists('validus_icon_opts')){
	function validus_icon_opts($args = []){
	    return [
			'title'  => esc_html__('Icon', 'validus'),
			'fields' => [
				'icon' => [
		            'type'        => Theme_Core_Options::ICON_PICKER_FIELD,
		            'title'       => __('Choose your icon', 'validus'),
		            'subtitle'    => __('These icons will show on CMS Post Grid - layouts 2,6,7,15; and on CMS Service Carousel - layout 2', 'validus')
		        ]
			]
		];
	}
}

/**
 * Sidebar
*/
if(!function_exists('validus_sidebar_opts')){
	function validus_sidebar_opts($args = []){
		$args = wp_parse_args($args, [
			'name'          => 'sidebar_page_pos',
			'default'       => false,
			'default_value' => validus_configs('blog')['archive_sidebar_pos'],
			'subsection'    => true,
			'fields_only'	=> false
		]);
		if($args['default']){
			$options = [
				'-1'    => esc_html__('Default','validus'),
				'0'     => esc_html__('No Sidebar','validus'),
				'left'  => esc_html__('Left','validus'),
				'right' => esc_html__('Right','validus'),
				'bottom' => esc_html__('Bottom','validus'),
			];
			$default_value = '-1';
		} else {
			$options = [
				'0'     => esc_html__('No Sidebar','validus'),
				'left'  => esc_html__('Left','validus'),
				'right' => esc_html__('Right','validus'),
				'bottom' => esc_html__('Bottom','validus'),
			];
			$default_value = $args['default_value'];
		}
		// Return
		if($args['fields_only']){
			return array(
                'title'    => esc_html__('Sidebar Position', 'validus'),
                'subtitle' => esc_html__('Choose position for sidebar', 'validus'),
                'id'       => $args['name'],
                'type'     => 'button_set',
                'options'  => $options,
                'default'  => $default_value,
            );
		} else {
			return array(
			    'title'      => esc_html__('Sidebar Position', 'validus'),
			    'icon'       => 'el-icon-website',
			    'subsection' => $args['subsection'],
			    'fields'     => array(
			        array(
	                    'title'    => esc_html__('Sidebar Position', 'validus'),
	                    'subtitle' => esc_html__('Choose position for sidebar', 'validus'),
	                    'id'       => $args['name'],
	                    'type'     => 'button_set',
	                    'options'  => $options,
	                    'default'  => $default_value,
	                )
	            )
			);
		}
	}
}