<?php
/**
 * Categories widget class
 *
 * @since 2.8.0
 */
class WP_Widget_CMS_Categories extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'box_widget widget_categories cms-shadow-3', 'description' => __( "The list categories on your site", 'validus') );
        parent::__construct('cms-widget-categories', __('CMS Categories', 'validus'), $widget_ops);
    }

    function widget($args, $instance) {
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Categories', 'validus' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 0;
        $dropdown  = ( ! empty( $instance['dropdown'] ) ) ? $instance['dropdown'] : [];
        $show_post_counts = isset( $instance['show_post_counts'] ) ? $instance['show_post_counts'] : false;
        
        echo wp_kses_post($before_widget); 

        if ( $title ) {
            echo wp_kses_post($before_title . $title . $after_title);;
        }

        $categories = get_categories(array(
            'orderby'    => 'name',
            'order'      => 'ASC',
            'hide_empty' => false,
            'number'     => $number,
            'exclude'    => $dropdown,
            'count'      => true
        ));
        ?>

        <ul>
            <?php foreach( $categories as $category ) { ?>
            <?php
            $class = '';
            $array = get_the_category();
            if (isset($array) && count($array)) {
                if (is_category()) {
                    $tern = get_queried_object();

                    if ($tern->term_id == $category->term_id) {
                        $class = 'current';
                    }
                } else {
                    if(!is_home() && !is_front_page() && !is_author() && !is_tag() && !is_search()) {
                        foreach ($array as $key => $cat) {
                            if ($cat->term_id == $category->term_id) {
                                $class = 'current';
                            }
                        }
                    }
                }
            }
            ?>
            <li class="cat-item cat-item-<?php echo esc_html($category->term_id);?> <?php echo esc_html($class);?>">
                <a href="<?php echo get_category_link($category->term_id);?>" class="btn btn-secondary btn-hover-primary d-flex align-items-center justify-content-between radius-2">
                    <span class="category-text"><?php echo esc_html($category->name);?></span>
                    <?php if ( $show_post_counts ) : ?>
                    <span class="post-count radius-50"><?php echo esc_html($category->count);?></span>
                    <?php endif; ?>
                </a>
            </li>
            <?php } ?>
        </ul>

        <?php 
        echo wp_kses_post($after_widget);

        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['dropdown'] = ! empty( $new_instance['dropdown'] ) ? $new_instance['dropdown'] : false;
        $instance['show_post_counts'] = (bool) $new_instance['show_post_counts'];

        return $instance;
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $dropdown  = isset( $instance['dropdown'] ) ? $instance['dropdown'] : false;
        //echo '<pre>';print_r($dropdown);echo '</pre>';
        $show_post_counts = isset( $instance['show_post_counts'] ) ? (bool) $instance['show_post_counts'] : false;
?>
        <p><label for="<?php echo esc_html($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:', 'validus' ); ?></label>
        <input class="widefat" id="<?php echo esc_html($this->get_field_id( 'title' )); ?>" name="<?php echo esc_html($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>

        <?php
        $list = array();
        $list['-1'] = esc_html__('All Categories', 'validus');
        $terms = get_terms(
            'category',
            array(
                //'fields'       => 'ids',
                'hierarchical' => true,
                'hide_empty'   => false,
            )
        );
        
        foreach ($terms as $term) {
            $list[$term->term_id] = $term->name;
        }

        if ( $list ) {
            printf(
                '<p><label for="%1$s">%2$s</label>' .
                '<select multiple class="widefat" id="%1$s" name="%3$s[]" size="10">',
                $this->get_field_id( 'dropdown' ),
                __( 'Exclude Category:', 'validus' ),
                $this->get_field_name( 'dropdown' )
            );

            foreach ( $list as $key => $item ) {
                $selected = '';
                if (!empty($dropdown)) {
                    foreach ($dropdown as $cat) {
                        if ($key == $cat) {
                            $selected = 'selected="selected"';
                        }
                    }
                }
                printf(
                    '<option value="%s"%s>%s</option>',
                    esc_attr( $key ),
                    $selected,
                    $item
                );
            }
            echo '</select></p>';
        }
        ?>

        <p><label for="<?php echo esc_html($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of categories to show:', 'validus' ); ?></label>
        <input id="<?php echo esc_html($this->get_field_id( 'number' )); ?>" name="<?php echo esc_html($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_html($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_post_counts ); ?> id="<?php echo esc_html($this->get_field_id( 'show_post_counts' )); ?>" name="<?php echo esc_html($this->get_field_name( 'show_post_counts' )); ?>" />
        <label for="<?php echo esc_html($this->get_field_id( 'show_post_counts' )); ?>"><?php _e( 'Display categories counts?', 'validus' ); ?></label></p>
<?php
    }
}
?>