<?php
/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class WP_Widget_CMS_Recent_Blog extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'box_widget widget_recent_posts cms-shadow-3', 'description' => __( "The most recent posts on your site", 'validus') );
        parent::__construct('cms-widget-recent-blog', __('CMS Recent Posts', 'validus'), $widget_ops);
    }

    function widget($args, $instance) {
        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'validus' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
        if ( ! $number )
        $number = 5;

        $num_chars = ( ! empty( $instance['num_chars'] ) ) ? absint( $instance['num_chars'] ) : 50;
        if ( ! $num_chars )
        $num_chars = 50;

        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        $r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo wp_kses_post($before_widget); ?>
        <?php if ( $title ) echo wp_kses_post($before_title . $title . $after_title); ?>
        <div class="post-items">
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
            <div class="post-item">
                <div class="post-image">
                    <?php echo the_post_thumbnail('thumbnail');?>
                </div>
                <div class="post-desc">
                    <?php if ( $show_date ) : ?>
                        <span class="post-date"><?php echo get_the_date(); ?></span>
                    <?php endif; ?>
                    <h5 class="post-title text-line-3">
                        <a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>">
                            <?php //if ( get_the_title() ) echo substr(get_the_title(),0,$num_chars).'...'; else the_ID(); ?>
                            <?php if ( get_the_title() ) echo get_the_title(); else the_ID(); ?>
                        </a>
                    </h5>
                </div>
            </div>
        <?php endwhile; ?>
        </div>
        <?php echo wp_kses_post($after_widget); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['num_chars'] = (int) $new_instance['num_chars'];
        $instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;

        return $instance;
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $num_chars = isset( $instance['num_chars'] ) ? absint( $instance['num_chars'] ) : 50;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo esc_html($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:', 'validus' ); ?></label>
        <input class="widefat" id="<?php echo esc_html($this->get_field_id( 'title' )); ?>" name="<?php echo esc_html($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>

        <p><label for="<?php echo esc_html($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of posts to show:', 'validus' ); ?></label>
        <input id="<?php echo esc_html($this->get_field_id( 'number' )); ?>" name="<?php echo esc_html($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_html($number); ?>" size="3" /></p>

        <p><label for="<?php echo esc_html($this->get_field_id( 'num_chars' )); ?>"><?php _e( 'Number of characters to show:', 'validus' ); ?></label>
        <input id="<?php echo esc_html($this->get_field_id( 'num_chars' )); ?>" name="<?php echo esc_html($this->get_field_name( 'num_chars' )); ?>" type="text" value="<?php echo esc_html($num_chars); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo esc_html($this->get_field_id( 'show_date' )); ?>" name="<?php echo esc_html($this->get_field_name( 'show_date' )); ?>" />
        <label for="<?php echo esc_html($this->get_field_id( 'show_date' )); ?>"><?php _e( 'Display post date?', 'validus' ); ?></label></p>
<?php
    }
}
?>