<?php
class WP_Widget_CMS_Tag_Cloud extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'box_widget widget_tag_cloud cms-shadow-3', 'description' => __( "Display tags cloud", 'validus') );
        parent::__construct( 'cms-tag-cloud', 'CMS Tag Cloud', $widget_ops );
    }

    /**
     * Allows for manipulation, calculation, etc. when saving the widget instance in the dashboard.
     *
     * @param array $new_instance
     * @param array $old_instance
     *
     * @return array
     */
    function update( $new_instance, $old_instance ) {
        $instance['title'] = ! empty( $new_instance['title'] ) ? $new_instance['title'] : __( 'Recent Posts', 'validus' );
        $instance['taxonomy']  = ( ! empty( $new_instance['taxonomy'] ) ) ? $new_instance['taxonomy'] : '';
        $instance['dropdown'] = ! empty( $new_instance['dropdown'] ) ? $new_instance['dropdown'] : false;
        
        return $instance;
    }

    /**
     * Echos the widget contents in a sidebar
     *
     * @param array $args - the general widget arguments
     * @param array $instance - the settings for this specific widget
     */
    function widget( $args, $instance ) {
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'validus' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $taxonomy     = isset( $instance['taxonomy'] ) ? esc_attr( $instance['taxonomy'] ) : '';
        $dropdown  = ( ! empty( $instance['dropdown'] ) ) ? $instance['dropdown'] : [];

        $tags_list = get_tags(array(
            'hide_empty' => true,
            'taxonomy' => ($taxonomy == 'product_tag')?'product_tag':'post_tag',
            'exclude' => $dropdown,
            'orderby' => 'id',
            'order' => 'asc'
        ));
        if (!$tags_list) return;

        $html = '';
        $post_tags = get_the_tags();
        
        foreach ( $tags_list as $tag ) {
            $class = 'radius-2 ';

            if (is_tag()) {
                $current = get_queried_object();
                if ($current->term_id == $tag->term_id) {
                    $class .= "tagged";
                } else {
                    $class .= '';
                }
            }

            $tag_link = get_tag_link( $tag->term_id );
            $html .= "<a href='{$tag_link}' title='{$tag->name} Tag' class='{$class}'>{$tag->name}</a>";
        }

        echo wp_kses_post($before_widget); 

        if ( $title ) {
            echo wp_kses_post($before_title . $title . $after_title);
        }
        ?>

        <div class="tags-list">
            <?php printf('%2$s', '', $html); ?>
        </div>
        
        <?php
        echo wp_kses_post($after_widget);

        wp_reset_postdata();
    }

    /**
     * Render the "Controls" in the dashboard menu under Appearance => Widgets
     *
     * @param array $instance - the settings for this instance of the widget
     *
     * @return null
     */
    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $taxonomy     = isset( $instance['taxonomy'] ) ? esc_attr( $instance['taxonomy'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $dropdown  = isset( $instance['dropdown'] ) ? $instance['dropdown'] : false;
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'taxonomy' => ($taxonomy == 'product_tag')?'product_tag':'post_tag' ) );

        // Load the list of taxonomies available
        $taxonomies = get_taxonomies( array( 'public' => TRUE , 'show_tagcloud' => TRUE), 'objects' );

        echo '<p><label>Title</label><input type="text" class="widefat" name="' . $this->get_field_name( 'title' ) . '" id="' . $this->get_field_id( 'title' ) . '" value="' . esc_attr( $instance['title'] ) . '" /></p>';
        echo '<p><label>Taxonomy</label><select class="widefat" name="' . $this->get_field_name('taxonomy') . ' id="' . $this->get_field_id('taxonomy') . '">';
        echo '<option value="">Select Taxonomy...</option>';
        foreach($taxonomies AS $tax) {
            echo '<option value="' . $tax->name . '"';
            echo (esc_html($tax->name) == $instance['taxonomy']) ? ' selected' : '';
            echo '>';
            echo esc_html($tax->label);
            echo '</option>';
        }
        echo '</select></p>';

        $list = array();
        $list['-1'] = esc_html__('All Tags', 'validus');
        $terms = get_terms(
            $instance['taxonomy'],
            array(
                //'fields'       => 'ids',
                'hierarchical' => false,
                'hide_empty'   => true,
            )
        );
        
        foreach ($terms as $term) {
            $list[$term->term_id] = $term->name;
        }

        if ( $list ) {
            printf(
                '<p><label for="%1$s">%2$s</label>' .
                '<select multiple class="widefat" id="%1$s" name="%3$s[]" size="10">',
                $this->get_field_id( 'dropdown' ),
                __( 'Exclude Tag:', 'validus' ),
                $this->get_field_name( 'dropdown' )
            );

            foreach ( $list as $key => $item ) {
                $selected = '';
                if (!empty($dropdown)) {
                    foreach ($dropdown as $cat) {
                        if ($key == $cat) {
                            $selected = 'selected="selected"';
                        }
                    }
                }
                printf(
                    '<option value="%s"%s>%s</option>',
                    esc_attr( $key ),
                    $selected,
                    $item
                );
            }
            echo '</select></p>';
        }
    }
}
?>