<?php
/**
 * Custom template tags for this theme.
 *
 * @package Validus
 */

/**
 * Page loading.
 **/
function validus_page_loading(){
    $page_loading = validus_get_opt('show_page_loading', false);
    if ($page_loading) { ?>
        <section id="cms-loadding" class="cms-loader cms-transition">
            <div class="loading-spinner">
                <div class="cms-bounce1 radius-100"></div>
                <div class="cms-bounce2 radius-100"></div>
                <div class="cms-bounce3 radius-100"></div>
            </div>
        </section>
    <?php }
}

/**
 * Header Top
 * 
 * **/
if(!function_exists('validus_header_top')){
    function validus_header_top($args = []){
        if(is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu') ) return;
        $args = wp_parse_args($args, []);
        $header_top_layout = validus_get_opts('header_top_layout', '', 'header_top_custom');
        $cms_post = get_post($header_top_layout);
        if(in_array($header_top_layout, ['-1', '0', 'none', ''])) return;
        if (!is_wp_error($cms_post) && $cms_post->ID == $header_top_layout && class_exists('Elementor_Theme_Core') && class_exists('\Elementor\Plugin')){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $header_top_layout );
            if(empty($content)){
                $content = $cms_post->post_content;
            }
        } else {
            $content = $cms_post->post_content;
        }
    ?>
    <div id="cms-header-top" class="cms-header-top empty-none"><?php printf('%s', $content); ?></div>
    <?php
    }
}

/**
 * Header layout.
 **/
function validus_header_layout(){
    $header_layout = validus_get_opts('header_layout', '1', 'header_custom');
    if ($header_layout == '0' || is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu')) return;
    get_template_part('template-parts/header/header-layout', $header_layout);
}
/**
 * Header
 * Header Class
 * **/
if(!function_exists('validus_header_classes')){
    function validus_header_classes($class = ''){
        $classes = [
            'cms-header',
            'header-layout-'.validus_get_opts('header_layout','1', 'header_custom'),
            'sticky-'.validus_get_opts( 'header_sticky', 'off', 'header_custom'),
            'transparent-'.validus_get_opts( 'header_transparent', 'off', 'header_custom'),
            $class
        ];
        if(validus_get_opts( 'header_transparent', 'off', 'header_custom') === 'on'){
            $classes[] = 'header-transparent';
        }
        return implode(' ', array_filter($classes));
    }
}
/**
 * Header Container class 
 * 
 * **/
if(!function_exists('validus_header_container_classes')){
    function validus_header_container_classes($class = ''){
        $classes = [
            'cms-header-main',
            validus_get_opts( 'header_width', 'container', 'header_custom'),
            $class
        ];
        return implode(' ', array_filter($classes));
    }
}
/**
 * Header Search 
 * 
 * */
if(!function_exists('validus_header_search')){
    function validus_header_search(){
        $search_on = validus_get_opts('search_icon', 'off', 'header_custom');
        if($search_on != 'on') return;
        add_action('wp_footer', 'validus_search_popup');
?>
    <div class="site-header-item site-header-search menu-color cms-modal" data-modal="#cms-modal-search" data-focus=".cms-search-input"><i class="cmsi-search search-toggle"></i></div>
<?php
    }
}
/**
 * Header Search Place
 * 
 * */
if(!function_exists('validus_header_search_place')){
    function validus_header_search_place($text = 'Search'){
        $search_on = validus_get_opts('search_icon', 'off', 'header_custom');
        if($search_on != 'on') return;
        ?>
            <form role="search" method="get" class="search-form-popup" action="<?php echo esc_url( home_url( '/' ) ); ?>">
                <div class="site-header-item site-header-search menu-color" data-modal="#cms-modal-search" data-focus=".cms-search-input">
                    <i class="cmsi-search search-toggle"></i>
                    <span>Search</span>
                    <input type="text" name="s" size="25" placeholder="<?php echo esc_html($text);?>" />
                    <i class="cmsi-remove"></i>
                </div>
            </form>
        <?php
    }
}
/**
 * Header Search Popup
 */
function validus_search_popup(){ 
    $placeholder = validus_get_opt('search_field_placeholder', esc_html__('Type Words Then Enter', 'validus'));
    ?>
    <div id="cms-modal-search" class="cms-modal-html cms-modal-fade cms-modal-search cms-transition">
        <i class="cms-modal-close cms-close cmsi-remove"></i>
        <div class="cms-modal-content">
            <form role="search" method="get" class="search-popup relative" action="<?php echo esc_url(home_url('/')); ?>">
                <input type="text" placeholder="<?php echo esc_attr($placeholder); ?>" name="s" class="cms-search-input radius-0"/>
                <button type="submit" class="cms-search-submit"><i class="cmsi-search"></i></button>
            </form>
        </div>
    </div>
<?php }
/**
 * Header Cart
 * 
 * */
if(!function_exists('validus_header_cart')){
    function validus_header_cart($args=[]){
        $args = wp_parse_args($args, [
            'class' => '',
            'text' => '',
            'type' => 'sidebar'
        ]);
        
        $cart_on = validus_get_opts('cart_icon', 'off', 'header_custom');
        if(!class_exists('Woocommerce') || $cart_on != 'on') return;
        add_action('wp_footer', 'validus_cart_content');

        $count = WC()->cart->cart_contents_count;
    ?>
        <div class="site-header-item site-header-cart <?php echo esc_attr($args['class']);?>">
            <div class="site-header-cart-click">
                <i class="cmsi-shopping-cart cart-icon"></i>
                <?php printf('%s', $args['text']); ?>
                <span class="cart-counter cart_total radius-100"><?php echo sprintf( _n( '%d', '%d', $count, 'validus' ), $count ); ?></span>
            </div>
            <?php 
                if($args['type'] === 'dropdown'){
                    validus_cart_dropdown();
                }
            ?>
        </div>
    <?php
    }
}
/**
 * Header Cart
 * Update cart count
 * 
 * */
if(!function_exists('validus_woocommerce_add_to_cart_fragments')){
    add_filter('woocommerce_add_to_cart_fragments', 'validus_woocommerce_add_to_cart_fragments', 10, 1 );
    function validus_woocommerce_add_to_cart_fragments( $fragments ) {
        if(!class_exists('WooCommerce')) return;
        ob_start();
        ?><span class="cart-counter cart_total radius-100">
            <?php echo sprintf( _n( '%d', '%d', WC()->cart->cart_contents_count, 'validus' ), WC()->cart->cart_contents_count ); ?>
        </span>
        <?php
        $fragments['.cart_total'] = ob_get_clean();
        return $fragments;
    }
}

/**
 * 
 * Cart Content
 * 
 */
function validus_cart_content(){
    if (!class_exists('Woocommerce')) return;
?>
    <div id="cms-modal-cart" class="cms-modal-html cms-modal-slide cms-modal-cart cms-shadow-1 cms-transition">
        <span class="cms-modal-close cms-close cmsi-remove"></span>
        <div class="cms-modal-content">
            <div class="widget_shopping_cart cms-mousewheel">
                <div class="widget_shopping_cart_content">
                    <?php woocommerce_mini_cart(); ?>
                </div>
            </div>
        </div>
    </div>
<?php
}

/**
 * Cart Sidebar
 */
function validus_cart_dropdown() {
	$cart_on = validus_get_opt( 'cart_icon', false );
	?>
	<?php if ( class_exists( 'Woocommerce' ) && $cart_on ) : ?>
        <div class="cms-widget-cart-wrap cms-widget-cart-dropdown">
            <!-- <div class="cms-close"><i class="cmdi cmsi-remove"></i></div> -->
            <div class="widget_shopping_cart">
                <div class="widget_shopping_cart_content">
                    <?php woocommerce_mini_cart(); ?>
                </div>
            </div>
        </div>
	<?php endif; ?>
<?php }

function validus_cart_sidebar() {
	$cart_on = validus_get_opt( 'cart_icon', false );
	?>
	<?php if ( class_exists( 'Woocommerce' ) && $cart_on ) : ?>
        <div class="cms-widget-cart-wrap">
            <div class="cms-widget-cart-sidebar">
                <div class="cms-close"><i class="cmdi cmsi-remove"></i></div>
                <div class="widget_shopping_cart">
                    <div class="widget_shopping_cart_content">
						<?php woocommerce_mini_cart(); ?>
                    </div>
                </div>
            </div>
        </div>
	<?php endif; ?>
<?php }

// add_action( 'wp_footer', 'validus_product_count_check' );
function validus_product_count_check() {
	if ( class_exists( 'Woocommerce' ) && is_checkout() ) {
		return;
	}
	?>
    <script type="text/javascript">
        jQuery(function ($) {
            if (typeof wc_add_to_cart_params === 'undefined')
                return false;

            $(document.body).on('added_to_cart', function (event, fragments, cart_hash, $button) {
                var $pid = $button.data('product_id');

                $.ajax({
                    type: 'POST',
                    url: wc_add_to_cart_params.ajax_url,
                    data: {
                        'action': 'item_added',
                        'id': $pid
                    },
                    success: function (response) {
                        //$('.added_to_cart').text('View Cart');

                        $('.cms-widget-cart-wrap').addClass('open');

                        var $header = $('#cms-header');
                        if ($header.hasClass('header-sticky-hidden') && $header.hasClass('sticky-on')) {
                            var w_height = $(window).height();
                            var total = 'calc(' + w_height + 'px - 30px - 60px)';//30px is toolbar wordpress
                            $('.cms-widget-cart-dropdown .widget_shopping_cart_content').css('max-height', total);
                        } else {
                            var w_height = $(window).height();
                            total = 'calc(' + w_height + 'px - var(--header-height) - 60px)';
                            $('.cms-widget-cart-dropdown .widget_shopping_cart_content').css('max-height', total);
                        }
                    }
                });
            });
        });
    </script>
	<?php
}
/**
 * Header Phone
 * */
if(!function_exists('validus_header_phone_render')){
    function validus_header_phone_render($args = []){
        $args = wp_parse_args($args, [
            'name' => '',
            'class' => 'cms-phone-number',
            'icon'  => 'cmsi-phone-alt'
        ]);
        $phone_lable = validus_get_opt('h_phone'.$args['name'].'_lable', '');
        $phone_number = validus_get_opt('h_phone'.$args['name'].'_number', '');
        if(validus_get_opts('h_phone'.$args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($phone_number) ) return;

        $tel = str_ireplace(' ', '', $phone_number); // remove space for link
    ?>
        <div class="site-header-phone d-flex gap-10 align-items-center">
            <?php if(!empty($args['icon'])) echo '<i class="phone-icon '.esc_attr($args['icon']).'"></i>'; ?>
            <div class="cms-call-phone">
                <span class="cms-phone-lable"><?php echo esc_html($phone_lable); ?></span>
                <a class="<?php echo esc_attr($args['class']) ?>" href="tel:<?php echo esc_attr($tel);?>"><?php echo esc_html($phone_number); ?></a>
            </div>
        </div>
    <?php
    }
}
/**
 * Header Button
 * */
if(!function_exists('validus_header_button_render')){
    function validus_header_button_render($args = []){
        $args = wp_parse_args($args, [
            'name'  => 'h_btn',
            'class' => 'btn btn-sm',
            'style' => '',
            'split' => false,
            'icon'  => ''
        ]);
        $h_btn_text        = validus_get_opt( $args['name'].'_text' );
        if(validus_get_opts($args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($h_btn_text)) return;

        $h_btn_link_type   = validus_get_opt( $args['name'].'_link_type', 'page' );
        $h_btn_link        = validus_get_opt( $args['name'].'_link' );
        $h_btn_link_custom = validus_get_opt( $args['name'].'_link_custom' );
        $h_btn_target      = validus_get_opt( $args['name'].'_target', '_self' );
        if ( $h_btn_link_type == 'page' ) {
            $h_btn_url = get_permalink( $h_btn_link );
        } else {
            $h_btn_url = $h_btn_link_custom;
        }
    ?>
    <?php if ($args['split']) { ?>
    <div class="header-separator col-auto cms-hidden-lg"><span></span></div>
    <?php } ?>
    <div class="site-header-button d-flex">
        <a class="<?php echo esc_attr($args['class']); ?>" href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr( $h_btn_target ); ?>">
            <span><?php echo esc_html( $h_btn_text ); ?></span> 
            <?php if($args['icon']) { ?>
                <i class="<?php printf('%s',$args['icon']);?>"></i>
            <?php } ?>
        </a>
    </div>
    <?php
    }
}

/**
 * Page title layout
 **/
function validus_page_title_layout($args = []){
    $default = ( class_exists('WooCommerce') && (is_shop() || is_product()) ) ? 'off' : 'on';

    $background = validus_get_opts('show_background', 'on', 'custom_ptitle');
    $title = validus_get_opts('show_title', 'on', 'custom_ptitle');
    $breadcrumb = validus_get_opts('show_breadcrumb', 'on', 'custom_ptitle');
    $align = validus_get_opts('ptitle_align', 'start', 'custom_ptitle');

    if (validus_get_page_opt('custom_ptitle') == 'on') {
        $theme_opt = validus_get_opt('pagetitle', '-1');
        $pagetitle = validus_get_page_opt('pagetitle',$theme_opt);

        if ($pagetitle == '-1') {
            $background = validus_get_opt('show_background');
            $title = validus_get_opt('show_title');
            $breadcrumb = validus_get_opt('show_breadcrumb');
            $align = validus_get_opt('ptitle_align');
        }
    }

    $args = wp_parse_args($args, [
        'show'            => validus_get_opts('pagetitle', $default, 'custom_ptitle'),//custom_ptitle
        'layout'          => validus_get_opts('ptitle_layout', '', 'custom_ptitle'),
        'show_background' => $background,
        'show_title'      => $title,
        'show_breadcrumb' => $breadcrumb,
        'ptitle_align'    => $align,
        'container'       => validus_get_opts('content_width', 'container', 'on')
    ]);
    if($args['show'] === 'off' || is_404() || is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu')) return;
    get_template_part('template-parts/page-title', $args['layout'], $args);
}
/**
 * Get page title and description.
 *
 * @return array Contains 'title'
 */
function validus_get_page_titles(){
    $title = '';

    // Default titles
    if (!is_archive()) {
        // Posts page view
        if (is_home()) {
            // Only available if posts page is set.
            if (
                !is_front_page() &&
                ($page_for_posts = get_option('page_for_posts'))
            ) {
                $title = get_post_meta($page_for_posts, 'custom_title', true);
                if (empty($title)) {
                    $title = get_the_title($page_for_posts);
                }
            }
            if (is_front_page()) {
                $title = esc_html__('Blog', 'validus');
            }
        }
        // Single page view
        elseif (is_page()) {
            $title = get_post_meta(get_the_ID(), 'custom_title', true);
            if (!$title) {
                $title = get_the_title();
            }
        } elseif (is_404()) {
            $title = esc_html__('404', 'validus');
        } elseif (is_search()) {
            $title = esc_html__('Search results', 'validus');
        } elseif (class_exists('WooCommerce') && is_product()) {
            $title = esc_html__('Single Product', 'validus');
        } elseif (get_post_type() == 'project' && is_singular()) {
            $title = esc_html__('Single Project', 'validus');
        } else {
            $title = get_post_meta(get_the_ID(), 'custom_title', true);
            if (!$title) {
                $title = get_the_title();
            }
        }
    } elseif (is_author()) {
        $title = esc_html__('Author:', 'validus') . ' ' . get_the_author();
    }
    // Author
    else {
        $title = get_the_archive_title();
        if (class_exists('WooCommerce') && is_shop()) {
            $title = esc_html__('Our Shop', 'validus');
        }
    }

    return [
        'title' => $title,
    ];
}
/**
 * Prints HTML for breadcrumbs.
 */
function validus_breadcrumb(){
    if (!class_exists('CMS_Breadcrumb')) {
        return;
    }

    $breadcrumb = new CMS_Breadcrumb();
    $entries = $breadcrumb->get_entries();

    if (empty($entries)) {
        return;
    }

    ob_start();

    foreach ($entries as $k => $entry) {
        $entry = wp_parse_args($entry, array(
            'label' => '',
            'url' => ''
        ));

        if (empty($entry['label'])) {
            continue;
        }

        echo '<li>';

        if (!empty($entry['url'])) {
            printf(
                '<a class="breadcrumb-entry" href="%1$s">%2$s</a>',
                esc_url($entry['url']),
                esc_attr($entry['label'])
            );
        } else {
            printf('<span class="breadcrumb-entry" >%s</span>', esc_html($entry['label']));
        }

        echo '</li>';

        if ($k < (count($entries) - 1)) {
            echo '<li class="separator"></li>';
        }
    }

    $output = ob_get_clean();

    if ($output) {
        $align = validus_get_opts('ptitle_align', 'start', 'custom_ptitle');

        if (validus_get_page_opt('custom_ptitle') == 'on') {
            $theme_opt = validus_get_opt('pagetitle', '-1');
            $pagetitle = validus_get_page_opt('pagetitle',$theme_opt);
    
            if ($pagetitle == '-1') {
                //just use these ways to get theme options, not get page options
                //$align = validus_get_opts('ptitle_align');
                //$align = validus_get_page_opts('ptitle_align');
                $align = validus_get_opt('ptitle_align');
            }
        }
        printf('<ul class="cms-breadcrumb d-flex justify-content-'.$align.'">%s</ul>', wp_kses_post($output));
    }
}
/**
 * Main Content 
 * 
 * **/
if(!function_exists('validus_main_content_classes')){
    function validus_main_content_classes($args = []){
        $args = wp_parse_args($args, [
            'class' => '',
            'sidebar' => ''
        ]);

        $condition = validus_get_opt('sidebar_on','off') === 'on' && !is_404() && !in_array(get_post_type(), ['cms-footer','cms-header-top','cms-service','cms-industry','cms-case','cms-porfolio','portfolio']);
        
        $condition = false;

        $widgets = wp_get_sidebars_widgets();

        if (validus_get_opt('sidebar_on','off') === 'on') {
            if (!is_404()) {
                if (!in_array(get_post_type(), ['cms-footer','cms-header-top','cms-service','cms-industry','cms-case','cms-porfolio','portfolio','page'])) {
                    if (is_active_sidebar('sidebar-post') && isset($widgets['sidebar-post']) && $widgets['sidebar-post']) {
                        $condition = true;
                    } else {
                        if (is_shop() && class_exists('WooCommerce') && isset($widgets['sidebar-product']) && $widgets['sidebar-product']) {
                            $condition = true;
                        } else {
                            $condition = false;
                        }
                    }
                } else {
                    if (is_active_sidebar('sidebar-post') && isset($widgets['sidebar-post']) && $widgets['sidebar-post'] && is_search()) {
                        $condition = true;
                    }
                }
            }
        }
        
        $classes = [
            'cms-main',
            validus_is_built_with_elementor() ? '' : validus_get_opts('content_width', 'container', 'on'),
            validus_is_built_with_elementor() ? 'is-elementor' : '',
            is_search() ? validus_get_opts('content_width', 'container', 'on') : '',
            $condition ? 'cms-main-sidebar d-flex' : 'no-sidebar',
            $args['class']
        ];

        echo implode(' ', array_filter($classes));
    }
}

function validus_content_has_sidebar_open($sidebar=''){
    if(!is_active_sidebar($sidebar) || validus_get_opt('sidebar_on', 'off') !== 'on') return;
    ?>
    <div class="cms-main-content">
    <?php
}
function validus_content_has_sidebar_close($sidebar=''){
    if(!is_active_sidebar($sidebar) || validus_get_opt('sidebar_on', 'off') !== 'on') return;
    ?>
    </div>
    <?php
}
/**
 * Footer layout
 **/
function validus_footer(){
    if(is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu')) return;
    $footer_layout = validus_get_opts('footer_layout', '1', 'footer_custom');

    switch ($footer_layout){
        case 'none':
            break;
        case '1':
            validus_footer_copyright();
            break;
        default : 
            validus_footer_elementor_builder();
            break;
    }
}
/*
 * Footer css class
*/
if(!function_exists('validus_footer_css_class')){
    function validus_footer_css_class($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $footer_layout = validus_get_opts( 'footer_layout', '1', 'footer_custom' );
        $footer_fixed = validus_get_opts('footer_fixed', '-1', 'footer_custom');
        $css_classes = [
            'cms-footer',
            'relative'
        ];
        if(!in_array($footer_layout, ['-1', '0', '1', 'none'])) {
            $css_classes[] = 'cms-footer-elementor';
        } else {
            $css_classes[] = validus_get_opts('content_width', 'container', 'on');
        }

        if($footer_fixed == 'on') $css_classes[] = 'cms-footer-fixed';
        echo implode(' ', array_filter($css_classes));
    }
}
if(!function_exists('validus_default_copyright_text')){
    function validus_default_copyright_text($text = '', $args = []){
        $args = wp_parse_args($args, [
            'link_color'       => '',
            'link_hover_color' => ''
        ]);
        if(!empty($text)){
            $default_copyright_text = $text;
        } else {
            $default_copyright_text = sprintf( esc_html__('&copy;%s %s, All Rights Reserved. With Love by %s ','validus'), date('Y') , get_bloginfo('name'), '<a href="'.esc_url('https://farost.net/').'" target="_blank" rel="nofollow" class="'.$args['link_color'].' '.$args['link_hover_color'].'">'.esc_html__('farost.net','validus').'</a>');
        }
        return $default_copyright_text;
    }
}
if(!function_exists('validus_footer_copyright')){
    function validus_footer_copyright($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $classes = ['cms-copyright-text cms-footer-copyright', $args['class']];

        if(is_404()) $classes[] = 'text-center';
    ?>
    <div class="<?php echo implode(' ', array_filter($classes));?>">
        <?php echo validus_default_copyright_text(); ?>
    </div>
    <?php
    }
}
/**
* Footer elementor builder
*
*/
if(!function_exists('validus_footer_elementor_builder')){
    function validus_footer_elementor_builder(){
        if(!class_exists('Elementor\Plugin') || !class_exists('Elementor_Theme_Core')) return;
        $footer_layout = validus_get_opts('footer_layout', '1', 'footer_custom');
        if(in_array($footer_layout, ['-1', '0', '1', 'none'])) return;
        $cms_post = get_post($footer_layout);
        if (!is_wp_error($cms_post) && $cms_post->ID == $footer_layout){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $footer_layout );
            if(!empty($content)){
                if (function_exists('etc_print_html')) {
                    etc_print_html($content);
                } else {
                    echo esc_html('You have to install the Element Theme Core plugin first!');
                }
            } else {
            ?>
            <div class="<?php echo wp_kses_post(validus_get_opts('content_width', 'container', 'on'));  ?> cms-copyright-text cms-footer-copyright">
                <?php echo wp_kses_post($cms_post->post_content); ?>
            </div>
            <?php 
            }
        }
    }
}

/**
 * Post Title
 * 
 * */
if(!function_exists('validus_entry_title')){
    function validus_entry_title(){
    ?>
        <h2 class="cms-title">
            <a href="<?php echo esc_url( get_permalink() ); ?>">
                <?php if ( is_sticky() ) { ?>
                    <i class="cmsi-thumbtack"></i>
                <?php } ?>
                <?php the_title(); ?>
            </a>
        </h2>
    <?php
    }
}
if(!function_exists('validus_entry_single_title')){
    function validus_entry_single_title(){
    ?>
        <h2 class="cms-title">
            <?php if ( is_sticky() ) { ?>
                <i class="cmsi-thumbtack"></i>
            <?php } ?>
            <?php the_title(); ?>
        </h2>
    <?php
    }
}
if(!function_exists('validus_entry_thumbnail')){
    function validus_entry_thumbnail($size = 'large', $type = ''){
        if ( !has_post_thumbnail() ) {
            return;
        }
    ?>
        <div class="cms-featured width-100">
            <?php ///if ($archive_date_on) : ?>
                <div class="date">
                    <h2 class="day"><?php echo get_the_date('d'); ?></h2>
                    <div class="month-year"><?php echo get_the_date('M Y'); ?></div>
                </div>
            <?php //endif; ?>
            <?php
            switch($type) {
                case 'etc':
                    $img = etc_get_image_by_size(array(
                        'attach_id' => get_post_thumbnail_id(get_the_ID()),
                        'thumb_size' => $size,
                        'class' => '',
                    ));
                    if(isset($img['thumbnail'])) {
                        echo wp_kses_post($img['thumbnail']);
                    }
                    break;
                case 'elementor':
                    if ( class_exists('\Elementor\Plugin') ) {
                        $settings['image']['id'] = get_post_thumbnail_id(get_the_ID());
        
                        $array = ['medium','large','full'];

                        if (!in_array($size,$array)) {
                            $array = explode('x', $size);
                            if (is_array($array) && !empty($array)) {
                                $width = $array[0];
                                $height = $array[1];
                            } else {
                                $width = get_option( $size.'_size_w' );
                                $height = get_option( $size.'_size_h' );
                            }
                        } else {
                            $width = get_option( $size.'_size_w' );
                            $height = get_option( $size.'_size_h' );
                        }

                        $settings['image_custom_dimension'] = ['width' => $width, 'height' => $height];
                        echo Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'image', 'image' );
                        //Elementor\Group_Control_Image_Size::print_attachment_image_html( $settings, 'thumbnail' );
                    }
                    break;
                default:
                    the_post_thumbnail($size);
                    break;
            }
            $id = get_post_thumbnail_id(get_the_ID());
            if (isset($id)) {
                $_size_h = get_option( $size.'_size_h' );
    
                $image = wp_get_attachment_image_src($id, $size);
    
                if ($image[2] < $_size_h) {
                    $height = $_size_h;
                } else {
                    $height = $image[2];
                }
                
                $array = explode('x',$size);
                if(is_array($array) && isset($array[1])) {
                    $height = $array[1];
                }
            } else {
                $height = '562';
            }
            ?>
            <style type="text/css">
            :root {
                --max-height: <?php echo esc_html($height.'px');?>;
            }
            </style>
        </div>
    <?php
    }
}

/**
 * Post Thumbnail
 * 
 * */
if(!function_exists('validus_entry_thumbnail')){
    function validus_entry_thumbnail(){
        if ( !has_post_thumbnail() ) return;
    ?>
            <div class="cms-featured">
                <?php //if ($archive_date_on) : ?>
                    <div class="date">
                        <div class="day"><?php echo get_the_date('d'); ?></div>
                        <div class="month-year"><?php echo get_the_date('M Y'); ?></div>
                    </div>
                <?php //endif; ?>
                <?php the_post_thumbnail(); ?>
            </div>
    <?php
    }
}


/**
 * Get excerpt
 * The excerpt with custom length.
 * @return string      
 */
function validus_get_the_excerpt($length = 55, $post = null){
    $post = get_post($post);

    if (empty($post) || 0 >= $length) {
        return '';
    }

    if (post_password_required($post)) {
        return esc_html__('Post password required.', 'validus');
    }

    $content = apply_filters(
        'the_content',
        strip_shortcodes($post->post_content)
    );
    $content = str_replace(']]>', ']]&gt;', $content);

    $excerpt_more = apply_filters('validus_excerpt_more', '&hellip;');
    $excerpt = wp_trim_words($content, $length, $excerpt_more);

    return $excerpt;
}
/**
* Print post excerpt based on length.
*
* @param integer $length
*/
if (!function_exists('validus_entry_excerpt')) :
    function validus_entry_excerpt($length = 55)
    {
        echo "<div class='cms-text text-line-4'>";
        $cms_the_excerpt = get_the_excerpt();
        if (!empty($cms_the_excerpt)) {
            echo esc_html($cms_the_excerpt);
        } else {
            echo wp_kses_post(validus_get_the_excerpt($length));
        }
        echo "</div>";
    }
endif;
/**
 * Post Page Link
 * */
function validus_entry_link_pages(){
    wp_link_pages(array(
        'before'      => '<div class="cms-page-links d-flex gap" style="--gap:20px;">',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
    ));
}
/**
 * Post Readmore
 * */
if(!function_exists('validus_entry_readmore')){
    function validus_entry_readmore(){
    ?>
        <div class="cms-readmore">
            <a href="<?php echo esc_url( get_permalink() ); ?>">
                <span class="the-link-readmore"><?php echo esc_html__( 'Read More', 'validus' ); ?></span>
                <span class="the-btn-readmore cmsi-chevron-right d-flex align-items-center justify-content-center text-11 text-secondary radius-100 cms-transition"></span>
            </a>
        </div>
    <?php
    }
}
/**
 * Prints post meta on archive
 */
if (!function_exists('validus_archive_meta')) :
    function validus_archive_meta()
    {
        $archive_author_on     = validus_get_opt('archive_author_on', true);
        $archive_categories_on = validus_get_opt('archive_categories_on', true);
        $archive_date_on       = validus_get_opt('archive_date_on', true);
        $archive_comments_on   = validus_get_opt('archive_comments_on', false);

        $post_type = get_post_type() != 'post' ? (get_post_type().'-') : '';

        $category = $post_type.'category';

        $terms = get_the_terms( get_the_ID(), $category );
        
        if ($archive_author_on || $archive_comments_on || $archive_categories_on || $archive_date_on) : ?>
            <ul class="cms-post-meta cms-archive-meta d-flex gap" style="--gap:10px;">
                <?php if(is_array($terms)) { ?>
                    <?php if ($archive_categories_on) : ?>
                        <li class="category empty-none"><?php the_terms(get_the_ID(), $category, '', ', '); ?></li>
                    <?php endif; ?>
                <?php } else { ?>
                    <li class="category empty-none"><?php echo esc_html__('Uncategorized', 'validus'); ?></li>
                <?php } ?>
                <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>

                <?php if ($archive_author_on) : ?>
                    <li class="author empty-none">
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>

                <?php if ($archive_comments_on) : ?>
                    <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                    <li class="comment empty-none"><a href="<?php the_permalink(); ?>"><?php echo comments_number(esc_html__('No Comments', 'validus'), 'Comment: <span class="comments-number">'.esc_html__('1', 'validus').'</span>', 'Comment: <span class="comments-number">'.esc_html__('%', 'validus').'</span>'); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;
/**
 * Prints post meta on single
 */
if (!function_exists('validus_post_meta')) :
    function validus_post_meta()
    {
        $post_author_on     = validus_get_opt('post_author_on', true);
        $post_categories_on = validus_get_opt('post_categories_on', true);
        $post_date_on       = validus_get_opt('post_date_on', true);
        $post_comments_on   = validus_get_opt('post_comments_on', false);
        $categories = get_the_category();
        if ($post_author_on || $post_comments_on || $post_categories_on || $post_date_on) : ?>
            <ul class="cms-post-meta d-flex gap" style="--gap:10px;">
                <?php if ($post_categories_on && count(get_categories()) && !empty($categories)) : ?>
                    <li class="category empty-none">
                        <?php the_terms(get_the_ID(), 'category', '', ', '); ?>
                        <?php the_terms(get_the_ID(), 'project-category', '', ', '); ?></li>
                        <?php the_terms(get_the_ID(), 'industry-category', '', ', '); ?></li>
                    <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                <?php endif; ?>
                <?php if ($post_author_on) : ?>
                    <li class="author empty-none">
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($post_comments_on) : ?>
                    <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                    <li class="comment empty-none"><a href="<?php the_permalink(); ?>"><?php echo comments_number(esc_html__('No Comments', 'validus'), 'Comment: <span class="comments-number">'.esc_html__('1', 'validus').'</span>', 'Comment: <span class="comments-number">'.esc_html__('%', 'validus').'</span>'); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;

/**
 * Prints tag list
 */
if (!function_exists('validus_entry_tagged_in')){
    function validus_entry_tagged_in() {
        $tags_list = get_the_tag_list('', ' ');
        if (!$tags_list) return;
    ?>
        <div class="cms-post-tags">
            <span class="title"><?php echo esc_html__('Post Tags:', 'validus');?></span>
            <div class="tags-list">
                <?php printf('%2$s', '', $tags_list); ?>
            </div>
        </div>
    <?php 
    }
}

if (!function_exists('validus_entry_tags')){
    function validus_entry_tags() {
        global $post;
        $tags_list = wp_get_post_tags($post->ID,['orderby' => 'id', 'asc']);
        if (!$tags_list) return;

        $html = '';

        foreach ( $tags_list as $tag ) {
            $class = 'radius-2';

            $tag_link = get_tag_link( $tag->term_id );
            $html .= "<a href='{$tag_link}' title='{$tag->name} Tag' class='{$class}'>{$tag->name}</a>";
        }
    ?>
        <div class="cms-post-tags d-flex flex-direction-column gap-12">
            <span class="title"><?php echo esc_html__('Post Tags:', 'validus');?></span>
            <div class="tags-list d-flex gap-10">
                <?php printf('%2$s', '', $html); ?>
            </div>
        </div>
    <?php 
    }
}

/**
 * List socials share for post.
 */
function validus_socials_share_default() { 
    $img_url = get_the_post_thumbnail_url();
    ?>
    <div class="cms-social-share d-flex flex-direction-column gap-18">
        <span class="title"><?php echo esc_html__('Share:', 'validus'); ?></span>
        <div class="icon">
            <a title="<?php echo esc_attr__('Facebook', 'validus'); ?>" target="_blank"
            href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>">
                <i class="cmsi-facebook-circle-alt radius-30"></i>
            </a>
            <a title="<?php echo esc_attr__('Twitter', 'validus'); ?>" target="_blank"
            href="https://twitter.com/intent/tweet?url=<?php the_permalink(); ?>&text=<?php the_title(); ?>"><i
                        class="cmsi-twitter-circle radius-30"></i></a>
            <a title="<?php echo esc_attr__('LinkedIn', 'validus'); ?>" target="_blank"
            href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>&title=<?php the_title(); ?>"><i
                        class="cmsi-linkedin-circle radius-30"></i></a>
        </div>
    </div>
    <?php
}

/**
 * Custom Comment List
 */
function validus_comment_list($comment, $args, $depth){
    if ('div' === $args['style']) {
        $tag = 'div';
        $add_below = 'comment';
    } else {
        $tag = 'li';
        $add_below = 'div-comment';
    } ?>
    <<?php echo '' .
     $tag; ?> <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?> id="comment-<?php comment_ID(); ?>">
        <?php if ('div' != $args['style']): ?>
            <div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
            <?php endif; ?>
            <div class="comment-inner">
                <?php if ($args['avatar_size'] != 0) {
        echo get_avatar($comment, 90);
    } ?>
                <div class="comment-content">
                    <div class="comment-title">
                        <span class="comment-author"><?php printf('%s', get_comment_author_link()); ?></span>
                        <span class="comment-date">
                            <?php echo get_comment_date() . ' - ' . get_comment_time(); ?>
                        </span>
                    </div>
                    <div class="comment-text"><span class="corner"></span><?php comment_text(); ?></div>
                    <div class="comment-reply">
                        <?php comment_reply_link(
          array_merge($args, [
              'reply_text' => __('<i class="cmsi-arrow-right"></i> Reply', 'validus'),
              'add_below' => $add_below,
              'depth' => $depth,
              'max_depth' => $args['max_depth'],
          ])
      ); ?>
                    </div>
                </div>
            </div>
            <?php if ('div' != $args['style']): ?>
            </div>
    <?php endif;
}

/**
 * Related Post
 */
function validus_related_post(){
    $post_related_on = validus_get_opt('post_related_on', false);

    if ($post_related_on) {
        global $post;
        $current_id = $post->ID;
        $posttags = get_the_category($post->ID);
        if (empty($posttags)) {
            return;
        }

        $tags = array();

        foreach ($posttags as $tag) {

            $tags[] = $tag->term_id;
        }
        $post_number = '6';
        $query_similar = new WP_Query(array(
            'posts_per_page' => $post_number,
            'post_type' => 'post',
            'post_status' => 'publish',
            'category__in' => $tags
        ));
        if (count($query_similar->posts) > 1) {
            wp_enqueue_script('owl-carousel');
            wp_enqueue_script('validus-carousel');
            ?>
            <div class="cms-related-post">
                <h4 class="widget-title"><?php echo esc_html__('Related Posts', 'validus'); ?></h4>
                <div class="cms-related-post-inner owl-carousel" data-item-xs="1" data-item-sm="2" data-item-md="3"
                     data-item-lg="3" data-item-xl="3" data-item-xxl="3" data-margin="30" data-loop="false"
                     data-autoplay="false" data-autoplaytimeout="5000" data-smartspeed="250" data-center="false"
                     data-arrows="false" data-bullets="false" data-stagepadding="0" data-stagepaddingsm="0"
                     data-rtl="false">
                    <?php foreach ($query_similar->posts as $post):
                        $thumbnail_url = '';
                        if (has_post_thumbnail(get_the_ID()) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)) :
                            $thumbnail_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'validus-blog-small', false);
                        endif;
                        if ($post->ID !== $current_id) : ?>
                            <div class="grid-item">
                                <div class="grid-item-inner">
                                    <?php if (has_post_thumbnail()) { ?>
                                        <div class="item-featured">
                                            <a href="<?php the_permalink(); ?>"><img
                                                        src="<?php echo esc_url($thumbnail_url[0]); ?>"/></a>
                                        </div>
                                    <?php } ?>
                                    <h3 class="item-title">
                                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                    </h3>
                                </div>
                            </div>
                        <?php endif;
                    endforeach; ?>
                </div>
            </div>
        <?php }
    }

    wp_reset_postdata();
}

/* Author Social */
function validus_get_user_social(){
    $user_facebook = get_user_meta(get_the_author_meta('ID'), 'user_facebook', true);
    $user_twitter = get_user_meta(get_the_author_meta('ID'), 'user_twitter', true);
    $user_linkedin = get_user_meta(get_the_author_meta('ID'), 'user_linkedin', true);
    $user_skype = get_user_meta(get_the_author_meta('ID'), 'user_skype', true);
    $user_youtube = get_user_meta(get_the_author_meta('ID'), 'user_youtube', true);
    $user_vimeo = get_user_meta(get_the_author_meta('ID'), 'user_vimeo', true);
    $user_tumblr = get_user_meta(get_the_author_meta('ID'), 'user_tumblr', true);
    $user_rss = get_user_meta(get_the_author_meta('ID'), 'user_rss', true);
    $user_pinterest = get_user_meta(get_the_author_meta('ID'), 'user_pinterest', true);
    $user_instagram = get_user_meta(get_the_author_meta('ID'), 'user_instagram', true);
    $user_yelp = get_user_meta(get_the_author_meta('ID'), 'user_yelp', true);

    ?>
    <ul class="user-social unstyled d-flex gap" style="--gap:10px;--gap-mobile:10px;">
        <?php if (!empty($user_facebook)) { ?>
            <li><a href="<?php echo esc_url($user_facebook); ?>"><i class="cmsi-facebook-circle-alt radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_twitter)) { ?>
            <li><a href="<?php echo esc_url($user_twitter); ?>"><i class="cmsi-twitter-circle radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_linkedin)) { ?>
            <li><a href="<?php echo esc_url($user_linkedin); ?>"><i class="cmsi-linkedin-circle radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_rss)) { ?>
            <li><a href="<?php echo esc_url($user_rss); ?>"><i class="cmsi-rss radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_instagram)) { ?>
            <li><a href="<?php echo esc_url($user_instagram); ?>"><i class="cmsi-instagram radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_skype)) { ?>
            <li><a href="<?php echo esc_url($user_skype); ?>"><i class="cmsi-skype radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_pinterest)) { ?>
            <li><a href="<?php echo esc_url($user_pinterest); ?>"><i class="cmsi-pinterest radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_vimeo)) { ?>
            <li><a href="<?php echo esc_url($user_vimeo); ?>"><i class="cmsi-vimeo-v radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_youtube)) { ?>
            <li><a href="<?php echo esc_url($user_youtube); ?>"><i class="cmsi-youtube radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_yelp)) { ?>
            <li><a href="<?php echo esc_url($user_yelp); ?>"><i class="cmsi-yelp radius-30"></i></a></li>
        <?php } ?>
        <?php if (!empty($user_tumblr)) { ?>
            <li><a href="<?php echo esc_url($user_tumblr); ?>"><i class="cmsi-tumblr radius-30"></i></a></li>
        <?php } ?>

    </ul> <?php
}
/**
 * Prints posts pagination based on query
 *
 * @param WP_Query $query Custom query, if left blank, this will use global query ( current query )
 *
 * @return void
 */
if(!function_exists('validus_posts_pagination')){
    function validus_posts_pagination($query = null, $ajax = false){
        if ($ajax) {
            add_filter('paginate_links', 'validus_ajax_paginate_links');
        }

        $classes = array();

        if (empty($query)) {
            $query = $GLOBALS['wp_query'];
        }

        if (empty($query->max_num_pages) || !is_numeric($query->max_num_pages) || $query->max_num_pages < 2) {
            return;
        }

        $paged = $query->get('paged', '');

        if (!$paged && is_front_page() && !is_home()) {
            $paged = $query->get('page', '');
        }

        $paged = $paged ? intval($paged) : 1;

        $pagenum_link = html_entity_decode(get_pagenum_link());
        $query_args = array();
        $url_parts = explode('?', $pagenum_link);

        if (isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $html_prev = '<i class="cmsi-arrow-left text-10"></i>';
        $html_next = '<i class="cmsi-arrow-right text-10"></i>';
        $paginate_links_args = array(
            'base' => $pagenum_link,
            'total' => $query->max_num_pages,
            'current' => $paged,
            'mid_size' => 1,
            'add_args' => array_map('urlencode', $query_args),
            'prev_text' => $html_prev,
            'next_text' => $html_next,
        );
        if ($ajax) {
            $paginate_links_args['format'] = '?page=%#%';
        }
        $links = paginate_links($paginate_links_args);
        if ($links):
            ?>
            <nav class="navigation posts-pagination <?php echo esc_attr($ajax ? 'ajax' : ''); ?>">
                <div class="posts-page-links d-flex gap-10">
                    <?php
                        printf($links);
                    ?>
                </div>
            </nav>
        <?php
        endif;
    }
}

if(!function_exists('validus_posts_pagination_woocommerce')){
    function validus_posts_pagination_woocommerce($query = null, $ajax = false){
        if ($ajax) {
            add_filter('paginate_links', 'validus_ajax_paginate_links');
        }

        $classes = array();

        if (empty($query)) {
            $query = $GLOBALS['wp_query'];
        }

        if (empty($query->max_num_pages) || !is_numeric($query->max_num_pages) || $query->max_num_pages < 2) {
            return;
        }

        $paged = $query->get('page', '');

        if (!$paged && is_front_page() && !is_home()) {
            $paged = $query->get('page', '');
        }

        $paged = $paged ? intval($paged) : 1;

        $pagenum_link = html_entity_decode(get_pagenum_link());
        $query_args = array();
        $url_parts = explode('?', $pagenum_link);

        if (isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $html_prev = '<i class="cmsi-arrow-left text-10"></i>';
        $html_next = '<i class="cmsi-arrow-right text-10"></i>';
        $paginate_links_args = array(
            'base' => $pagenum_link,
            'total' => $query->max_num_pages,
            'current' => $paged,
            'mid_size' => 1,
            'add_args' => array_map('urlencode', $query_args),
            'prev_text' => $html_prev,
            'next_text' => $html_next,
        );
        if ($ajax) {
            $paginate_links_args['format'] = '?page=%#%';
        }
        $links = paginate_links($paginate_links_args);
        if ($links):
            ?>
            <nav class="navigation posts-pagination <?php echo esc_attr($ajax ? 'ajax' : ''); ?>">
                <div class="posts-page-links d-flex gap-10">
                    <?php
                        printf($links);
                    ?>
                </div>
            </nav>
        <?php
        endif;
    }
}

/**
 * Single Post
 * 
 * Display navigation to next/previous post when applicable.
 */
function validus_post_nav_default(){
    global $post;
    $previous = (is_attachment()) ? get_post($post->post_parent) : get_adjacent_post(false, '', true);
    $next = get_adjacent_post(false, '', false);

    if (!$next && !$previous) {
        return;
    }
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();
    if (!empty($next_post) || !empty($previous_post)) {
        ?>
        <div class="nav-links d-flex gap justify-content-between width-100" style="--gap:40px;">
            <?php if (is_a($previous_post, 'WP_Post') && get_the_title($previous_post->ID) != '') {
                $prev_img_id = get_post_thumbnail_id($previous_post->ID);
                $prev_img_url = wp_get_attachment_image_src($prev_img_id, 'validus-mini');
                ?>
                <div class="nav-item nav-post-prev">
                    <div class="nav-post-meta d-flex align-items-center gap-18 text-white">
                        <a href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>">
                            <span class="cmsi-arrow-left d-flex align-items-center justify-content-center text-white bg-secondary radius-3 cms-transition"></span>
                        </a>
                        <a class="nav-text" href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>">
                            <?php echo esc_html__('Prev Post', 'validus'); ?>
                        </a>
                    </div>
                </div>
            <?php } ?>
            <?php if (is_a($next_post, 'WP_Post') && get_the_title($next_post->ID) != '') {
                $next_img_id = get_post_thumbnail_id($next_post->ID);
                $next_img_url = wp_get_attachment_image_src($next_img_id, 'validus-mini');
                ?>
                <div class="nav-item nav-post-next">
                    <div class="nav-post-meta d-flex align-items-center gap-18 text-white">
                        <a class="nav-text" href="<?php echo esc_url(get_permalink($next_post->ID)); ?>">
                            <?php echo esc_html__('Next Post', 'validus'); ?>
                        </a>
                        <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>">
                            <span class="cmsi-arrow-right d-flex align-items-center justify-content-center text-white bg-secondary radius-3 cms-transition"></span>
                        </a>
                    </div>
                </div>
            <?php } ?>
        </div>
    <?php }
}

// function for inline style
// make some configs
if (!function_exists('validus_configs')) {
    function validus_configs($value)
    {
        $body_font    = apply_filters('validus_body_font','Roboto, sans-serif');
        $heading_font = apply_filters('validus_heading_font', '\'Changa\', sans-serif');

        $_heading_font = validus_get_page_opt( 'font_family', '\'Changa\', sans-serif' );
        $_head_font = validus_get_opts('heading_font_typo', ['font_family' => $heading_font], 'on')['font_family'];

        $btn_font     = apply_filters('validus_btn_font', '\'Roboto\', sans-serif');

        $logo_w       = '110';
        $logo_h       = '29';
        $logo_w_sm    = '55';
        $logo_h_sm    = '29';

        $primary_color   = apply_filters('primary_color', '#ff5e14');
        $secondary_color = apply_filters('secondary_color', '#161616');
        $heading_color   = apply_filters('heading_color', '#222');
        $content_color   = apply_filters('content_color', '#f3f3f3');
        $content_text_color   = apply_filters('content_color', '#9b9b9b');
        $tertiary_color   = apply_filters('tertiary_color', '#f6f6f6');//eaeaea
        $quaternary_color   = apply_filters('quaternary_color', '#030303');//db001b
        $red_color   = apply_filters('red_color', '#ff0000');
        $blue_color   = apply_filters('blue_color', '#0849ad');
        $green_color   = apply_filters('green_color', '#84a120');
        $yellow_color   = apply_filters('yellow_color', '#fdb900');
        $white_color   = apply_filters('white_color', '#fff');
        $bullet_color   = apply_filters('bullet_color', '#eaeaea');
        if (validus_get_opts('body_font') == 'default') {
            $body_font_family = $body_font;
        } else {
            $body_font_family = validus_get_opts('body_font_typo', ['font_family' => $body_font])['font_family'];
        }

        //$link_color = ['regular' => $secondary_color, 'hover' => $primary_color, 'active' => $primary_color];

        $link_color = [
            'regular' => validus_get_opts('secondary_color', $secondary_color, 'color_custom'),//$secondary_color
            'hover' => validus_get_opts('primary_color', $primary_color, 'color_custom'),//$primary_color
            'active' => validus_get_opts('primary_color', $primary_color, 'color_custom')//$primary_color
        ];

        $menu_color = [
            'regular' => validus_get_opts('secondary_color', $secondary_color, 'color_custom'),//'regular' => '#1e4773'
            'hover' => validus_get_opts('primary_color', $primary_color, 'color_custom'),//$primary_color
            'active' => validus_get_opts('primary_color', $primary_color, 'color_custom')//$primary_color
        ];

        $transparent_menu_color = [
            'regular' => '#fff',//#ffffff
            'hover' => validus_get_opts('primary_color', $primary_color, 'color_custom'),
            'active' => validus_get_opts('primary_color', $primary_color, 'color_custom')
        ];

        $ptitle_image = validus_get_opts('page_title_bg', ['background-color' => '#f9f9f9', 'background-image' => ''], 'custom_ptitle', false)['background-image'];
        $ptitle_color = validus_get_opts('page_title_bg', ['background-color' => '#f9f9f9', 'background-image' => ''], 'custom_ptitle', false)['background-color'];

        if (validus_get_page_opt('custom_ptitle') == 'on') {
            $theme_opt = validus_get_opt('pagetitle', '-1');
            $pagetitle = validus_get_page_opt('pagetitle',$theme_opt);
    
            if ($pagetitle == '-1') {
                $ptitle_image = validus_get_opt('page_title_bg', ['background-color' => '#f9f9f9', 'background-image' => ''])['background-image'];
                $ptitle_color = validus_get_opt('page_title_bg', ['background-color' => '#f9f9f9', 'background-image' => ''])['background-color'];
            }
        }

        $line_height = '110';
        $header_height = '110';
        $header_width = '320';

        $h_btn_radius = validus_get_opts('h_btn_radius', '2', 'on');
        $h_btn2_radius = validus_get_opts('h_btn2_radius', '2', 'on');

        $padding_bottom = validus_get_opts( 'padding_bottom', '90', 'on' ) . 'px';

        $configs = [
            // color
            'theme_colors' => [
                'primary' => [
                    'title' => esc_html__('Primary', 'validus'),
                    'value' => validus_get_opts('primary_color', $primary_color, 'color_custom')
                ],
                'secondary' => [
                    'title' => esc_html__('Secondary', 'validus'),
                    'value' => validus_get_opts('secondary_color', $secondary_color, 'color_custom')
                ],
                'tertiary' => [
                    'title' => esc_html__('Tertiary', 'validus'),
                    'value' => validus_get_opts('tertiary_color', $tertiary_color, 'color_custom')
                ],
                'quaternary' => [
                    'title' => esc_html__('Quaternary', 'validus'),
                    'value' => validus_get_opts('quaternary_color', $quaternary_color, 'color_custom')
                ],
                'red' => [
                    'title' => esc_html__('Red', 'validus'),
                    'value' => validus_get_opts('blue_color', $red_color, 'color_custom')
                ],
                'blue' => [
                    'title' => esc_html__('Blue', 'validus'),
                    'value' => validus_get_opts('blue_color', $blue_color, 'color_custom')
                ],
                'green' => [
                    'title' => esc_html__('Green', 'validus'),
                    'value' => validus_get_opts('green_color', $green_color, 'color_custom')
                ],
                'yellow' => [
                    'title' => esc_html__('Yellow', 'validus'),
                    'value' => validus_get_opts('yellow_color', $yellow_color, 'color_custom')
                ],
                'white' => [
                    'title' => esc_html__('White', 'validus'),
                    'value' => validus_get_opts('white_color', $white_color, 'color_custom')
                ],
                'bullet' => [
                    'title' => esc_html__('Bullet', 'validus'),
                    'value' => validus_get_opts('bullet_color', $bullet_color, 'color_custom')
                ],
            ],
            // link color
            'link_color' => [
                'regular' => validus_get_opts('link_color', $link_color, 'color_custom')['regular'],
                'hover'   => validus_get_opts('link_color', $link_color, 'color_custom')['hover'],
                'active'  => validus_get_opts('link_color', $link_color, 'color_custom')['active'],
            ],
            // body typo
            'body' => [
                'bg'          => '#fff',
                'font-family' => $body_font_family,
                'font-size'   => '15px',
                'font-weight' => substr(validus_get_opts('body_font_typo', ['font_style' => '400normal'])['font_style'], 0, 3),
                'font-style'  => substr(validus_get_opts('body_font_typo', ['font_style' => '400normal'])['font_style'], 3),
                'font-color'  => $content_text_color,
                'line-height' => 1.66667
            ],
            // Heading type
            'heading' => [
                'font-family' => validus_get_opts('heading_font_typo', ['font_family' => $heading_font], 'on')['font_family'],
                'font-weight' => substr(validus_get_opts('heading_font_typo', ['font_style' => '500medium'], 'on')['font_style'], 0, 3),
                'font-style'  => substr(validus_get_opts('heading_font_typo', ['font_style' => '500medium'], 'on')['font_style'], 3),
                'font-color'  => $secondary_color,
                'line-height' => 1.2,
            ],
            // Heading type
            'content' => [
                'font-color'     => $content_color,
                'text-color'     => $content_text_color,
                'padding-bottom' => $padding_bottom
            ],
            // Header 
            'header'    => [
                'height' => validus_get_opts('header_height', ['height' => $header_height], 'header_custom')['height'].'px',
                'line-height' => validus_get_opts('line_height', ['height' => $line_height], 'header_custom')['height'].'px',
                'btn-radius' => $h_btn_radius.'px',
                'btn2-radius' => $h_btn2_radius.'px'
            ],
            // logo
            'logo'  => [
                'width'     => validus_get_opt('logo_maxh',['width' => $logo_w, 'height' => $logo_h])['width'],
                'height'    => validus_get_opt('logo_maxh',['width' => $logo_w, 'height' => $logo_h])['height'],
                'width-mobile'  => validus_get_opt('logo_maxh_sm',['width' => $logo_w_sm, 'height' => $logo_h_sm])['width'],
                'height-mobile' => validus_get_opt('logo_maxh_sm',['width' => $logo_w_sm, 'height' => $logo_h_sm])['height']
            ],
            // menu color
            'menu_color' => [
                'regular' => validus_get_page_opts('main_menu_color', $menu_color, 'color_custom')['regular'],
                'hover'   => validus_get_page_opts('main_menu_color', $menu_color, 'color_custom')['hover'],
                'active'  => validus_get_page_opts('main_menu_color', $menu_color, 'color_custom')['active'],
            ],
            // transparent menu color
            'transparent_menu_color' => [
                'regular' => validus_get_opts('transparent_menu_color', $transparent_menu_color)['regular'],
                'hover'   => validus_get_opts('transparent_menu_color', $transparent_menu_color)['hover'],
                'active'  => validus_get_opts('transparent_menu_color', $transparent_menu_color)['active'],
            ],
            // Page title
            'ptitle'  => [
                'image'   => 'url('.$ptitle_image.')',
                'color'   => $ptitle_color,
                //'overlay' => validus_get_opts('page_title_overlay', 'linear-gradient(190deg, #434040 20%, #dcdcdc 50%)', 'custom_ptitle')
            ]
        ];
        return $configs[$value];
    }
}
if (!function_exists('validus_hex_to_rgb')) {
    function validus_hex_to_rgb($color)
    {

        $default = '0,0,0';

        //Return default if no color provided
        if (empty($color))
            return $default;

        //Sanitize $color if "#" is provided 
        if ($color[0] == '#') {
            $color = substr($color, 1);
        }

        //Check if color has 6 or 3 characters and get values
        if (strlen($color) == 6) {
            $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
        } elseif (strlen($color) == 3) {
            $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
        } else {
            return $default;
        }

        //Convert hexadec to rgb
        $rgb = array_map('hexdec', $hex);

        $output = implode(",", $rgb);

        //Return rgb(a) color string
        return $output;
    }
}

if (!function_exists('validus_inline_styles')) {
    function validus_inline_styles()
    {
        ob_start();
        // CSS Variable
        $theme_colors           = array_merge(validus_configs('theme_colors'), validus_custom_colors());
        $body                   = validus_configs('body');
        $heading                = validus_configs('heading');
        $content                = validus_configs('content');
        $link_color             = validus_configs('link_color');
        $header                 = validus_configs('header');
        $logo                   = validus_configs('logo');
        $menu_color             = validus_configs('menu_color');
        $transparent_menu_color = validus_configs('transparent_menu_color');
        $ptitle                 = validus_configs('ptitle');

        // var_dump($theme_colors); exit;
        echo ':root{';
        // color rgb
        foreach ($theme_colors as $color => $value) {
            printf('--color-%1$s-rgb: %2$s;', str_replace('#', '', $color), validus_hex_to_rgb($value['value']));
        }
        // color hex
        foreach ($theme_colors as $color => $value) {
            printf('--color-%1$s: %2$s;', str_replace('#', '', $color), $value['value']);
        }
        // Body
        foreach ($body as $key => $value) {
            printf('--body-%1$s: %2$s;', $key, $value);
        }
        // Heading
        foreach ($heading as $key => $value) {
            printf('--heading-%1$s: %2$s;', $key, $value);
        }
        // Content
        foreach ($content as $key => $value) {
            printf('--content-%1$s: %2$s;', $key, $value);
        }
        // link color
        foreach ($link_color as $color => $value) {
            printf('--link-%1$s-color: %2$s;', $color, $value);
        }
        // Header
        foreach ($header as $key => $value) {
            printf('--header-%1$s: %2$s;', $key, $value);
        }
        // Logo
        foreach ($logo as $key => $value) {
            printf('--logo-%1$s: %2$s;', $key, $value.'px');
        }
        // Menu color
        foreach ($menu_color as $color => $value) {
            printf('--menu-%1$s: %2$s;', $color, $value);
        }
        // Transparent Menu color
        foreach ($transparent_menu_color as $color => $value) {
            printf('--menu-transparent-%1$s: %2$s;', $color, $value);
        }
        // Page title
        foreach ($ptitle as $key => $value) {
            printf('--ptitle-bg-%1$s: %2$s;', $key, $value);
        }
        echo '}';
        return ob_get_clean();
    }
}
// end function for inline style

/**
 *
 * Get Theme Color
 *
 * @return array
 */
function validus_theme_colors(){
    $_theme_color = validus_configs('theme_colors');
    $theme_color = [];
    foreach ($_theme_color as $key => $color) {
        $key = str_replace('#', '', $key);
        if(is_array($color['value'])){
            foreach ($color['value'] as $color_key => $color_value) {
                $theme_color[$color_key] = $color_value;
            }
        } else {
            $theme_color[$key] = $color['value'];
        }
    }
    return $theme_color;
}

/**
 *
 * Theme Custom Color
 *
 * @return array
 */
function validus_custom_colors(){
    $custom_color = validus_get_opts('custom_color', []);
    $validus_custom_colors = [];
    foreach ($custom_color as $color) {
        $_custom_color = explode('|', $color);
        $validus_custom_colors[$_custom_color[1]] = [
            'title' => $_custom_color[0]. ' ('.$_custom_color[1].')',
            'value' => $_custom_color[1]
        ];
    }
    return $validus_custom_colors;
}

/**
 * Theme Options
 * 
 * **/
/**
 * Get Page List
 * @return array
 */
if (!function_exists('validus_list_page')) {
    function validus_list_page($default = [])
    {
        $page_list = array();
        if (!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_pages(array('hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach ($pages as $page) {
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}

/**
 * Get Post List
 * @return array
 */
if (!function_exists('validus_list_post')) {
    function validus_list_post($post_type = 'post', $default = false)
    {
        $post_list = array();
        if ($default) {
            $post_list['none'] = esc_html__('None', 'validus');
            $post_list['-1'] = esc_html__('Default', 'validus');
        }
        $posts = get_posts(array('post_type' => $post_type, 'posts_per_page' => '-1'));
        foreach ($posts as $post) {
            $post_list[$post->ID] = $post->post_title;
        }
        return $post_list;
    }
}

/**
 * Get theme option based on its id.
 *
 * @param string $opt_id Required. the option id.
 * @param mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function validus_get_opt($opt_id, $default = false){
    $opt_name = validus_get_opt_name();
    if (empty($opt_name)) {
        return $default;
    }

    global ${$opt_name};
    if (!isset(${$opt_name}) || !isset(${$opt_name}[$opt_id])) {
        $options = get_option($opt_name);
    } else {
        $options = ${$opt_name};
    }
    if (
        !isset($options) ||
        !isset($options[$opt_id]) ||
        $options[$opt_id] === ''
    ) {
        return $default;
    }

    if (is_array($options[$opt_id]) && is_array($default)) {
        foreach ($options[$opt_id] as $key => $value) {
            if (isset($default[$key]) && $value === '') {
                $options[$opt_id][$key] = $default[$key];
            }
        }
    }

    return $options[$opt_id];
}

/**
 * Get theme option based on its id.
 *
 * @param string $opt_id Required. the option id.
 * @param mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function validus_get_page_opt($opt_id, $default = false){
    $page_opt_name = validus_get_page_opt_name();
    if (empty($page_opt_name)) {
        return $default;
    }
    $id = get_the_ID();
    if (!is_archive() && is_home()) {
        if (!is_front_page()) {
            $page_for_posts = get_option('page_for_posts');
            $id = $page_for_posts;
        }
    }

    // Get page option for Shop Page
    if (class_exists('WooCommerce') && is_shop()) {
        $id = get_option('woocommerce_shop_page_id');
    }

    // validus custom
    if (is_search() || is_tax() || (in_array(get_post_type(),['service','industry','case-study','project','product']) && !is_singular() && !is_search() && !is_tax() && !is_shop())) {
        $id = null;
    }

    if (!empty($id)) {
        $options = get_post_meta(intval($id), $opt_id, true);

        if (is_array($options) && !array_filter($options)) {
            $options = $default;
        }
    } else {
        $options = $default;
    }

    return $options;

    /* return $options = !empty($id)
        ? get_post_meta(intval($id), $opt_id, true)
        : $default; */
}

/**
 *
 * Get post format values.
 *
 * @param $post_format_key
 * @param bool $default
 *
 * @return bool|mixed
 */
function validus_get_post_format_value($post_format_key, $default = false){
    global $post;

    return $value = !empty($post->ID)
        ? get_post_meta($post->ID, $post_format_key, true)
        : $default;
}

/**
 * Get option based on its id.
 * get option of theme and page
 *
 * @param  string $opt_id Required. the option id.
 * @param  mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 * @return mixed
 */
function validus_get_opts($opt_id, $default = false, $dependency = '', $overrite = true){
    $theme_opt = validus_get_opt($opt_id, $default);
    $_dependency = validus_get_page_opt($dependency);
    if($dependency === 'on' || $_dependency === 'on'){
        $page_opt = validus_get_page_opt($opt_id, $theme_opt);
        if ($page_opt !== null && $page_opt !== '' && $page_opt !== '-1') {//-1
            if (is_array($page_opt) && is_array($theme_opt)) {
                foreach ($page_opt as $key => $value) {
                    foreach ($theme_opt as $key => $value) {
                        if ((empty($page_opt[$key]) || $page_opt[$key] === 'px') && $overrite) {
                            $page_opt[$key] = $theme_opt[$key];
                        }
                    }
                }
            }
            $theme_opt = $page_opt;
        }
    }
    return $theme_opt;
}
//Use in case we have the option in theme options, but don't have it in page options and want to override again
function validus_get_page_opts($opt_id, $default = false, $dependency = '', $overrite = true){
    $theme_opt = validus_get_opt($opt_id, $default);
    $_dependency = validus_get_page_opt($dependency);
    if($dependency === 'on' || $_dependency === 'on'){
        $page_opt = validus_get_page_opt($opt_id, $default);
        if ($page_opt !== null && $page_opt !== '' && $page_opt !== '-1') {
            if (is_array($page_opt) && is_array($theme_opt)) {
                foreach ($page_opt as $key => $value) {
                    foreach ($theme_opt as $key => $value) {
                        if ((empty($page_opt[$key]) || $page_opt[$key] === 'px') && $overrite) {
                            $page_opt[$key] = $theme_opt[$key];
                        }
                    }
                }
            }
            $theme_opt = $page_opt;
        }
    }
    return $theme_opt;
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function validus_get_opt_name_default(){
    return apply_filters('validus_opt_name', 'cms_theme_options');
}
function validus_get_opt_name(){
    if (isset($_POST['opt_name']) && !empty($_POST['opt_name'])) {
        return $_POST['opt_name'];
    }
    $opt_name = validus_get_opt_name_default();
    if (defined('ICL_LANGUAGE_CODE')) {
        if (ICL_LANGUAGE_CODE != 'all' && !empty(ICL_LANGUAGE_CODE)) {
            $opt_name = $opt_name . '_' . ICL_LANGUAGE_CODE;
        }
    }

    return $opt_name;
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function validus_get_page_opt_name(){
    return apply_filters('validus_page_opt_name', 'cms_page_options');
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function validus_get_post_opt_name(){
    return apply_filters('validus_post_opt_name', 'validus_post_options');
}
/*====== End Theme Option ==========*/
/**
 * Elementor
 * All function for Elementor
 * 
 * **/
/**
 * Theme Color for Elementor
 * */
if(!function_exists('validus_elementor_theme_color_opts')){
    function validus_elementor_theme_color_opts($args = []){
        $args = wp_parse_args($args, [
            'custom' => true
        ]);
        $theme_colors = wp_parse_args(validus_custom_colors(), validus_configs('theme_colors'));
        $option = ['' => esc_html('Default', 'validus')];
        foreach ($theme_colors as $key => $color) {
            $key = str_replace('#', '', $key);
            if(is_array($color['value'])){
                foreach ($color['value'] as $color_key => $color_value) {
                    $option[$color_key] = str_replace(['#', '-', '_'], ' ', $color_key).' ('.$color_value.')';
                }
            } else {
                $option[$key] = $color['title'];
            }
        }
        if($args['custom']) $option['custom'] = esc_html('Custom', 'validus');
        return $option;
    }
}
if (!function_exists('validus_elementor_theme_color_opts')) {
    function validus_elementor_theme_color_opts($args = [])
    {
        $args = wp_parse_args($args, [
            'custom' => true
        ]);
        $theme_colors = wp_parse_args(validus_custom_colors(), validus_configs('theme_colors'));
        $option = ['' => esc_html('Default', 'validus')];
        foreach ($theme_colors as $key => $color) {
            $key = str_replace('#', '', $key);
            $option[$key] = $color['title'];
        }
        if ($args['custom']) $option['custom'] = esc_html('Custom', 'validus');
        return $option;
    }
}
/**
 * Ajax Pagination
 * Use in Element Post Grid/Blog
 * 
 * */
if (!function_exists('validus_ajax_paginate_links')) {
    function validus_ajax_paginate_links($link)
    {
        $parts = parse_url($link);
        $query = [];
        if(isset($parts['query']) && !empty($parts['query'])){
            parse_str($parts['query'], $query);
        }
        
        if(isset($query['page']) && !empty($query['page'])){
            return '#' . $query['page'];
        }
        else{
            return '#1';
        }
    }
}

if ( ! function_exists( 'validus_get_portfolio_layout1' ) ) {
	function validus_get_portfolio_layout1( $settings = [], $posts = []  ) {
		extract( $settings );
		if ( $thumbnail_size != 'custom' ) {
			$img_size = $thumbnail_size;
		} elseif ( ! empty( $thumbnail_custom_dimension['width'] ) && ! empty( $thumbnail_custom_dimension['height'] ) ) {
			$img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
		} else {
			$img_size = '370x370';
		}
		if ( is_array( $posts ) ):
			foreach ( $posts as $post ):
				$img_id = get_post_thumbnail_id( $post->ID );
				$img = etc_get_image_by_size( array(
					'attach_id'  => $img_id,
					'thumb_size' => $img_size,
					'class'      => '',
				) );
				//$thumbnail = $img['thumbnail'];
                $thumbnail = '<img decoding="async" class="cms-transition" src="'.$img['p_img_large'][0].'" loading="lazy" />';
				$item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
				?>
                <div class="<?php echo esc_attr( $item_class ); ?>">
                    <div class="grid-item-inner <?php echo esc_attr( $cms_animate ); ?>">
						<?php if ( has_post_thumbnail( $post->ID ) && wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), false ) ):
							$thumbnail_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false );
							?>
                            <div class="item-featured">
								<?php echo wp_kses_post( $thumbnail ); ?>
                                <a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><i
                                            class="cms-icon-plus size-md-white"></i></a>
                            </div>
						<?php endif; ?>
                        <div class="item-body">
                            <h3 class="item-title"><a
                                        href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><?php echo esc_attr( get_the_title( $post->ID ) ); ?></a>
                            </h3>
                            <div class="item-category"><?php the_terms( $post->ID, 'portfolio-category', '', ', ' ); ?></div>
                        </div>
                    </div>
                </div>
			<?php
			endforeach;
		endif;
	}
}

if ( ! function_exists( 'validus_get_portfolio_layout2' ) ) {
	function validus_get_portfolio_layout2( $settings = [], $posts = [] ) {
		extract( $settings );
		if ( $thumbnail_size != 'custom' ) {
			$img_size = $thumbnail_size;
		} elseif ( ! empty( $thumbnail_custom_dimension['width'] ) && ! empty( $thumbnail_custom_dimension['height'] ) ) {
			$img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
		} else {
			$img_size = '600x600';
		}
		if ( is_array( $posts ) ):
			foreach ( $posts as $post ):
				$img_id = get_post_thumbnail_id( $post->ID );
				$img = etc_get_image_by_size( array(
					'attach_id'  => $img_id,
					'thumb_size' => $img_size,
					'class'      => '',
				) );
				//$thumbnail = $img['thumbnail'];
                $thumbnail = '<img decoding="async" class="cms-transition" src="'.$img['p_img_large'][0].'" loading="lazy" />';
				$item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
				if ( has_post_thumbnail( $post->ID ) && wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), false ) ): ?>
                    <div class="<?php echo esc_attr( $item_class ); ?>">
                        <div class="grid-item-inner <?php echo esc_attr( $cms_animate ); ?>">
                            <div class="item-featured">
								<?php echo wp_kses_post( $thumbnail ); ?>
                            </div>
                            <a class="item-link" href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><i
                                        class="cms-icon-plus size-md-white"></i></a>
                            <div class="item-meta">
                                <h3 class="item-title"><a
                                            href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><?php echo esc_attr( get_the_title( $post->ID ) ); ?></a>
                                </h3>
                                <div class="item-category"><?php the_terms( $post->ID, 'portfolio-category', '', ', ' ); ?></div>
                            </div>
                        </div>
                    </div>
				<?php endif; ?>
			<?php
			endforeach;
		endif;
	}
}

if ( ! function_exists( 'validus_get_portfolio_layout3' ) ) {
	function validus_get_portfolio_layout3( $settings = [], $posts = [] ) {
		extract( $settings );
		if ( $thumbnail_size != 'custom' ) {
			$img_size = $thumbnail_size;
		} elseif ( ! empty( $thumbnail_custom_dimension['width'] ) && ! empty( $thumbnail_custom_dimension['height'] ) ) {
			$img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
		} else {
			$img_size = '534x400';
		}
		if ( is_array( $posts ) ):
			if ( ! empty( $size_list ) ) {
				$sizes = explode( ',', $size_list );
				$i     = 0;
			}
			foreach ( $posts as $post ):
				if ( ! empty( $size_list ) ) {
					$img_size = end( $sizes );
					if ( ! empty( $sizes[ $i ] ) ) {
						$img_size = $sizes[ $i ];
					}
				}
				$img_id       = get_post_thumbnail_id( $post->ID );
				$img          = etc_get_image_by_size( array(
					'attach_id'  => $img_id,
					'thumb_size' => $img_size,
					'class'      => '',
				) );
				//$thumbnail    = $img['thumbnail'];
                $thumbnail = '<img decoding="async" class="cms-transition" src="'.$img['p_img_large'][0].'" loading="lazy" />';
				$item_class   = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
				if ( has_post_thumbnail( $post->ID ) && wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), false ) ): ?>
                    <div class="<?php echo esc_attr( $item_class ); ?>">
                        <div class="grid-item-inner <?php echo esc_attr( $cms_animate ); ?>">
                            <div class="item-featured">
								<?php echo wp_kses_post( $thumbnail ); ?>
                            </div>
                            <div class="item-meta">
                                <h3 class="item-title"><a
                                            href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><?php echo esc_attr( get_the_title( $post->ID ) ); ?></a>
                                </h3>
                                <div class="item-category"><?php the_terms( $post->ID, 'portfolio-category', '', ', ' ); ?></div>
                            </div>
                        </div>
                    </div>
				<?php endif; ?>
				<?php
				if ( ! empty( $size_list ) ) {
					$i ++;
				} endforeach;
		endif;
	}
}

if(!function_exists('validus_get_blog_grid_layout1')) {
    function validus_get_blog_grid_layout1($settings,$posts,$posts_data,$args) {
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
            
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $img_size = $width.'x'.$height;

                        $settings['thumbnail_size'] = 'custom';
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $image = get_the_post_thumbnail_url($post->ID,'medium_large');
            if($image == '') {
                $image = Elementor\Utils::get_placeholder_image_src();
                if($image == '') {
                    $image = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner" style="background: #fff url('<?php echo esc_html($image);?>') no-repeat;background-size: cover;">
                    <?php switch ($settings['layout']) { 
                        default:
                        // post image
                        echo "<div class='cms-image'>";
                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id' => $post->ID,
                            'custom_size' => $params
                        ]);
                        echo "</div>";
                    ?>
                    <h3 class="date">
                        <div class="day"><?php echo get_the_date('d', $post->ID); ?></div>
                        <div class="month-year"><?php echo get_the_date('M Y', $post->ID); ?></div>
                    </h3>
                    <div class="cms--content cms-shadow-3">
                        <div class="cms-content"></div>
                        <div class="cms-content-body">
                            <h4 class="cms-heading"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a></h4>
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex align-items-center gap" style="--gap:10px;">
                                <?php if(is_array(get_the_terms( $post->ID, 'category' ))) { ?>
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <?php } else { ?>
                                    <li class="category empty-none"><?php echo esc_html__('Uncategorized', 'validus'); ?></li>
                                <?php } ?>
                                
                                <li class="separator"></li>

                                <li class="author empty-none">
                                    <a href="<?php echo get_author_posts_url( $post->post_author ); ?>"><?php the_author_meta( 'display_name', $post->post_author ); ?></a>
                                </li>
                            </ul>
                            <div class="cms-excerpt text-line-4"><?php
                                echo wp_kses_post($post->post_content);
                                // Read More
                            ?></div>
                            <div class="cms-readmore">
                                <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="d-flex align-items-center gap-9 text-15 font-bold">
                                    <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                    <span class="the-btn-readmore cmsi-chevron-right cms-transition d-flex align-items-center justify-content-center radius-100"></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_blog_grid_layout2')) {
    function validus_get_blog_grid_layout2($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class'   => 'bg-primary',
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
            
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;

                        $settings['thumbnail_size'] = 'custom';
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            //src
            $src = get_the_post_thumbnail_url($post->ID,'medium_large');
            if ($src == '') {
                $src = Elementor\Utils::get_placeholder_image_src();
                if ($src == '') {
                    $src = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }
            
            $class = 'cms-content-body '.(isset($args['position']) && $args['position'] == 'absolute'?'cms-shadow-3':'');
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner d-flex flex-direction-column">
                    <?php switch ($settings['layout']) { 
                        default:
                        // post image
                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id'     => $post->ID,
                            'prefix'      => 'cms-blog-grid',
                            'custom_size' => $params,
                        ]);
                    ?>
                    <div class="cms--content">
                        <div class="<?php echo esc_html($class); ?>">
                            <h4 class="cms-heading text-line-3"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a></h4>
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex gap" style="--gap:10px;">
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                                <li class="date empty-none">
                                    <span class="day"><?php echo get_the_date('M d', $post->ID).', '; ?></span>
                                    <span class="year"><?php echo get_the_date('Y', $post->ID); ?></span>
                                </li>
                            </ul>
                            <div class="cms-excerpt text-line-4"><?php
                                echo wp_kses_post($post->post_content);
                            ?></div>
                            <div class="cms-readmore">
                                <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="d-flex align-items-center gap-10 text-15 font-bold">
                                    <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                    <span class="the-btn-readmore cmsi-chevron-right cms-transition d-flex align-items-center justify-content-center radius-100"></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_blog_grid_layout3')) {
    function validus_get_blog_grid_layout3($settings = [], $posts = [], $posts_data = [], $args = []){
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
            
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;

                        $settings['thumbnail_size'] = 'custom';
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $image = get_the_post_thumbnail_url($post->ID,'medium_large');
            if($image == '') {
                $image = Elementor\Utils::get_placeholder_image_src();
                if($image == '') {
                    $image = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <?php switch ($settings['layout']) { 
                        default:
                        // post image
                        echo "<div class='cms-image'>";
                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id' => $post->ID,
                            'custom_size' => $params,
                            'img_size' => $params['width'].'x'.$params['height']
                        ]);
                        echo "</div>";
                    ?>
                    <div class="cms--content">
                        <div class="cms-content-body cms-shadow-3">
                            <h4 class="cms-heading text-line-3">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </h4>
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex align-items-center gap" style="--gap:10px;">
                                <?php if(is_array(get_the_terms( $post->ID, 'category' ))) { ?>
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <?php } else { ?>
                                    <li class="category empty-none"><?php echo esc_html__('Uncategorized', 'validus'); ?></li>
                                <?php } ?>
                                
                                <li class="separator"></li>

                                <li class="date empty-none">
                                    <span class="day"><?php echo get_the_date('M d', $post->ID).', '; ?></span>
                                    <span class="year"><?php echo get_the_date('Y', $post->ID); ?></span>
                                </li>
                            </ul>
                            <div class="cms-excerpt text-line-4"><?php
                                echo wp_kses_post($post->post_content);
                                // Read More
                            ?></div>
                            <div class="cms-readmore">
                                <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="d-flex align-items-center gap-9 text-15 font-bold">
                                    <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                    <span class="the-btn-readmore cmsi-chevron-right cms-transition d-flex align-items-center justify-content-center radius-100"></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_blog_grid_layout4')) {
    function validus_get_blog_grid_layout4($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary'
        ]);

        $class = 'grid-'.$settings['col'];
        $class .= 'grid-tablet-'.(isset($settings['col_tablet']) ? $settings['col_tablet'] : '');//2
        $class .= 'grid-mobile-'.(isset($settings['col_mobile']) ? $settings['col_mobile'] : '');//1
        $class .= 'd-grid gap mb-40';

        echo "<div class='cms-blog-grid-list $class'>";
        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <?php switch ($settings['layout']) { 
                        default:
                        // post image
                        $settings['thumbnail_size'] = 'custom';

                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id'     => $post->ID,
                            'custom_size' => ['width' => '180', 'height' => '120'],
                            'prefix'      => 'cms-blog-grid'
                        ]);
                    ?>
                    <div class="cms-content">
                        <?php 
                        // post category
                        //the_terms($post->ID, 'category', '<div class="cms-post-meta bg-primary">', ', ','</div>');
                        ?>
                        <div class="cms--content cms-shadow-3">
                            <h4 class="cms-heading">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php echo get_the_title($post->ID); ?>
                                </a>
                            </h4>
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex gap" style="--gap:10px;">
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                                <li class="date empty-none">
                                    <span class="day"><?php echo get_the_date('M d', $post->ID).', '; ?></span>
                                    <span class="year"><?php echo get_the_date('Y', $post->ID); ?></span>
                                </li>
                            </ul>
                        </div>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
        echo "</div>";
    }
}
if (!function_exists('validus_get_blog_grid_layout4_featured')) {
    function validus_get_blog_grid_layout4_featured($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }
        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => 'cms-blog-grid-featured',
            'bg_class' => 'bg-primary',
            'image_size' => ['width' => 620, 'height' => 560]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];

        // Start build post item 
        $count = 0;
        foreach ($posts as $key => $post):
            if ($key == 0) :

                $thumbnail_size = $settings['thumbnail_size'];
                $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];
                if ($thumbnail_size != 'custom') {
                    $img_size = $thumbnail_size;

                    $image = wp_get_attachment_image_src($post->ID,$thumbnail_size);
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $params = array(
                            'width' => $image[1],
                            'height' => $image[2]
                        );
                    } else {
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                    $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                    $params = array(
                        'width' => $thumbnail_custom_dimension['width'],
                        'height' => $thumbnail_custom_dimension['height']
                    );
                } else {
                    $img_size = $_w_default.'x'.$_h_default;

                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                }
                ?>
                <div class="<?php echo implode(' ', array_filter([$args['item_class'], 'item-'.$count])); ?>">
                    <div class="cms-grid-item-inner">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id'     => $post->ID,
                                'custom_size' => ['width' => $params['width'], 'height' => $params['height']],
                                'prefix'      => 'cms-blog-grid'
                            ]);
                        ?>
                        <div class="cms-content">
                            <?php 
                            // post category
                            //the_terms($post->ID, 'category', '<div class="cms-post-meta bg-primary">', ', ','</div>');
                            ?>
                            <div class="cms--content cms-shadow-3">
                                <h4 class="cms-heading"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a></h4>
                                <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex gap" style="--gap:10px;">
                                    <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                    <li class="space"><span><?php echo esc_html__('_', 'validus'); ?></span></li>
                                    <li class="date empty-none">
                                        <span class="day"><?php echo get_the_date('M d', $post->ID).', '; ?></span>
                                        <span class="year"><?php echo get_the_date('Y', $post->ID); ?></span>
                                    </li>
                                </ul>
                                <div class="cms-excerpt text-line-4"><?php
                                    //echo wp_trim_words($post->post_content, $settings['num_words'], '&hellip;');
                                    echo wp_kses_post($post->post_excerpt);
                                    // Read More
                                ?></div>
                                <div class="cms-readmore">
                                    <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>">
                                        <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                        <span class="the-btn-readmore cmsi-chevron-right"></span>
                                    </a>
                                </div>
                                <!-- <div class="cms-meta d-flex justify-content-between align-items-center">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore">
                                        <i class="cmsi-arrow-right rtl-flip"></i>
                                        <?php echo wp_kses_post($settings['readmore_text']); ?>
                                    </a>
                                </div> -->
                            </div>
                        </div>
                        <?php
                            break;
                        } ?>
                    </div>
                </div>
                <?php
            endif;
        $count++;
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout1')) {
    function validus_get_post_grid_layout1($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }
                    
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;

                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }

                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';

                        $img_size = $width.'x'.$height;
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>

                        <?php 
                        if (isset($settings['show_categories']) && $settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary cms-transition">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>

                    <?php if(isset($settings['show_title']) || isset($settings['show_excerpt'])) : ?>
                    <div class="item-body d-flex flex-direction-column">
                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    $title = esc_attr($title);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                        <div class="item-content text-line-4"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>

                <!--can move "item-readmore" into "cms-grid-item-inner", but the width of it have to equal itself, not equal 100% ("cms-grid=item-inner")-->
                <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                <div class="item-readmore">
                    <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="d-flex align-items-center flex-direction-column gap-10 text-15 font-bold">
                        <span class="the-link-readmore cms-transition cmsi-plus d-flex align-items-center justify-content-center text-center text-10 radius-100"></span>
                    </a>
                </div>
                <?php } ?>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout3')) {
    function validus_get_post_grid_layout3($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 485]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
    
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$image[2];

                        if ($image[2] <= $_h_default && $image[2] <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $image[2]
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }

                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    
                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;
    
                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $src = get_the_post_thumbnail_url($post->ID,'medium_large');
            if ($src == '') {
                $src = Elementor\Utils::get_placeholder_image_src();
                if ($src == '') {
                    $src = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }

            $style = '';
            if ($args['background']) {
                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $img_size
                            ]);
                        ?>
                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore d-flex align-items-center justify-content-center">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="d-inline-flex radius-200 cms-transition">
                                <span class="the-link-readmore cmsi-plus cms-transition d-inline-flex align-items-center justify-content-center text-align-center radius-200"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none absolute d-flex flex-direction-column gap-14 b-0 cms-transition">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                            
                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title text-white text-line-3">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4 text-white text-15 mb-7"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout4')) {
    function validus_get_post_grid_layout4($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
                
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }

                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;
    
                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }

                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $img_size
                            ]);
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body d-flex flex-direction-column gap-12 text-center">
                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                        <div class="item-content text-line-3"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="btn btn-xxm btn-secondary btn-hover-primary d-flex align-items-center gap-10 text-15 font-bold radius-4">
                                <span class="btn-icon cmsi-chevron-circle-right-01"></span>
                                <span class="btn-text"><?php echo esc_html__( 'Explore More', 'validus' ); ?></span>
                            </a>
                        </div>
                        <?php } ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout5')) {
    function validus_get_post_grid_layout5($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
                
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }

                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if ($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $params['width'].'x'.$params['height']
                            ]);
                        ?>
                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore d-flex align-items-center justify-content-center">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                <span class="the-link-readmore cmsi-plus cms-transition d-inline-flex align-items-center justify-content-center text-align-center"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none d-flex flex-direction-column align-items-center justify-content-center t-0 r-0 l-0 b-0 cms-transition">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';

                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title text-white">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4 text-white text-15 mb-7"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout6')) {
    function validus_get_post_grid_layout6($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'widget'     => null,
            'image_size' => ['width' => 320, 'height' => 428]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        $widget = $args['widget'];

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            // post image
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );

                $settings['thumbnail_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
            }

            $style = '';
            $mheight = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                $image = Elementor\Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id($post->ID), 'thumbnail', $settings );

                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    $image = get_template_directory_uri() . '/assets/images/elementor/jasper-garratt.jpg';
                    
                    if ($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }
            
                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
                //$mheight = 'style="min-height: 392px;"';
            }

            $widget->add_render_attribute( 'item-body', 'class', 'item-body d-flex flex-direction-column item-' . $settings['content_order'] );
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner d-flex cms-hover-icon-bounce">
                <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div <?php echo wp_kses_post( $widget->get_render_attribute_string( 'item-body' ) ); ?>>
                        <div class="item-icon">
                            <?php 
                            $icon = get_post_meta($post->ID, 'icon', true);
                            $array['value'] = $icon;
                            $array['library'] = 'cmsi-validus';
                            //$icon = str_replace('cmsi-','',$icon);
                            //$icon = str_replace('validus-icon-','',$icon);

                            if(!is_array($array) || !$array || $array['value'] == '') {
                                $array['value'] = 'validus-icon-gear';
                                $array['library'] = 'validusicon';
                            }
                            ?>
                            <?php \Elementor\Icons_Manager::render_icon( $array, [ 'aria-hidden' => 'true', 'class' => 'cms-icon' ] ); ?>
                        </div>

                        <?php 
                            // post category
                            //the_terms($post->ID, 'category', '<div class="cms-post-meta bg-primary">', ', ','</div>');
                        ?>
                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php 
                                    echo get_the_title($post->ID);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                        <div class="item-content text-line-4"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="btn-secondary btn-hover-primary d-flex align-items-center gap-10 text-15 font-bold">
                                <span class="btn-icon cms-transition cmsi-chevron-circle-right-01 d-flex align-items-center justify-content-center text-23 text-primary radius-100"></span>
                                <span class="btn-text"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                            </a>
                        </div>
                        <?php } ?>
                    </div>
                    <?php endif; ?>

                    <?php $class = ($settings['show_title'] == '' && $settings['show_excerpt'] == '') ? 'flex-100' : 'flex-50';?>

                    <div class="item-featured d-flex justify-content-center <?php echo wp_kses_post($class);?>">
                        <?php switch ($settings['layout']) { 
                            default:
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $params['width'].'x'.$params['height']
                            ]);
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout7')) {
    function validus_get_post_grid_layout7($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 320, 'height' => 428]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            // post image
            $thumbnail_size = $settings['thumbnail_size'];
            $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$image[2];
    
                        $params = array(
                            'width' => $image[1],
                            'height' => $image[2]
                        );
                    } else {
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;
    
                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );

                $settings['thumbnail_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
            }

            $style = '';
            $mheight = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                $image = Elementor\Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id($post->ID), 'thumbnail', $settings );

                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    $image = get_template_directory_uri() . '/assets/images/elementor/jasper-garratt.jpg';
                    
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner" <?php echo esc_html($mheight);?>>
                    <div class="item-featured">
                        <?php switch ($settings['layout']) { 
                            default:
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>

                    <div class="item-body cms-hover-icon-bounce" <?php echo wp_kses_post($style);?>>
                        <div class="item-icon">
                            <?php 
                            $icon = get_post_meta($post->ID, 'icon', true);
                            $array['value'] = $icon;
                            $array['library'] = 'cmsi-validus';

                            if(!is_array($array) || !$array || $array['value'] == '') {
                                $array['value'] = 'validus-icon-gear';
                                $array['library'] = 'validusicon';
                            }
                            ?>
                            <?php \Elementor\Icons_Manager::render_icon( $array, [ 'aria-hidden' => 'true', 'class' => 'cms-icon' ] ); ?>
                        </div>

                        <?php if($settings['show_title'] || $settings['show_excerpt']) : ?>
                            <?php if ($settings['show_title'] == 'yes') : ?>
                                <h4 class="item-title">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                        <?php 
                                        echo get_the_title($post->ID);
                                        ?>
                                    </a>
                                </h4>
                            <?php endif; ?>

                            <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                            <div class="item-content text-line-4"><?php
                                echo wp_kses_post($post->post_excerpt);
                            ?></div>
                            <?php endif; ?>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="btn-secondary btn-hover-primary">
                                <span class="btn-icon cmsi-chevron-circle-right-01 radius-100"></span>
                                <span class="btn-text"><?php echo esc_html__( 'Explore More', 'validus' ); ?></span>
                            </a>
                        </div>
                        <?php } ?>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout8')) {
    function validus_get_post_grid_layout8($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 1600, 'height' => 800]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }

                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$image[2];
    
                        if ($image[2] <= $_h_default && $image[2] <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $image[2]
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }

                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if ($args['background']) { 
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }
                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
                $bg = "background: #fff url($src) no-repeat;background-size: cover;";
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body">
                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category">
                            <span class="<?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary radius-2">
                                <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                            </span>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                        <div class="item-content text-line-4"><?php
                            echo wp_kses_post($post->post_excerpt);
                        ?></div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                <span class="the-link-readmore"><?php echo esc_html( $settings['readmore_text'] ); ?></span>
                                <span class="the-btn-readmore cmsi-chevron-right radius-100 d-flex align-items-center justify-content-center bg-primary text-white text-11 cms-transition"></span>
                            </a>
                        </div>
                        <?php } ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout9')) {
    function validus_get_post_grid_layout9($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            $style = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');
                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }
                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }

                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;
    
                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }

                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
                
                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body">
                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                        <div class="item-content text-line-4"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                <span class="btn-icon cmsi-chevron-right radius-100 d-flex align-items-center justify-content-center bg-primary text-white text-11"></span>
                                <span class="btn-text"><?php echo esc_html__( 'Explore More', 'validus' ); ?></span>
                            </a>
                        </div>
                        <?php } ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if (!function_exists('validus_get_post_grid_layout10')) {
    function validus_get_post_grid_layout10($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $settings['thumbnail_size'] = 'custom';//set size = custom
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if ($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $params['width'].'x'.$params['height']
                            ]);
                        ?>
                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore d-flex align-items-center justify-content-center">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="d-inline-flex radius-200 cms-transition">
                                <span class="the-link-readmore cmsi-plus cms-transition d-inline-flex align-items-center justify-content-center text-align-center radius-200"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none d-flex flex-direction-column justify-content-center align-items-center t-0 r-0 l-0 b-0 cms-transition">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';

                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title text-white">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4 text-white text-15 mb-7"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout11')) {
    function validus_get_post_grid_layout11($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 500]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            //need these to play on click
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            //
                        } else {
                            $_w_default = $_w_size;
                            $_h_default = $_h_size;
                        }
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured radius-8 d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                            
                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                <span class="btn-icon cmsi-chevron-right d-flex align-items-center justify-content-center text-11 radius-100 bg-white text-primary"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout12')) {
    function validus_get_post_grid_layout12($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 400]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
            
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;

                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center radius-12" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $img_size
                            ]);
                        ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none">
                        <div class="item-body-container d-flex flex-direction-column gap-10 radius-10 bg-white">
                            <?php 
                                $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';

                                // post category
                                $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                            ?>
                            <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                            <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                                <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                            </div>
                            <?php endif; ?>

                            <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                                <h4 class="item-title">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                        <?php 
                                        $title = get_the_title($post->ID);
                                        echo esc_html($title);
                                        ?>
                                    </a>
                                </h4>
                            <?php endif; ?>

                            <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                            <!-- <h3 class="item-content text-line-4"><?php
                                echo wp_kses_post($post->post_excerpt);
                                // Read More
                            ?></h3> -->
                            <?php endif; ?>

                            <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text']) && $settings['show_readmore'] == 'yes') { ?>
                            <div class="item-readmore">
                                <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                    <span class="btn-icon cmsi-chevron-right"></span>
                                </a>
                            </div>
                            <?php } ?>
                        </div>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout13')) {
    function validus_get_post_grid_layout13($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 415]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;

                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                if ($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if ($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-container cms-shadow-4">
                    <div class="item-featured" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>
                    </div>

                    <div class="cms-grid-item-inner cms-shadow-3">
                        <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                        <div class="item-body d-flex flex-direction-column gap-16">
                            <?php if ($settings['show_title'] == 'yes') : ?>
                                <h4 class="item-title text-line-2">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                        <?php 
                                        $title = get_the_title($post->ID);
                                        echo esc_html($title);
                                        ?>
                                    </a>
                                </h4>
                            <?php endif; ?>

                            <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                            <div class="item-content text-line-4 text-15 mb-7"><?php
                                echo wp_kses_post($post->post_excerpt);
                                // Read More
                            ?></div>
                            <?php endif; ?>
                        </div>
                        <?php endif; ?>

                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                            <div class="item-readmore cms-transition">
                                <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                                    <span class="btn-icon cmsi-chevron-right d-flex align-items-center justify-content-center text-11 text-white bg-primary cms-transition radius-100"></span>
                                    <span class="btn-text"><?php echo esc_html__( 'Explore More', 'validus' ); ?></span>
                                </a>
                            </div>
                            <?php } ?>
                        <?php
                            break;
                        } ?>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout14')) {
    function validus_get_post_grid_layout14($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 400]
        ]);
        
        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;
        
        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;

                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');
                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-container cms-shadow-3">
                    <?php
                    switch ($settings['layout']) { 
                        default:
                    ?>
                    <div class="item-featured" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                        <div class="item-body">
                            <?php if ($settings['show_title'] == 'yes') : ?>
                                <h4 class="item-title text-line-2">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                        <?php 
                                        $title = get_the_title($post->ID);
                                        echo esc_html($title);
                                        ?>
                                    </a>
                                </h4>
                            <?php endif; ?>

                            <?php if ($settings['show_excerpt'] == 'yes' && !empty($post->post_excerpt)) : ?>
                            <div class="item-content text-line-3"><?php
                                echo wp_kses_post($post->post_excerpt);
                                // Read More
                            ?></div>
                            <?php endif; ?>
                        </div>
                        <?php endif; ?>
                    </div>

                    <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                    <div class="item-readmore cms-transition">
                        <a href="<?php echo esc_url(get_permalink($post->ID));?>">
                            <span class="btn-text"><?php echo esc_html__( 'Explore More', 'validus' ); ?></span>
                            <span class="btn-icon cmsi-chevron-right d-flex align-items-center justify-content-center text-11 radius-100 cms-transition"></span>
                        </a>
                    </div>
                    <?php } ?>
                    
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout15')) {
    function validus_get_post_grid_layout15($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 320, 'height' => 428]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            // post image
            $thumbnail_size = $settings['thumbnail_size'];
            $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                if(isset($image) && is_array($image) && !empty($image)) {
                    $params = array(
                        'width' => $image[1],
                        'height' => $image[2]
                    );
                } else {
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );

                $settings['thumbnail_custom_dimension'] = ['width' => $_w_default, 'height' => $_h_default];
            }

            $style = '';
            $mheight = '';
            if($args['background']) {
                $image = get_the_post_thumbnail_url($post->ID,'medium_large');

                $image = Elementor\Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id($post->ID), 'thumbnail', $settings );

                if($image == '') {
                    $image = Elementor\Utils::get_placeholder_image_src();
                    $image = get_template_directory_uri() . '/assets/images/elementor/jasper-garratt.jpg';
                    
                    if($image == '') {
                        $image = get_template_directory_uri().'/assets/images/placeholder.png';
                    }

                    //crop image by $params['width'],$params['height']
                }
            
                $style = 'style="background: #fff url('.$image.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner" <?php echo wp_kses_post($style);?>>
                    <div class="item-image-overlay cms-transition">
                        <?php echo '<img decoding="async" src="'.$image.'" loading="lazy" />';?>
                    </div>
                    <div class="item-overlay cms-transition absolute d-flex align-items-center justify-content-center t-0 r-0 l-0 b-0 bg-primary"></div>

                    <div class="item-featured d-flex align-items-center justify-content-center text-center cms-transition">
                        <?php switch ($settings['layout']) { 
                            default:
                        ?>

                        <?php
                        if ($settings['show_categories'] == 'yes') :
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';
                        ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-13 text-white p-lr-15 bg-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <div class="item-image">
                            <a href="<?php echo esc_url(get_permalink($post->ID)); ?>">
                                <?php
                                validus_elementor_post_thumbnail_render($settings, [
                                    'post_id' => $post->ID,
                                    'custom_size' => $params
                                ]);
                            ?>
                            </a>
                        </div>

                        <div class="item-icon-top cms-transition absolute d-flex align-items-start t-0 r-0 l-0 b-0">
                            <?php 
                            $icon = get_post_meta($post->ID, 'icon', true);
                            $array['value'] = $icon;
                            $array['library'] = 'cmsi-validus';

                            if(!is_array($array) || !$array || $array['value'] == '') {
                                $array['value'] = 'validus-icon-gear';
                                $array['library'] = 'validusicon';
                            }
                            ?>
                            <?php \Elementor\Icons_Manager::render_icon( $array, [ 'aria-hidden' => 'true', 'class' => 'cms-transition d-flex align-items-center justify-content-center text-center text-white text-65' ] ); ?>
                        </div>

                        <div class="item-icon cms-transition absolute d-flex align-items-center justify-content-center text-center t-0 r-0 l-0 b-0">
                            <?php 
                            $icon = get_post_meta($post->ID, 'icon', true);
                            $array['value'] = $icon;
                            $array['library'] = 'cmsi-validus';

                            if(!is_array($array) || !$array || $array['value'] == '') {
                                $array['value'] = 'validus-icon-gear';
                                $array['library'] = 'validusicon';
                            }
                            ?>
                            <?php \Elementor\Icons_Manager::render_icon( $array, [ 'aria-hidden' => 'true', 'class' => 'cms-transition d-flex align-items-center justify-content-center text-center text-65 text-white bg-primary radius-100' ] ); ?>
                        </div>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body">
                        <?php if ($settings['show_title'] == 'yes') : ?>
                            <?php
                            $title = get_the_title($post->ID);
                            if (!empty($title)) {
                            ?>
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>">
                                    <?php echo esc_html($title);?>
                                </a>
                            </h4>
                            <?php } ?>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes') : ?>
                        <div class="item-content">
                            <?php
                            $excerpt = $post->post_excerpt;
                            if (!empty($excerpt)) {
                            ?>
                            <span class="item-text text-line-4">
                                <?php echo wp_kses_post($post->post_excerpt);?>
                            </span>
                            <?php } ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="btn-icon">
                                <i class="cmsi-chevron-right cms-transition d-inline-flex align-items-center justify-content-center text-center text-11 text-white bg-secondary radius-100"></i>
                            </a>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout16')) {
    function validus_get_post_grid_layout16($settings = [], $posts = [], $posts_data = [], $args = []) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 400]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;
            
            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);
                    
                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$image[2];

                        if ($image[2] <= $_h_default && $image[2] <= 300) {
                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $image[2]
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if ($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params
                            ]);
                        ?>
                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore d-flex align-items-center justify-content-center">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="d-inline-flex radius-200 cms-transition">
                                <span class="the-link-readmore cmsi-plus cms-transition d-inline-flex align-items-center justify-content-center text-align-center radius-200"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none d-flex flex-direction-column cms-transition">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';

                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title text-white text-line-3">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4 text-white text-15 mb-7" style="--body-font-size: 15px;"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}
if (!function_exists('validus_get_post_grid_layout17')) {
    function validus_get_post_grid_layout17($settings,$posts,$posts_data,$args) {
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }

        // extract($posts_data);
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'background' => false,
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;

                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );

                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }

                if (empty($height) || $height == '' || $height == 0) {
                    //need the 'custom' param, if the size = 80x80,
                    //the image will ugly bcos the thumbnail_size = thumbnail
                    if ($settings['thumbnail_size'] == 'thumbnail') {
                        $settings['thumbnail_size'] = 'custom';
                    }

                    $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

                    if(isset($image) && is_array($image) && !empty($image)) {
                        $img_size = $image[1].'x'.$_h_size;

                        if ($_h_size <= $_h_default && $_h_size <= 300) {
                            $img_size = $_w_default.'x'.$_h_default;

                            $params = array(
                                'width' => $_w_default,
                                'height' => $_h_default
                            );

                            $settings['thumbnail_size'] = 'custom';
                            $settings['thumbnail_custom_dimension'] = $params;
                        } else {
                            $params = array(
                                'width' => $image[1],
                                'height' => $_h_size
                            );
                        }
                    } else {
                        if ($_h_default <= $_h_size) {
                            $_h_default = $_h_size;
                        }
                        $params = array(
                            'width' => $_w_default,
                            'height' => $_h_default
                        );
                    }
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;

                        $img_size = $width.'x'.$height;

                        $settings['thumbnail_size'] = 'custom';
                    }

                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $style = '';
            if ($args['background']) {
                $src = get_the_post_thumbnail_url($post->ID,'medium_large');
                if ($src == '') {
                    $src = Elementor\Utils::get_placeholder_image_src();
                    if ($src == '') {
                        $src = get_template_directory_uri().'/assets/images/placeholder.png';
                    }
                }

                $style = 'style="background: #fff url('.$src.') no-repeat center;background-size: cover;"';
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner">
                    <div class="item-featured d-flex align-items-center justify-content-center" style="--min-height: <?php echo esc_html($params['height']);?>px;">
                        <?php switch ($settings['layout']) { 
                            default:
                            // post image
                            validus_elementor_post_thumbnail_render($settings, [
                                'post_id' => $post->ID,
                                'custom_size' => $params,
                                'img_size' => $img_size
                            ]);
                        ?>
                        <?php if(isset($settings['readmore_text']) && !empty($settings['readmore_text'])) { ?>
                        <div class="item-readmore d-flex align-items-center justify-content-center">
                            <?php if($settings['show_readmore'] == 'yes') { ?>
                            <a href="<?php echo esc_url(get_permalink($post->ID));?>" class="d-inline-flex radius-200 cms-transition">
                                <span class="the-link-readmore cmsi-plus cms-transition d-inline-flex align-items-center justify-content-center text-align-center radius-200"></span>
                            </a>
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if($settings['show_title'] || $settings['show_categories'] || $settings['show_excerpt']) : ?>
                    <div class="item-body empty-none d-flex flex-direction-column justify-content-center t-0 r-0 l-0 b-0 cms-transition">
                        <?php 
                            $post_type = $post->post_type != 'post' ? ($post->post_type.'-') : '';

                            // post category
                            $term_list = get_the_term_list( $post->ID, $post_type.'category' );
                        ?>
                        <?php if ($settings['show_title'] == 'yes' && get_the_title($post->ID) != '') : ?>
                            <h4 class="item-title text-white">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-transition">
                                    <?php 
                                    $title = get_the_title($post->ID);
                                    echo esc_html($title);
                                    ?>
                                </a>
                            </h4>
                        <?php endif; ?>

                        <?php if ($settings['show_categories'] == 'yes' && !empty($term_list)) : ?>
                        <div class="item-category <?php echo esc_html($args['bg_class']);?> text-14 text-primary">
                            <?php the_terms($post->ID, $post_type.'category', '', ', '); ?>
                        </div>
                        <?php endif; ?>

                        <?php if ($settings['show_excerpt'] == 'yes' && $post->post_excerpt !== '') : ?>
                        <div class="item-content text-line-4 text-white text-15 mb-7"><?php
                            echo wp_kses_post($post->post_excerpt);
                            // Read More
                        ?></div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('validus_get_post_grid_default')) {
    function validus_get_post_grid_default($settings, $posts) {
        $args = wp_parse_args($args, [
            'item_class' => '',
            'bg_class' => 'bg-primary',
            'image_size' => ['width' => 400, 'height' => 300]
        ]);

        $_w_default = $args['image_size']['width'];
        $_h_default = $args['image_size']['height'];
        $_w_size = 0;
        $_h_size = 0;

        $thumbnail_size = $settings['thumbnail_size'];
        $thumbnail_custom_dimension = $settings['thumbnail_custom_dimension'];

        foreach ($posts as $post):
            $image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),$thumbnail_size);

            if(isset($image) && is_array($image) && !empty($image)) {
                $_w_size = $image[1];
                $_h_size = $image[2];
            }
        endforeach;

        // Start build post item 
        $count = 0;
        foreach ($posts as $post):
            $count ++;

            if ($thumbnail_size != 'custom') {
                $img_size = $thumbnail_size;
            
                $width = get_option( $thumbnail_size.'_size_w' );
                $height = get_option( $thumbnail_size.'_size_h' );
    
                if ($thumbnail_size == '1536x1536' || $thumbnail_size == '2048x2048') {
                    $array = explode('x',$thumbnail_size);
                    $width = $array[0];
                    $height = $array[1];
                }
    
                if (empty($height) || $height == '' || $height == 0) {
                    if ($_w_size && $_h_size) {
                        $_w_default = $_w_size;
                        $_h_default = $_h_size;
                    }
                    $params = array(
                        'width' => $_w_default,
                        'height' => $_h_default
                    );
                } else {
                    if ($width <= get_option( 'thumbnail_size_w' )) {
                        $width = $_w_default;
                    }
                    if ($height <= get_option( 'thumbnail_size_h' )) {
                        $height = $_h_default;
    
                        $img_size = $width.'x'.$height;

                        $settings['thumbnail_size'] = 'custom';
                    }
    
                    $params = array(
                        'width' => $width,
                        'height' => $height
                    );
                }
            } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
                $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];

                $params = array(
                    'width' => $thumbnail_custom_dimension['width'],
                    'height' => $thumbnail_custom_dimension['height']
                );
            } else {
                $img_size = $_w_default.'x'.$_h_default;

                $params = array(
                    'width' => $_w_default,
                    'height' => $_h_default
                );
            }

            $image = get_the_post_thumbnail_url($post->ID,'medium_large');
            if($image == '') {
                $image = Elementor\Utils::get_placeholder_image_src();
                if($image == '') {
                    $image = get_template_directory_uri().'/assets/images/placeholder.png';
                }
            }
            ?>
            <div class="<?php echo implode(' ', array_filter(['cms-grid-item', $args['item_class'], 'item-'.$count])); ?>">
                <div class="cms-grid-item-inner" style="background: #fff url('<?php echo esc_html($image);?>') no-repeat;background-size: cover;">
                    <?php switch ($settings['layout']) { 
                        default:
                        // post image
                        echo "<div class='cms-image'>";
                        validus_elementor_post_thumbnail_render($settings, [
                            'post_id' => $post->ID,
                            'custom_size' => $params
                        ]);
                        echo "</div>";
                    ?>
                    <h3 class="date">
                        <div class="day"><?php echo get_the_date('d', $post->ID); ?></div>
                        <div class="month-year"><?php echo get_the_date('M Y', $post->ID); ?></div>
                    </h3>
                    <div class="cms--content cms-shadow-3">
                        <div class="cms-content"></div>
                        <div class="cms-content-body">
                            <h4 class="cms-heading"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a></h4>
                            <ul class="cms-post-meta <?php echo esc_html($args['bg_class']);?> d-flex align-items-center gap" style="--gap:10px;">
                                <?php if(is_array(get_the_terms( $post->ID, 'category' ))) { ?>
                                <li class="category empty-none"><?php the_terms($post->ID, 'category', '', ', '); ?></li>
                                <?php } else { ?>
                                    <li class="category empty-none"><?php echo esc_html__('Uncategorized', 'validus'); ?></li>
                                <?php } ?>
                                
                                <li class="separator"></li>

                                <li class="author empty-none">
                                    <a href="<?php echo get_author_posts_url( $post->post_author ); ?>"><?php the_author_meta( 'display_name', $post->post_author ); ?></a>
                                </li>
                            </ul>
                            <div class="cms-excerpt text-line-4"><?php
                                echo wp_kses_post($post->post_content);
                                // Read More
                            ?></div>
                            <div class="cms-readmore">
                                <a href="<?php echo esc_url( get_permalink($post->ID) ); ?>" class="d-flex align-items-center gap-9 text-15 font-bold">
                                    <span class="the-link-readmore"><?php echo esc_html__( $settings['readmore_text'], 'validus' ); ?></span>
                                    <span class="the-btn-readmore cmsi-chevron-right cms-transition d-flex align-items-center justify-content-center radius-100"></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php
                        break;
                    } ?>
                </div>
            </div>
        <?php
        endforeach;
    }
}

// Elementor Build Post Layout 
if(!function_exists('validus_get_post_grid')){
    function validus_get_post_grid($settings = [], $posts = [], $posts_data = [], $args = []){
        if(empty($settings) || !is_array($settings) || empty($posts) || !is_array($posts)){
            return false;
        }
        switch ($settings['template_type']) {
            case 'blog_grid_layout1':
                validus_get_blog_grid_layout1($settings,$posts,$posts_data,$args);
                break;
            case 'blog_grid_layout2':
                validus_get_blog_grid_layout2($settings,$posts,$posts_data,$args);
                break;
            case 'blog_grid_layout3':
                validus_get_blog_grid_layout3($settings,$posts,$posts_data,$args);
                break;
            case 'blog_grid_layout4':
                validus_get_blog_grid_layout4($settings,$posts,$posts_data,$args);
                break;
            case 'blog_grid_layout4_featured':
                validus_get_blog_grid_layout4_featured($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout1':
                $args = [
                    'item_class' => 'd-flex justify-content-center cms-shadow-3',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout1($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout3':
                $args = [
                    'item_class' => '',
                    'bg_class' => '',
                    'custom_size' => ['width' => 400, 'height' => 485]
                ];
                validus_get_post_grid_layout3($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout4':
                $args = [
                    'item_class' => 'cms-shadow-3',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout4($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout5':
                $args = [
                    'item_class' => '',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout5($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout6':
                $args = [
                    'item_class' => 'cms-shadow-3',
                    'bg_class' => '',
                    'background' => true,
                    'widget'     => $settings['widget']
                ];
                validus_get_post_grid_layout6($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout7':
                $args = [
                    'item_class' => '',
                    'bg_class' => '',
                    'background' => true
                ];
                validus_get_post_grid_layout7($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout8':
                $args = [
                    'item_class' => '',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout8($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout9':
                $args = [
                    'item_class' => 'cms-shadow-7',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout9($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout10':
                $args = [
                    'item_class' => '',
                    'bg_class' => '',
                    'custom_size' => ['width' => 400, 'height' => 400]
                ];
                validus_get_post_grid_layout10($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout11':
                $args = [
                    'item_class' => '',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout11($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout12':
                $args = [
                    'item_class' => '',
                    'bg_class' => '',
                ];
                validus_get_post_grid_layout12($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout13':
                $cls_bottom = ($settings['total'] > 3) ? 'mb-72' : '';
                $args = [
                    'item_class' => $cls_bottom,
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout13($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout14':
                $args = [
                    'item_class' => '',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout14($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout15':
                $args = [
                    'item_class' => 'cms-shadow-3',
                    'bg_class' => '',
                    'background' => true
                ];
                validus_get_post_grid_layout15($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout16':
                $args = [
                    'item_class' => '',
                    'bg_class' => '',
                    'custom_size' => ['width' => 400, 'height' => 485]
                ];
                validus_get_post_grid_layout16($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout2':
                $args = [
                    'item_class' => 'cms-shadow-3',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout17($settings,$posts,$posts_data,$args);
                break;
            case 'post_grid_layout17':
                $args = [
                    'item_class' => '',
                    'bg_class' => ''
                ];
                validus_get_post_grid_layout17($settings,$posts,$posts_data,$args);
                break;
			case 'portfolio_layout1':
				validus_get_portfolio_layout1( $settings, $posts );
				break;
			case 'portfolio_layout2':
				validus_get_portfolio_layout2( $settings, $posts );
				break;
			case 'portfolio_layout3':
				validus_get_portfolio_layout3( $settings, $posts );
				break;
            default:
                //return false;
                validus_get_post_grid_default( $settings, $posts );
                break;
        }
    }
}


/************************************** WOOCOMMERCE **************************************/
/**
 * Get Categories
 * @return array
 */
if (!function_exists('validus_list_categories')) {
    function validus_list_categories($default = false)
    {
        $list = array();
        $list['-1'] = esc_html__('All Categories', 'validus');
        $terms = get_terms(
            'product_cat',
            array(
                //'fields'       => 'ids',
                'hierarchical' => true,
                'hide_empty'   => false,
            )
        );
        
        if (!empty($terms)) {
            foreach ($terms as $term) {
                if (isset($term->term_id))
                $list[$term->term_id] = $term->name;
            }
        }
        return $list;
    }
}